(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    489395,      10378]*)
(*NotebookOutlinePosition[    490068,      10401]*)
(*  CellTagsIndexPosition[    490024,      10397]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
BCC Alloys in the Bragg-Williams Approximation\
\>", "Title"],

Cell["The Model", "Subtitle"],

Cell[CellGroupData[{

Cell["Samuel M. Allen\tApril 19, 2006", "Subsection"],

Cell[BoxData[{
    \(Clear["\<Global`*\>"]\), "\[IndentingNewLine]", 
    \(<< Graphics`Legend`\)}], "Input"],

Cell["Define values for Agogadro and Boltzmann constants", "Text"],

Cell[BoxData[{
    \(\(N0 = 6.02214\[Times]10\^23;\)\), "\[IndentingNewLine]", 
    \(\(kB = 1.3806503\[Times]10\^\(-23\);\)\)}], "Input"],

Cell[TextData[StyleBox["Bragg-Williams model for b.c.c. alloys with \
first-neighbor pairwise interactions. ", "Subsection"]], "Subsubtitle"],

Cell[TextData[StyleBox["Order parameters are the atom fraction of B, XB, and \
the long-range order parameter, \[Eta] (see KoM Fig. 17.4 and Eqs. \
17.7\[Dash]8 for definitions).", "Subsection",
  FontSize->16,
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text"],

Cell["\<\
Enter expressions for internal energy,entropy, and free energy as \
in KoM Eqs. 17.13\[Dash]14. In the formuation below \[CapitalDelta]F has \
units of energy/mole\
\>", "Text"],

Cell[BoxData[{
    \(\(\[CapitalDelta]U[
          XB_, \[Eta]_] := \(-4\)\ N0\ W\ \((XB \((1 - 
                    XB)\) + \[Eta]\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]S\ [
          XB_, \[Eta]_] := \(-N0\)\ kB \((\((XB + \[Eta])\) 
                Log[XB + \[Eta]] + \((XB - \[Eta])\) 
                Log[XB - \[Eta]] + \((1 - XB + \[Eta])\) 
                Log[1 - XB + \[Eta]] + \((1 - XB - \[Eta])\) 
                Log[1 - XB - \[Eta]])\);\)\), "\[IndentingNewLine]", 
    \(\[CapitalDelta]F[XB_, \[Eta]_, T_] := \[CapitalDelta]U[XB, \[Eta]] - 
        T\ \[CapitalDelta]S[XB, \[Eta]]\)}], "Input"],

Cell["\<\
Look first at the possibility for order-disorder transitions by \
calculating the order-disorder transition temperature at XB = 0.5:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SecDerivEta = \[PartialD]\_\(\[Eta], \[Eta]\)\[CapitalDelta]F[
          XB, \[Eta], T]\), "\[IndentingNewLine]", 
    \(Fetaeta = Limit[SecDerivEta, \[Eta] -> 0]\), "\[IndentingNewLine]", 
    \(Fetaeta /. XB \[Rule] 0.5\)}], "Input"],

Cell[BoxData[
    \(\(-4.817712`*^24\)\ W + 
      8.314469397642002`\ T\ \((1\/\(1 - XB - \[Eta]\) + 1\/\(XB - \[Eta]\) + 
            1\/\(1 - XB + \[Eta]\) + 1\/\(XB + \[Eta]\))\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(16.628938795284004`\ T\)\/\((\(-1.`\) + XB)\)\^2\)\) - \
\(4.817712`*^24\ W\)\/\((\(-1.`\) + XB)\)\^2 + \(16.628938795284004`\ T\)\/\(\
\((\(-1.`\) + XB)\)\^2\ XB\) + \(9.635424`*^24\ W\ XB\)\/\((\(-1.`\) + \
XB)\)\^2 - \(4.817712`*^24\ W\ XB\^2\)\/\((\(-1.`\) + XB)\)\^2\)], "Output"],

Cell[BoxData[
    \(66.51575518113602`\ T - 4.817712000000002`*^24\ W\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We see that there will only be order-disorder transitions (i.e., a \
positive-temperature solution to \n\tLimit",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            RowBox[{"(", 
              FormBox[\(F\_\[Eta]\[Eta]\),
                "TraditionalForm"], ")"}], \(\[Eta] \[Rule] 0\)], "=", "0"}], 
        TraditionalForm]]],
  " \nwhen W>0. With this result, we can explore the simpler case of phase \
equilibria with miscibility gaps by considering only W<0 and setting \[Eta]=0 \
in the free energy model. (In this way, we recover the regular solution \
model.)"
}], "Text"],

Cell["Spinodal Decomposition", "Subtitle"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculation of Miscibility Gap and Chemical Spinodal in the \
Bragg-Williams Approximation\
\>", "Subsection"],

Cell["\<\
We'll need to make calculations and draw graphs so I begin by \
picking a suitable negative value for W\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(W = \(-1000\)\[Times]kB\)], "Input"],

Cell[BoxData[
    \(\(-1.3806503000000003`*^-20\)\)], "Output"]
}, Open  ]],

Cell["Begin by evaluating the spinodal temperature at XB = 0.5", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, 
        T]\), "\[IndentingNewLine]", 
    \(FXBXB = 
      Limit[\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, T], 
        XB -> 0.5]\)}], "Input"],

Cell[BoxData[
    \(\(-66515.755181136`\) + 
      8.314469397642002`\ T\ \((2\/\(1 - XB\) + 2\/XB)\)\)], "Output"],

Cell[BoxData[
    \(\(-66515.755181136`\) + 66.51575518113602`\ T\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[FXBXB \[Equal] 0, T]\)], "Input"],

Cell[BoxData[
    \({{T \[Rule] 999.9999999999998`}}\)], "Output"]
}, Open  ]],

Cell["\<\
So the top of the miscibility gap (remember, this free-energy model \
is symmetric about XB = 0.5) is at T = 1000 K.\
\>", "Text"],

Cell["\<\
Plot \[CapitalDelta]F vs. XB for T = 800, 900, 1000, 1100 K\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\[CapitalDelta]F[XB, 0, 800], \[CapitalDelta]F[XB, 0, 
          900], \[CapitalDelta]F[XB, 0, 1000], \[CapitalDelta]F[XB, 0, 
          1100]}, {XB, 0.0, 1}, AxesLabel \[Rule] {XB, \[CapitalDelta]F}, 
      PlotStyle \[Rule] {{Hue[ .3]}, {Hue[ .5]}, {Hue[ .7]}, {Hue[ .9]}}, 
      PlotLegend \[Rule] {"\<800 K\>", "\<900 K\>", "\<1000 K\>", "\<1100 \
K\>"}, LegendPosition \[Rule] {1, \(-1\)}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64023 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.389355 0.365545 0.399066 0.365545 [
[ 0 0 0 0 ]
[ 1 .64023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.173147 0.7549 0.624985 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603319 0.000134863 [
[.21429 .59082 -9 -9 ]
[.21429 .59082 9 0 ]
[.40476 .59082 -9 -9 ]
[.40476 .59082 9 0 ]
[.59524 .59082 -9 -9 ]
[.59524 .59082 9 0 ]
[.78571 .59082 -9 -9 ]
[.78571 .59082 9 0 ]
[.97619 .59082 -3 -9 ]
[.97619 .59082 3 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 16 6 ]
[.01131 .06387 -30 -4.5 ]
[.01131 .06387 0 4.5 ]
[.01131 .19873 -30 -4.5 ]
[.01131 .19873 0 4.5 ]
[.01131 .33359 -30 -4.5 ]
[.01131 .33359 0 4.5 ]
[.01131 .46846 -30 -4.5 ]
[.01131 .46846 0 4.5 ]
[.02381 .64303 -8 0 ]
[.02381 .64303 8 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(0.2)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(0.4)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(0.6)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(0.8)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(1)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
1.000 setlinewidth
grestore
.02381 .06387 m
.03006 .06387 L
s
[(-4000)] .01131 .06387 1 0 Mshowa
.02381 .19873 m
.03006 .19873 L
s
[(-3000)] .01131 .19873 1 0 Mshowa
.02381 .33359 m
.03006 .33359 L
s
[(-2000)] .01131 .33359 1 0 Mshowa
.02381 .46846 m
.03006 .46846 L
s
[(-1000)] .01131 .46846 1 0 Mshowa
.125 Mabswid
.02381 .09084 m
.02756 .09084 L
s
.02381 .11781 m
.02756 .11781 L
s
.02381 .14479 m
.02756 .14479 L
s
.02381 .17176 m
.02756 .17176 L
s
.02381 .2257 m
.02756 .2257 L
s
.02381 .25268 m
.02756 .25268 L
s
.02381 .27965 m
.02756 .27965 L
s
.02381 .30662 m
.02756 .30662 L
s
.02381 .36057 m
.02756 .36057 L
s
.02381 .38754 m
.02756 .38754 L
s
.02381 .41451 m
.02756 .41451 L
s
.02381 .44148 m
.02756 .44148 L
s
.02381 .49543 m
.02756 .49543 L
s
.02381 .5224 m
.02756 .5224 L
s
.02381 .54937 m
.02756 .54937 L
s
.02381 .57635 m
.02756 .57635 L
s
.02381 .0369 m
.02756 .0369 L
s
.02381 .00992 m
.02756 .00992 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.5 Mabswid
.02381 .60332 m
.02499 .5918 L
.02605 .58405 L
.02846 .56977 L
.03279 .54949 L
.04262 .51601 L
.05281 .49119 L
.06244 .47336 L
.07295 .45826 L
.08265 .44736 L
.09329 .43802 L
.10458 .43051 L
.11399 .4258 L
.12411 .42203 L
.12901 .42063 L
.13367 .41952 L
.13817 .41865 L
.14241 .41799 L
.14483 .41768 L
.14744 .4174 L
.14962 .41721 L
.152 .41703 L
.15459 .41689 L
.156 .41684 L
.15732 .41679 L
.15856 .41676 L
.15969 .41675 L
.16099 .41673 L
.16222 .41673 L
.16327 .41674 L
.16444 .41676 L
.16565 .41678 L
.1668 .41681 L
.16883 .41688 L
.17103 .41698 L
.17603 .41731 L
.18061 .41772 L
.19041 .4189 L
.19953 .42032 L
.22023 .4245 L
.25928 .43467 L
.30077 .44674 L
.34076 .45794 L
.37922 .46726 L
.39871 .47122 L
.42014 .47487 L
.4405 .47759 L
.45954 .47945 L
.46995 .48017 L
.47508 .48044 L
Mistroke
.47983 .48065 L
.48413 .48081 L
.4887 .48093 L
.49132 .48098 L
.4926 .481 L
.49377 .48102 L
.49483 .48103 L
.49598 .48104 L
.49714 .48105 L
.49837 .48105 L
.49968 .48106 L
.50089 .48106 L
.50152 .48105 L
.50222 .48105 L
.50294 .48105 L
.50363 .48104 L
.50488 .48103 L
.50602 .48102 L
.5086 .48098 L
.51077 .48094 L
.51314 .48089 L
.51792 .48074 L
.52317 .48053 L
.52877 .48024 L
.53885 .47957 L
.54911 .47869 L
.56023 .47751 L
.5804 .47479 L
.62137 .46714 L
.66082 .45752 L
.69876 .44687 L
.73915 .43512 L
.77803 .4249 L
.78819 .42266 L
.79924 .42054 L
.8088 .41901 L
.81388 .41833 L
.81936 .41772 L
.82467 .41726 L
.82699 .4171 L
.82954 .41696 L
.83071 .4169 L
.83195 .41685 L
.83303 .41681 L
.8342 .41678 L
.83552 .41676 L
.83677 .41674 L
.83799 .41673 L
.83911 .41674 L
.84032 .41675 L
Mistroke
.84162 .41677 L
.84284 .4168 L
.84396 .41683 L
.8467 .41696 L
.8493 .41712 L
.85198 .41735 L
.85447 .4176 L
.86011 .41836 L
.86519 .41928 L
.87069 .42055 L
.88065 .42365 L
.89034 .42781 L
.89926 .43282 L
.909 .43983 L
.9181 .44811 L
.92807 .45957 L
.93877 .47536 L
.94798 .49286 L
.95799 .51775 L
.96258 .53211 L
.96745 .55046 L
.9716 .57009 L
.97274 .5765 L
.97397 .58422 L
.97619 .60332 L
Mfstroke
0 1 1 r
.02381 .60332 m
.02605 .58033 L
.02846 .56285 L
.03279 .53753 L
.04262 .49425 L
.053 .46008 L
.06244 .43529 L
.07283 .41292 L
.0841 .39301 L
.10458 .3654 L
.12442 .34629 L
.13455 .33873 L
.14545 .33194 L
.15565 .32667 L
.16498 .32266 L
.18328 .31667 L
.19313 .31433 L
.20227 .31262 L
.2123 .3112 L
.21791 .31058 L
.22299 .31013 L
.22786 .30979 L
.23301 .30951 L
.23741 .30934 L
.23991 .30927 L
.24224 .30921 L
.24353 .30919 L
.24494 .30917 L
.24558 .30916 L
.24626 .30916 L
.24749 .30915 L
.24867 .30914 L
.24977 .30914 L
.25098 .30914 L
.25228 .30915 L
.25359 .30916 L
.25502 .30917 L
.25652 .30919 L
.2579 .30922 L
.26306 .30934 L
.26811 .30951 L
.27358 .30974 L
.28351 .31029 L
.3021 .31164 L
.34302 .3155 L
.38242 .31941 L
.42031 .3226 L
.43976 .32386 L
.4506 .32442 L
.46065 .32485 L
Mistroke
.47078 .32519 L
.47613 .32533 L
.48183 .32545 L
.48444 .32549 L
.48726 .32553 L
.48975 .32556 L
.49237 .32558 L
.49475 .3256 L
.4961 .3256 L
.49735 .32561 L
.49851 .32561 L
.49956 .32561 L
.50078 .32561 L
.50193 .32561 L
.50307 .3256 L
.5043 .3256 L
.50547 .32559 L
.50653 .32559 L
.50901 .32557 L
.51161 .32554 L
.51651 .32547 L
.52188 .32537 L
.53143 .32512 L
.54031 .32481 L
.56081 .32383 L
.57941 .32262 L
.61944 .31924 L
.65796 .3154 L
.67748 .31347 L
.69893 .31156 L
.70877 .3108 L
.71933 .31012 L
.72444 .30984 L
.72929 .30961 L
.73398 .30943 L
.73839 .3093 L
.74059 .30925 L
.74296 .3092 L
.74425 .30918 L
.7456 .30917 L
.74676 .30916 L
.74802 .30915 L
.74871 .30914 L
.74937 .30914 L
.75059 .30914 L
.7519 .30914 L
.75264 .30915 L
.75333 .30915 L
.75447 .30916 L
.75573 .30918 L
Mistroke
.75827 .30922 L
.76066 .30928 L
.76285 .30935 L
.76778 .30955 L
.77234 .3098 L
.77668 .31011 L
.78628 .31103 L
.7965 .31242 L
.80615 .31418 L
.8149 .3162 L
.83416 .32232 L
.84501 .32698 L
.85498 .33218 L
.87382 .34488 L
.89449 .36435 L
.91401 .39005 L
.92496 .4087 L
.93493 .42922 L
.9442 .45219 L
.95403 .48224 L
.95916 .5011 L
.96482 .52558 L
.96997 .55295 L
.97249 .56932 L
.9748 .58766 L
.97619 .60332 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.02605 .5766 L
.02846 .55594 L
.03279 .52557 L
.04262 .47248 L
.053 .42935 L
.06244 .39722 L
.0841 .34009 L
.10458 .30028 L
.12455 .27047 L
.14299 .2488 L
.16331 .22991 L
.18234 .21596 L
.20174 .20471 L
.22018 .19625 L
.24043 .18901 L
.25895 .1839 L
.27876 .17972 L
.29714 .17681 L
.31767 .17444 L
.33627 .17291 L
.3463 .17228 L
.35552 .17181 L
.36629 .17136 L
.37634 .17104 L
.38543 .1708 L
.39517 .17061 L
.40597 .17045 L
.41583 .17035 L
.42063 .17031 L
.42574 .17027 L
.43491 .17023 L
.44 .17021 L
.44478 .1702 L
.45002 .17018 L
.45275 .17018 L
.45567 .17018 L
.45827 .17017 L
.46063 .17017 L
.46524 .17017 L
.46783 .17017 L
.47063 .17016 L
.47328 .17016 L
.47571 .17016 L
.47824 .17016 L
.48059 .17016 L
.48195 .17016 L
.48318 .17016 L
.48461 .17016 L
.48596 .17016 L
Mistroke
.48727 .17016 L
.48798 .17016 L
.48866 .17016 L
.48997 .17016 L
.49115 .17016 L
.49184 .17016 L
.49257 .17016 L
.49387 .17016 L
.4946 .17016 L
.49528 .17016 L
.49602 .17016 L
.49681 .17016 L
.49804 .17016 L
.49873 .17016 L
.49939 .17016 L
.5007 .17016 L
.50144 .17016 L
.50211 .17016 L
.50326 .17016 L
.5045 .17016 L
.5058 .17016 L
.50701 .17016 L
.50771 .17016 L
.50846 .17016 L
.50917 .17016 L
.50982 .17016 L
.51106 .17016 L
.51237 .17016 L
.51378 .17016 L
.5151 .17016 L
.51654 .17016 L
.51809 .17016 L
.52068 .17016 L
.52214 .17016 L
.5235 .17016 L
.52598 .17016 L
.52862 .17016 L
.53097 .17017 L
.53318 .17017 L
.5358 .17017 L
.53823 .17017 L
.54291 .17017 L
.54804 .17018 L
.55304 .17019 L
.55838 .1702 L
.56337 .17022 L
.56807 .17024 L
.57688 .17029 L
.5815 .17032 L
.58659 .17037 L
Mistroke
.59687 .17049 L
.6064 .17064 L
.61532 .17082 L
.62571 .1711 L
.63558 .17143 L
.65411 .1723 L
.6637 .1729 L
.67393 .17368 L
.69232 .17549 L
.71375 .17844 L
.73392 .18226 L
.75402 .18734 L
.77249 .19341 L
.79133 .2013 L
.812 .2124 L
.83153 .2258 L
.85244 .24414 L
.8737 .2682 L
.89383 .29761 L
.91375 .33538 L
.93218 .38117 L
.95085 .44423 L
.96149 .49273 L
.96669 .52229 L
.96902 .53743 L
.97146 .5553 L
.97619 .60332 L
Mfstroke
1 0 .6 r
.02381 .60332 m
.02605 .57287 L
.02846 .54902 L
.03279 .5136 L
.04262 .45072 L
.06244 .35916 L
.08451 .28602 L
.10458 .23516 L
.12534 .19333 L
.14451 .16197 L
.18292 .11439 L
.20165 .09678 L
.22227 .08063 L
.24331 .06706 L
.26256 .05676 L
.30133 .04094 L
.32032 .0351 L
.34104 .02988 L
.36236 .02557 L
.38169 .02244 L
.40207 .01983 L
.42082 .01797 L
.44006 .01654 L
.45019 .01597 L
.46088 .01548 L
.47036 .01515 L
.47558 .01501 L
.48052 .0149 L
.48512 .01482 L
.48754 .01479 L
.49011 .01476 L
.49227 .01474 L
.49342 .01474 L
.49465 .01473 L
.49578 .01472 L
.49682 .01472 L
.49781 .01472 L
.49886 .01472 L
.50009 .01472 L
.50079 .01472 L
.50143 .01472 L
.50261 .01472 L
.50386 .01472 L
.50497 .01473 L
.50602 .01473 L
.5084 .01475 L
.51097 .01477 L
.51332 .0148 L
.5186 .01489 L
.52311 .01498 L
Mistroke
.52802 .01511 L
.53696 .0154 L
.54731 .01584 L
.55668 .01634 L
.57766 .01784 L
.59695 .01972 L
.61778 .02236 L
.63776 .02559 L
.65884 .02986 L
.69686 .04034 L
.71641 .04746 L
.73734 .05671 L
.75719 .06735 L
.77875 .08136 L
.81865 .11601 L
.83846 .1387 L
.85948 .16801 L
.89728 .2394 L
.91667 .2894 L
.93754 .3591 L
.95638 .44518 L
.96585 .50369 L
.96844 .52295 L
.97121 .546 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.77318 .01524 m
.77318 .30768 L
.97619 .30768 L
.97619 .01524 L
F
1 g
.7549 .03352 m
.7549 .32596 L
.95791 .32596 L
.95791 .03352 L
F
0 g
.001 w
[ ] 0 setdash
.7549 .03352 m
.95791 .03352 L
.95791 .32596 L
.7549 .32596 L
.7549 .03352 L
s
% Start of sub-graphic
p
0.7549 0.0335208 0.957913 0.325957 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 1.44048 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.44048 L
0 1.44048 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 .6 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1100) show
93.000 13.000 moveto
(K) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
93.000 13.000 moveto
(K) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(900) show
87.000 13.000 moveto
(K) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.08929 0.35119 1.3869 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.2381 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
87.000 13.000 moveto
(K) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .64023 L
0 .64023 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{622, 398.188},
  ImageMargins->{{14, 0}, {0, 10}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009^0001SR000`400?l00000o`00003ooooooooo
ooooog3ooooo003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo
003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003ooooooooo
ooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool0
0?ooooooh?oooomno`00017ooooo003oooooon3oooooO_l0000Aooooo`00oooooooPooooogko0000
4Oooool00?ooooooh?oooomno`00017ooooo003oooooon3oooooO_l0000Aooooo`00oooooooPoooo
ogko00004Oooool00?ooooooh?oooomno`00017ooooo003oooooon3oooooO_l0000Aooooo`00oooo
oooPooooogko00004Oooool00?ooooooh?oooomno`00017ooooo003oooooomGoooooROl0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo037ooooo0ol00003ooooo`?o00001?ooool2
o`0000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000009oooool;o`00017ooooo003ooooo
omGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0002Sooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo00Gooooo9?oo
09T9ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000:Oooool;o`00017o
oooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008oooo
o`;o0000:_ooool;o`00017ooooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000002Wooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000:?ooool;o`00017ooooo
003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00002?ooool3o`000003ooooool0003o000002Oooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo037ooooo0ol00004oooo
o`;o00001?ooool2o`0000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000009oooool;o`00
017ooooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0002Sooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oo
oooooooo00Gooooo9?lc0?l9ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000:Oooool;o`00017ooooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00008ooooo`;o0000:_ooool;o`00017ooooo003oooooomGooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002Wo
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0002Sooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool3
o`000003ooooool0003o000002Oooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00
oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oo
oooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000A
ooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03
o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooE
ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00
oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oo
oooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000A
ooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03
o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`3ooooooj3ooooo00?o0000ooooooooool0Nooo
ool;o`00017ooooo000booooo`03o`000?oooooooooo0?ooooooX?ooool00ol0003oooooooooo`1k
ooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0oooooonPooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`3ooooooj3ooooo00?o0000oooooooo
ool0Noooool;o`00017ooooo000booooo`;o0000oooooonQooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`3ooooooj3ooooo00?o0000ooooooooool0Nooo
ool;o`00017ooooo000booooo`03o`000?oooooooooo0:3ooooo>?oo09W7ooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`2Iooooo`Ooo`2I>?ooool8ool0
VKoooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo097o
oooo2?oo09U7ooooo`Soo`2I]oooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo
00?o0000ooooooooool0ROooool8ool0VEOooooo2?oo09V_ooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`23ooooo`Koo`2IIoooool6ool0VJWooooo00?o
0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo07kooooo1Ooo09Uc
ooooo`Goo`2IY?ooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000oooo
ooooool0N_ooool4ool0VGgooooo1?oo09VPooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00<_ooool00ol0003oooooooooo`1fooooo`Coo`2IQOooool4ool0VIcooooo00?o0000oooooooo
ool0Noooool;o`00017ooooo000booooo`;o0000Loooool4ool0VHgooooo0ooo09VIooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`1^ooooo`Coo`2IU?oo
ool4ool0VIGooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooo
oooo06_ooooo0ooo09VLooooo`?oo`2IT_ooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo00?o0000ooooooooool0J?ooool3ool0VJ;ooooo0ooo09V?ooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`1Vooooo`;oo`2IZ?ooool3ool0VHco
oooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo06?ooooo
0ooo09V]ooooo`;oo`2IR_ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000Cooooo
0_l00008ooooo`?o000000?oooooo`000?l00000;Oooool;o`00017ooooo000booooo`03o`000?oo
oooooooo067ooooo0_oo09Vbooooo`?oo`2IQoooool00ol0003oooooooooo`0cooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo0000;_ooool;o`00017ooooo000booooo`03o`000?oooooooooo05ko
oooo0ooo09Vgooooo`?oo`2IQ?ooool00ol0003oooooooooo`05ooooobCo0?oo2oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooo`00000_ooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0G?ooool2ool0
VKgooooo0_oo09V2ooooo`03o`000?oooooooooo037ooooo1?l00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool2o`00033ooooo2ol0000Aooooo`005oooool3
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0Foooool0
0ooo09Woooooooooo`2oooooo`03ool0VOoooooooooo07oooooo00?o0000ooooooooool0<?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000002oooooo2ol0000Aooooo`006?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool2ool0VL?ooooo0_oo09Uo
ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000^oooo
o`_o00004Oooool000oooooo1Ol000000ooooooo0000o`000003o`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo0ol0
001Gooooo`;oo`2Iaoooool2ool0VGgooooo00?o0000ooooooooool0<Oooool3o`0000Cooooo0_l0
0004ooooo`;o00002?ooool3o`000003ooooool0003o000002gooooo2ol0000Aooooo`005Oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05Kooooo00?oo`2Ioooo
ooooool0bOooool00ooo09Woooooooooo`1jooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`005_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05Cooooo0_oo
09W=ooooo`;oo`2IN_ooool00ol0003oooooooooo`1kooooo`_o00004Oooool001Oooooo0_l00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo05;ooooo0_oo09WAooooo`;oo`2IN?ooool00ol0003o
ooooooooo`1kooooo`_o00004Oooool001Sooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
0_l00004ooooo`;o00001oooool00ol0003oooooooooo`1@ooooo`;oo`2IeOooool2ool0VGKooooo
00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04oooooo00?o
o`2Iooooooooool0eoooool00ooo09Woooooooooo`1cooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00<_ooool00ol0003oooooooooo`1=ooooo`;oo`2Ifoooool2ool0VG?ooooo00?o0000
ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04_ooooo0_oo09WOoooo
o`;oo`2ILOooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000oooooooo
ool0B_ooool00ooo09Woooooooooo`3Qooooo`03ool0VOoooooooooo06kooooo00?o0000oooooooo
ool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04Wooooo00?oo`2Iooooooooool0
hoooool00ooo09Woooooooooo`1]ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_oo
ool00ol0003oooooooooo`18ooooo`03ool0VOoooooooooo0>Gooooo00?oo`2Iooooooooool0K?oo
ool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo0_l00018ooooo`03ool0VOoooooo
oooo0>Oooooo00?oo`2Iooooooooool0Joooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo00?o0000ooooooooool0A_ooool00ooo09Woooooooooo`3Yooooo`03ool0VOoooooooooo
06[ooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04Go
oooo00?oo`2Iooooooooool0joooool00ooo09Woooooooooo`1Yooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`14ooooo`03ool0VOoooooooooo0>gooooo
0_oo09UYooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003ooooooooo
o`13ooooo`03ool0VOoooooooooo0?3ooooo00?oo`2Iooooooooool0I_ooool00ol0003ooooooooo
o`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0@_ooool00ooo09Woooooooooo`3b
ooooo`03ool0VOoooooooooo06Gooooo00?o0000ooooooooool0Noooool;o`00017ooooo000boooo
o`03o`000?oooooooooo047ooooo00?oo`2Iooooooooool0m?ooool00ooo09Woooooooooo`1Toooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`10ooooo`03
ool0VOoooooooooo0?Kooooo00?oo`2Iooooooooool0Hoooool00ol0003oooooooooo`1kooooo`_o
00004Oooool003;ooooo00?o0000ooooooooool0?oooool00ooo09Woooooooooo`3hooooo`03ool0
VOoooooooooo06;ooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oo
oooooooo03kooooo00?oo`2Iooooooooool0n_ooool00ooo09Woooooooooo`1Qooooo`03o`000?oo
oooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0mooooo`03ool0VOoooooo
oooo0?cooooo00?oo`2Iooooooooool0H?ooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo0_l0000nooooo`03ool0VOoooooooooo0?cooooo00?oo`2Iooooooooool0H?ooool00ol0
003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0??ooool00ooo09Wo
ooooooooo`3nooooo`03ool0VOoooooooooo05oooooo00?o0000ooooooooool0Noooool;o`00017o
oooo000booooo`03o`000?oooooooooo03_ooooo00?oo`2Iooooooooool0ooooool1ooooo`03ool0
VOoooooooooo05kooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oo
oooooooo03[ooooo00?oo`2Iooooooooool0ooooool3ooooo`03ool0VOoooooooooo05gooooo00?o
0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo03Wooooo00?oo`2I
ooooooooool0ooooool5ooooo`03ool0VOoooooooooo05cooooo00?o0000ooooooooool0Noooool;
o`00017ooooo000booooo`03o`000?oooooooooo03Sooooo00?oo`2Iooooooooool0ooooool7oooo
o`03ool0VOoooooooooo05_ooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03
o`000?oooooooooo03Sooooo00?oo`2Iooooooooool0ooooool8ooooo`03ool0VOoooooooooo05[o
oooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo03Oooooo
00?oo`2Iooooooooool0ooooool:ooooo`03ool0VOoooooooooo05Wooooo00?o0000ooooooooool0
Noooool;o`00017ooooo000booooo`03o`000?oooooooooo03Kooooo00?oo`2Iooooooooool0oooo
ool<ooooo`03ool0VOoooooooooo05Sooooo00?o0000ooooooooool0Noooool;o`00017ooooo000b
ooooo`03o`000?oooooooooo03Gooooo00?oo`2Iooooooooool0ooooool=ooooo`03ool0VOoooooo
oooo05Sooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo
03Cooooo00?oo`2Iooooooooool0ooooool?ooooo`03ool0VOoooooooooo05Oooooo00?o0000oooo
ooooool0Noooool;o`00017ooooo000booooo`;o0000=?ooool00ooo09Woooooooooo`3ooooooa7o
oooo00?oo`2Iooooooooool0E_ooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo
00?o0000ooooooooool0<_ooool00ooo09Woooooooooo`3ooooooa?ooooo00?oo`2Iooooooooool0
EOooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0<_oo
ool00ooo09Woooooooooo`3ooooooa?ooooo00?oo`2Iooooooooool0EOooool00ol0003ooooooooo
o`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0<Oooool00ooo09Woooooooooo`3o
oooooaGooooo00?oo`2Iooooooooool0E?ooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo00?o0000ooooooooool0<?ooool00ooo09Woooooooooo`3ooooooaOooooo00?oo`2Ioooo
ooooool0Doooool00ol0003oooooooooo`0aooooo`?o00001?ooool2o`0000Cooooo0_l00008oooo
o`?o000000?oooooo`000?l00000;Oooool;o`00017ooooo000booooo`03o`000?oooooooooo02oo
oooo00?oo`2Iooooooooool0oooooolIooooo`03ool0VOoooooooooo05;ooooo00?o0000oooooooo
ool0<?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0002kooooo2ol0000Aooooo`00<_oo
ool00ol0003oooooooooo`0^ooooo`03ool0VOoooooooooo0?oooooo6_ooool00ooo09Wooooooooo
o`1Booooo`03o`000?oooooooooo00Gooooo9?lco`07ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000;oooool;o`00017ooooo000booooo`03o`000?oooooooooo02gooooo00?oo`2Ioooooooo
ool0oooooolLooooo`03ool0VOoooooooooo057ooooo00?o0000ooooooooool0<Oooool3o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`;o0000<?ooool;
o`00017ooooo000booooo`03o`000?oooooooooo02gooooo00?oo`2Iooooooooool0oooooolMoooo
o`03ool0VOoooooooooo053ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000002oooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0/ooooo`03ool0VOoo
oooooooo0?oooooo7oooool00ooo09Woooooooooo`1?ooooo`03o`000?oooooooooo033ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0000^ooooo`_o00004Oooool003;ooooo00?o0000oooo
ooooool0:oooool00ooo09Woooooooooo`1Jooooof[o<`3oFoooool00ooo09Woooooooooo`1?oooo
o`03o`000?oooooooooo037ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo0ol000000ooo
oooo0000o`00000]ooooo`_o00004Oooool003;ooooo0_l0000/ooooo`03ool0VOoooooooooo04Wo
oooo4Olc0?mZoooooaGo<`3oAoooool00ooo09Woooooooooo`1>ooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0Zooooo`03ool0VOoooooooooo04;ooooo
2?lc0?n@ooooo`So<`3o?oooool00ooo09Woooooooooo`1>ooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0Yooooo`03ool0VOoooooooooo03_ooooo2?lc
0?nPooooo`Ko<`3o>_ooool00ooo09Woooooooooo`1=ooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00<_ooool00ol0003oooooooooo`0Yooooo`03ool0VOoooooooooo03Gooooo1_lc0?n^
ooooo`Co<`3o=_ooool00ooo09Woooooooooo`1=ooooo`03o`000?oooooooooo07_ooooo2ol0000A
ooooo`00<_ooool00ol0003oooooooooo`0Xooooo`03ool0VOoooooooooo03;ooooo1?lc0?nhoooo
o`Co<`3o<oooool00ooo09Woooooooooo`1<ooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00<_ooool00ol0003oooooooooo`0Wooooo`03ool0VOoooooooooo02oooooo1?lc0?o0ooooo`Co
<`3o;oooool00ooo09Woooooooooo`1<ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00
<_ooool00ol0003oooooooooo`0Wooooo`03ool0VOoooooooooo02cooooo0olc0?o8ooooo`Co<`3o
;?ooool00ooo09Woooooooooo`1;ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_oo
ool00ol0003oooooooooo`0Vooooo`03ool0VOoooooooooo02[ooooo0olc0?o?ooooo`Co<`3o:?oo
ool00ooo09Woooooooooo`1;ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`005_ooool3
o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool09Oooool0
0ooo09Woooooooooo`0Xooooo`?o<`3oe_ooool3oc<0obKooooo00?oo`2Iooooooooool0B_ooool0
0ol0003oooooooooo`1kooooo`_o00004Oooool001Gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo02Gooooo00?oo`2Iooooooooool09Oooool3oc<0omco
oooo0_lc0?lTooooo`03ool0VOoooooooooo04[ooooo00?o0000ooooooooool0Noooool;o`00017o
oooo000?ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Cooooo00?oo`2Iooooooooool09?ooool2oc<0on7ooooo00?o<`3oooooooooool08_ooool0
0ooo09Woooooooooo`19ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06Oooool0
01Oooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00006ooooo`?o00009?ooool00ooo09Woooooooooo`0Qooooo`?o<`3o
i?ooool2oc<0ob;ooooo00?oo`2Iooooooooool0BOooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo01Wooooo000Iooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08oooool00ooo09Woooooooooo`0Oooooo`?o<`3ojOooool2oc<0ob7ooooo00?oo`2Ioooo
ooooool0B?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01Wooooo000Eooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Sooooo`03ool0
VOoooooooooo01gooooo0_lc0?o^ooooo`;o<`3o8?ooool00ooo09Woooooooooo`17ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool06Oooool001Kooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo02;ooooo00?oo`2Iooooooooool07?oo
ool2oc<0oo;ooooo0_lc0?lNooooo`03ool0VOoooooooooo04Oooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0Iooooo`00<_ooool00ol0003oooooooooo`0Rooooo`03ool0VOoooooo
oooo01[ooooo0_lc0?ofooooo`;o<`3o7Oooool00ooo09Woooooooooo`16ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool06Oooool003;ooooo00?o0000ooooooooool08Oooool00ooo
09Woooooooooo`0Iooooo`;o<`3on_ooool2oc<0oa_ooooo00?oo`2Iooooooooool0A_ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo01Wooooo000booooo`03o`000?oooooooooo027o
oooo00?oo`2Iooooooooool05oooool2oc<0ookooooo00?o<`3oooooooooool06Oooool00ooo09Wo
ooooooooo`15ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06Oooool003;ooooo
00?o0000ooooooooool08Oooool00ooo09Woooooooooo`0Fooooo`03oc<0oooooooooooo0?oooooo
0_lc0?lIooooo`03ool0VOoooooooooo04Gooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0Iooooo`00<_ooool00ol0003oooooooooo`0Pooooo`03ool0VOoooooooooo01Kooooo00?o
<`3oooooooooool0ooooool3ooooo`;o<`3o6?ooool00ooo09Woooooooooo`14ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool06Oooool003;ooooo00?o0000ooooooooool08?ooool0
0ooo09Woooooooooo`0Eooooo`03oc<0oooooooooooo0?oooooo1_ooool00olc0?ooooooooooo`0E
ooooo`03ool0VOoooooooooo04Cooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0I
ooooo`00<_ooool2o`00023ooooo00?oo`2Iooooooooool05Oooool00olc0?ooooooooooo`3ooooo
o`Sooooo0_lc0?lFooooo`03ool0VOoooooooooo04?oooooOol0000Kooooo`00<_ooool00ol0003o
ooooooooo`0Oooooo`03ool0VOoooooooooo01Cooooo00?o<`3oooooooooool0ooooool;ooooo`03
oc<0oooooooooooo01?ooooo00?oo`2Iooooooooool0gOooool003;ooooo00?o0000ooooooooool0
7_ooool00ooo09Woooooooooo`0Dooooo`03oc<0oooooooooooo0?oooooo3Oooool00olc0?oooooo
ooooo`0Cooooo`03ool0VOoooooooooo0=cooooo000booooo`03o`000?oooooooooo01kooooo00?o
o`2Iooooooooool04oooool00olc0?ooooooooooo`3oooooo`oooooo00?o<`3oooooooooool04_oo
ool00ooo09Woooooooooo`3Looooo`00<_ooool00ol0003oooooooooo`0Mooooo`03ool0VOoooooo
oooo01?ooooo00?o<`3oooooooooool0oooooolAooooo`03oc<0oooooooooooo01;ooooo00?oo`2I
ooooooooool0foooool003;ooooo00?o0000ooooooooool07Oooool00ooo09Woooooooooo`0Boooo
o`03oc<0oooooooooooo0?oooooo4oooool00olc0?ooooooooooo`0Aooooo`03ool0VOoooooooooo
0=_ooooo000booooo`03o`000?oooooooooo01cooooo00?oo`2Iooooooooool04_ooool00olc0?oo
ooooooooo`3ooooooaGooooo00?o<`3oooooooooool04Oooool00ooo09Woooooooooo`3Jooooo`00
<_ooool00ol0003oooooooooo`0Looooo`03ool0VOoooooooooo017ooooo00?o<`3oooooooooool0
oooooolGooooo`03oc<0oooooooooooo013ooooo00?oo`2Iooooooooool0f_ooool003;ooooo00?o
0000ooooooooool07?ooool00ooo09Woooooooooo`0@ooooo`03oc<0oooooooooooo0?oooooo6Ooo
ool00olc0?ooooooooooo`0@ooooo`03ool0VOoooooooooo0=Wooooo000booooo`03o`000?oooooo
oooo01_ooooo00?oo`2Iooooooooool04?ooool00olc0?ooooooooooo`3ooooooa[ooooo00?o<`3o
ooooooooool04?ooool00ooo09Woooooooooo`3Iooooo`00<_ooool00ol0003oooooooooo`0Koooo
o`03ool0VOoooooooooo00oooooo00?o<`3oooooooooool0oooooolLooooo`03oc<0oooooooooooo
00oooooo00?oo`2Iooooooooool0fOooool003;ooooo0_l0000Looooo`03ool0VOoooooooooo00ko
oooo00?o<`3oooooooooool0oooooolNooooo`03oc<0oooooooooooo00oooooo00?oo`2Ioooooooo
ool0f?ooool003;ooooo00?o0000ooooooooool06_ooool00ooo09Woooooooooo`0>ooooo`03oc<0
oooooooooooo0?oooooo8?ooool00olc0?ooooooooooo`0>ooooo`03ool0VOoooooooooo0=Sooooo
000booooo`03o`000?oooooooooo01[ooooo00?oo`2Iooooooooool03Oooool00olc0?oooooooooo
o`3oooooob;ooooo00?o<`3oooooooooool03_ooool00ooo09Woooooooooo`3Gooooo`00<_ooool0
0ol0003oooooooooo`0Iooooo`03ool0VOoooooooooo00gooooo00?o<`3oooooooooool0oooooolT
ooooo`03oc<0oooooooooooo00gooooo00?oo`2Iooooooooool0eoooool003;ooooo00?o0000oooo
ooooool06Oooool00ooo09Woooooooooo`0<ooooo`03oc<0oooooooooooo0?oooooo9_ooool00olc
0?ooooooooooo`0<ooooo`03ool0VOoooooooooo0=Oooooo000booooo`03o`000?oooooooooo01Wo
oooo00?oo`2Iooooooooool02oooool00olc0?ooooooooooo`3oooooobSooooo00?o<`3ooooooooo
ool03?ooool00ooo09Woooooooooo`3Fooooo`00<_ooool00ol0003oooooooooo`0Hooooo`03ool0
VOoooooooooo00_ooooo00?o<`3oooooooooool0oooooolZooooo`03oc<0oooooooooooo00_ooooo
00?oo`2Iooooooooool0e_ooool003;ooooo00?o0000ooooooooool06?ooool00ooo09Wooooooooo
o`0:ooooo`03oc<0oooooooooooo0?oooooo:oooool00olc0?ooooooooooo`0<ooooo`03ool0VOoo
oooooooo0=Gooooo000booooo`03o`000?oooooooooo01Oooooo00?oo`2Iooooooooool02oooool0
0olc0?ooooooooooo`3oooooobcooooo00?o<`3oooooooooool02oooool00ooo09Woooooooooo`3E
ooooo`00<_ooool00ol0003oooooooooo`0Gooooo`03ool0VOoooooooooo00[ooooo00?o<`3ooooo
ooooool0ooooool^ooooo`03oc<0oooooooooooo00[ooooo00?oo`2Iooooooooool0eOooool003;o
oooo00?o0000ooooooooool05oooool00ooo09Woooooooooo`09ooooo`03oc<0oooooooooooo0?oo
oooo;oooool00olc0?ooooooooooo`0;ooooo`03ool0VOoooooooooo0=Cooooo000booooo`;o0000
5oooool00ooo09Woooooooooo`0:ooooo`03oc<0oooooooooooo0?oooooo<?ooool00olc0?oooooo
ooooo`0:ooooo`03ool0VOoooooooooo0=Cooooo000booooo`03o`000?oooooooooo01Kooooo00?o
o`2Iooooooooool02Oooool00olc0?ooooooooooo`3ooooooc;ooooo00?o<`3oooooooooool02_oo
ool00ooo09Woooooooooo`3Cooooo`00<_ooool00ol0003oooooooooo`0Fooooo`03ool0VOoooooo
oooo00Sooooo00?o<`3oooooooooool0oooooolcooooo`03oc<0oooooooooooo00[ooooo00?oo`2I
ooooooooool0doooool003;ooooo00?o0000ooooooooool05Oooool00ooo09Woooooooooo`09oooo
o`03oc<0oooooooooooo0?oooooo=?ooool00olc0?ooooooooooo`09ooooo`03ool0VOoooooooooo
0=?ooooo000booooo`03o`000?oooooooooo01Gooooo00?oo`2Iooooooooool02?ooool00olc0?oo
ooooooooo`3oooooocKooooo00?o<`3oooooooooool02Oooool00ooo09Woooooooooo`3Booooo`00
<_ooool00ol0003oooooooooo`0Eooooo`03ool0VOoooooooooo00Oooooo00?o<`3oooooooooool0
oooooolgooooo`03oc<0oooooooooooo00Wooooo00?oo`2Iooooooooool0d_ooool003;ooooo00?o
0000ooooooooool05?ooool00ooo09Woooooooooo`08ooooo`03oc<0oooooooooooo0?oooooo>?oo
ool00olc0?ooooooooooo`08ooooo`03ool0VOoooooooooo0=;ooooo000booooo`03o`000?oooooo
oooo01Cooooo00?oo`2Iooooooooool01oooool00olc0?ooooooooooo`3ooooooc[ooooo00?o<`3o
ooooooooool02?ooool00ooo09Woooooooooo`3Aooooo`00<_ooool00ol0003oooooooooo`0Doooo
o`03ool0VOoooooooooo00Kooooo00?o<`3oooooooooool0oooooolkooooo`03oc<0oooooooooooo
00Sooooo00?oo`2Iooooooooool0dOooool003;ooooo00?o0000ooooooooool04oooool00ooo09Wo
ooooooooo`07ooooo`03oc<0oooooooooooo0?oooooo??ooool00olc0?ooooooooooo`07ooooo`03
ool0VOoooooooooo0=7ooooo000booooo`03o`000?oooooooooo01?ooooo00?oo`2Iooooooooool0
1_ooool00olc0?ooooooooooo`3oooooocgooooo00?o<`3oooooooooool02?ooool00ooo09Wooooo
ooooo`3@ooooo`00<_ooool2o`0001Cooooo00?oo`2Iooooooooool01_ooool00olc0?oooooooooo
o`3oooooockooooo00?o<`3oooooooooool01oooool00ooo09Woooooooooo`3@ooooo`00<_ooool0
0ol0003oooooooooo`0Booooo`03ool0VOoooooooooo00Kooooo00?o<`3oooooooooool0;_oooolN
o`3oojSooooo7?l0ool^ooooo`03oc<0oooooooooooo00Oooooo00?oo`2Iooooooooool0d?ooool0
03;ooooo00?o0000ooooooooool04_ooool00ooo09Woooooooooo`06ooooo`03oc<0oooooooooooo
02Gooooo2Ol0oolNooooo`co0?ooT_ooool:o`3ooacooooo2?l0oolWooooo`03oc<0oooooooooooo
00Kooooo00?oo`2Iooooooooool0d?ooool003;ooooo00?o0000ooooooooool04_ooool00ooo09Wo
ooooooooo`05ooooo`03oc<0oooooooooooo02;ooooo1?l0oolcooooo`co0?ooM_ooool@o`3oobko
oooo1?l0oolSooooo`03oc<0oooooooooooo00Oooooo00?oo`2Iooooooooool0coooool003;ooooo
00?o0000ooooooooool04Oooool00ooo09Woooooooooo`06ooooo`03oc<0oooooooooooo01kooooo
1?l0oom3ooooo`So0?ooI_ooool8o`3ood;ooooo1?l0oolPooooo`03oc<0oooooooooooo00Kooooo
00?oo`2Iooooooooool0coooool003;ooooo00?o0000ooooooooool04Oooool00ooo09Wooooooooo
o`05ooooo`03oc<0oooooooooooo01_ooooo1?l0oom?ooooo`co0?ooC_ooool<o`3oodkooooo0ol0
oolNooooo`03oc<0oooooooooooo00Gooooo00?oo`2Iooooooooool0coooool003;ooooo00?o0000
ooooooooool04Oooool00ooo09Woooooooooo`05ooooo`03oc<0oooooooooooo01Sooooo0ol0oomO
ooooo`_o0?oo=oooool<o`3ooegooooo0ol0oolKooooo`03oc<0oooooooooooo00Kooooo00?oo`2I
ooooooooool0c_ooool003;ooooo00?o0000ooooooooool04?ooool00ooo09Woooooooooo`05oooo
o`03oc<0oooooooooooo01Sooooo00?o0?ooooooooooool0JooooolEo`3oo`cooooo5_l0oom/oooo
o`?o0?oo6Oooool00olc0?ooooooooooo`05ooooo`03ool0VOoooooooooo0<kooooo000Eooooo`Go
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`0@ooooo`03
ool0VOoooooooooo00Gooooo00?o<`3oooooooooool05_ooool2o`3ooh?ooooo3?l0oon5ooooo`;o
0?oo5oooool00olc0?ooooooooooo`05ooooo`03ool0VOoooooooooo0<kooooo000Fooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04?ooool00ooo09Wooooooooo
o`04ooooo`03oc<0oooooooooooo01Cooooo0ol0oooooooooaWooooo0_l0oolFooooo`03oc<0oooo
oooooooo00Cooooo00?oo`2Iooooooooool0c_ooool000oooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool04?ooool00ooo09Woooooooooo`04ooooo`03
oc<0oooooooooooo01;ooooo0_l0oooooooooakooooo0_l0oolDooooo`03oc<0oooooooooooo00Go
oooo00?oo`2Iooooooooool0cOooool001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04
ooooo`?o00003oooool00ooo09Woooooooooo`04ooooo`03oc<0oooooooooooo01;ooooo00?o0?oo
ooooooooool0oooooolPooooo`03o`3ooooooooooooo01;ooooo00?o<`3oooooooooool01?ooool0
0ooo09Woooooooooo`3=ooooo`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool03oooool00ooo09Woooooooooo`04ooooo`03oc<0oooooooooooo017o
oooo00?o0?ooooooooooool0oooooolRooooo`;o0?oo4_ooool00olc0?ooooooooooo`04ooooo`03
ool0VOoooooooooo0<gooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0?ooooo`03ool0VOoooooooooo00?ooooo00?o<`3oooooooooool04?oo
ool2o`3ooooooooo9oooool00ol0ooooooooooooo`0@ooooo`03oc<0oooooooooooo00Cooooo00?o
o`2Iooooooooool0c?ooool001Kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007
ooooo`03o`000?oooooooooo00kooooo00?oo`2Iooooooooool01?ooool00olc0?ooooooooooo`0?
ooooo`03o`3ooooooooooooo0?oooooo:?ooool00ol0ooooooooooooo`0?ooooo`03oc<0oooooooo
oooo00Cooooo00?oo`2Iooooooooool0c?ooool003;ooooo00?o0000ooooooooool03_ooool00ooo
09Woooooooooo`03ooooo`03oc<0oooooooooooo00oooooo00?o0?ooooooooooool0oooooolZoooo
o`;o0?oo3oooool00olc0?ooooooooooo`04ooooo`03ool0VOoooooooooo0<cooooo000booooo`03
o`000?oooooooooo00kooooo00?oo`2Iooooooooool00oooool00olc0?ooooooooooo`0>ooooo`03
o`3ooooooooooooo0?oooooo;Oooool00ol0ooooooooooooo`0=ooooo`03oc<0oooooooooooo00?o
oooo00?oo`2Iooooooooool0c?ooool003;ooooo00?o0000ooooooooool03Oooool00ooo09Wooooo
ooooo`04ooooo`03oc<0oooooooooooo00gooooo00?o0?ooooooooooool0ooooool_ooooo`03o`3o
oooooooooooo00cooooo00?o<`3oooooooooool01?ooool00ooo09Woooooooooo`3;ooooo`00<_oo
ool00ol0003oooooooooo`0=ooooo`03ool0VOoooooooooo00?ooooo00?o<`3oooooooooool03Ooo
ool00ol0ooooooooooooo`3ooooooc7ooooo00?o0?ooooooooooool03?ooool00olc0?oooooooooo
o`03ooooo`03ool0VOoooooooooo0<_ooooo000booooo`03o`000?oooooooooo00gooooo00?oo`2I
ooooooooool00oooool00olc0?ooooooooooo`0<ooooo`03o`3ooooooooooooo0?oooooo<oooool0
0ol0ooooooooooooo`0;ooooo`03oc<0oooooooooooo00?ooooo00?oo`2Iooooooooool0boooool0
03;ooooo00?o0000ooooooooool03?ooool00ooo09Woooooooooo`03ooooo`03oc<0oooooooooooo
00cooooo00?o0?ooooooooooool0ooooooleooooo`03o`3ooooooooooooo00_ooooo00?o<`3ooooo
ooooool00oooool00ooo09Woooooooooo`3:ooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03
ool0VOoooooooooo00?ooooo00?o<`3oooooooooool02oooool00ol0ooooooooooooo`3oooooocOo
oooo00?o0?ooooooooooool02_ooool00olc0?ooooooooooo`03ooooo`03ool0VOoooooooooo0<[o
oooo000booooo`;o00003Oooool00ooo09Woooooooooo`03ooooo`03oc<0oooooooooooo00[ooooo
00?o0?ooooooooooool0ooooooliooooo`03o`3ooooooooooooo00Wooooo00?o<`3oooooooooool0
0oooool00ooo09Woooooooooo`3:ooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03ool0VOoo
oooooooo00;ooooo00?o<`3oooooooooool02_ooool00ol0ooooooooooooo`3ooooooc_ooooo00?o
0?ooooooooooool02Oooool00olc0?ooooooooooo`02ooooo`03ool0VOoooooooooo0<[ooooo000b
ooooo`03o`000?oooooooooo00_ooooo00?oo`2Iooooooooool00oooool00olc0?ooooooooooo`09
ooooo`03o`3ooooooooooooo0?oooooo??ooool00ol0ooooooooooooo`09ooooo`03oc<0oooooooo
oooo00?ooooo00?oo`2Iooooooooool0bOooool003;ooooo00?o0000ooooooooool02oooool00ooo
09Woooooooooo`02ooooo`03oc<0oooooooooooo00[ooooo00?o0?ooooooooooool0oooooolmoooo
o`03o`3ooooooooooooo00Wooooo00?o<`3oooooooooool00_ooool00ooo09Woooooooooo`39oooo
o`00<_ooool00ol0003oooooooooo`0;ooooo`03ool0VOoooooooooo00;ooooo00?o<`3ooooooooo
ool02Oooool00ol0ooooooooooooo`3oooooocoooooo00?o0?ooooooooooool02?ooool00olc0?oo
ooooooooo`02ooooo`03ool0VOoooooooooo0<Wooooo000booooo`03o`000?oooooooooo00_ooooo
00?oo`2Iooooooooool00_ooool00olc0?ooooooooooo`08ooooo`03o`3ooooooooooooo0?oooooo
@Oooool00ol0ooooooooooooo`08ooooo`05oc<0oooooooooooooooooooo09T0boooool003;ooooo
00?o0000ooooooooool02oooool01Ooo09Wooooooooooooooooo<`3o00[ooooo00?o0?oooooooooo
ool0oooooom3ooooo`03o`3ooooooooooooo00Oooooo00Go<`3oooooooooooooooooool0V@3;oooo
o`00<_ooool00ol0003oooooooooo`0:ooooo`03ool0VOoooooooooo00;ooooo00?o<`3ooooooooo
ool02?ooool00ol0ooooooooooooo`3ooooood?ooooo00?o0?ooooooooooool01oooool00olc0?oo
ooooooooo`02ooooo`03ool0VOoooooooooo0<Sooooo000booooo`03o`000?oooooooooo00[ooooo
00?oo`2Iooooooooool00_ooool00olc0?ooooooooooo`07ooooo`03o`3ooooooooooooo0?oooooo
AOooool00ol0ooooooooooooo`07ooooo`05oc<0oooooooooooooooooooo09T0b_ooool003;ooooo
00?o0000ooooooooool02_ooool01Ooo09Wooooooooooooooooo<`3o00Wooooo00?o0?oooooooooo
ool0oooooom7ooooo`03o`3ooooooooooooo00Kooooo00Go<`3oooooooooooooooooool0V@3:oooo
o`00<_ooool2o`0000_ooooo00Goo`2Ioooooooooooooooooc<0o`09ooooo`03o`3ooooooooooooo
0?ooooooB?ooool00ol0ooooooooooooo`05ooooo`05oc<0oooooooooooooooooooo09T0b_ooool0
03;ooooo00?o0000ooooooooool02_ooool01?oo09Wooooooooooolc0?l9ooooo`03o`3ooooooooo
oooo0?ooooooB_ooool00ol0ooooooooooooo`05ooooo`05oc<0oooooooooooooooooooo09T0bOoo
ool003;ooooo00?o0000ooooooooool02Oooool01Ooo09Wooooooooooooooooo<`3o00Sooooo00?o
0?ooooooooooool0oooooom;ooooo`03o`3ooooooooooooo00Gooooo00Go<`3ooooooooooooooooo
ool0V@39ooooo`00<_ooool00ol0003oooooooooo`09ooooo`05ool0VOoooooooooooooooolc0?l0
1oooool00ol0ooooooooooooo`3oooooodgooooo00?o0?ooooooooooool01?ooool01Olc0?oooooo
ooooooooooooo`2I0<Wooooo000booooo`03o`000?oooooooooo00Wooooo00Coo`2Ioooooooooooo
<`3o2?ooool00ol0ooooooooooooo`3oooooodgooooo00?o0?ooooooooooool01Oooool01?lc0?oo
oooooooooooo09W9ooooo`00<_ooool00ol0003oooooooooo`09ooooo`04ool0VOoooooooooooc<0
o`Oooooo00?o0?ooooooooooool0oooooom?ooooo`03o`3ooooooooooooo00Cooooo00Go<`3ooooo
ooooooooooooool0V@38ooooo`00<_ooool00ol0003oooooooooo`08ooooo`05ool0VOoooooooooo
oooooolc0?l01_ooool00ol0ooooooooooooo`3ooooooe3ooooo00?o0?ooooooooooool01?ooool0
1Olc0?ooooooooooooooooooo`2I0<Sooooo000booooo`03o`000?oooooooooo00Sooooo00Coo`2I
oooooooooooo<`3o1oooool00ol0ooooooooooooo`3ooooooe7ooooo00?o0?ooooooooooool00ooo
ool01Olc0?ooooooooooooooooooo`2I0<Sooooo000booooo`03o`000?oooooooooo00Sooooo00Co
o`2Ioooooooooooo<`3o1_ooool00ol0ooooooooooooo`3ooooooe;ooooo00?o0?ooooooooooool0
1?ooool01?lc0?oooooooooooooo09W8ooooo`00<_ooool00ol0003oooooooooo`08ooooo`04ool0
VOoooooooooooc<0o`Kooooo00?o0?ooooooooooool0oooooomCooooo`03o`3ooooooooooooo00?o
oooo00Co<`3oooooooooooooo`2Ib?ooool003;ooooo00?o0000ooooooooool02?ooool00ooo09Wo
oooooc<0o`06ooooo`03o`3ooooooooooooo0?ooooooE?ooool00ol0ooooooooooooo`03ooooo`05
oc<0oooooooooooooooooooo09T0aoooool003;ooooo0_l00008ooooo`04ool0VOoooooooooooc<0
o`Gooooo00?o0?ooooooooooool0oooooomFooooo`03o`3ooooooooooooo00?ooooo00Co<`3ooooo
ooooooooo`2Iaoooool003;ooooo00?o0000ooooooooool01oooool01?oo09Wooooooooooolc0?l5
ooooo`03o`3ooooooooooooo01_ooooo3_lco`3oooooo`?ooooo3Olco`0Mooooo`03o`3ooooooooo
oooo00?ooooo00Co<`3oooooooooooooo`2Iaoooool003;ooooo00?o0000ooooooooool01oooool0
0ooo09Wooooooc<0o`05ooooo`03o`3ooooooooooooo01Kooooo1_lco`0>ooooo`Oo<ol0loooool8
oc?o00gooooo1_lco`0Hooooo`03o`3ooooooooooooo00;ooooo00Co<`3oooooooooooooo`2Iaooo
ool003;ooooo00?o0000ooooooooool01oooool00ooo09Wooooooc<0o`05ooooo`03o`3ooooooooo
oooo01;ooooo1?lco`0Kooooo`Ko<ol0jOooool4oc?o01_ooooo0olco`0Eooooo`03o`3ooooooooo
oooo00;ooooo00Go<`3oooooooooooooooooool0V@36ooooo`00<_ooool00ol0003oooooooooo`06
ooooo`04ool0VOoooooooooooc<0o`Cooooo00?o0?ooooooooooool04Oooool2oc?o02Gooooo1_lc
o`3Kooooo`So<ol08_ooool3oc?o01?ooooo00?o0?ooooooooooool00_ooool01?lc0?oooooooooo
oooo09W6ooooo`00<_ooool00ol0003oooooooooo`06ooooo`03ool0VOoooooo<`3o00Gooooo00?o
0?ooooooooooool03oooool2oc?o02gooooo1?lco`3Dooooo`?o<ol0;Oooool2oc?o017ooooo00?o
0?ooooooooooool00_ooool01?lc0?oooooooooooooo09W6ooooo`00<_ooool00ol0003ooooooooo
o`06ooooo`03ool0VOoooooo<`3o00Gooooo00?o0?ooooooooooool03Oooool2oc?o03?ooooo0olc
o`3>ooooo`?o<ol0<_ooool2oc?o013ooooo00Go0?oooooooooooooooooooc<0o`02ooooo`03ool0
VOoooooooooo0<Cooooo000booooo`03o`000?oooooooooo00Kooooo00?oo`2Ioooooolc0?l01?oo
ool00ol0ooooooooooooo`0<ooooo`;o<ol0>?ooool4oc?o0<Oooooo0olco`0gooooo`;o<ol03_oo
ool01Ol0oooooooooooooooooooo<`3o00?ooooo00?oo`2Iooooooooool0`oooool003;ooooo00?o
0000ooooooooool01_ooool00ooo09Wooooooc<0o`04ooooo`03o`3ooooooooooooo00_ooooo00?o
<ol0ooooooooool0??ooool4oc?o0<3ooooo0olco`0looooo`;o<ol03Oooool01Ol0oooooooooooo
oooooooo<`3o00;ooooo00?oo`2Iooooooooool0`oooool003;ooooo00?o0000ooooooooool01Ooo
ool00ooo09Wooooooc<0o`04ooooo`03o`3ooooooooooooo00_ooooo00?o<ol0ooooooooool0@Ooo
ool3oc?o0;Wooooo1?lco`11ooooo`03oc?o0?oooooooooo00[ooooo00Go0?oooooooooooooooooo
oc<0o`02ooooo`03ool0VOoooooooooo0<?ooooo000booooo`03o`000?oooooooooo00Gooooo00?o
o`2Ioooooolc0?l01?ooool00ol0ooooooooooooo`09ooooo`;o<ol0Aoooool4oc?o0;7ooooo1?lc
o`16ooooo`03oc?o0?oooooooooo00[ooooo00Co0?oooooooooooooo<`3o0_ooool00ooo09Wooooo
ooooo`33ooooo`00<_ooool2o`0000Kooooo00?oo`2Ioooooolc0?l00oooool00ol0oooooooooooo
o`09ooooo`03oc?o0?oooooooooo04_ooooo0olco`2Zooooo`Co<ol0Boooool00olco`3ooooooooo
o`09ooooo`07o`3ooooooooooooooooooolc0?ooooooool0V@35ooooo`00<_ooool00ol0003ooooo
ooooo`05ooooo`03ool0VOoooooo<`3o00?ooooo00?o0?ooooooooooool02?ooool00olco`3ooooo
ooooo`1?ooooo`?o<ol0Xoooool4oc?o053ooooo00?o<ol0ooooooooool02?ooool01Ol0oooooooo
oooooooooooo<`3o00;ooooo00?oo`2Iooooooooool0`_ooool003;ooooo00?o0000ooooooooool0
1Oooool00ooo09Wooooooc<0o`03ooooo`03o`3ooooooooooooo00Oooooo00?o<ol0ooooooooool0
Doooool4oc?o09cooooo0olco`1Eooooo`03oc?o0?oooooooooo00Sooooo00Co0?oooooooooooooo
<`3o0_ooool00ooo09Woooooooooo`32ooooo`00<_ooool00ol0003oooooooooo`04ooooo`03ool0
VOoooooo<`3o00?ooooo00?o0?ooooooooooool01oooool00olco`3oooooooooo`1Hooooo`?o<ol0
U_ooool3oc?o05Wooooo00?o<ol0ooooooooool01oooool01?l0oooooooooooooolc0?l2ooooo`03
ool0VOoooooooooo0<;ooooo000booooo`03o`000?oooooooooo00Cooooo00?oo`2Ioooooolc0?l0
0oooool00ol0ooooooooooooo`06ooooo`03oc?o0?oooooooooo05cooooo0olco`2@ooooo`?o<ol0
GOooool00olco`3oooooooooo`07ooooo`06o`3ooooooooooooooc<0ooooooooo`2Ia?ooool003;o
oooo00?o0000ooooooooool01?ooool00ooo09Wooooooc<0o`02ooooo`03o`3ooooooooooooo00Ko
oooo00?o<ol0ooooooooool0H?ooool3oc?o08[ooooo0olco`1Qooooo`03oc?o0?oooooooooo00Ko
oooo00Ko0?oooooooooooooo<`3ooooooooo09W4ooooo`00<_ooool00ol0003oooooooooo`04oooo
o`03ool0VOoooooo<`3o00;ooooo00?o0?ooooooooooool01Oooool00olco`3oooooooooo`1Toooo
o`?o<ol0Q?ooool3oc?o06Gooooo00?o<ol0ooooooooool01Oooool01_l0oooooooooooooolc0?oo
ooooool0VLCooooo000booooo`03o`000?oooooooooo00Cooooo00?oo`2Ioc<0ooooool00_ooool0
0ol0ooooooooooooo`04ooooo`03oc?o0?oooooooooo06Sooooo1?lco`1kooooo`Go<ol0JOooool0
0olco`3oooooooooo`05ooooo`03o`3ooooooooo<`3o00;ooooo00?oo`2Iooooooooool0`Oooool0
01Kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
00?ooooo00?oo`2Ioooooolc0?l00_ooool00ol0ooooooooooooo`05ooooo`03oc?o0?oooooooooo
06cooooo1?lco`1booooo`Go<ol0K_ooool00olco`3oooooooooo`05ooooo`06o`3ooooooooooooo
oc<0ooooooooo`2I`oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`03ooooo`03ool0VOoooooo<`3o00;ooooo00?o0?ooooooooooool01?ooool00olco`3o
ooooooooo`1aooooo`?o<ol0J_ooool5oc?o07Cooooo00?o<ol0ooooooooool01?ooool01_l0oooo
oooooooooolc0?ooooooool0VL?ooooo000?ooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00?ooooo00?oo`2Ioooooolc0?l00_ooool00ol0oooooooo
ooooo`03ooooo`03oc?o0?oooooooooo07Gooooo1?lco`1Qooooo`Go<ol0NOooool00olco`3ooooo
ooooo`05ooooo`05o`3ooooooooo<`3ooooooooo09T0`oooool001Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001_ooool3o`0000?ooooo00Goo`2Ioooooolc0?ooooooo`3oo`06ooooo`03oc?o0?oo
oooooooo07Wooooo1_lco`1Gooooo`Co<ol0Ooooool00olco`3oooooooooo`04ooooo`05o`3ooooo
oooo<`3ooooooooo09T0`oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`03ooooo`05ool0VOlc0?ooooooooooool0ool01Oooool00olco`3oooooooooo`20
ooooo`Ko<ol0C?ooool5oc?o08Cooooo00?o<ol0ooooooooool00oooool01Ol0oooooooooooooolc
0?ooo`2I0<?ooooo000Fooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`05
ool0VOlc0?ooooooooooool0ool01?ooool00olco`3oooooooooo`27ooooo`Go<ol0@oooool4oc?o
08Wooooo00?o<ol0ooooooooool01?ooool01?l0oooooooooc<0oooo09W3ooooo`005oooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
00;ooooo00Goo`2Ioooooolc0?ooooooo`3oo`05ooooo`03oc?o0?oooooooooo08cooooo1_lco`0g
ooooo`Ko<ol0S_ooool00olco`3oooooooooo`03ooooo`05o`3ooooooooo<`3ooooooooo09T0`_oo
ool003;ooooo00?o0000ooooooooool00_ooool01Ooo09Wooooooc<0oooooooo0?oo00Cooooo00?o
<ol0ooooooooool0Toooool>oc?o01_ooooo3_lco`2Dooooo`03oc?o0?oooooooooo00?ooooo00Go
0?oooooooolc0?ooooooool0V@32ooooo`00<_ooool00ol0003oooooooooo`02ooooo`05ool0VOoo
oooo<`3oooooool0ool01?ooool00olco`3oooooooooo`2Qoooooa_o<ol0Xoooool00olco`3ooooo
ooooo`03ooooo`04o`3ooooooooo<`3oool0VL;ooooo000booooo`03o`000?oooooooooo00;ooooo
00Coo`2Ioc<0oooooooo0?oo1?ooool00olco`3oooooooooo`3oooooof7ooooo00?o<ol0oooooooo
ool00oooool01?l0oooooooooc<0oooo09W2ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04
ool0VOlc0?ooooooo`3oo`?ooooo00?o<ol0ooooooooool0oooooomSooooo`03oc?o0?oooooooooo
00;ooooo00Co0?oooooooolc0?ooo`2I`_ooool003;ooooo00?o0000ooooooooool00_ooool01?oo
09Wo<`3oooooool0ool3ooooo`03oc?o0?oooooooooo0?ooooooI?ooool02?lco`3ooooooooooooo
oooo0?oooooooolc0?ooo`2I`_ooool003;ooooo00?o0000ooooooooool00_ooool00ooo09Wo<`3o
o`3oo`03ooooo`03oc?o0?oooooooooo0?ooooooIOooool00olco`3oooooooooo`02ooooo`03o`3o
ooooooooo`2I0<;ooooo000booooo`08o`000?oooooooooooooooooo09Wooooooc<0ool0ool3oooo
o`03oc?o0?oooooooooo0?ooooooI_ooool01olco`3ooooooooooooooooo0?oooooooooo09T0`_oo
ool003;ooooo0_l00002ooooo`04ool0VOlc0?ooooooo`3oo`;ooooo00?o<ol0ooooooooool0oooo
oomWooooo`08oc?o0?ooooooooooooooool0oooooooooc<0oooo09W1ooooo`00<_ooool02?l0003o
ooooooooooooooooo`2Ioc<0oooooooo0?oo0_ooool00olco`3oooooooooo`3oooooofSooooo00Oo
<ol0ooooooooooooooooo`3ooolc0?ooo`2I0<7ooooo000booooo`07o`000?oooooooooooooooooo
09Wo<`3oo`3oo`03ooooo`03oc?o0?oooooooooo0?ooooooJ?ooool01olco`3ooooooooooooooooo
0?oooc<0oooo09T0`Oooool003;ooooo00Oo0000ooooooooooooooooool0VOlc0?oo0?oo00;ooooo
00?o<ol0ooooooooool0oooooomYooooo`07oc?o0?ooooooooooooooool0ooooooooool0V@31oooo
o`00<_ooool01ol0003oooooooooooooooooo`2Ioc<0ool0ool00_ooool00olco`3oooooooooo`3o
ooooof[ooooo00Ko<ol0oooooooooooo0?oooooooooo09W1ooooo`00<_ooool02Ol0003ooooooooo
oooo09Wo<`3oooooool0oooooooooc?o003oooooofgooooo00Ko<ol0ooooooooooooooooo`3ooooo
09W1ooooo`00<_ooool02Ol0003ooooooooooooo09Wo<`3oooooool0oooooooooc?o003oooooofko
oooo00Go<ol0oooooooooooo0?ooool0V@31ooooo`00<_ooool01_l0003ooooooooooooo09Wo<`3o
o`3oo`;ooooo00?o<ol0ooooooooool0oooooom/ooooo`05oc?o0?ooooooooooo`3ooooo09T0`Ooo
ool003;ooooo00So0000ooooooooooooo`2Ioc<0ool0oooooooooc?o0?ooooooKoooool01_lco`3o
ooooooooool0oooo<`3oool0VL3ooooo000booooo`08o`000?ooooooooooool0VOlc0?oo0?oooooo
oolco`3oooooog3ooooo00Go<ol0ooooool0ooooooooool0V@30ooooo`00<_ooool02?l0003ooooo
oooooooo09Woooooo`3ooooooooo<ol0oooooom`ooooo`05oc?o0?ooooooooooo`3ooooo09T0`?oo
ool003;ooooo0_l000001Ooo09Wo<`3oo`3ooooooooo<ol00?ooooooL_ooool01?lco`3oooooo`3o
oooo09W0ooooo`00<_ooool01ol0003oooooool0VOlc0?oo0?oooooooolco`00oooooombooooo`04
oc?o0?oooooo0?ooool0VL3ooooo000booooo`07o`000?ooooooo`2Ioc<0ool0oooooooooc?o003o
ooooog;ooooo00Co<ol0ooooool0ooooo`2I`?ooool003;ooooo00Ko0000oooooooo09Wo<`3oo`3o
oolco`3oooooogCooooo00?o<ol0o`3ooooo09T0`?ooool003;ooooo00Ko0000oooooooo09Wo<`3o
o`3ooolco`3oooooogCooooo00Co<ol0o`3ooooo09Wo<`3o_oooool003;ooooo00Ko0000oooooooo
09Wo0?oooooooolco`3oooooogCooooo00Co<ol0ooooool0ooooo`2I_oooool003;ooooo00Ko0000
oooooooo09Wo0?oooooooolco`3oooooogCooooo00Co<ol0ooooool0ooooo`2I_oooool003;ooooo
00Go0000ool0VOlc0?oo0?oooc?o003oooooogKooooo00?o<ol0o`3ooooo09T0_oooool003;ooooo
00Go0000ool0VOlc0?oo0?oooc?o003oooooogKooooo00?o<ol0o`3ooooo09T0_oooool003;ooooo
00Go0000ool0VOlc0?oooooooc?o003oooooogKooooo00?o<ol0o`3ooooo09T0_oooool003;ooooo
00Co0000ool0VOlc0?oo<ol0oooooomhooooo`03oc?o0?oo09Wo<`3o0;kooooo000booooo`04o`00
0?oo09Wo0?oooc?o0?ooooooN?ooool00olco`3oo`2Ioc<0o`2nooooo`00<_ooool01?l0003oo`2I
o`3ooolco`3oooooogSooooo00?o<ol0ool0VOlc0?l0__ooool003;ooooo00Co0000ool0VOl0oooo
<ol0oooooomhooooo`03oc?o0?oo09Wo<`3o0;kooooo000booooo`03o`000?oo09Wo<ol00?oooooo
N_ooool00ol0ooooo`2Iooooo`2mooooo`00<_ooool00ol0003oo`2Ioc?o003oooooog[ooooo00?o
0?ooool0VOooool0_Oooool003;ooooo00?oo`2Ioc<0oolco`00oooooomjooooo`03oc?o0?oo09Wo
oooo0;gooooo000booooo`03ool0VOlc0?oo<ol00?ooooooN_ooool00olco`3oo`2Iooooo`2moooo
o`00<_ooool00ooo09Wo0?ooooooo`3oooooog_ooooo00?oo`2Iooooooooool0_?ooool003;ooooo
00?oo`2Io`3oooooool0@_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000nooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`?o0000?Oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0003oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00014ooooo`03
ool0VOlc0?oo00000;cooooo000booooo`03ool0VOlco`3ooooo047ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool0000mooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool0>oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
?Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000@oooool00ooo
09Wo<`3oooooo`2looooo`00<_ooool00ooo09Wo<ol0ooooo`11ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0?Oooool01?l0003oooooooooool00007ooooo`Go0000??ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000?Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool00000@oooool00ol0ooooo`2Iooooo`2loooo
o`00<_ooool00ooo09Woooooooooo`11ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool0??ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0003gooooo00Co
0000oooooooooooo00001oooool4o`0003kooooo00Co0000oooooooooooo00002?ooool3o`0004Co
oooo00?o0?ooool0VOooool0_?ooool003;ooooo00?oo`2Iooooooooool0@Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool00000?Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000003gooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0oooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`03
oc?o0?oo09Wooooo0;cooooo000booooo`03ool0VOoooooooooo047ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000003gooooo00Co0000oooooooooooo00002Oooool2
o`0003gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0nooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`03o`000?oo09Wooooo0;co
oooo000booooo`03ool0VOoooooooooo04;ooooo0_l00009ooooo`?o0000?oooool2o`0000_ooooo
00?o0000ooooooooool0??ooool2o`0000[ooooo0_l0000oooooo`;o00002Oooool3o`0004Gooooo
00?oo`2Iooooooooool0^oooool003;ooooo00?oo`2Iooooooooool0oooooomlooooo`03ool0VOoo
oooooooo0;_ooooo000booooo`03ool0VOoooooooooo0?ooooooO?ooool00ooo09Woooooooooo`2k
ooooo`00<_ooool00ooo09Woooooooooo`3oooooogcooooo00?oo`2Ioc<0ooooool0^oooool003;o
oooo00?oo`2Iooooooooool0oooooomlooooo`03o`3ooooo09Wooooo0;_ooooo000booooo`03ool0
VOoooooooooo0?ooooooOOooool00ooo09Woooooooooo`0Booooo`;o000000Coooooo`000?l0003o
oooo1?l0002Nooooo`00<_ooool00ooo09Woooooooooo`3ooooooggooooo00?oo`2Iooooooooool0
4oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0009gooooo000Xooooo`[o0000
00?oo`2Io`000?l00000ool0001mo`000003ool0VOl0003o000000Oo00003Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0009gooooo000booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo
0ol0002Nooooo`00<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0009gooooo
000booooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000WOooool003;ooooo00?o
0000ooooooooool0oooooonBooooo`;o000000Coooooo`000?l0003ooooo1?l0002Nooooo`00<_oo
ool00ol0003oooooooooo`3ooooooooooooo>oooool003;ooooo00?o0000ooooooooool0oooooooo
oooooc_ooooo003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo
003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003ooooooooo
ooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool0
0?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool002cooooo1Ol0
00001?oooooo0000o`000?l0003ooooooooooooo>oooool002gooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`3ooooooooooooo>_ooool002gooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`3ooooooooooooo>_ooool002kooooo00?o0000ooooooooool00_ooool3o`00
0?ooooooooooooljooooo`00;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
ooooooooooljooooo`00;_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`000?oo
ooooooooooliooooo`00<_ooool5o`000?ooooooooooooliooooo`00ooooooooooooog3ooooo003o
ooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003ooooooooooooo
L?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool00?oo
oooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool00?oooooooooooom`
ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool00?oooooooooooom`ooooo`00oooo
ooooooooog3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 621}, {397.188, 0}} -> {-1.06651, -1.09171, \
0.00440965, 0.00440965}, {{15.0625, 468.625}, {289.75, 9.4375}} -> \
{-0.130814, -6545.18, 0.00261159, 18.4426}, {{468.625, 594.562}, {376.375, \
194.938}} -> {-12.603, -0.655666, 0.0266802, 0.0266802}, {{475.312, 512.812}, \
{369.562, 332.125}} -> {-13.3339, -4.19925, 0.0280003, 0.0906108}, {{475.312, \
512.812}, {326.125, 288.625}} -> {-13.3339, -8.13799, 0.0280003, 0.0906108}, \
{{475.312, 512.812}, {282.625, 245.125}} -> {-13.3339, -12.0796, 0.0280003, \
0.0906108}, {{475.312, 512.812}, {239.125, 201.688}} -> {-13.3339, -16.0183, \
0.0280003, 0.0906108}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here is a 3D representation of the free energy surface \
\[CapitalDelta]F(XB,T):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\[CapitalDelta]F[XB, 0, T], {XB, 0.01, 0.99}, {T, 300, 1500}, 
      AxesLabel \[Rule] {XB, T, \[CapitalDelta]F}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.62961e-17 1.04977 -0.0679587 1.04977 [
[.14227 .20104 -17.9089 -9 ]
[.14227 .20104 .09106 0 ]
[.26884 .15124 -17.1431 -9 ]
[.26884 .15124 .85695 0 ]
[.40182 .09894 -16.3772 -9 ]
[.40182 .09894 1.62284 0 ]
[.54173 .04395 -15.6113 -9 ]
[.54173 .04395 2.38873 0 ]
[.29165 .07573 -14.8979 -12 ]
[.29165 .07573 1.10213 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 18 2.82223 ]
[.82083 .17876 0 -6.08311 ]
[.82083 .17876 18 2.91689 ]
[.87924 .26821 0 -5.99856 ]
[.87924 .26821 24 3.00144 ]
[.93273 .35014 0 -5.92258 ]
[.93273 .35014 24 3.07742 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.0144 .32601 -30 -2.79382 ]
[.0144 .32601 0 6.20618 ]
[.00161 .40612 -6 -2.86188 ]
[.00161 .40612 0 6.13812 ]
[-0.01184 .49043 -24 -2.93388 ]
[-0.01184 .49043 0 6.06612 ]
[-0.05457 .39542 -16 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.1515 .21036 m
.15612 .21503 L
s
[(0.2)] .14227 .20104 .98988 1 Mshowa
.27764 .16097 m
.28204 .16584 L
s
[(0.4)] .26884 .15124 .90478 1 Mshowa
.41014 .10909 m
.4143 .11416 L
s
[(0.6)] .40182 .09894 .81968 1 Mshowa
.5495 .05452 m
.55338 .05981 L
s
[(0.8)] .54173 .04395 .73459 1 Mshowa
.125 Mabswid
.06081 .24588 m
.06366 .24859 L
s
.09068 .23418 m
.09351 .23692 L
s
.12091 .22234 m
.12371 .22511 L
s
.18247 .19824 m
.18521 .20107 L
s
.21381 .18597 m
.21651 .18883 L
s
.24553 .17355 m
.2482 .17644 L
s
.31015 .14824 m
.31276 .15119 L
s
.34306 .13535 m
.34564 .13834 L
s
.37639 .1223 m
.37893 .12532 L
s
.44432 .09571 m
.44677 .09878 L
s
.47893 .08215 m
.48134 .08526 L
s
.51399 .06843 m
.51636 .07157 L
s
.58547 .04044 m
.58776 .04364 L
s
.62192 .02616 m
.62416 .0294 L
s
.65884 .01171 m
.66104 .01497 L
s
gsave
.29165 .07573 -75.8979 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(500)] .75679 .08071 -1 .37284 Mshowa
.80845 .18312 m
.80226 .18529 L
s
[(750)] .82083 .17876 -1 .3518 Mshowa
.86679 .27235 m
.86056 .27443 L
s
[(1000)] .87924 .26821 -1 .33301 Mshowa
.92022 .35409 m
.91397 .35607 L
s
[(1250)] .93273 .35014 -1 .31613 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1500)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75778 .10561 m
.75408 .10697 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.87784 .28927 m
.87411 .2905 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.93037 .36962 m
.92662 .3708 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
.73096 .06459 m
.72728 .06598 L
s
.71716 .04348 m
.71349 .04489 L
s
.70309 .02196 m
.69942 .02338 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02667 .32136 m
.0328 .31903 L
s
[(-5000)] .0144 .32601 1 -0.37915 Mshowa
.01394 .40163 m
.02011 .39939 L
s
[(0)] .00161 .40612 1 -0.36403 Mshowa
.00056 .48612 m
.00675 .48396 L
s
[(5000)] -0.01184 .49043 1 -0.34803 Mshowa
.125 Mabswid
.02417 .33709 m
.02786 .3357 L
s
.02165 .35298 m
.02534 .35161 L
s
.01911 .36904 m
.0228 .36767 L
s
.01654 .38525 m
.02024 .38389 L
s
.01132 .41818 m
.01503 .41685 L
s
.00867 .4349 m
.01238 .43358 L
s
.006 .4518 m
.00971 .45048 L
s
.00329 .46887 m
.007 .46756 L
s
.02913 .30578 m
.03281 .30437 L
s
.03158 .29035 m
.03525 .28894 L
s
.034 .27508 m
.03767 .27366 L
s
.0364 .25996 m
.04006 .25852 L
s
gsave
-0.05457 .39542 -77 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.872 .762 .738 r
.38794 .70565 .40118 .71639 .42424 .67603 .4112 .6668 Metetra
.848 .793 .798 r
.4112 .6668 .42424 .67603 .44676 .64862 .4339 .64044 Metetra
.827 .818 .84 r
.4339 .64044 .44676 .64862 .4691 .62707 .45641 .61972 Metetra
.806 .839 .875 r
.45641 .61972 .4691 .62707 .49139 .60916 .47888 .60248 Metetra
.784 .856 .904 r
.47888 .60248 .49139 .60916 .51371 .59379 .50137 .58765 Metetra
.761 .87 .928 r
.50137 .58765 .51371 .59379 .53609 .58031 .52394 .5746 Metetra
.737 .88 .946 r
.52394 .5746 .53609 .58031 .55859 .56831 .54663 .56293 Metetra
.712 .886 .961 r
.54663 .56293 .55859 .56831 .58122 .5575 .56945 .55237 Metetra
.686 .89 .972 r
.56945 .55237 .58122 .5575 .604 .54769 .59243 .54274 Metetra
.662 .89 .98 r
.59243 .54274 .604 .54769 .62696 .53876 .61558 .53389 Metetra
.637 .888 .986 r
.61558 .53389 .62696 .53876 .65012 .53061 .63893 .52576 Metetra
.613 .883 .99 r
.63893 .52576 .65012 .53061 .67349 .5232 .6625 .5183 Metetra
.59 .876 .993 r
.6625 .5183 .67349 .5232 .69709 .51652 .68629 .51149 Metetra
.566 .867 .996 r
.68629 .51149 .69709 .51652 .72093 .51059 .71032 .50536 Metetra
.542 .855 .997 r
.71032 .50536 .72093 .51059 .74506 .50547 .73463 .49995 Metetra
.517 .841 .999 r
.73463 .49995 .74506 .50547 .76949 .50124 .75924 .49537 Metetra
.489 .822 .999 r
.75924 .49537 .76949 .50124 .79425 .49806 .78417 .49174 Metetra
.457 .799 .999 r
.78417 .49174 .79425 .49806 .81941 .49614 .80948 .48928 Metetra
.417 .768 .996 r
.80948 .48928 .81941 .49614 .84502 .49577 .83523 .48827 Metetra
.365 .727 .988 r
.83523 .48827 .84502 .49577 .87117 .49741 .8615 .48916 Metetra
.295 .67 .973 r
.8615 .48916 .87117 .49741 .898 .50176 .88842 .49262 Metetra
.193 .586 .942 r
.88842 .49262 .898 .50176 .92572 .51001 .9162 .4998 Metetra
.029 .447 .873 r
.9162 .4998 .92572 .51001 .95474 .52455 .94522 .51303 Metetra
0 .163 .675 r
.94522 .51303 .95474 .52455 .98626 .553 .97663 .53967 Metetra
.869 .764 .744 r
.37449 .69475 .38794 .70565 .4112 .6668 .39793 .65741 Metetra
.842 .795 .805 r
.39793 .65741 .4112 .6668 .4339 .64044 .4208 .63212 Metetra
.82 .819 .848 r
.4208 .63212 .4339 .64044 .45641 .61972 .44349 .61224 Metetra
.799 .84 .882 r
.44349 .61224 .45641 .61972 .47888 .60248 .46613 .59567 Metetra
.776 .856 .911 r
.46613 .59567 .47888 .60248 .50137 .58765 .48881 .58138 Metetra
.752 .87 .933 r
.48881 .58138 .50137 .58765 .52394 .5746 .51156 .56877 Metetra
.728 .879 .951 r
.51156 .56877 .52394 .5746 .54663 .56293 .53443 .55745 Metetra
.704 .885 .964 r
.53443 .55745 .54663 .56293 .56945 .55237 .55744 .54714 Metetra
.68 .889 .974 r
.55744 .54714 .56945 .55237 .59243 .54274 .58062 .53768 Metetra
.656 .889 .982 r
.58062 .53768 .59243 .54274 .61558 .53389 .60397 .52893 Metetra
.634 .887 .987 r
.60397 .52893 .61558 .53389 .63893 .52576 .62752 .52082 Metetra
.612 .883 .99 r
.62752 .52082 .63893 .52576 .6625 .5183 .65128 .5133 Metetra
.591 .877 .993 r
.65128 .5133 .6625 .5183 .68629 .51149 .67526 .50636 Metetra
.57 .869 .995 r
.67526 .50636 .68629 .51149 .71032 .50536 .69949 .50001 Metetra
.55 .858 .997 r
.69949 .50001 .71032 .50536 .73463 .49995 .72399 .49432 Metetra
.527 .845 .999 r
.72399 .49432 .73463 .49995 .75924 .49537 .74877 .48937 Metetra
.503 .829 .999 r
.74877 .48937 .75924 .49537 .78417 .49174 .77388 .48529 Metetra
.474 .807 .999 r
.77388 .48529 .78417 .49174 .80948 .48928 .79936 .48228 Metetra
.439 .78 .998 r
.79936 .48228 .80948 .48928 .83523 .48827 .82525 .48062 Metetra
.392 .742 .992 r
.82525 .48062 .83523 .48827 .8615 .48916 .85165 .48074 Metetra
.328 .69 .98 r
.85165 .48074 .8615 .48916 .88842 .49262 .87866 .4833 Metetra
.232 .612 .954 r
.87866 .4833 .88842 .49262 .9162 .4998 .9065 .4894 Metetra
.076 .481 .893 r
.9065 .4894 .9162 .4998 .94522 .51303 .93552 .50129 Metetra
0 .204 .709 r
.93552 .50129 .94522 .51303 .97663 .53967 .96683 .52611 Metetra
.865 .765 .751 r
.36082 .68368 .37449 .69475 .39793 .65741 .38445 .64787 Metetra
.837 .796 .813 r
.38445 .64787 .39793 .65741 .4208 .63212 .40748 .62366 Metetra
.813 .82 .856 r
.40748 .62366 .4208 .63212 .44349 .61224 .43034 .60462 Metetra
.79 .841 .89 r
.43034 .60462 .44349 .61224 .46613 .59567 .45315 .58873 Metetra
.767 .857 .917 r
.45315 .58873 .46613 .59567 .48881 .58138 .476 .575 Metetra
.743 .869 .939 r
.476 .575 .48881 .58138 .51156 .56877 .49894 .56283 Metetra
.719 .878 .955 r
.49894 .56283 .51156 .56877 .53443 .55745 .52199 .55185 Metetra
.695 .884 .968 r
.52199 .55185 .53443 .55745 .55744 .54714 .5452 .54181 Metetra
.673 .887 .977 r
.5452 .54181 .55744 .54714 .58062 .53768 .56857 .53252 Metetra
.651 .888 .983 r
.56857 .53252 .58062 .53768 .60397 .52893 .59212 .52386 Metetra
.63 .886 .987 r
.59212 .52386 .60397 .52893 .62752 .52082 .61586 .51577 Metetra
.611 .882 .991 r
.61586 .51577 .62752 .52082 .65128 .5133 .63982 .50819 Metetra
.592 .877 .993 r
.63982 .50819 .65128 .5133 .67526 .50636 .66401 .50111 Metetra
.574 .87 .995 r
.66401 .50111 .67526 .50636 .69949 .50001 .68844 .49456 Metetra
.556 .861 .997 r
.68844 .49456 .69949 .50001 .72399 .49432 .71312 .48857 Metetra
.538 .849 .998 r
.71312 .48857 .72399 .49432 .74877 .48937 .7381 .48324 Metetra
.516 .835 .999 r
.7381 .48324 .74877 .48937 .77388 .48529 .76338 .4787 Metetra
.491 .815 1 r
.76338 .4787 .77388 .48529 .79936 .48228 .78902 .47514 Metetra
.46 .79 .999 r
.78902 .47514 .79936 .48228 .82525 .48062 .81506 .47282 Metetra
.418 .756 .995 r
.81506 .47282 .82525 .48062 .85165 .48074 .84159 .47216 Metetra
.36 .708 .986 r
.84159 .47216 .85165 .48074 .87866 .4833 .86871 .4738 Metetra
.271 .636 .964 r
.86871 .4738 .87866 .4833 .9065 .4894 .89661 .4788 Metetra
.122 .515 .912 r
.89661 .4788 .9065 .4894 .93552 .50129 .92565 .48934 Metetra
0 .246 .742 r
.92565 .48934 .93552 .50129 .96683 .52611 .95686 .51231 Metetra
.86 .767 .758 r
.34694 .67243 .36082 .68368 .38445 .64787 .37073 .63816 Metetra
.83 .798 .821 r
.37073 .63816 .38445 .64787 .40748 .62366 .39393 .61504 Metetra
.806 .822 .864 r
.39393 .61504 .40748 .62366 .43034 .60462 .41694 .59686 Metetra
.781 .841 .897 r
.41694 .59686 .43034 .60462 .45315 .58873 .43992 .58167 Metetra
.757 .857 .924 r
.43992 .58167 .45315 .58873 .476 .575 .46295 .5685 Metetra
.733 .869 .944 r
.46295 .5685 .476 .575 .49894 .56283 .48607 .55678 Metetra
.71 .877 .96 r
.48607 .55678 .49894 .56283 .52199 .55185 .50931 .54615 Metetra
.687 .883 .971 r
.50931 .54615 .52199 .55185 .5452 .54181 .5327 .53636 Metetra
.665 .886 .979 r
.5327 .53636 .5452 .54181 .56857 .53252 .55627 .52725 Metetra
.645 .886 .984 r
.55627 .52725 .56857 .53252 .59212 .52386 .58002 .51869 Metetra
.627 .885 .988 r
.58002 .51869 .59212 .52386 .61586 .51577 .60397 .51061 Metetra
.609 .882 .991 r
.60397 .51061 .61586 .51577 .63982 .50819 .62813 .50297 Metetra
.594 .878 .993 r
.62813 .50297 .63982 .50819 .66401 .50111 .65252 .49576 Metetra
.578 .871 .995 r
.65252 .49576 .66401 .50111 .68844 .49456 .67714 .48899 Metetra
.563 .864 .996 r
.67714 .48899 .68844 .49456 .71312 .48857 .70203 .4827 Metetra
.547 .853 .998 r
.70203 .4827 .71312 .48857 .7381 .48324 .72719 .47699 Metetra
.53 .84 .999 r
.72719 .47699 .7381 .48324 .76338 .4787 .75266 .47198 Metetra
.508 .823 1 r
.75266 .47198 .76338 .4787 .78902 .47514 .77847 .46784 Metetra
.481 .8 1 r
.77847 .46784 .78902 .47514 .81506 .47282 .80467 .46486 Metetra
.444 .77 .997 r
.80467 .46486 .81506 .47282 .84159 .47216 .83133 .46341 Metetra
.39 .726 .99 r
.83133 .46341 .84159 .47216 .86871 .4738 .85856 .46411 Metetra
.309 .66 .972 r
.85856 .46411 .86871 .4738 .89661 .4788 .88653 .46799 Metetra
.169 .547 .928 r
.88653 .46799 .89661 .4788 .92565 .48934 .91559 .47716 Metetra
0 .289 .775 r
.91559 .47716 .92565 .48934 .95686 .51231 .94672 .49827 Metetra
.856 .769 .765 r
.33283 .66099 .34694 .67243 .37073 .63816 .35678 .62829 Metetra
.823 .799 .829 r
.35678 .62829 .37073 .63816 .39393 .61504 .38013 .60627 Metetra
.797 .823 .872 r
.38013 .60627 .39393 .61504 .41694 .59686 .4033 .58896 Metetra
.772 .842 .905 r
.4033 .58896 .41694 .59686 .43992 .58167 .42644 .57447 Metetra
.747 .857 .93 r
.42644 .57447 .43992 .58167 .46295 .5685 .44964 .56186 Metetra
.723 .868 .95 r
.44964 .56186 .46295 .5685 .48607 .55678 .47294 .5506 Metetra
.7 .876 .964 r
.47294 .5506 .48607 .55678 .50931 .54615 .49637 .54033 Metetra
.678 .881 .974 r
.49637 .54033 .50931 .54615 .5327 .53636 .51995 .53081 Metetra
.658 .884 .981 r
.51995 .53081 .5327 .53636 .55627 .52725 .54371 .52187 Metetra
.639 .885 .986 r
.54371 .52187 .55627 .52725 .58002 .51869 .56766 .51341 Metetra
.623 .884 .989 r
.56766 .51341 .58002 .51869 .60397 .51061 .59182 .50535 Metetra
.608 .882 .991 r
.59182 .50535 .60397 .51061 .62813 .50297 .61619 .49765 Metetra
.595 .878 .993 r
.61619 .49765 .62813 .50297 .65252 .49576 .64078 .49029 Metetra
.582 .873 .994 r
.64078 .49029 .65252 .49576 .67714 .48899 .66561 .48329 Metetra
.57 .866 .996 r
.66561 .48329 .67714 .48899 .70203 .4827 .6907 .47671 Metetra
.557 .857 .997 r
.6907 .47671 .70203 .4827 .72719 .47699 .71606 .47061 Metetra
.542 .846 .999 r
.71606 .47061 .72719 .47699 .75266 .47198 .74171 .46511 Metetra
.524 .83 1 r
.74171 .46511 .75266 .47198 .77847 .46784 .7677 .4604 Metetra
.501 .81 1 r
.7677 .4604 .77847 .46784 .80467 .46486 .79406 .45673 Metetra
.468 .782 .998 r
.79406 .45673 .80467 .46486 .83133 .46341 .82086 .45447 Metetra
.42 .742 .993 r
.82086 .45447 .83133 .46341 .85856 .46411 .84821 .45422 Metetra
.346 .682 .979 r
.84821 .45422 .85856 .46411 .88653 .46799 .87626 .45698 Metetra
.215 .578 .942 r
.87626 .45698 .88653 .46799 .91559 .47716 .90534 .46476 Metetra
0 .333 .806 r
.90534 .46476 .91559 .47716 .94672 .49827 .93639 .48398 Metetra
.85 .77 .773 r
.3185 .64937 .33283 .66099 .35678 .62829 .34259 .61825 Metetra
.816 .801 .838 r
.34259 .61825 .35678 .62829 .38013 .60627 .36608 .59735 Metetra
.788 .824 .88 r
.36608 .59735 .38013 .60627 .4033 .58896 .3894 .58091 Metetra
.761 .842 .913 r
.3894 .58091 .4033 .58896 .42644 .57447 .41271 .56713 Metetra
.736 .856 .937 r
.41271 .56713 .42644 .57447 .44964 .56186 .43607 .5551 Metetra
.712 .867 .955 r
.43607 .5551 .44964 .56186 .47294 .5506 .45954 .5443 Metetra
.689 .874 .968 r
.45954 .5443 .47294 .5506 .49637 .54033 .48316 .53439 Metetra
.669 .879 .977 r
.48316 .53439 .49637 .54033 .51995 .53081 .50694 .52514 Metetra
.65 .882 .983 r
.50694 .52514 .51995 .53081 .54371 .52187 .53089 .51638 Metetra
.634 .883 .987 r
.53089 .51638 .54371 .52187 .56766 .51341 .55505 .50802 Metetra
.619 .883 .989 r
.55505 .50802 .56766 .51341 .59182 .50535 .57941 .49997 Metetra
.607 .881 .991 r
.57941 .49997 .59182 .50535 .61619 .49765 .60399 .49221 Metetra
.596 .878 .992 r
.60399 .49221 .61619 .49765 .64078 .49029 .62879 .4847 Metetra
.586 .874 .994 r
.62879 .4847 .64078 .49029 .66561 .48329 .65383 .47748 Metetra
.577 .869 .995 r
.65383 .47748 .66561 .48329 .6907 .47671 .67912 .47058 Metetra
.567 .861 .996 r
.67912 .47058 .6907 .47671 .71606 .47061 .70468 .46408 Metetra
.555 .851 .998 r
.70468 .46408 .71606 .47061 .74171 .46511 .73053 .4581 Metetra
.54 .837 .999 r
.73053 .4581 .74171 .46511 .7677 .4604 .7567 .4528 Metetra
.52 .819 .999 r
.7567 .4528 .7677 .4604 .79406 .45673 .78323 .44843 Metetra
.492 .793 .999 r
.78323 .44843 .79406 .45673 .82086 .45447 .81018 .44536 Metetra
.449 .757 .995 r
.81018 .44536 .82086 .45447 .84821 .45422 .83764 .44414 Metetra
.381 .703 .984 r
.83764 .44414 .84821 .45422 .87626 .45698 .86578 .44575 Metetra
.26 .607 .955 r
.86578 .44575 .87626 .45698 .90534 .46476 .8949 .45212 Metetra
0 .377 .836 r
.8949 .45212 .90534 .46476 .93639 .48398 .92587 .46942 Metetra
.845 .772 .781 r
.30393 .63757 .3185 .64937 .34259 .61825 .32815 .60803 Metetra
.807 .802 .847 r
.32815 .60803 .34259 .61825 .36608 .59735 .35178 .58826 Metetra
.778 .824 .889 r
.35178 .58826 .36608 .59735 .3894 .58091 .37524 .57271 Metetra
.75 .842 .92 r
.37524 .57271 .3894 .58091 .41271 .56713 .3987 .55965 Metetra
.724 .855 .943 r
.3987 .55965 .41271 .56713 .43607 .5551 .42223 .5482 Metetra
.7 .865 .96 r
.42223 .5482 .43607 .5551 .45954 .5443 .44588 .53787 Metetra
.678 .873 .972 r
.44588 .53787 .45954 .5443 .48316 .53439 .46968 .52833 Metetra
.659 .877 .98 r
.46968 .52833 .48316 .53439 .50694 .52514 .49365 .51935 Metetra
.642 .88 .985 r
.49365 .51935 .50694 .52514 .53089 .51638 .5178 .51078 Metetra
.628 .882 .988 r
.5178 .51078 .53089 .51638 .55505 .50802 .54216 .50251 Metetra
.616 .882 .99 r
.54216 .50251 .55505 .50802 .57941 .49997 .56673 .49448 Metetra
.606 .881 .991 r
.56673 .49448 .57941 .49997 .60399 .49221 .59152 .48665 Metetra
.597 .879 .992 r
.59152 .48665 .60399 .49221 .62879 .4847 .61654 .47899 Metetra
.59 .876 .993 r
.61654 .47899 .62879 .4847 .65383 .47748 .64179 .47154 Metetra
.583 .871 .994 r
.64179 .47154 .65383 .47748 .67912 .47058 .66729 .46432 Metetra
.576 .864 .996 r
.66729 .46432 .67912 .47058 .70468 .46408 .69306 .45742 Metetra
.567 .856 .997 r
.69306 .45742 .70468 .46408 .73053 .4581 .7191 .45093 Metetra
.555 .843 .998 r
.7191 .45093 .73053 .4581 .7567 .4528 .74546 .44503 Metetra
.539 .827 .999 r
.74546 .44503 .7567 .4528 .78323 .44843 .77216 .43996 Metetra
.514 .804 .998 r
.77216 .43996 .78323 .44843 .81018 .44536 .79927 .43605 Metetra
.477 .772 .996 r
.79927 .43605 .81018 .44536 .83764 .44414 .82687 .43385 Metetra
.416 .722 .988 r
.82687 .43385 .83764 .44414 .86578 .44575 .8551 .43429 Metetra
.305 .635 .964 r
.8551 .43429 .86578 .44575 .8949 .45212 .88425 .43923 Metetra
.028 .421 .863 r
.88425 .43923 .8949 .45212 .92587 .46942 .91516 .4546 Metetra
.838 .774 .79 r
.28911 .62556 .30393 .63757 .32815 .60803 .31346 .59763 Metetra
.798 .803 .856 r
.31346 .59763 .32815 .60803 .35178 .58826 .33721 .579 Metetra
.766 .825 .898 r
.33721 .579 .35178 .58826 .37524 .57271 .36082 .56435 Metetra
.738 .841 .928 r
.36082 .56435 .37524 .57271 .3987 .55965 .38442 .55202 Metetra
.712 .854 .95 r
.38442 .55202 .3987 .55965 .42223 .5482 .40811 .54116 Metetra
.688 .864 .965 r
.40811 .54116 .42223 .5482 .44588 .53787 .43193 .53131 Metetra
.667 .87 .976 r
.43193 .53131 .44588 .53787 .46968 .52833 .45591 .52214 Metetra
.649 .875 .982 r
.45591 .52214 .46968 .52833 .49365 .51935 .48007 .51343 Metetra
.634 .878 .987 r
.48007 .51343 .49365 .51935 .5178 .51078 .50443 .50505 Metetra
.622 .88 .989 r
.50443 .50505 .5178 .51078 .54216 .50251 .529 .49688 Metetra
.612 .881 .991 r
.529 .49688 .54216 .50251 .56673 .49448 .55378 .48887 Metetra
.604 .88 .991 r
.55378 .48887 .56673 .49448 .59152 .48665 .57878 .48096 Metetra
.599 .879 .992 r
.57878 .48096 .59152 .48665 .61654 .47899 .60401 .47316 Metetra
.594 .877 .993 r
.60401 .47316 .61654 .47899 .64179 .47154 .62948 .46547 Metetra
.59 .873 .994 r
.62948 .46547 .64179 .47154 .66729 .46432 .6552 .45793 Metetra
.585 .868 .995 r
.6552 .45793 .66729 .46432 .69306 .45742 .68118 .45061 Metetra
.579 .86 .996 r
.68118 .45061 .69306 .45742 .7191 .45093 .70743 .44361 Metetra
.57 .849 .997 r
.70743 .44361 .7191 .45093 .74546 .44503 .73398 .4371 Metetra
.557 .835 .997 r
.73398 .4371 .74546 .44503 .77216 .43996 .76086 .4313 Metetra
.536 .814 .997 r
.76086 .4313 .77216 .43996 .79927 .43605 .78813 .42654 Metetra
.503 .785 .996 r
.78813 .42654 .79927 .43605 .82687 .43385 .81587 .42335 Metetra
.449 .74 .99 r
.81587 .42335 .82687 .43385 .8551 .43429 .8442 .42261 Metetra
.348 .661 .972 r
.8442 .42261 .8551 .43429 .88425 .43923 .8734 .4261 Metetra
.087 .464 .888 r
.8734 .4261 .88425 .43923 .91516 .4546 .90425 .43951 Metetra
.831 .775 .799 r
.27406 .61336 .28911 .62556 .31346 .59763 .29851 .58705 Metetra
.788 .804 .866 r
.29851 .58705 .31346 .59763 .33721 .579 .32238 .56958 Metetra
.754 .825 .907 r
.32238 .56958 .33721 .579 .36082 .56435 .34611 .55584 Metetra
.724 .84 .936 r
.34611 .55584 .36082 .56435 .38442 .55202 .36986 .54424 Metetra
.698 .852 .956 r
.36986 .54424 .38442 .55202 .40811 .54116 .39371 .53399 Metetra
.675 .861 .97 r
.39371 .53399 .40811 .54116 .43193 .53131 .4177 .52461 Metetra
.655 .868 .979 r
.4177 .52461 .43193 .53131 .45591 .52214 .44186 .51582 Metetra
.639 .873 .985 r
.44186 .51582 .45591 .52214 .48007 .51343 .46621 .5074 Metetra
.626 .876 .988 r
.46621 .5074 .48007 .51343 .50443 .50505 .49077 .4992 Metetra
.616 .878 .99 r
.49077 .4992 .50443 .50505 .529 .49688 .51554 .49113 Metetra
.608 .88 .991 r
.51554 .49113 .529 .49688 .55378 .48887 .54053 .48313 Metetra
.603 .88 .992 r
.54053 .48313 .55378 .48887 .57878 .48096 .56576 .47516 Metetra
.6 .88 .992 r
.56576 .47516 .57878 .48096 .60401 .47316 .59121 .46719 Metetra
.598 .878 .992 r
.59121 .46719 .60401 .47316 .62948 .46547 .6169 .45926 Metetra
.596 .875 .993 r
.6169 .45926 .62948 .46547 .6552 .45793 .64284 .45139 Metetra
.594 .871 .993 r
.64284 .45139 .6552 .45793 .68118 .45061 .66903 .44364 Metetra
.59 .864 .994 r
.66903 .44364 .68118 .45061 .70743 .44361 .6955 .43613 Metetra
.584 .855 .995 r
.6955 .43613 .70743 .44361 .73398 .4371 .72225 .429 Metetra
.574 .842 .995 r
.72225 .429 .73398 .4371 .76086 .4313 .74932 .42246 Metetra
.557 .823 .995 r
.74932 .42246 .76086 .4313 .78813 .42654 .77676 .41684 Metetra
.529 .797 .994 r
.77676 .41684 .78813 .42654 .81587 .42335 .80464 .41263 Metetra
.481 .756 .991 r
.80464 .41263 .81587 .42335 .8442 .42261 .83308 .41068 Metetra
.389 .686 .978 r
.83308 .41068 .8442 .42261 .8734 .4261 .86234 .4127 Metetra
.147 .505 .91 r
.86234 .4127 .8734 .4261 .90425 .43951 .89314 .42414 Metetra
.823 .777 .809 r
.25875 .60095 .27406 .61336 .29851 .58705 .28329 .57628 Metetra
.776 .805 .876 r
.28329 .57628 .29851 .58705 .32238 .56958 .30727 .55997 Metetra
.74 .824 .916 r
.30727 .55997 .32238 .56958 .34611 .55584 .33112 .54716 Metetra
.71 .839 .944 r
.33112 .54716 .34611 .55584 .36986 .54424 .35501 .5363 Metetra
.683 .85 .963 r
.35501 .5363 .36986 .54424 .39371 .53399 .37901 .52666 Metetra
.661 .859 .975 r
.37901 .52666 .39371 .53399 .4177 .52461 .40317 .51778 Metetra
.642 .865 .983 r
.40317 .51778 .4177 .52461 .44186 .51582 .42751 .50936 Metetra
.628 .87 .988 r
.42751 .50936 .44186 .51582 .46621 .5074 .45205 .50122 Metetra
.617 .873 .99 r
.45205 .50122 .46621 .5074 .49077 .4992 .47681 .49322 Metetra
.609 .876 .991 r
.47681 .49322 .49077 .4992 .51554 .49113 .50179 .48525 Metetra
.604 .878 .992 r
.50179 .48525 .51554 .49113 .54053 .48313 .527 .47727 Metetra
.602 .88 .992 r
.527 .47727 .54053 .48313 .56576 .47516 .55244 .46922 Metetra
.601 .88 .992 r
.55244 .46922 .56576 .47516 .59121 .46719 .57812 .46109 Metetra
.602 .88 .992 r
.57812 .46109 .59121 .46719 .6169 .45926 .60404 .45291 Metetra
.602 .878 .992 r
.60404 .45291 .6169 .45926 .64284 .45139 .6302 .4447 Metetra
.603 .874 .992 r
.6302 .4447 .64284 .45139 .66903 .44364 .65662 .43652 Metetra
.602 .868 .993 r
.65662 .43652 .66903 .44364 .6955 .43613 .6833 .42848 Metetra
.598 .86 .993 r
.6833 .42848 .6955 .43613 .72225 .429 .71026 .42071 Metetra
.591 .848 .993 r
.71026 .42071 .72225 .429 .74932 .42246 .73752 .41342 Metetra
.577 .832 .993 r
.73752 .41342 .74932 .42246 .77676 .41684 .76514 .40692 Metetra
.553 .808 .993 r
.76514 .40692 .77676 .41684 .80464 .41263 .79317 .40168 Metetra
.511 .771 .99 r
.79317 .40168 .80464 .41263 .83308 .41068 .82173 .39852 Metetra
.429 .708 .981 r
.82173 .39852 .83308 .41068 .86234 .4127 .85106 .39905 Metetra
.206 .546 .929 r
.85106 .39905 .86234 .4127 .89314 .42414 .88182 .40847 Metetra
.813 .778 .82 r
.24318 .58833 .25875 .60095 .28329 .57628 .2678 .56532 Metetra
.763 .805 .886 r
.2678 .56532 .28329 .57628 .30727 .55997 .29187 .55019 Metetra
.725 .823 .926 r
.29187 .55019 .30727 .55997 .33112 .54716 .31584 .5383 Metetra
.694 .837 .952 r
.31584 .5383 .33112 .54716 .35501 .5363 .33986 .52821 Metetra
.668 .847 .969 r
.33986 .52821 .35501 .5363 .37901 .52666 .36401 .51918 Metetra
.646 .855 .98 r
.36401 .51918 .37901 .52666 .40317 .51778 .38833 .51079 Metetra
.629 .862 .986 r
.38833 .51079 .40317 .51778 .42751 .50936 .41284 .50277 Metetra
.617 .867 .99 r
.41284 .50277 .42751 .50936 .45205 .50122 .43758 .49492 Metetra
.608 .871 .992 r
.43758 .49492 .45205 .50122 .47681 .49322 .46253 .48711 Metetra
.603 .874 .992 r
.46253 .48711 .47681 .49322 .50179 .48525 .48772 .47924 Metetra
.601 .877 .992 r
.48772 .47924 .50179 .48525 .527 .47727 .51315 .47127 Metetra
.601 .879 .992 r
.51315 .47127 .527 .47727 .55244 .46922 .53882 .46314 Metetra
.602 .881 .992 r
.53882 .46314 .55244 .46922 .57812 .46109 .56473 .45486 Metetra
.605 .881 .991 r
.56473 .45486 .57812 .46109 .60404 .45291 .59088 .44642 Metetra
.608 .88 .991 r
.59088 .44642 .60404 .45291 .6302 .4447 .61727 .43786 Metetra
.611 .877 .991 r
.61727 .43786 .6302 .4447 .65662 .43652 .64392 .42924 Metetra
.612 .872 .991 r
.64392 .42924 .65662 .43652 .6833 .42848 .67082 .42066 Metetra
.611 .865 .991 r
.67082 .42066 .6833 .42848 .71026 .42071 .698 .41224 Metetra
.607 .854 .991 r
.698 .41224 .71026 .42071 .73752 .41342 .72547 .40419 Metetra
.596 .839 .99 r
.72547 .40419 .73752 .41342 .76514 .40692 .75327 .39679 Metetra
.577 .817 .99 r
.75327 .39679 .76514 .40692 .79317 .40168 .78146 .39051 Metetra
.54 .785 .988 r
.78146 .39051 .79317 .40168 .82173 .39852 .81015 .3861 Metetra
.467 .728 .983 r
.81015 .3861 .82173 .39852 .85106 .39905 .83955 .38512 Metetra
.264 .583 .945 r
.83955 .38512 .85106 .39905 .88182 .40847 .87029 .39251 Metetra
.803 .779 .831 r
.22734 .5755 .24318 .58833 .2678 .56532 .25202 .55416 Metetra
.749 .804 .897 r
.25202 .55416 .2678 .56532 .29187 .55019 .27618 .54022 Metetra
.709 .822 .935 r
.27618 .54022 .29187 .55019 .31584 .5383 .30026 .52928 Metetra
.677 .834 .959 r
.30026 .52928 .31584 .5383 .33986 .52821 .3244 .51995 Metetra
.651 .844 .974 r
.3244 .51995 .33986 .52821 .36401 .51918 .34869 .51155 Metetra
.63 .852 .984 r
.34869 .51155 .36401 .51918 .38833 .51079 .37317 .50366 Metetra
.615 .858 .989 r
.37317 .50366 .38833 .51079 .41284 .50277 .39786 .49603 Metetra
.605 .863 .992 r
.39786 .49603 .41284 .50277 .43758 .49492 .42278 .48847 Metetra
.599 .868 .993 r
.42278 .48847 .43758 .49492 .46253 .48711 .44794 .48086 Metetra
.596 .872 .993 r
.44794 .48086 .46253 .48711 .48772 .47924 .47334 .4731 Metetra
.597 .876 .993 r
.47334 .4731 .48772 .47924 .51315 .47127 .49899 .46513 Metetra
.599 .879 .992 r
.49899 .46513 .51315 .47127 .53882 .46314 .52489 .45693 Metetra
.604 .881 .991 r
.52489 .45693 .53882 .46314 .56473 .45486 .55103 .44847 Metetra
.609 .882 .991 r
.55103 .44847 .56473 .45486 .59088 .44642 .57741 .43977 Metetra
.614 .882 .99 r
.57741 .43977 .59088 .44642 .61727 .43786 .60405 .43086 Metetra
.619 .88 .99 r
.60405 .43086 .61727 .43786 .64392 .42924 .63093 .42179 Metetra
.623 .876 .989 r
.63093 .42179 .64392 .42924 .67082 .42066 .65806 .41265 Metetra
.624 .869 .988 r
.65806 .41265 .67082 .42066 .698 .41224 .68546 .40358 Metetra
.622 .86 .988 r
.68546 .40358 .698 .41224 .72547 .40419 .71314 .39475 Metetra
.615 .846 .987 r
.71314 .39475 .72547 .40419 .75327 .39679 .74114 .38644 Metetra
.599 .827 .987 r
.74114 .38644 .75327 .39679 .78146 .39051 .7695 .37909 Metetra
.567 .797 .986 r
.7695 .37909 .78146 .39051 .81015 .3861 .79832 .37342 Metetra
.503 .747 .983 r
.79832 .37342 .81015 .3861 .83955 .38512 .82781 .37091 Metetra
.32 .619 .956 r
.82781 .37091 .83955 .38512 .87029 .39251 .85853 .37625 Metetra
.791 .78 .843 r
.21123 .56244 .22734 .5755 .25202 .55416 .23596 .54279 Metetra
.732 .803 .908 r
.23596 .54279 .25202 .55416 .27618 .54022 .26019 .53006 Metetra
.691 .819 .944 r
.26019 .53006 .27618 .54022 .30026 .52928 .28436 .52007 Metetra
.658 .831 .966 r
.28436 .52007 .30026 .52928 .3244 .51995 .30862 .51152 Metetra
.633 .84 .98 r
.30862 .51152 .3244 .51995 .34869 .51155 .33305 .50375 Metetra
.614 .847 .988 r
.33305 .50375 .34869 .51155 .37317 .50366 .35769 .49638 Metetra
.601 .854 .992 r
.35769 .49638 .37317 .50366 .39786 .49603 .38255 .48915 Metetra
.593 .86 .994 r
.38255 .48915 .39786 .49603 .42278 .48847 .40766 .48188 Metetra
.59 .865 .994 r
.40766 .48188 .42278 .48847 .44794 .48086 .43302 .47447 Metetra
.59 .87 .994 r
.43302 .47447 .44794 .48086 .47334 .4731 .45863 .46681 Metetra
.593 .875 .993 r
.45863 .46681 .47334 .4731 .49899 .46513 .4845 .45886 Metetra
.598 .878 .992 r
.4845 .45886 .49899 .46513 .52489 .45693 .51063 .45057 Metetra
.605 .881 .991 r
.51063 .45057 .52489 .45693 .55103 .44847 .53701 .44194 Metetra
.613 .883 .99 r
.53701 .44194 .55103 .44847 .57741 .43977 .56364 .43297 Metetra
.62 .884 .989 r
.56364 .43297 .57741 .43977 .60405 .43086 .59051 .4237 Metetra
.627 .882 .988 r
.59051 .4237 .60405 .43086 .63093 .42179 .61764 .41417 Metetra
.633 .879 .987 r
.61764 .41417 .63093 .42179 .65806 .41265 .64501 .40447 Metetra
.637 .874 .986 r
.64501 .40447 .65806 .41265 .68546 .40358 .67264 .39471 Metetra
.637 .865 .984 r
.67264 .39471 .68546 .40358 .71314 .39475 .70054 .38509 Metetra
.632 .853 .983 r
.70054 .38509 .71314 .39475 .74114 .38644 .72874 .37586 Metetra
.62 .835 .983 r
.72874 .37586 .74114 .38644 .7695 .37909 .75728 .36742 Metetra
.593 .808 .982 r
.75728 .36742 .7695 .37909 .79832 .37342 .78625 .36047 Metetra
.537 .764 .981 r
.78625 .36047 .79832 .37342 .82781 .37091 .81583 .3564 Metetra
.374 .651 .965 r
.81583 .3564 .82781 .37091 .85853 .37625 .84655 .35967 Metetra
.777 .78 .855 r
.19484 .54916 .21123 .56244 .23596 .54279 .2196 .53121 Metetra
.714 .802 .919 r
.2196 .53121 .23596 .54279 .26019 .53006 .24389 .5197 Metetra
.67 .816 .953 r
.24389 .5197 .26019 .53006 .28436 .52007 .26814 .51068 Metetra
.638 .826 .973 r
.26814 .51068 .28436 .52007 .30862 .51152 .29252 .50292 Metetra
.613 .835 .985 r
.29252 .50292 .30862 .51152 .33305 .50375 .31708 .49579 Metetra
.596 .843 .991 r
.31708 .49579 .33305 .50375 .35769 .49638 .34186 .48893 Metetra
.586 .849 .994 r
.34186 .48893 .35769 .49638 .38255 .48915 .3669 .48211 Metetra
.58 .856 .995 r
.3669 .48211 .38255 .48915 .40766 .48188 .39219 .47515 Metetra
.58 .862 .995 r
.39219 .47515 .40766 .48188 .43302 .47447 .41775 .46793 Metetra
.583 .868 .995 r
.41775 .46793 .43302 .47447 .45863 .46681 .44358 .46038 Metetra
.589 .873 .994 r
.44358 .46038 .45863 .46681 .4845 .45886 .46968 .45243 Metetra
.597 .878 .992 r
.46968 .45243 .4845 .45886 .51063 .45057 .49604 .44406 Metetra
.606 .882 .991 r
.49604 .44406 .51063 .45057 .53701 .44194 .52266 .43525 Metetra
.616 .884 .99 r
.52266 .43525 .53701 .44194 .56364 .43297 .54953 .42601 Metetra
.626 .885 .988 r
.54953 .42601 .56364 .43297 .59051 .4237 .57666 .41637 Metetra
.635 .885 .986 r
.57666 .41637 .59051 .4237 .61764 .41417 .60403 .40637 Metetra
.643 .882 .985 r
.60403 .40637 .61764 .41417 .64501 .40447 .63165 .39609 Metetra
.649 .877 .983 r
.63165 .39609 .64501 .40447 .67264 .39471 .65952 .38565 Metetra
.651 .87 .981 r
.65952 .38565 .67264 .39471 .70054 .38509 .68765 .37521 Metetra
.649 .858 .979 r
.68765 .37521 .70054 .38509 .72874 .37586 .71606 .36503 Metetra
.639 .842 .978 r
.71606 .36503 .72874 .37586 .75728 .36742 .74479 .35549 Metetra
.618 .818 .977 r
.74479 .35549 .75728 .36742 .78625 .36047 .77392 .34725 Metetra
.57 .779 .977 r
.77392 .34725 .78625 .36047 .81583 .3564 .8036 .3416 Metetra
.426 .681 .97 r
.8036 .3416 .81583 .3564 .84655 .35967 .83434 .34277 Metetra
.761 .78 .868 r
.17817 .53565 .19484 .54916 .2196 .53121 .20293 .51942 Metetra
.693 .799 .93 r
.20293 .51942 .2196 .53121 .24389 .5197 .22726 .50914 Metetra
.648 .811 .962 r
.22726 .50914 .24389 .5197 .26814 .51068 .2516 .5011 Metetra
.615 .821 .979 r
.2516 .5011 .26814 .51068 .29252 .50292 .27607 .49413 Metetra
.592 .829 .989 r
.27607 .49413 .29252 .50292 .31708 .49579 .30076 .48766 Metetra
.578 .837 .994 r
.30076 .48766 .31708 .49579 .34186 .48893 .32569 .48133 Metetra
.57 .844 .996 r
.32569 .48133 .34186 .48893 .3669 .48211 .35089 .47491 Metetra
.568 .852 .997 r
.35089 .47491 .3669 .48211 .39219 .47515 .37637 .46825 Metetra
.57 .859 .996 r
.37637 .46825 .39219 .47515 .41775 .46793 .40213 .46124 Metetra
.576 .866 .995 r
.40213 .46124 .41775 .46793 .44358 .46038 .42817 .45379 Metetra
.585 .872 .994 r
.42817 .45379 .44358 .46038 .46968 .45243 .4545 .44585 Metetra
.596 .878 .993 r
.4545 .44585 .46968 .45243 .49604 .44406 .4811 .4374 Metetra
.607 .882 .991 r
.4811 .4374 .49604 .44406 .52266 .43525 .50796 .42841 Metetra
.62 .885 .989 r
.50796 .42841 .52266 .43525 .54953 .42601 .53509 .41889 Metetra
.632 .887 .987 r
.53509 .41889 .54953 .42601 .57666 .41637 .56247 .40886 Metetra
.643 .887 .985 r
.56247 .40886 .57666 .41637 .60403 .40637 .5901 .39838 Metetra
.653 .885 .982 r
.5901 .39838 .60403 .40637 .63165 .39609 .61797 .38751 Metetra
.66 .881 .98 r
.61797 .38751 .63165 .39609 .65952 .38565 .64609 .37637 Metetra
.665 .874 .977 r
.64609 .37637 .65952 .38565 .68765 .37521 .67445 .36511 Metetra
.665 .863 .975 r
.67445 .36511 .68765 .37521 .71606 .36503 .70309 .35397 Metetra
.658 .849 .973 r
.70309 .35397 .71606 .36503 .74479 .35549 .73202 .3433 Metetra
.641 .827 .972 r
.73202 .3433 .74479 .35549 .77392 .34725 .76131 .33374 Metetra
.6 .792 .973 r
.76131 .33374 .77392 .34725 .8036 .3416 .79112 .3265 Metetra
.474 .708 .971 r
.79112 .3265 .8036 .3416 .83434 .34277 .82188 .32553 Metetra
.743 .779 .882 r
.1612 .5219 .17817 .53565 .20293 .51942 .18595 .5074 Metetra
.669 .795 .942 r
.18595 .5074 .20293 .51942 .22726 .50914 .21031 .49836 Metetra
.623 .805 .97 r
.21031 .49836 .22726 .50914 .2516 .5011 .23471 .49131 Metetra
.591 .814 .985 r
.23471 .49131 .2516 .5011 .27607 .49413 .25928 .48516 Metetra
.57 .822 .993 r
.25928 .48516 .27607 .49413 .30076 .48766 .28408 .47934 Metetra
.558 .83 .997 r
.28408 .47934 .30076 .48766 .32569 .48133 .30916 .47355 Metetra
.553 .839 .998 r
.30916 .47355 .32569 .48133 .35089 .47491 .33452 .46755 Metetra
.554 .847 .998 r
.33452 .46755 .35089 .47491 .37637 .46825 .36018 .4612 Metetra
.56 .855 .997 r
.36018 .4612 .37637 .46825 .40213 .46124 .38614 .45439 Metetra
.569 .863 .996 r
.38614 .45439 .40213 .46124 .42817 .45379 .4124 .44705 Metetra
.581 .871 .995 r
.4124 .44705 .42817 .45379 .4545 .44585 .43895 .43912 Metetra
.594 .877 .993 r
.43895 .43912 .4545 .44585 .4811 .4374 .46579 .43057 Metetra
.609 .883 .991 r
.46579 .43057 .4811 .4374 .50796 .42841 .49291 .42139 Metetra
.623 .886 .988 r
.49291 .42139 .50796 .42841 .53509 .41889 .5203 .41159 Metetra
.638 .889 .986 r
.5203 .41159 .53509 .41889 .56247 .40886 .54794 .40117 Metetra
.651 .889 .983 r
.54794 .40117 .56247 .40886 .5901 .39838 .57583 .3902 Metetra
.662 .888 .98 r
.57583 .3902 .5901 .39838 .61797 .38751 .60397 .37873 Metetra
.672 .884 .977 r
.60397 .37873 .61797 .38751 .64609 .37637 .63234 .36687 Metetra
.678 .878 .973 r
.63234 .36687 .64609 .37637 .67445 .36511 .66096 .35477 Metetra
.68 .868 .97 r
.66096 .35477 .67445 .36511 .70309 .35397 .68982 .34265 Metetra
.676 .854 .967 r
.68982 .34265 .70309 .35397 .73202 .3433 .71896 .33084 Metetra
.662 .835 .966 r
.71896 .33084 .73202 .3433 .76131 .33374 .74844 .31993 Metetra
.628 .803 .967 r
.74844 .31993 .76131 .33374 .79112 .3265 .77838 .31107 Metetra
.52 .731 .97 r
.77838 .31107 .79112 .3265 .82188 .32553 .80918 .30795 Metetra
.722 .777 .896 r
.14392 .5079 .1612 .5219 .18595 .5074 .16865 .49516 Metetra
.643 .789 .952 r
.16865 .49516 .18595 .5074 .21031 .49836 .19302 .48738 Metetra
.595 .798 .977 r
.19302 .48738 .21031 .49836 .23471 .49131 .21747 .48133 Metetra
.564 .806 .99 r
.21747 .48133 .23471 .49131 .25928 .48516 .24213 .47599 Metetra
.546 .814 .996 r
.24213 .47599 .25928 .48516 .28408 .47934 .26704 .47085 Metetra
.537 .823 .998 r
.26704 .47085 .28408 .47934 .30916 .47355 .29225 .46559 Metetra
.536 .832 .999 r
.29225 .46559 .30916 .47355 .33452 .46755 .31777 .46002 Metetra
.54 .842 .999 r
.31777 .46002 .33452 .46755 .36018 .4612 .34361 .45398 Metetra
.549 .852 .998 r
.34361 .45398 .36018 .4612 .38614 .45439 .36977 .44738 Metetra
.562 .861 .997 r
.36977 .44738 .38614 .45439 .4124 .44705 .39625 .44015 Metetra
.577 .869 .995 r
.39625 .44015 .4124 .44705 .43895 .43912 .42303 .43222 Metetra
.593 .877 .993 r
.42303 .43222 .43895 .43912 .46579 .43057 .45012 .42358 Metetra
.61 .883 .991 r
.45012 .42358 .46579 .43057 .49291 .42139 .47749 .41421 Metetra
.627 .888 .988 r
.47749 .41421 .49291 .42139 .5203 .41159 .50514 .40411 Metetra
.643 .89 .985 r
.50514 .40411 .5203 .41159 .54794 .40117 .53305 .3933 Metetra
.658 .891 .981 r
.53305 .3933 .54794 .40117 .57583 .3902 .56122 .38182 Metetra
.671 .89 .977 r
.56122 .38182 .57583 .3902 .60397 .37873 .58962 .36973 Metetra
.682 .887 .973 r
.58962 .36973 .60397 .37873 .63234 .36687 .61826 .35714 Metetra
.691 .881 .969 r
.61826 .35714 .63234 .36687 .66096 .35477 .64714 .34418 Metetra
.695 .872 .965 r
.64714 .34418 .66096 .35477 .68982 .34265 .67624 .33106 Metetra
.693 .859 .962 r
.67624 .33106 .68982 .34265 .71896 .33084 .70561 .31809 Metetra
.682 .842 .959 r
.70561 .31809 .71896 .33084 .74844 .31993 .73528 .30582 Metetra
.654 .814 .96 r
.73528 .30582 .74844 .31993 .77838 .31107 .76536 .29532 Metetra
.562 .752 .966 r
.76536 .29532 .77838 .31107 .80918 .30795 .79622 .29002 Metetra
.696 .773 .911 r
.12634 .49365 .14392 .5079 .16865 .49516 .15101 .48267 Metetra
.612 .781 .962 r
.15101 .48267 .16865 .49516 .19302 .48738 .17539 .47617 Metetra
.564 .788 .983 r
.17539 .47617 .19302 .48738 .21747 .48133 .19987 .47114 Metetra
.535 .796 .993 r
.19987 .47114 .21747 .48133 .24213 .47599 .2246 .46663 Metetra
.52 .805 .998 r
.2246 .46663 .24213 .47599 .26704 .47085 .24961 .46216 Metetra
.515 .815 .999 r
.24961 .46216 .26704 .47085 .29225 .46559 .27495 .45746 Metetra
.517 .826 1 r
.27495 .45746 .29225 .46559 .31777 .46002 .30063 .45231 Metetra
.526 .837 .999 r
.30063 .45231 .31777 .46002 .34361 .45398 .32665 .44659 Metetra
.539 .848 .998 r
.32665 .44659 .34361 .45398 .36977 .44738 .35301 .4402 Metetra
.555 .858 .997 r
.35301 .4402 .36977 .44738 .39625 .44015 .3797 .43307 Metetra
.573 .868 .995 r
.3797 .43307 .39625 .44015 .42303 .43222 .40672 .42516 Metetra
.592 .876 .993 r
.40672 .42516 .42303 .43222 .45012 .42358 .43406 .41642 Metetra
.611 .883 .99 r
.43406 .41642 .45012 .42358 .47749 .41421 .46169 .40685 Metetra
.63 .889 .987 r
.46169 .40685 .47749 .41421 .50514 .40411 .48961 .39644 Metetra
.648 .892 .983 r
.48961 .39644 .50514 .40411 .53305 .3933 .5178 .38522 Metetra
.665 .893 .979 r
.5178 .38522 .53305 .3933 .56122 .38182 .54624 .37323 Metetra
.68 .893 .975 r
.54624 .37323 .56122 .38182 .58962 .36973 .57493 .36052 Metetra
.693 .89 .97 r
.57493 .36052 .58962 .36973 .61826 .35714 .60385 .34718 Metetra
.702 .884 .965 r
.60385 .34718 .61826 .35714 .64714 .34418 .63299 .33334 Metetra
.708 .876 .96 r
.63299 .33334 .64714 .34418 .67624 .33106 .66235 .3192 Metetra
.709 .864 .955 r
.66235 .3192 .67624 .33106 .70561 .31809 .69195 .30505 Metetra
.701 .847 .952 r
.69195 .30505 .70561 .31809 .73528 .30582 .72182 .29139 Metetra
.678 .823 .952 r
.72182 .29139 .73528 .30582 .76536 .29532 .75207 .27922 Metetra
.601 .77 .961 r
.75207 .27922 .76536 .29532 .79622 .29002 .783 .27172 Metetra
.667 .767 .925 r
.10844 .47914 .12634 .49365 .15101 .48267 .13303 .46995 Metetra
.578 .771 .971 r
.13303 .46995 .15101 .48267 .17539 .47617 .15739 .46473 Metetra
.53 .777 .988 r
.15739 .46473 .17539 .47617 .19987 .47114 .1819 .46073 Metetra
.504 .785 .995 r
.1819 .46073 .19987 .47114 .2246 .46663 .20669 .45706 Metetra
.492 .795 .999 r
.20669 .45706 .2246 .46663 .24961 .46216 .2318 .45328 Metetra
.491 .806 1 r
.2318 .45328 .24961 .46216 .27495 .45746 .25726 .44913 Metetra
.498 .818 1 r
.25726 .44913 .27495 .45746 .30063 .45231 .28309 .44442 Metetra
.511 .831 1 r
.28309 .44442 .30063 .45231 .32665 .44659 .30928 .43902 Metetra
.528 .844 .999 r
.30928 .43902 .32665 .44659 .35301 .4402 .33584 .43285 Metetra
.547 .855 .997 r
.33584 .43285 .35301 .4402 .3797 .43307 .36275 .42583 Metetra
.568 .866 .996 r
.36275 .42583 .3797 .43307 .40672 .42516 .39001 .41791 Metetra
.59 .876 .993 r
.39001 .41791 .40672 .42516 .43406 .41642 .41759 .40908 Metetra
.612 .884 .99 r
.41759 .40908 .43406 .41642 .46169 .40685 .44549 .3993 Metetra
.634 .89 .986 r
.44549 .3993 .46169 .40685 .48961 .39644 .47369 .38859 Metetra
.654 .894 .982 r
.47369 .38859 .48961 .39644 .5178 .38522 .50216 .37695 Metetra
.672 .895 .977 r
.50216 .37695 .5178 .38522 .54624 .37323 .53089 .36443 Metetra
.689 .895 .972 r
.53089 .36443 .54624 .37323 .57493 .36052 .55987 .35107 Metetra
.703 .892 .966 r
.55987 .35107 .57493 .36052 .60385 .34718 .58907 .33697 Metetra
.714 .887 .96 r
.58907 .33697 .60385 .34718 .63299 .33334 .61849 .32224 Metetra
.721 .879 .954 r
.61849 .32224 .63299 .33334 .66235 .3192 .64812 .30706 Metetra
.724 .868 .949 r
.64812 .30706 .66235 .3192 .69195 .30505 .67797 .29171 Metetra
.719 .853 .945 r
.67797 .29171 .69195 .30505 .72182 .29139 .70807 .27664 Metetra
.701 .83 .944 r
.70807 .27664 .72182 .29139 .75207 .27922 .73848 .26278 Metetra
.637 .785 .953 r
.73848 .26278 .75207 .27922 .783 .27172 .7695 .25305 Metetra
.632 .759 .939 r
.09021 .46436 .10844 .47914 .13303 .46995 .11469 .45698 Metetra
.539 .759 .978 r
.11469 .45698 .13303 .46995 .15739 .46473 .13902 .45306 Metetra
.493 .763 .991 r
.13902 .45306 .15739 .46473 .1819 .46073 .16354 .45009 Metetra
.47 .771 .996 r
.16354 .45009 .1819 .46073 .20669 .45706 .18838 .44728 Metetra
.463 .782 .998 r
.18838 .44728 .20669 .45706 .2318 .45328 .21357 .4442 Metetra
.467 .796 .999 r
.21357 .4442 .2318 .45328 .25726 .44913 .23915 .44061 Metetra
.478 .81 1 r
.23915 .44061 .25726 .44913 .28309 .44442 .26512 .43634 Metetra
.496 .825 .999 r
.26512 .43634 .28309 .44442 .30928 .43902 .29149 .43127 Metetra
.516 .839 .999 r
.29149 .43127 .30928 .43902 .33584 .43285 .31824 .42531 Metetra
.54 .853 .998 r
.31824 .42531 .33584 .43285 .36275 .42583 .34537 .4184 Metetra
.564 .865 .996 r
.34537 .4184 .36275 .42583 .39001 .41791 .37287 .41049 Metetra
.589 .875 .993 r
.37287 .41049 .39001 .41791 .41759 .40908 .40071 .40155 Metetra
.614 .884 .99 r
.40071 .40155 .41759 .40908 .44549 .3993 .42888 .39156 Metetra
.637 .891 .986 r
.42888 .39156 .44549 .3993 .47369 .38859 .45736 .38053 Metetra
.659 .895 .981 r
.45736 .38053 .47369 .38859 .50216 .37695 .48612 .36846 Metetra
.679 .897 .975 r
.48612 .36846 .50216 .37695 .53089 .36443 .51515 .3554 Metetra
.697 .897 .969 r
.51515 .3554 .53089 .36443 .55987 .35107 .54443 .34139 Metetra
.713 .894 .962 r
.54443 .34139 .55987 .35107 .58907 .33697 .57393 .32651 Metetra
.725 .889 .955 r
.57393 .32651 .58907 .33697 .61849 .32224 .60364 .31087 Metetra
.734 .882 .949 r
.60364 .31087 .61849 .32224 .64812 .30706 .63356 .29463 Metetra
.738 .871 .942 r
.63356 .29463 .64812 .30706 .67797 .29171 .66367 .27805 Metetra
.736 .857 .937 r
.66367 .27805 .67797 .29171 .70807 .27664 .69399 .26156 Metetra
.722 .837 .935 r
.69399 .26156 .70807 .27664 .73848 .26278 .7246 .24598 Metetra
.669 .798 .944 r
.7246 .24598 .73848 .26278 .7695 .25305 .75573 .23399 Metetra
.591 .747 .952 r
.07164 .44932 .09021 .46436 .11469 .45698 .096 .44375 Metetra
.495 .742 .983 r
.096 .44375 .11469 .45698 .13902 .45306 .12027 .44114 Metetra
.452 .746 .992 r
.12027 .44114 .13902 .45306 .16354 .45009 .14479 .43923 Metetra
.434 .756 .995 r
.14479 .43923 .16354 .45009 .18838 .44728 .16966 .43728 Metetra
.432 .769 .997 r
.16966 .43728 .18838 .44728 .21357 .4442 .19493 .43491 Metetra
.441 .784 .998 r
.19493 .43491 .21357 .4442 .23915 .44061 .22061 .43189 Metetra
.458 .801 .999 r
.22061 .43189 .23915 .44061 .26512 .43634 .24673 .42807 Metetra
.48 .818 .999 r
.24673 .42807 .26512 .43634 .29149 .43127 .27326 .42333 Metetra
.505 .834 .999 r
.27326 .42333 .29149 .43127 .31824 .42531 .30021 .41759 Metetra
.532 .85 .998 r
.30021 .41759 .31824 .42531 .34537 .4184 .32756 .41079 Metetra
.56 .863 .996 r
.32756 .41079 .34537 .4184 .37287 .41049 .35529 .40287 Metetra
.588 .875 .994 r
.35529 .40287 .37287 .41049 .40071 .40155 .3834 .39382 Metetra
.615 .884 .99 r
.3834 .39382 .40071 .40155 .42888 .39156 .41184 .38362 Metetra
.64 .892 .985 r
.41184 .38362 .42888 .39156 .45736 .38053 .44061 .37226 Metetra
.664 .896 .979 r
.44061 .37226 .45736 .38053 .48612 .36846 .46967 .35976 Metetra
.686 .899 .973 r
.46967 .35976 .48612 .36846 .51515 .3554 .49901 .34614 Metetra
.705 .899 .966 r
.49901 .34614 .51515 .3554 .54443 .34139 .5286 .33146 Metetra
.722 .896 .958 r
.5286 .33146 .54443 .34139 .57393 .32651 .55841 .31578 Metetra
.735 .891 .951 r
.55841 .31578 .57393 .32651 .60364 .31087 .58843 .29921 Metetra
.746 .884 .943 r
.58843 .29921 .60364 .31087 .63356 .29463 .61863 .28189 Metetra
.751 .874 .936 r
.61863 .28189 .63356 .29463 .66367 .27805 .64902 .26407 Metetra
.751 .861 .929 r
.64902 .26407 .66367 .27805 .69399 .26156 .6796 .24612 Metetra
.741 .842 .926 r
.6796 .24612 .69399 .26156 .7246 .24598 .71041 .2288 Metetra
.699 .809 .933 r
.71041 .2288 .7246 .24598 .75573 .23399 .74167 .21453 Metetra
.542 .731 .962 r
.05272 .43399 .07164 .44932 .096 .44375 .07693 .43025 Metetra
.445 .722 .984 r
.07693 .43025 .096 .44375 .12027 .44114 .10112 .42898 Metetra
.406 .726 .99 r
.10112 .42898 .12027 .44114 .14479 .43923 .12562 .42813 Metetra
.394 .738 .992 r
.12562 .42813 .14479 .43923 .16966 .43728 .15051 .42705 Metetra
.399 .754 .994 r
.15051 .42705 .16966 .43728 .19493 .43491 .17585 .4254 Metetra
.414 .772 .995 r
.17585 .4254 .19493 .43491 .22061 .43189 .20163 .42296 Metetra
.436 .792 .997 r
.20163 .42296 .22061 .43189 .24673 .42807 .22788 .41959 Metetra
.463 .811 .998 r
.22788 .41959 .24673 .42807 .27326 .42333 .25458 .41519 Metetra
.493 .83 .999 r
.25458 .41519 .27326 .42333 .30021 .41759 .28172 .40967 Metetra
.524 .847 .998 r
.28172 .40967 .30021 .41759 .32756 .41079 .30929 .40298 Metetra
.556 .862 .997 r
.30929 .40298 .32756 .41079 .35529 .40287 .33727 .39506 Metetra
.586 .875 .994 r
.33727 .39506 .35529 .40287 .3834 .39382 .36563 .3859 Metetra
.616 .885 .99 r
.36563 .3859 .3834 .39382 .41184 .38362 .39436 .37547 Metetra
.644 .893 .984 r
.39436 .37547 .41184 .38362 .44061 .37226 .42342 .36378 Metetra
.669 .898 .978 r
.42342 .36378 .44061 .37226 .46967 .35976 .45279 .35083 Metetra
.693 .9 .971 r
.45279 .35083 .46967 .35976 .49901 .34614 .48245 .33665 Metetra
.713 .9 .963 r
.48245 .33665 .49901 .34614 .5286 .33146 .51236 .32128 Metetra
.731 .898 .954 r
.51236 .32128 .5286 .33146 .55841 .31578 .54249 .30478 Metetra
.745 .893 .946 r
.54249 .30478 .55841 .31578 .58843 .29921 .57283 .28726 Metetra
.757 .886 .937 r
.57283 .28726 .58843 .29921 .61863 .28189 .60334 .26884 Metetra
.764 .877 .929 r
.60334 .26884 .61863 .28189 .64902 .26407 .63402 .24975 Metetra
.766 .864 .921 r
.63402 .24975 .64902 .26407 .6796 .24612 .66486 .23032 Metetra
.759 .847 .917 r
.66486 .23032 .6796 .24612 .71041 .2288 .69591 .21124 Metetra
.726 .818 .922 r
.69591 .21124 .71041 .2288 .74167 .21453 .72731 .19466 Metetra
.484 .709 .97 r
.03345 .41837 .05272 .43399 .07693 .43025 .05747 .41648 Metetra
.389 .697 .982 r
.05747 .41648 .07693 .43025 .10112 .42898 .08157 .41655 Metetra
.357 .703 .984 r
.08157 .41655 .10112 .42898 .12562 .42813 .10603 .41678 Metetra
.352 .717 .986 r
.10603 .41678 .12562 .42813 .15051 .42705 .13093 .41659 Metetra
.364 .737 .989 r
.13093 .41659 .15051 .42705 .17585 .4254 .15631 .41566 Metetra
.386 .758 .992 r
.15631 .41566 .17585 .4254 .20163 .42296 .18219 .41381 Metetra
.414 .781 .994 r
.18219 .41381 .20163 .42296 .22788 .41959 .20857 .41091 Metetra
.446 .803 .997 r
.20857 .41091 .22788 .41959 .25458 .41519 .23542 .40685 Metetra
.481 .824 .998 r
.23542 .40685 .25458 .41519 .28172 .40967 .26276 .40155 Metetra
.516 .844 .998 r
.26276 .40155 .28172 .40967 .30929 .40298 .29054 .39496 Metetra
.551 .86 .997 r
.29054 .39496 .30929 .40298 .33727 .39506 .31877 .38705 Metetra
.585 .874 .994 r
.31877 .38705 .33727 .39506 .36563 .3859 .3474 .37777 Metetra
.617 .885 .989 r
.3474 .37777 .36563 .3859 .39436 .37547 .37641 .36711 Metetra
.647 .893 .984 r
.37641 .36711 .39436 .37547 .42342 .36378 .40578 .35507 Metetra
.674 .899 .977 r
.40578 .35507 .42342 .36378 .45279 .35083 .43547 .34166 Metetra
.699 .902 .969 r
.43547 .34166 .45279 .35083 .48245 .33665 .46545 .3269 Metetra
.721 .902 .96 r
.46545 .3269 .48245 .33665 .51236 .32128 .49569 .31082 Metetra
.739 .9 .95 r
.49569 .31082 .51236 .32128 .54249 .30478 .52616 .2935 Metetra
.755 .895 .941 r
.52616 .2935 .54249 .30478 .57283 .28726 .55683 .275 Metetra
.767 .888 .931 r
.55683 .275 .57283 .28726 .60334 .26884 .58767 .25547 Metetra
.776 .879 .921 r
.58767 .25547 .60334 .26884 .63402 .24975 .61865 .23508 Metetra
.78 .866 .913 r
.61865 .23508 .63402 .24975 .66486 .23032 .64978 .21415 Metetra
.776 .85 .907 r
.64978 .21415 .66486 .23032 .69591 .21124 .68107 .19328 Metetra
.751 .825 .91 r
.68107 .19328 .69591 .21124 .72731 .19466 .71264 .17436 Metetra
.415 .68 .971 r
.01381 .40245 .03345 .41837 .05747 .41648 .03762 .40243 Metetra
.327 .666 .975 r
.03762 .40243 .05747 .41648 .08157 .41655 .06159 .40386 Metetra
.304 .675 .975 r
.06159 .40386 .08157 .41655 .10603 .41678 .08599 .40518 Metetra
.308 .694 .978 r
.08599 .40518 .10603 .41678 .13093 .41659 .11089 .40588 Metetra
.327 .718 .982 r
.11089 .40588 .13093 .41659 .15631 .41566 .13632 .40569 Metetra
.356 .744 .987 r
.13632 .40569 .15631 .41566 .18219 .41381 .16228 .40444 Metetra
.391 .77 .991 r
.16228 .40444 .18219 .41381 .20857 .41091 .18877 .402 Metetra
.429 .795 .995 r
.18877 .402 .20857 .41091 .23542 .40685 .21578 .39829 Metetra
.469 .819 .997 r
.21578 .39829 .23542 .40685 .26276 .40155 .2433 .39322 Metetra
.508 .84 .998 r
.2433 .39322 .26276 .40155 .29054 .39496 .27131 .38674 Metetra
.547 .858 .997 r
.27131 .38674 .29054 .39496 .31877 .38705 .29977 .37882 Metetra
.584 .874 .994 r
.29977 .37882 .31877 .38705 .3474 .37777 .32868 .36942 Metetra
.618 .886 .989 r
.32868 .36942 .3474 .37777 .37641 .36711 .35798 .35853 Metetra
.65 .894 .983 r
.35798 .35853 .37641 .36711 .40578 .35507 .38766 .34613 Metetra
.679 .9 .975 r
.38766 .34613 .40578 .35507 .43547 .34166 .41768 .33225 Metetra
.705 .903 .966 r
.41768 .33225 .43547 .34166 .46545 .3269 .448 .31689 Metetra
.728 .903 .957 r
.448 .31689 .46545 .3269 .49569 .31082 .47858 .3001 Metetra
.748 .901 .946 r
.47858 .3001 .49569 .31082 .52616 .2935 .5094 .28192 Metetra
.764 .896 .936 r
.5094 .28192 .52616 .2935 .55683 .275 .54042 .26243 Metetra
.777 .889 .925 r
.54042 .26243 .55683 .275 .58767 .25547 .57159 .24175 Metetra
.787 .88 .914 r
.57159 .24175 .58767 .25547 .61865 .23508 .60291 .22005 Metetra
.792 .868 .905 r
.60291 .22005 .61865 .23508 .64978 .21415 .63434 .19759 Metetra
.791 .853 .897 r
.63434 .19759 .64978 .21415 .68107 .19328 .66589 .17491 Metetra
.773 .831 .897 r
.66589 .17491 .68107 .19328 .71264 .17436 .69765 .15362 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.1515 .21036 m
.15612 .21503 L
s
[(0.2)] .14227 .20104 .98988 1 Mshowa
.27764 .16097 m
.28204 .16584 L
s
[(0.4)] .26884 .15124 .90478 1 Mshowa
.41014 .10909 m
.4143 .11416 L
s
[(0.6)] .40182 .09894 .81968 1 Mshowa
.5495 .05452 m
.55338 .05981 L
s
[(0.8)] .54173 .04395 .73459 1 Mshowa
.125 Mabswid
.06081 .24588 m
.06366 .24859 L
s
.09068 .23418 m
.09351 .23692 L
s
.12091 .22234 m
.12371 .22511 L
s
.18247 .19824 m
.18521 .20107 L
s
.21381 .18597 m
.21651 .18883 L
s
.24553 .17355 m
.2482 .17644 L
s
.31015 .14824 m
.31276 .15119 L
s
.34306 .13535 m
.34564 .13834 L
s
.37639 .1223 m
.37893 .12532 L
s
.44432 .09571 m
.44677 .09878 L
s
.47893 .08215 m
.48134 .08526 L
s
.51399 .06843 m
.51636 .07157 L
s
.58547 .04044 m
.58776 .04364 L
s
.62192 .02616 m
.62416 .0294 L
s
.65884 .01171 m
.66104 .01497 L
s
gsave
.29165 .07573 -75.8979 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooon?ooooo`;o0000/?oo
ool00?ooooooS?ooool3o`000003ooooool0003ooooo0:oooooo003ooooooh[ooooo0_l00004oooo
o`;o0000[oooool00?ooooooQoooool3o`0000Kooooo00?o0000ooooool00000[_ooool00?oooooo
QOooool2o`0000Wooooo00?o0000ooooool00000[_ooool00?ooooooP_ooool3o`0000_ooooo00Co
0000oooooooooooo0000[Oooool00?ooooooOoooool3o`0000kooooo00Go0000oooooooooooooooo
o`00002/ooooo`00oooooommooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`05o`000?oo
ooooooooooooool00000[?ooool00?ooooooN_ooool3o`0000Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo003oooooogSooooo0_l0000G
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool00?ooooooMOooool3o`00
01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00oooooomcooooo`;o
00007?ooool00ol0003oooooooooo`03ooooo`;o0000Z?ooool00?ooooooL?ooool3o`0001kooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`00002Xooooo`00oooooom^ooooo`;o00008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo003oooooof_ooooo1?l0000R
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0YOooool00?oooooo=oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0002Cooooo0_l00004ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Uooooo`00oooooolfooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`?o0000:?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Cooooo003oooooocKooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000001gooooo0ol0000[ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Xoooool00?oooooo=_ooool01?l0003oooooooooool0
0008ooooo`?o00007?ooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2Sooooo`00oooooolfooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000Hooooo`?o0000<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:;ooooo
003oooooocKooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Ko
oooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00?oooooo
=oooool2o`0000Wooooo0ol0000Dooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0:7ooooo003ooooooeOooooo0_l00002ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00oooooomDooooo`?o00001Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo0ol0002Qooooo`00oooooomBoooo
o`;o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo003oooooodoo
oooo0ol00010ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0W_ooool00?oooooo
COooool2o`0004?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Mooooo`00oooo
oom:ooooo`?o0000AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo003o
ooooodOooooo0ol00018ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0W?ooool0
0?ooooooAOooool2o`000003ooooool0003ooooo04Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2Kooooo`00oooooom2ooooo`?o00001?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Voooool00;Gooooo0_l000001?oooooo0000
o`000?ooool4o`00083ooooo0_l00008ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2Jooooo`00]_ooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0007cooooo0ol0001Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0VOooool00;Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001jooooo`;o
0000EOooool00ol0003oooooooooo`0@ooooo`;o0000V_ooool00;Oooooo00?o0000ooooooooool0
0_ooool3o`0007Sooooo0ol0001Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000
V_ooool00;Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001eooooo`;o0000
F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09Oooooo002fooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo0000L_ooool4o`0005_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`2Gooooo`00]Oooool2o`000004ooooool0003o0000ooooo`Co0000
LOooool2o`0000Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Wooooo0ol00004ooooo`;o00001?ooool2o`0007kooooo003oooooobkooooo0ol0
001Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001moooo
o`00ooooool[ooooo`?o0000I?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo07_ooooo003oooooobWooooo0_l0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0Noooool00?oooooo9_ooool3o`0006[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`06ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0007gooooo003oooooobCooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo0000OOooool00>gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol0000Uooooo`Co0000K_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
1Ol00003ooooo`;o00001?ooool2o`0007kooooo003/ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Rooooo`;o00001?ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo01Kooooo0_l0002Cooooo`00k?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000007oooool3o`0007Cooooo00?o0000ooooooooool05?ooool2o`00
0003ooooool0003ooooo09;ooooo003/ooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Noooo
o`;o0000Moooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo093ooooo003/ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07?ooool3o`0007Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`2@ooooo`00k?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo01Wooooo0_l0001looooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0Soooool00>gooooo0_l0000:ooooo`;o00005_ooool3o`0007kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`2>ooooo`00ooooool?ooooo`Co0000P?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo08kooooo003oooooo`gooooo0_l00004ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2=ooooo`00ooooool:
ooooo`?o0000Q_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08cooooo003ooooo
o`Sooooo0_l00029ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0S?ooool00?oo
oooo1Oooool3o`0008_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2;ooooo`00
ooooool3ooooo`;o0000S_ooool00ol0003oooooooooo`0Looooo`?o0000S?ooool00?oooooo0ol0
002@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0R_ooool00?gooooo0_l00000
0ooooooo0000ooooo`2Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0ROooool0
0?[ooooo0ol00004ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`28ooooo`00n?ooool2o`0000Sooooo00?o0000ooooooooool0S_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo08Sooooo003eooooo`?o0000Voooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo08Oooooo003booooo`?o0000W_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo08Kooooo003`ooooo`;o0000XOooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo08Kooooo003]ooooo`?o0000Xoooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo08Gooooo003[ooooo`;o000000?oooooo`000?ooool0Xoooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo08Gooooo003Xooooo`?o00001?ooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo02?ooooo0_l00025ooooo`00i_ooool2o`000:_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooo`000025ooooo`00hoooool3o`000:gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`23ooooo`00hOooool2o`000;3ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`22ooooo`00g_ooool3o`000;;ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`21ooooo`00Yoooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0002Kooooo0_l0002eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
POooool00:Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Rooooo`?o0000
0_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
P?ooool00:Kooooo00Co0000oooooooooooo00001oooool5o`00023ooooo0ol0002kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0Ooooool00:Kooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0000Oooooo`;o0000__ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo07oooooo002Vooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
00007?ooool3o`000<3ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1nooooo`00
Y_ooool01?l0003oooooooooool00009ooooo`;o00006_ooool2o`000<?ooooo00?o0000oooooooo
ool0:?ooool2o`0007oooooo002Wooooo`;o00002oooool00ol0003oooooooooo`0Eooooo`?o0000
aOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo000007oooooo003:ooooo`?o0000aooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07cooooo0037ooooo`?o00000oooool0
0ol0003oooooooooo`34ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Noooool0
0<Gooooo0_l0003<ooooo`;o0000;Oooool00ol0003oooooooooo`1kooooo`00`_ooool3o`000<go
oooo00?o0000olGDiOl00000;_ooool00ol0003oooooooooo`1jooooo`00`?ooool2o`000<kooooo
0_l00002olGDi@;o0000;_ooool00ol0003oooooooooo`1iooooo`00_Oooool3o`000<oooooo00?o
0000olGDiOo5e>D00_o5e>D00ol0003oaMCUo`00000]ooooo`03o`000?oooooooooo07Wooooo002j
ooooo`?o0000d?ooool2o`0000GoaMCU00Co0000olGDiOo5e>Go0000;Oooool00ol0003ooooooooo
o`1hooooo`00^?ooool2o`000003ooooool0003ooooo0<kooooo0_l00007olGDi@04o`000?o5e>Go
aMCUo`0002kooooo00?o0000ooooooooool0Moooool00;Gooooo0ol00004ooooo`03o`000?oooooo
oooo0<_ooooo00?o0000olGDiOo5e>D01oo5e>D01Ol0003oaMCUolGDiOo5e>Go000002gooooo0_l0
001hooooo`00/oooool2o`0000Sooooo00?o0000ooooooooool0b?ooool2o`0000[oaMCU00?o0000
olGDiOo5e>D00_o5e>D00ol0003oooooooooo`0Yooooo`03o`000?oooooo000007Sooooo002`oooo
o`?o0000e?ooool00ol0003oaMCUolGDi@0:olGDi@03o`000?o5e>GoaMCU00;oaMCU00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`1fooooo`00[_ooool2o`000=Gooooo0_l0000>olGDi@03
o`000?o5e>GoaMCU00;oaMCU00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`;o0000GOooool00:_ooooo0ol0003Fooooo`03o`00
0?o5e>GoaMCU00koaMCU00?o0000olGDiOo5e>D00oo5e>D00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0F_ooool00:Wooooo0ol0003Fooooo`;o00004Oo5e>D00ol0003o
aMCUolGDi@03olGDi@;o0000;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1Jooooo`00Y_ooool3o`0000?o
oooo00?o0000ooooooooool0d_ooool00ol0003ob][Uo`00000AolGDi@04o`000?o5e>GoaMCUolGD
i@;o000000?o`=?Xo`000?ooool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1Jooooo`00Y?ooool2o`00
0=[ooooo00Go0000ol[JiOo:f^Gob][Uo`00000@olGDi@04o`000?o5e>GoaMCUo`0000Co`=?X00?o
0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000?o00000ooo
ool01?l0003oooooooooool0001Looooo`00XOooool3o`000=[ooooo0_l00005ol[Ji@03o`000?o5
e>GoaMCU00goaMCU0ol00006ol3Cj003o`000?oooooooooo02[ooooo00?o0000ooooooooool01Ooo
ool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0001Loooo
o`00W_ooool3o`000=cooooo00?o0000ol[JiOo:f^D01_o:f^D00ol0003oaMCUolGDi@0;olGDi@;o
00002?o0dnP00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo
0000o`000003o`0000?ooooo0_l0001Mooooo`00W?ooool2o`000=kooooo00?o0000ol[JiOo:f^D0
2?o:f^D00ol0003oaMCUolGDi@09olGDi@03o`000?o0dnSo000000Wo`=?X00?o0000ooooooooool0
:_ooool2o`0007;ooooo001Uooooo`;o00001?ooool01?l0003oooooooooooooool5o`0002Gooooo
0ol0003Nooooo`;o00002oo:f^D00ol0003oaMCUolGDi@07olGDi@;o00000_o0dnP00ol0003o`=?X
ol3Cj008ol3Cj003o`000?oooooooooo02Oooooo0_l000000ooooooo0000ooooo`1aooooo`00I?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0002?ooooo0_l000000ooooooo
0000ooooo`3Mooooo`03o`000?o:f^Gob][U00cob][U00?o0000olGDiOo5e>D01?o5e>D2o`0000Co
`=?X00?o0000ol3Cj?o0dnP02?o0dnP00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06oo
oooo001Tooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08?ooool3o`0000Co
oooo00?o0000ooooooooool0f_ooool00ol0003ob][Uol[Ji@0>ol[Ji@03o`000?o5e>GoaMCU00;o
aMCU00?o0000ol3Cj?o0dnP01?o0dnP00ol0003o`=?Xol3Cj009ol3Cj003o`000?oooooooooo02_o
oooo00?o0000ooooooooool0K_ooool006Cooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`0Mooooo`;o0000h_ooool2o`0001;ob][U00Co0000olGDiOl0003o00001oo0dnP00ol0
003o`=?Xol3Cj009ol3Cj003o`000?oooooooooo02_ooooo00?o0000ooooooooool0K_ooool006Co
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001_ooooo0ol0003S
ooooo`03o`000?o:f^Gob][U01;ob][U0_l00009ol3Cj003o`000?o0dnSo`=?X00[o`=?X00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1]ooooo`00I?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000006Oooool2o`000>Gooooo00?o0000ol[JiOo:f^D04_o:
f^D00ol0003oa]WXo`000009ol3Cj003o`000?o0dnSo`=?X00[o`=?X0_l0000]ooooo`03o`000?oo
oooooooo06cooooo001Uooooo`;o00002Oooool3o`0001Oooooo0ol0003Uooooo`;o00004oo:f^D2
o`0000?oa]WX00?o0000ol3Cj?o0dnP01_o0dnP00ol0003o`=?Xol3Cj008ol3Cj0;o000000?o^M7/
o`000?ooool0;?ooool00ol0003oooooooooo`1/ooooo`00R?ooool3o`000>Kooooo00?o0000ol[N
iol000004_o:f^D00ol0003oa]WXolKIj004olKIj003o`000?o0dnSo`=?X00Go`=?X00?o0000ol3C
j?o0dnP01_o0dnP2o`0000Co^M7/00?o0000ooooooooool0:oooool00ol0003oooooooooo`1[oooo
o`00QOooool3o`0000?ooooo00?o0000ooooooooool0h_ooool01Ol0003ob]kWol[Nioo:g^Oo0000
00oob][U0_l00008olKIj003o`000?o0dnSo`=?X00Go`=?X00?o0000ol3Cj?o0dnP00oo0dnP2o`00
00Oo^M7/00?o0000ooooooooool0:_ooool2o`0006cooooo0022ooooo`?o0000jOooool2o`0000Go
b]kW00?o0000ol[JiOo:f^D02oo:f^D00ol0003oa]WXolKIj009olKIj003o`000?o0dnSo`=?X00Co
`=?X00Co0000ol3Cj?o0dnSo`=?X0_l00009okWAk003o`000?oooooooooo02Wooooo00?o0000oooo
ool00000K?ooool0083ooooo0_l0003[ooooo`03o`000?o:g^Oob]kW00Kob]kW00?o0000ol[JiOo:
f^D02Oo:f^D00ol0003oa]WXolKIj00;olKIj003o`000?o0dnSo`=?X00?o`=?X00Co0000ol3Cj?l0
003o00003?nidN`00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo0ol0000doooo
o`00OOooool3o`000>cooooo00?o0000ol[Nioo:g^L02?o:g^L00ol0003ob][Uol[Ji@06ol[Ji@;o
00003oo6fNP00ol0003o`=?Xol3Cj002ol3Cj0;o00003onidN`00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool007_ooooo0_l0003]ooooo`;o0000
3?o:g^L00ol0003ob][Uol[Ji@04ol[Ji@03o`000?o6fNSoa]WX013oa]WX00?o0000ol3Cj?l00000
0_l0000AokWAk003o`000?oooooooooo02[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0cooooo`00N?ooool3o`000>kooooo00?o0000ol[Nioo:g^L03Oo:g^L01?l0003ob][Uol[J
iOo:f^D2o`0001?oa]WX0_l00002okWAk003o`000?nidNco^M7/00oo^M7/00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03?ooooo001fooooo`;o00000ooo
ool00ol0003oooooooooo`3Zooooo`03o`000?o:g^Oob]kW00oob]kW00?o0000ol[JiOl000005?o6
fNP00ol0003o`]SZo`000002okWAk003o`000?nidNco^M7/013o^M7/00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0^ooooo`05o`000?oooooo0000ooooool00000<oooool007?ooooo0ol0
0006ooooo`03o`000?oooooooooo0>Oooooo0_l0000Bol[Ni`;o00004oo6fNP2o`0000?o`]SZ00?o
0000okWAk?l000004_nidN`2o`0002cooooo00?o0000ooooooooool0;_ooool01Ol0003oooooo`00
0?oooooo000003?ooooo001aooooo`;o0000l_ooool00ol0003ob]kWol[Ni`0Aol[Ni`04o`000?o7
gNWoamgYo`00013oa]WX0_l00006ol;HjP;o00004?nidN`2o`000003ok;?k_l0003ooooo02cooooo
00?o0000ooooooooool0;Oooool5o`0003?ooooo001^ooooo`?o0000loooool00ol0003ob]kWol[N
i`0@ol[Ni`;o00001?o7gNT00ol0003oa]WXolKIj00<olKIj003o`000?o2f>[o`]SZ00Oo`]SZ00?o
0000okWAk?nidN`02onidN`3o`0000Co//o^00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1Uooooo`00K?ooool2o`000?Cooooo0ol0000@ol[Ni`;o00001oo7gNT00ol0003oa]WXolKIj009
olKIj0;o00002_o2f>X2o`0000[o^M7/0_l00008ok;?kP03o`000?oooooooooo02Sooooo0ol0001V
ooooo`00JOooool3o`000?Gooooo00Go0000olWQjOo9hNWobN7Yo`00000>ol[Ni`03o`000?o7gNWo
amgY00SoamgY00?o0000olKIj?o6fNP01oo6fNP00ol0003o`]SZol;HjP0:ol;HjP;o00002?nidN`2
o`0000_o//o^00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`00I_ooool3o`00
00?ooooo00?o0000ooooooooool0l?ooool2o`0000GobN7Y00?o0000ol[Nioo:g^L02Oo:g^L2o`00
00coamgY00?o0000olKIj?o6fNP01?o6fNP2o`0000go`]SZ00?o0000ol;Hj_l000001?nidN`3o`00
00ko//o^00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Sooooo`00I?ooool2o`000?So
oooo00?o0000olWQjOo9hNT01_o9hNT00ol0003ob]kWol[Ni`07ol[Ni`03o`000?o7gNWoamgY00go
amgY00Co0000olKIj?o6fNSoa]WX0_l0000?ol;HjP05o`000?o2f>[o`]SZo`000?nidN`00_l0000A
ok;?kP03o`000?oooooooooo02[ooooo00?o0000ooooooooool0H_ooool0067ooooo0ol0003hoooo
o`;o00002_o9hNT00ol0003ob]kWol[Ni`04ol[Ni`;o00004Oo7gNT00ol0003oa]WXo`00000Aol;H
jP03o`000?o2f>[o`]SZ00;o00005?nbcnh00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
067ooooo001Oooooo`;o0000n_ooool00ol0003obN7YolWQj@0;olWQj@04o`000?o:g^Oob]kWol[N
i`;o00004oo7gNT2o`0001;o`]SZ0ol000000onmengo0000ok;?kP0Dok;?kP03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0HOooool005cooooo0ol0003kooooo`03o`000?o9hNWobN7Y00go
bN7Y00?o0000ol[Niol000005?o7gNT00ol0003oa=g[o`00000Bol;HjP;o00000onmend00ol0003o
//o^ok;?kP0Cok;?kP03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H?ooool005[ooooo
0_l0003looooo`;o00004?o9hNT2o`0001?oamgY0_l00003olCMj`03o`000?o2f>[o`]SZ00go`]SZ
0_l000000onmengo0000okgGk@03okgGk@03o`000?nbcnko//o^01;o//o^0_l0000[ooooo`03o`00
0?oooooooooo05oooooo001Gooooo`?o00000_ooool00ol0003oooooooooo`3hooooo`03o`000?o9
hNWobN7Y00oobN7Y00Co0000olKQjoo6hN_o00004?o7gNT2o`0000Koa=g[00?o0000ol;Hj_o2f>X0
2_o2f>X2o`0000?o_MO]00?o0000okgGkOnmend00onmend00ol0003o//o^ok;?kP0>ok;?kP?o0000
00?oZlcao`000?ooool0:_ooool00ol0003oooooooooo`1Oooooo`00EOooool2o`000?kooooo0_l0
000@olWQj@;o00001?o6hN/00ol0003oamgYolOMj@0<olOMj@03o`000?o4gN_oa=g[00Ooa=g[00?o
0000ol;Hj_o2f>X01oo2f>X2o`0000Go_MO]00?o0000okgGkOnmend01?nmend00ol0003o//o^ok;?
kP0:ok;?kP?o00001On[c?400ol0003oooooooooo`0Wooooo`?o0000H?ooool005;ooooo0ol0003o
ooooo`03o`000?o9hNWobN7Y00oobN7Y00?o0000olKQjoo6hN/01Oo6hN/00ol0003oamgYolOMj@09
olOMj@;o00002oo4gN/00ol0003o`]SZol;HjP04ol;HjP;o00001onmend00ol0003o_MO]okgGk@05
okgGk@03o`000?nbcnko//o^00Oo//o^0_l00009oj_<l@03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0GOooool0053ooooo0_l0003oooooo`7ooooo0ol0000?olWQj@;o00002Oo6hN/00ol0
003oamgYolOMj@07olOMj@03o`000?o4gN_oa=g[00coa=g[00?o0000ol;Hj_o2f>X00_o2f>X00ol0
003o_MO]okgGk@07okgGk@03o`000?nmengo_MO]00Ko_MO]00?o0000ok;?k_nbcnh00onbcnh3o`00
00_oZlca00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Mooooo`00COooool3o`000?oo
oooo0_ooool01Ol0003oa^?/olKSk?o6hnco000000gobN7Y00?o0000olKQjoo6hN/02_o6hN/00ol0
003oamgYolOMj@04olOMj@;o00004?o4gN/01?l0003o`]SZo`000?l0000:okgGk@03o`000?nmengo
_MO]00Oo_MO]00?o0000ok;?k_l000000_l0000?oj_<l@03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0G?ooool004[ooooo0ol0003oooooo`?ooooo0_l00005olKSk003o`000?o9hNWobN7Y
00WobN7Y00?o0000olKQjoo6hN/03?o6hN/01?l0003oamgYolOMjOo7gNT2o`0001;oa=g[0_l0000;
okgGk@;o00002Onmend2o`0001?oZlca00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1K
ooooo`00B?ooool2o`0000?ooooo00?o0000ooooooooool0o_ooool00ol0003oa^?/olKSk006olKS
k003o`000?o9hNWobN7Y00KobN7Y0_l0000@olKQj`03o`000?o7gNWo000001;oa=g[0_l00002ol3L
k@03o`000?nmengo_MO]00Go_MO]0ol000000onmengo0000okgGk@06okgGk@;o000000?o^=K_o`00
0?n[c?404on[c?400ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05_ooooo0015ooooo`?o
0000ooooool5ooooo`;o00002_o6hn`00ol0003obN7YolWQj@04olWQj@03o`000?o6hN_oa^7[013o
a^7[0ol0000AolCMj`03o`000?o0g>go`=c]00?o`=c]00Co0000okgGkOnmengo_MO]0ol00005okgG
k@03o`000?nmengo_MO]00;o_MO]0_l00004okSFk`03o`000?n[c?7oZlca017oZlca00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Jooooo`00@oooool2o`000?oooooo1oooool00ol0003o
a^?/olKSk00;olKSk004o`000?o9hNWobN7YolWQj@;o00004_o6hN/01Ol0003o`n3]ol?PkOo3h>go
000000koa=g[0_l00007ol3Lk@?o00002Onmend01?l0003o_MO]o`000?l00007okSFk`03o`000?n[
c?7oZlca017oZlca00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Iooooo`00@?ooool3
o`000?oooooo2?ooool00ol0003oa^?/olKSk00=olKSk003o`000?o9hNWo000001;oa^7[0_l00005
ol?Pk@03o`000?o4gN_oa=g[00Woa=g[0_l00006ol3Lk@?o000000?o`=c]o`000?nmend02Onmend2
o`0000[o^=K_00?o0000oj_<lOn[c?403on[c?43o`0002[ooooo00?o0000ooooooooool0FOooool0
03oooooo0_l0003oooooo`Sooooo0_l0000@olKSk0?o00004?o6hN/2o`0000So`n3]00?o0000olCM
joo4gN/01oo4gN/00ol0003o`=c]ol3Lk@03ol3Lk@?o00001Oo0g>d00ol0003o_MO]okgGk@05okgG
k@;o000000?o^=K_o`000?nhe^l02_nhe^l00ol0003oZlcaoj_<l@0;oj_<l@?o00000_nSb?<00ol0
003oooooooooo`0Wooooo`?o0000F_ooool003oooooo00?o0000ooooool00000ooooool6ooooo`03
o`000?o6hncoa^?/00ooa^?/00Go0000olCSk_o4hnkoa>?^o`00000>olKQj`03o`000?o3h>go`n3]
00Wo`n3]00?o0000olCMjoo4gN/01?o4gN/2o`0000?o`=c]0ol00009ol3Lk@03o`000?nmengo_MO]
00;o_MO]0_l00004okSFk`03o`000?nhe^oo^=K_00So^=K_00?o0000oj_<lOn[c?402?n[c?43o`00
00KoXlSc00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Gooooo`00?_ooool3o`000003
ooooool0003ooooo0?oooooo0_ooool2o`00013oa^?/0_l00005olCSkP03o`000?o6hN_oa^7[00Wo
a^7[0_l0000=ol?Pk@04o`000?o4gN_oa=g[olCMj`;o00000_o0g>d3o`0000go`=c]00Co0000okgG
kOl0003o00001onhe^l00ol0003o^=K_okSFk`08okSFk`03o`000?n[c?7oZlca00CoZlca0ol0000:
oj?8l`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool3o`0000Cooooo0_l00004
ooooo`;o00001?ooool2o`0003Sooooo000oooooo`05o`000?ooooooooooooooool00000ooooool1
ooooo`03o`000?o6hncoa^?/00koa^?/0_l00008olCSkP03o`000?o6hN_oa^7[00Ooa^7[00?o0000
ol?PkOo3h>d03_o3h>d00ol0003oa=g[o`000002ol3Lk@;o00004?o0g>d2o`0000Wo^=K_00?o0000
okSFkonhe^l02Onhe^l00ol0003oZlcaoj_<l@03o`0000koXlSc00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003Oooooo000nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0noooool3o`0000ooa^?/00?o0000olCSk_o4hnh0
2Oo4hnh00ol0003oa^7[olKQj`04olKQj`;o00004Oo3h>d5o`00013o`=c]0_l000000onlfnoo0000
okSFk`09okSFk`03o`000?nhe^oo^=K_00So^=K_0ol0000Boj?8l`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000gooooo`00?_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?Wooooo00Go0000ol?Ukoo3iNoo`nG_o`00000<
olKSk0;o00003Oo4hnh01?l0003oa^7[olKQjoo6hN/2o`0001;o`n3]0ol0000Bol3Lk@03o`000?nl
fnoo_=__00;o_=__00?o0000okSFkonhe^l02?nhe^l00ol0003o^=K_okSFk`05okSFk`;o000000?o
/mCao`000?nSb?<04_nSb?<00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000=oooool003kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3fooooo`;o00001Oo3iNl00ol0003oa^?/olKSk008olKSk003o`000?o4hnkoa>?^00ko
a>?^00?o0000olKQjol000004Oo3h>d3o`0000?o`=o_00?o0000ol3LkOo0g>d03Oo0g>d2o`0000Ko
_=__00?o0000okSFkonhe^l02?nhe^l01?l0003o^=K_okSFkonhe^l3o`0000Co/mCa00?o0000oj?8
lonSb?<04OnSb?<00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000=oooool003kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3cooooo`;o00002?o3iNl2o`0000Koa^?/0_l0000AolCSkP?o00003_o3h>d4o`0000Ko`=o_00?o
0000ol3LkOo0g>d02_o0g>d2o`0000Wo_=__00?o0000okSFkonhe^l01onhe^l01?l0003o^=K_o`00
0?l00008ok?Dl@03o`000?nSb??oXlSc017oXlSc00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`07ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000=oooool003kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3aooooo`03o`000?o3iNoo`nG_00[o`nG_00Co0000olKSk?o6hncoa^?/0_l0000A
olCSkP;o00000oo1h^l00ol0003o`n3]ol?Pk@08ol?Pk@?o000000?o`n3]o`000?o0gnl02?o0gnl0
0ol0003o`=c]ol3Lk@07ol3Lk@;o00003?nlfnl00ol0003o^=K_okSFk`06okSFk`;o00002once?40
0ol0003oXlScoj?8l`0?oj?8l`?o0000:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0003Sooooo000nooooo`;o00002Oooool00ol0
003oooooooooo`3^ooooo`;o00003_o3iNl00ol0003oa^?/o`00000BolCSkP03o`000?o1h^oo`N;_
00Co`N;_00?o0000ol?PkOo3h>d01?o3h>d3o`0000;o`n3]0_l0000;ol3Ok`03o`000?o0g>go`=c]
00Co`=c]0_l0000?okcKk`03o`000?nhe^oo^=K_00;o^=K_0ol00002ok?Dl@03o`000?nce?7o/mCa
00Wo/mCa00?o0000oj?8lonSb?<02_nSb?<4o`0000;oVLGf00?o0000ooooooooool09oooool2o`00
05Cooooo000mooooo`;o00002oooool00ol0003oooooooooo`3/ooooo`03o`000?o3iNoo`nG_00ko
`nG_0ol0000@olCSkP;o00002?o1h^l00ol0003o`n3]ol?Pk@03o`0000Co`n3]00?o0000ol3Okoo0
gnl03?o0gnl00ol0003o`=c]ol3Lk@02ol3Lk@03o`000?nlfnoo_=__013o_=__00Co0000okSFkol0
003o00001_nce?400ol0003o/mCaok?Dl@09ok?Dl@03o`000?nSb??oXlSc00GoXlSc1?l00007oiW5
mP03o`000?oooooooooo02Cooooo0_l000000ooooooo0000ooooo`1Cooooo`00?Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0>Wooooo0_l0000@ol?Uk`05o`000?o1iO3o`NG`ol7U
l?l000003Oo4hnh2o`0000[o`N;_0ol00005ol?Pk@;o00004?o0gnl01?l0003o`=c]o`000?l0000C
okcKk`;o00002?nce?400ol0003o/mCaok?Dl@0:ok?Dl@03o`000?nSb??oXlSc00Co00003?nIaOH0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo057ooooo000mooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0i_ooool2o`00013o`nG_0_l00005ol7Ul003o`000?o4hnkoa>?^
00Soa>?^0_l0000:ol7Rk`;o00000_o1h^l01?l0003o`n3]ol?PkOo3h>d2o`0001;o`=o_0ol0000B
okcKk`;o00000_nhf_400ol0003o/mCaok?Dl@06ok?Dl@03o`000?nce?7o/mCa00Wo/mCa0ol0000@
oiW5mP03o`000?oooooooooo02Sooooo00?o0000ooooooooool0D?ooool003gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3Tooooo`03o`000?o3iNoo`nG_00ko`nG_0_l00008ol7U
l0;o00001_o4hnh2o`0000Wo`N;_0ol00005ol7Rk`03o`000?o3h>go000001;o`=o_0_l00003okcN
l@03o`000?nlfnoo_=__00go_=__0_l00005okSJl@03o`000?nce?7o/mCa00Ko/mCa00?o0000ok?D
lOnce?401Once?43o`000003ojgBlol0003oVLGf017oVLGf00?o0000ooooooooool09oooool00ol0
003oooooooooo`1@ooooo`00?Oooool00ol0003oooooooooo`0>ooooo`;o0000h_ooool3o`0000oo
`nG_00?o0000ol7Ul?o1iO002_o1iO000ol0003oa>?^olCSkP02olCSkP03o`000?o1h^oo`N;_00Ko
`N;_0ol00008ol7Rk`?o00004?o0gnl2o`0000Ko_=ka00?o0000okcKkonlfnl02_nlfnl2o`0000So
^=[a00?o0000ok?DlOnce?401Once?400ol0003o/mCaok?Dl@02ok?Dl@?o00001On]d_<00ol0003o
VLGfoiW5mP0@oiW5mP03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Coooool003gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Mooooo`;o00000onoi_800ol0003o`nG_
ol?Uk`0:ol?Uk`;o00003_o1iO001?l0003oa>?^o`000?l00006ol7Rk`?o00002Oo1h^l2o`0000?o
_^;a00?o0000ol3Okoo0gnl02oo0gnl2o`0000Wo_=ka00?o0000okcKkonlfnl02?nlfnl00ol0003o
^=[aokSJl@09okSJl@03o`000?nce?7o/mCa00Go/mCa00Co0000ok?DlOl0003o00002On]d_<00ol0
003oVLGfoiW5mP0@oiW5mP03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool003go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Kooooo`03o`000?noi_;o_nKb00Co
_nKb00?o0000ol?Ukoo3iNl02?o3iNl00ol0003o`NG`ol7Ul00>ol7Ul0?o00001?o1h^l3o`0000_o
`N;_00?o0000okkRlOnnh_401?nnh_400ol0003o`=o_ol3Ok`09ol3Ok`03o`000?nlg_7o_=ka00[o
_=ka00?o0000okcKkonlfnl01Onlfnl2o`0000go^=[a00?o0000ok?DlOnce?400once?43o`0000co
[M;c00?o0000oiW5m_nIaOH03onIaOH00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04ko
oooo000looooo`?o00004oooool00ol0003oooooooooo`3Hooooo`;o00002?noi_82o`0000Ko`nG_
0_l0000?ol7Ul0;o00000onni?84o`0000co`N;_0_l00008okkRl@;o00001oo0gnl2o`0000ko_=ka
00?o0000okcKkonlfnl00_nlfnl2o`00013o^=[a00?o0000ok?DlOl000000_l00003ojgBl`03o`00
0?n]d_?o[M;c00[o[M;c00?o0000oiW5m_nIaOH03onIaOH00ol0003oooooooooo`0Wooooo`;o0000
C_ooool003cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3Eooooo`;o00003?no
i_801?l0003o`nG_ol?Ukoo3iNl2o`00013o`NG`00Co0000okkTl_nni?;o_^Cb1?l0000<ol7Rk`;o
00003?nnh_400ol0003o`=o_ol3Ok`02ol3Ok`;o00004Onlg_401?l0003o_=__o`000?l0000BokSJ
l@;o00001_n]d_<00ol0003o[M;cojgBl`0;ojgBl`03o`000?nIaOKoVLGf00_oVLGf1Ol0000Woooo
o`03o`000?oooooo000004kooooo000looooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0d_ooool2o`0000oo_nKb00?o0000ol?Ukol000004?o1iO02o`000004okkTl_l0003o0000o`00
00Co_^Cb00?o0000ol7Rkoo1h^l01oo1h^l2o`0000oo_^;a00Co0000ol3Okol0003o00004onlg_42
o`0001;o^=[a0_l000000oncf??o0000ojgBl`06ojgBl`03o`000?n]d_?o[M;c00_o[M;c00?o0000
oiW5m_nIaOH00_nIaOH8o`0000CoSl3g00?o0000ooooooooool09oooool00ol0003oooooooooo`1<
ooooo`00??ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<oooooo0_l0000AokoV
lP?o00003_o1iO02o`000003okkTl_l0003o000000So_^Cb00?o0000ol7Rkoo1h^l01?o1h^l2o`00
017o_^;a0_l0000CokcNl@;o00000_nig_800ol0003o^=[aokSJl@0=okSJl@;o00001?ncf?<00ol0
003o[M;cojgBl`05ojgBl`03o`000?n]d_?o[M;c00[o[M;c1Ol0000=oho0m`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0Boooool003cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3=ooooo`03o`000?noi_;o_nKb00oo_nKb0_l00003okgVl`;o00002oo1iO04o`0000_o
_^Cb00?o0000ol7Rkoo1h^l00_o1h^l00ol0003o_^;aokkRl@0?okkRl@;o00000_nkhO800ol0003o
_=kaokcNl@0>okcNl@;o00001Onig_800ol0003o^=[aokSJl@0:okSJl@;o00001oncf?<00ol0003o
[M;cojgBl`05ojgBl`03o`000?n]d_?o[M;c00Ko[M;c0ol000000onWd?Go0000oho0m`0@oho0m`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0B_ooool003cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`3:ooooo`;o00004?noi_82o`0000Oo_NKc0_l00007ol7Ul0?o0000
3onni?801?l0003o`N;_o`000?l0000AokkRl@03o`000?nkhO;o^n7b00?o^n7b00?o0000okcNlOnl
g_402onlg_42o`0000So^Mkb00?o0000okSJlOnhf_402?nhf_400ol0003o/mScok?Hl`08ok?Hl`03
o`000?n]d_?o[M;c00Co[M;c00?o0000ojgBlon]d_<00on]d_<3o`0000GoYm3e00?o0000oho0mon?
`?L03_n?`?L00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04[ooooo000kooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0aoooool3o`0000oo_nKb0_l0000;okgVl`04o`00
0?o1iO3o`NG`ol7Ul0?o00004_nni?83o`00013o_^;a0_l00007ok_QlP03o`000?nlg_7o_=ka00So
_=ka0_l0000;okWNlP03o`000?nhf_7o^=[a00Go^=[a0_l0000<ok?Hl`03o`000?n]d_?o[M;c00Co
[M;c00?o0000ojgBlon]d_<00_l00009ojO@m@03o`000?n?`?OoSl3g00koSl3g00?o0000oooooooo
ool09oooool00ol0003oooooooooo`19ooooo`00>oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0<Cooooo0_l00003ok[Wm0;o00003?noi_800ol0003o_NKcokgVl`0<okgVl`Co0000
4_nni?82o`0000?o_>Cc00?o0000okkRlOnnh_402onnh_42o`0000[o^n7b00?o0000okcNlOnlg_40
1Onlg_42o`0000ko^Mkb00?o0000okSJlOnhf_400_nhf_42o`0000oo/mSc00?o0000ojgBlon]d_<0
0on]d_<3o`0000_oYm3e00?o0000oho0mon?`?L03on?`?L00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo04Sooooo000kooooo`?o00007?ooool00ol0003oooooooooo`32ooooo`03o`000?nj
ioCo^^Od00Go^^Od0_l00008okoVlP;o00003?nmi_<3o`000004okgVlol0003o0000o`00013o_^Cb
0_l00006okcTl`03o`000?nnh_7o_^;a00So_^;a0_l0000=ok_QlP03o`000?nlg_7o_=ka00;o_=ka
0_l0000AokWNlP04o`000?nhf_7o0000o`0001;o/mSc00?o0000ojgBlol000000_l000000onWd?Go
0000ojO@m@0<ojO@m@03o`000?n?`?OoSl3g00koSl3g00?o0000ooooooooool09oooool00ol0003o
ooooooooo`18ooooo`00>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;oooooo
0_l0000:ok[Wm003o`000?noi_;o_nKb00?o_nKb0_l0000;okgVl`?o00000_nmi_<2o`0000?o^nGd
00?o0000okkTl_nni?802onni?82o`0000Wo_>Cc0_l00006okkRl@;o00004?nkhO801?l0003o_=ka
o`000?l0000CokWNlP?o00004oncf?<2o`0000GoYm3e00?o0000ojO@mOnWd?D02onWd?D00ol0003o
Sl3goho0m`0>oho0m`03o`000?oooooooooo02Kooooo0_l00019ooooo`00>oooool00ol0003ooooo
ooooo`0Nooooo`;o0000_Oooool2o`0000go^^Od0_l000000onoi_;o0000o`00000:okgVl`?o0000
1?nmi_<00ol0003o^nGdok_Um004ok_Um003o`000?nni?;o_^Cb00Wo_^Cb00?o0000okcTlonli?<0
2onli?<00ol0003o_^;aokkRl@02okkRl@03o`000?nkhO;o^n7b013o^n7b0ol0000BokWNlP;o0000
0onegO@00ol0003o/mScok?Hl`0=ok?Hl`?o00000_n^eoD00ol0003oYm3eojO@m@03ojO@m@03o`00
0?nWd?GoYm3e00[oYm3e00?o0000oho0mon?`?L02on?`?L5o`0002Kooooo00Co0000oooooooooooo
0000B?ooool003_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2hooooo`;o0000
4?njio@3o`0000So_NKc0ol00005okgVl`;o00002?nkiO@2o`0000Oo_^Cb0_l0000?okcTl`04o`00
0?nnh_7o0000o`00017o^n7b0_l00003okSQm003o`000?nig_;o^Mkb00go^Mkb0_l00006okGMm003
o`000?ncf??o/mSc00[o/mSc0_l00006ojkGm@03o`000?nWd?GoYm3e00?oYm3e00?o0000ojO@mOnW
d?D02_nWd?D00ol0003oSl3goho0m`02oho0m`So00001?n5^oP00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo04Kooooo000kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
]Oooool2o`00013o^^Od0_l00003okSVm@03o`000?nmi_?o_NKc00?o_NKc0_l00006okgVl`;o0000
3?nkiO@00ol0003o_^CbokkTlP02okkTlP;o00004Onli?<3o`00013o^n7b0_l00006okSQm003o`00
0?nig_;o^Mkb00Wo^Mkb0ol00009okGMm003o`000?ncf??o/mSc00Ko/mSc0ol00009ojkGm@03o`00
0?nWd?GoYm3e00;oYm3e00?o0000ojO@mOnWd?D02OnWd?D6o`0000goQK_h00?o0000ooooooooool0
9oooool00ol0003oooooooooo`15ooooo`00>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ok[Wm?njio@03onjio@00ol0003o^>KeokSVm@04okSVm@03o`000?nm
i_?o000000;o00001_nmi_<2o`0000oo^nGd00Co0000okkTl_l0003o00004Onli?<2o`0000?o^N?d
00?o0000ok_Ql_nkhO802_nkhO83o`0000Wo^>7d0_l00007okWNlP;o00003OnegO@00ol0003o/mSc
ok?Hl`03ok?Hl`;o00003On^eoD00ol0003oYm3eojO@m@02ojO@m@03o`000?nWd?GoYm3e00CoYm3e
1?l00002oj3=m`03o`000?n5^oSoQK_h00ooQK_h00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`15ooooo`00>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;3ooooo0_l0
000@ok[Wm0;o00001_nhi_D4o`0000Ko_NKc0_l0000Aok_Um0?o00004?nli?<2o`0000Ko^N?d0_l0
0008ok_QlP;o00003_nhhO@00ol0003o^MkbokWNlP02okWNlP;o00004?negO@00ol0003o/mSco`00
0002o`00013o[]Oe00?o0000ojO@mOnWd?D00_nWd?D00ol0003oYm3eojO@m@03o`0000OoX<gg00?o
0000ohFkn?n5^oP03on5^oP00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Cooooo000j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0[Oooool3o`0000oo^^Od0_l00005
okSVm@?o00001?nhi_D00ol0003o_NKcokgVl`02okgVl`03o`000?nkiOCo^nGd00oo^nGd0_l00003
okSUm@03o`000?nli??o_>Cc00_o_>Cc0_l0000:okWSm0;o00001?nkhO82o`00017o^>7d00Co0000
okWNl_l0003o00004_negO@2o`0001Co[]Oe00?o0000ojO@mOnWd?D01?l0000;oj3=m`03o`000?n5
^oSoQK_h00ooQK_h00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`00>_ooool4
o`0002Gooooo00?o0000ooooooooool0Z_ooool2o`0000?o]>Og0_l0000;ok[Wm0;o00001?nhi_D3
o`0000So^>Ke00Co0000okgVlol0003o00004?nkiO@2o`0000Ko^>Ge00?o0000okcTlonli?<02Onl
i?<00ol0003o^N?dokWSm00<okWSm004o`000?nkhO;o0000o`0001?o^>7d0ol0000AokGMm0;o0000
0_nafoH00ol0003o[]OeojkGm@0AojkGm@?o00000_nPcOL00ol0003oX<ggoj3=m`0;oj3=m`03o`00
0?n5^oSoQK_h00koQK_h00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`00>Ooo
ool2o`0002Wooooo00?o0000ooooooooool0Yoooool2o`0000Oo]>Og0_l00007ok[Wm0;o00000onh
i_D3o`0000_o^>Ke0ol0000?ok_Um0;o00002OnhiOD2o`0000Oo_>Cc0_l0000?okWSm0?o00004_nh
hO@2o`0000?o]N3e00?o0000okGMm?negO@03?negO@2o`0000Go/M_f00?o0000ojkGmOn^eoD03On^
eoD3o`0000;oZMGg00Go0000oj3=monPcOOoX<ggo`00000=oj3=m`03o`000?n5^oSoQK_h00koQK_h
00?o0000ooooooooool09_ooool2o`0004?ooooo000jooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0Y?ooool2o`0000_o]>Og00?o0000ok[Wm?njio@00onjio@00ol0003o^>KeokSV
m@03o`0000co^>Ke0_l00003okKVmP;o00003?nkiO@00ol0003o^>GeokSUm@0;okSUm@03o`000?nl
i??o_>Cc00;o_>Cc0_l0000?okWSm0;o00000onfhoD00ol0003o^>7dokSQm00<okSQm0?o00001_ne
h?D00ol0003o]MgdokGMm008okGMm0?o00002?nafoH00ol0003o[]OeojkGm@0:ojkGm@;o00001_nY
eOL01Ol0003oX<ggoj3=monPcOOo000000goX<gg00?o0000ohFkn?n5^oP03_n5^oP00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooo000004?ooooo000Looooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00002?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0:7ooooo0_l0
000>okCWm`;o000000?o^^Odo`000?l000000ol0000=okSVm@;o00001onfi_H2o`0000So^nGd0_l0
000?okSUm@04o`000?nli??o0000o`0000oo^N?d0_l00006okKSm@03o`000?nhhOCo^>7d00Wo^>7d
0_l0000:okGPm@03o`000?negOCo]Mgd00Go]Mgd0_l0000<ok7KmP03o`000?n^eoGo[]Oe00Ko[]Oe
0ol00009ojWEm`05o`000?nPcOOoX<ggoj3=mol000003OnPcOL00ol0003oQK_hohFkn006ohFkn0Wo
00009oooool00ol0003oooooooooo`11ooooo`006oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Nooooo`;o00004Ond
ioL4o`0000ko^>Ke0_l0000;okKVmP03o`000?nkiOCo^nGd00?o^nGd0_l0000AokSUm@?o00003_ni
ho@2o`0000Wo]^?e00?o0000okSQm?nhhO@01_nhhO@2o`0000go]N3e00?o0000okGMm?negO@00_ne
gO@2o`0000oo/M_f00?o0000ojkGmOn^eoD00on^eoD2o`0000goZMGg00Co0000oj3=monPcOOo0000
3?nPcOL:o`0000SoNKGh00?o0000ooooooooool09_ooool00ol0003oooooooooo`10ooooo`005Ooo
ool5o`0000Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09_ooooo0_l0000AokCWm`Co000000?o/^Kho`000?l000003?nhi_D00ol0
003o]^KfokKVmP0<okKVmP;o000000?o^nGdo`000?l000004OnhiOD2o`0000?o]^Cf00?o0000okWS
m?niho@02_niho@00ol0003o]^?eokKSm@0:okKSm@03o`000?nhhOCo^>7d00;o^>7d0ol0000@okGP
m@04o`000?negOCo0000o`0001;o/M_f00?o0000ojkGmOl000000_l0000@ojWEm`04o`000?nPcOOo
X<ggo`0000KoX<gg1Ol00002oiW:n@03o`000?mi]OSoNKGh00koNKGh00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0oooooo`007oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0V?ooool2o`00013o]>Og1?l00006ok;Vn0;o
00002?nhi_D2o`00013o]^Kf0ol0000@okSUm@;o00001_nfi?H2o`0000So^N?d0_l0000>okKSm@04
o`000?nhhOCo0000o`0001?o]N3e0ol0000Cok7KmP?o00004onYeOL00ol0003oX<ggoj3=m`06o`00
00SoVL[i00?o0000ogVen?mi]OP03_mi]OP00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03oooooo000Kooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo09Gooooo0ol0000?okCWm`?o00002onbi_P00ol0003o^>KeokSVm@03okSVm@;o00004?nf
i_H2o`0000?o]>Kg00?o0000okSUmOnhiOD02_nhiOD3o`0000[o]^Cf0_l00004okWSm0;o00004?nf
hoD3o`0001;o]N3e0_l00003ok7Om`03o`000?nafoKo/M_f00go/M_f0ol00003ojgJm`03o`000?nY
eOOoZMGg013oZMGg1?l0000>oiW:n@03o`000?mi]OSoNKGh00goNKGh00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0nooooo`006oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`;o
0000<?ooool2o`0009?ooooo0_l00003ojgVn@;o00002_ndioL3o`0000oo/^Kh0_l000000onhi_Go
0000o`00000@okKVmP;o00001_ndi_L2o`0000So^>Ge0_l0000?okKTmP04o`000?nihoCo0000o`00
013o]^?e0_l00003ok?Rm`03o`000?neh?Go]N3e00go]N3e0_l00006ok7Om`03o`000?nafoKo/M_f
00[o/M_f0_l00007ojgJm`03o`000?nYeOOoZMGg00coZMGg0ol000001OnTdoSo0000oiW:nOnIb_Wo
000000koVL[i00?o0000ogVen?mi]OP03Omi]OP00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03gooooo000Kooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo08kooooo0_l00007ojgVn@?o00001?ndioL4o`00
01;o/^Kh0ol0000?okKVmP;o00002_ndi_L2o`0000Co^>Ge0_l0000AokKTmP?o00003onfhoD2o`00
00Ko/n;g00?o0000okGPmOneh?D02Oneh?D3o`0000Wo/Mog00?o0000ok7Km_nafoH01_nafoH3o`00
00[o[M[g00?o0000ojWEmonYeOL02?nYeOL3o`0000GoY=?h00Co0000oiW:nOnIb_Wo00003_nIb_T0
0ol0003oNKGhogVen00=ogVen003o`000?oooooooooo02Gooooo00?o0000ooooooooool0?Oooool0
03Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`?o00003?n]i_T5o`00
01?o/^Kh0_l00003ok7Vn003o`000?nfi_Ko]^Kf00[o]^Kf0_l0000>okCVm`04o`000?nhiOGo0000
o`00017o]^Cf0_l00003ok?Tm`03o`000?nfhoGo]^?e00Wo]^?e0ol00009ok?Rm`;o00001oneh?D2
o`0000go/Mog00?o0000ok7Km_nafoH00onafoH2o`0000ko[M[g00?o0000ojWEmonYeOL01?nYeOL3
o`0000WoY=?h00Co0000oiW:nOnIb_Wo00003_nIb_T00ol0003oNKGhogVen00<ogVen003o`000?oo
oooooooo02Cooooo0ol0000nooooo`00>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo08Oooooo0_l0000=ojgVn@Ko00004Onbi_P3o`0000Ko/NKh0_l00008okKVmP;o00004?ndi_L3
o`00013o]^Cf0_l00006ok?Tm`;o00001onfhoD2o`0000ko/n;g00?o0000okGPmOneh?D00_neh?D2
o`00013o/Mog00?o0000ok7Km_l000000_l0000AojgJm`03o`000?nYeOOoZMGg00?o00003OnTdoP0
0ol0003oVL[io`00000=oiW:n@_o00001_mi]OP00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03_ooooo000hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Q?ooool2o`00
00go[NKi0_l000000on]i_Wo0000o`000003ojcVnP;o00003Onbi_P2o`0000_o/NKh0_l00004okKV
mP;o00004?ndi_L2o`0000?o/^Gh00?o0000okKTm_nfi?H02_nfi?H3o`0000[o/nCg00?o0000okKS
mOnfhoD00_nfhoD2o`00017o/n;g00Co0000okGPmOl0003o00004_nagoL3o`0001?o[M[g0ol0000A
ojCCn003o`000?nIb_Wo000000OoVL[i1Ol00002oi77nP03o`000?m][_SoKJkh00KoKJkh2?l0000W
ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool3o`0000Cooooo0_l0000M
ooooo`00>?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo087ooooo0_l0000<ojgV
n@?o000000?o[NKio`000?l000001on/i_X2o`0000Wo/^Kh0_l0000?ok7Vn004o`000?nfi_Ko0000
o`00013o]>Kg0_l00006ok;Un0;o00002?nfi?H2o`0000ko/nCg00Co0000okKSmOl0003o00004onc
h_L3o`00013o/Mog0ol00003ojkNn003o`000?n]f_Oo[M[g00go[M[g0ol000000onXfOWo0000ojCC
n00BojCCn004o`000?nIb_Wo0000oiW:n@Go00002?nAaoX00ol0003oKJkhoff^n00<off^n003o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo01[ooooo000hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O_ooool3o`00
00[o[NKi0ol000001?n]i_Wo0000o`000?l0000;ojcVnP03o`000?nbi_So/^Kh00?o/^Kh0ol0000A
ok7Vn0?o00003ondi_L2o`0000[o/^Gh0_l00004okKTmP;o00004?nci?L3o`00017o/n;g0ol00003
ok3Qn003o`000?nagoOo/Mog00_o/Mog0_l00007ojkNn003o`000?n]f_Oo[M[g00[o[M[g0_l00005
ojSIn@03o`000?nTdoSoY=?h013oY=?h1?l0000>oi77nP03o`000?m][_SoKJkh00coKJkh00?o0000
ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01[ooooo000h
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0N_ooool3o`0000?oY^Ck0_l00005
ojgVn@?o00000_n]i_T2o`0000oo[>Kj0_l000000onbi_So0000o`00000Bok7Vn0;o00000on_i_T2
o`0000co]>Kg00?o0000ok;Un?nbiOP03?nbiOP01?l0003o]^Cfo`000?l0000@ok?Tm`;o00000ona
hoP00ol0003o/n;gok?Rm`0<ok?Rm`;o00001on`hOP2o`0000So/Mog0ol0000:ojkNn003o`000?n]
f_Oo[M[g00Ko[M[g0ol00008ojSIn@03o`000?nTdoSoY=?h00coY=?h0ol00002oikAnP;o00003onA
aoX00ol0003oKJkhoff^n00<off^n003o`000?oooooooooo02Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0Jooooo`00=oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo07Kooooo0ol00008ojKTn`Go00000on]i_T2o`0001;o[>Kj0ol0000Aok7Vn0;o00001on_
i_T2o`0000So]>Kg0_l0000?ok;Un0?o00003onci?L2o`0000Ko/N?h0_l00009ok?Rm`?o00002on`
hOP00ol0003o/Mogok7Om`03ok7Om`;o00003_n^g_P00ol0003o[M[gojgJm`03ojgJm`;o00003?nX
fOT00ol0003oY=?hojCCn008ojCCn0?o00001_nNdOX2o`0000ooTLOj00?o0000off^n?m][_P03?m]
[_P00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooooooool0000Looooo`00
=oooool3o`0003_ooooo00?o0000ooooooooool0Loooool2o`0000[oY^Ck0ol000001?nVi?_o0000
o`000?n]i_T2o`0001;o[>Kj0_l00003oj_UnP;o00003?nai_P3o`0000_o[nKi00?o0000okCVmond
i_L00ondi_L2o`0000oo/^Gh0_l00003ok3Un003o`000?nci?Oo/nCg00Wo/nCg0ol0000:ok7Sn0;o
00001Onch_L2o`0000oo/>7h00?o0000ok7Omol000000_l0000AojkNn003o`000?n]f_Oo000000;o
00003onXfOT00ol0003oY=?hojCCn004ojCCn0?o00002_nNdOX2o`0000ooTLOj00?o0000off^n?m]
[_P03?m][_P00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`07
o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0001cooooo000g
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Koooool3o`0000WoY^Ck0ol00005
ojKTn`?o00004On/i_X2o`0000OoZnGj0_l00008ok7Vn0;o00003on_i_T2o`000003okCVmol0003o
000000oo/^Gh0_l00006ok3Un0;o00001onci?L2o`0000oo/N?h00?o0000ok?Rmol000000_l0000A
ok3Qn0?o00004on^g_P3o`0001;oZ=Wi00?o0000ojCCn?nTdoP00ol0000>oikAnP03o`000?nAao[o
TLOj00koTLOj00?o0000off^n?m][_P02om][_P00ol0003oooooooooo`0Tooooo`?o00001oooool0
0ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?ooooo0_l0000Mooooo`00=oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo06_ooooo0ol00009ojKTn`?o00001_nVi?/2o`00
00?oYNCk0_l0000<ojcVnP?o00002on[iOX00ol0003o/NKhok7Vn003ok7Vn0;o00004_n_i_T3o`00
00go/^Gh0ol0000:ok3Un003o`000?nci?Oo/nCg00;o/nCg0_l0000Aok7Sn0?o00004?n`hOP3o`00
00?o[N3i00?o0000ojkNn?n^g_P03On^g_P3o`0000?oZ]ci00?o0000ojSInOnXfOT03_nXfOT4o`00
01;oW]7j00?o0000oi77n_nAaoX02_nAaoX9o`0000WoKJkh00?o0000ooooooooool08Oooool2o`00
00;ooooo00?o0000ooooooooool0=_ooool003Oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`1Xooooo`?o00002?nVi?/3o`0000OoY^Ck0_l00007ojGTn`;o00002?n/i_X2o`0000oo
ZnGj0_l000000onai_So0000o`00000AojoVn@?o00000on]iOT2o`0000Wo/^Gh0_l0000>ok3Un004
o`000?nci?Oo0000o`00017o/N?h0_l00003ojkSn@03o`000?n`hOSo/>7h00_o/>7h0_l00007ojgP
n@03o`000?n^g_So[]kh00[o[]kh0_l00007oj[Ln@03o`000?nXfOWoZ=Wi00WoZ=Wi1?l00004oj?G
nP03o`000?nNdO[oW]7j013oW]7j00?o0000oi77n_nAaoX00_nAaoX7o`0000CoRL?k00?o0000oenV
momOY_L00_mOY_L8o`0000;oKJkh00?o0000ooooooooool09Oooool00ol0003oooooooooo`0eoooo
o`00=oooool00ol0003oooooooooo`0oooooo`;o0000IOooool3o`0000?oW^;m0_l00004ojKTn`;o
00001onVi?/3o`0000_oYNCk00?o0000ojcVn_n/i_X00on/i_X2o`0001;oZnGj0ol0000@ojoVn@;o
00002?n]iOT2o`0000Go/^Gh0_l0000@ok3Un0?o00004?nahoP2o`0000Ko[^?i0_l00008ok3Qn0?o
00002_n]h?T00ol0003o[]khojkNn006ojkNn0?o00002_nZg?T00ol0003oZ=WiojSIn@05ojSIn@?o
00002OnSeoX00ol0003oW]7joikAnP0>oikAnPKo00003?n9`o/00ol0003oGjKgoenVm`09oenVm`Co
00009_ooool00ol0003oooooooooo`0eooooo`00=_ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo063ooooo0_l00008oikRo@Co00001onVi?/2o`0000ooYNCk0_l000000on/i_[o0000
o`00000Aoj_UnP?o00000onYiOX2o`0000_o[nKi0ol0000<ojgUn@;o000000?o/^Gho`000?l00000
4?n`iOP2o`0000?o[^Ci00?o0000ok7Sn?nahoP02_nahoP3o`0000[o[^?i00?o0000ok3Qn?n`hOP0
0on`hOP2o`0000ko[N3i00?o0000ojkNn?n^g_P00on^g_P2o`0000koZ]ci00?o0000ojSInOnXfOT0
1?l0000=oj?GnP03o`000?nNdO[oW]7j00WoW]7j1?l00002oiO>n`03o`000?n9`o_oRL?k00koRL?k
00?o0000oenVmomOY_L02omOY_L00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Cooooo
000fooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0G?ooool3o`0000SoW^;m0ol0
00000onNh_go0000o`000005ojKTn`;o00004_nUi?/3o`00013oZnGj0_l00008ojWUnP?o00001_n_
i_T2o`00013o[NGi0ol0000?ok3Un0;o00001_n^i?T2o`0000So/N?h0_l0000>ojkSn@03o`000?n`
hOSo000000;o00004On]h?T00ol0003o[]kho`000002o`00013oZ]ci0ol0000Boj?GnP03o`000?nN
dO[oW]7j00GoW]7j0ol00007oiO>n`03o`000?n9`o_oRL?k00koRL?k00?o0000oenVmomOY_L02omO
Y_L00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo000fooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0FOooool2o`0000SoW^;m0ol00006oikRo@;o000000?oY^Ck
o`000?l000004OnUi?/3o`0000?oY>Ck0_l0000;oj_UnP?o00003OnYiOX2o`000004ojoVnOl0003o
0000o`00013o[NGi0_l00003ojcUnP03o`000?n`iOSo/>Gh00[o/>Gh0_l0000:ojkTn@;o00001?na
hoP2o`00013o[^?i0ol0000CojgPn@?o00003onZg?T3o`0000?oY]_j00?o0000oj?Gn_nSeoX04?nS
eoX00ol0003oW]7joikAnP04o`0000_oUlkk00?o0000ohW3non9`o/03On9`o/00ol0003oGjKgoenV
m`0<oenVm`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<oooool003Kooooo0_l00016
ooooo`03o`000?oooooooooo05Gooooo0ol00007oikRo@?o00002_nNh_d3o`00013oYNCk0_l00008
ojCTn`?o00001_n[iOX2o`00017oZNGj0ol0000@ojgUn@;o00001_n/iOX2o`0000So/>Gh0_l0000>
ojkTn@04o`000?nahoSo0000o`00013o[^?i0_l00003ojcRnP03o`000?n]h?Wo[N3i00go[N3i0ol0
0003oj[OnP03o`000?nZg?WoZ]ci00[oZ]ci0_l00007ojKKnP03o`000?nSeo[oXmOj00koXmOj1?l0
000@oiO>n`03o`000?n9`o_oRL?k00goRL?k00?o0000oenVmomOY_L03?mOY_L00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03;ooooo000fooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0D_ooool3o`0000KoW^;m0ol0000:oikRo@?o00000onMh_d2o`0000_oYNCk0ol0000=
ojCTn`;o000000CoZnGjo`000?l0003o00004?nYiOX3o`0000?oZ>Gk00?o0000ojgUnOn]iOT02_n]
iOT3o`0000[o[>Gj0_l00004ok3Un0;o00004?n^i?T3o`0000oo[^?i0_l00006ojcRnP;o00002_n]
h?T3o`0000OoZ]oj0_l00008oj[Ln@;o00002_nVfoX00ol0003oXmOjoj?GnP09oj?GnPCo00000onN
eO/00ol0003oUlkkoiO>n`0>oiO>n`;o00003on9`o/00ol0003oGjKgoenVm`0;oenVm`03o`000?oo
oooooooo02?ooooo0ol0000cooooo`00=_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo04kooooo0ol00003oiGOoPKo00002_nNh_d3o`0000SoWN;m0ol00006ojGTn`;o00004OnTi?/3
o`00013oZNGj0_l00007ojSUn`;o00002?n]iOT2o`0000oo[>Gj00Co0000ok3Un?l0003o00003on^
i?T3o`0000?oZn?j00?o0000ojkSnOn^hoT02On^hoT3o`0000[o[>;j00?o0000ojgPnOn]h?T01?n]
h?T3o`0000coZ]oj00?o0000oj[LnOnZg?T00_nZg?T3o`0000goY]_j00?o0000oj?Gn_nSeoX01OnS
eoX3o`0000SoW]Gk00?o0000oiO>nonGc_/03_nGc_/2o`0000SoRL?k3?l00009oenVm`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0<Oooool003Gooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`1:ooooo`?o00001_nEgoh5o`0000SoW^;m0ol0000>oigRo@;o000000CoYNCk
o`000?l0003o00004?nTi?/3o`0000?oXnCl0_l0000;ojWUnP?o00002onXiO/2o`0000Co[NGi0_l0
000AojcUnP?o00003_n^i?T2o`0000OoZn?j0_l00007ojkSn@;o00003_n/h_X00ol0003o[N3iojgP
n@03o`00013oZ]oj00Co0000oj[LnOl0003o00004OnVfoX00ol0003oXmOjoj?GnP04o`0000coW]Gk
00?o0000oiO>nonGc_/03OnGc_/:o`0000OoP;ok00?o0000oe6Nm?mAW_@00_mAW_@8o`0000;oGjKg
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0`ooooo`00=Oooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo04Kooooo0ol00007oiGOoP;o00001OnEgoh3o`0000;oW^;m0ol0
000BoigRo@?o00004?nTi?/2o`0000SoXnCl0ol00006ojWUnP;o00004?nXiO/01?l0003o[NGio`00
0?l0000@ojcUnP?o00000onZi?X2o`0000Wo[^Ci0ol0000;oj_SnP03o`000?n^hoWo[^?i00;o[^?i
0_l0000@ojcRnP?o00004onZgoX3o`0001;oY]_j0ol0000AoikEn`03o`000?nGc__oUlkk00OoUlkk
1Ol000001?nAc?co0000oi7<o?l0000>oh2on`03o`000?mAW_CoDIkd00WoDIkd1?l0000Uooooo`03
o`000?oooooooooo033ooooo000eooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
@_ooool3o`0000OoUMon0ol00009oiGOoP?o00004_nMh_d3o`0000?oWN;m0_l0000;ojCTn`?o0000
3OnSi?`2o`000004ojWUn_l0003o0000o`0001;oZ>Gk0ol0000?ojcUnP;o00002?nZi?X00ol0003o
[^CiojkTn@04ojkTn@;o00003on[hoX01?l0003o[^?io`000?l0000?ojcRnP?o00000onXhOX00ol0
003oZ]ojoj[OnP0=oj[OnP?o00000onVg_/00ol0003oY]_jojKKnP0<ojKKnP?o00000_nQf_/00ol0
003oW]GkoikEn`0@oikEn`04o`000?nGc__oUlkkoiO>n`Go00001onAc?`00ol0003oTLclo`00000>
oh2on`03o`000?mAW_CoDIkd00_oDIkd00?o0000ooooooooool09?ooool00ol0003oooooooooo`0_
ooooo`00=Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03gooooo1?l00007oiGO
oP?o00002OnEgoh3o`0000?oUMon0_l0000=oigRo@?o00002?nMh_d3o`0000KoY>Ck0_l0000Aoj?T
o0?o00004OnXiO/3o`0000?oYnCk0_l0000:ojcUnP?o00002onZi?X2o`000004ojkTnOl0003o0000
o`00017oZn?j0ol0000>ojcRnP;o00001onXhOX2o`0000[oZ]oj0ol00007ojKNn`03o`000?nVfo[o
Y]_j00SoY]_j0ol00006oj7Jn`03o`000?nNeO_oW]Gk00koW]Gk1Ol0000=oi7<o003o`000?nAc?co
000000koP;ok00?o0000oe6Nm?mAW_@02omAW_@00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02kooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>Oooool3o`00
00CoS=_o0ol000001?nEgoko0000o`000?l00009oiGOoP?o00002?nEgoh3o`0000OoWN;m0ol0000>
oigRo@;o000000CoY>Cko`000?l0003o00004?nSi?`3o`0000?oXnCl00?o0000ojSUnonXiO/03?nX
iO/2o`0000SoYnCk0_l00006ojcUnP;o00003onZi?X3o`00013oZn?j0ol00003ojWSnP;o00002_n/
h_X2o`0000_oZ>7j00?o0000oj[On_nZgoX01?nZgoX3o`0000_oY]kk00?o0000ojKKn_nVfoX01?nV
foX3o`0000[oXM[k00?o0000oikEnonNeO/02OnNeO/4o`0000?oVM?l00?o0000oi7<o?nAc?`03OnA
c?`00ol0003oTLclo`00000>oh2on`03o`000?mAW_CoDIkd00_oDIkd00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0^ooooo`00=Oooool2o`0004oooooo00?o0000ooooooooool0=?ooool4
o`0000SoS=_o1?l00008oiGOoP?o00003_nEgoh2o`0000;oWN;m0ol0000BoigRo@?o00004?nSi?`2
o`0000OoXnCl0_l00009ojSUn`?o00003?nWi?/2o`000004ojcUn_l0003o0000o`0000koZ^Cj0ol0
0003ojSTn`;o00002on[hoX3o`0000SoZN?j0_l00005ojcRnP?o00003_nXhOX00ol0003oZ]ojoj[O
nP03o`0000ooY]kk00?o0000ojKKn_nVfoX00ol0000>oj7Jn`03o`000?nNeO_oW]Gk00GoW]Gk0ol0
0008oiWCo003o`000?nAc?coTLcl00coTLcl00Co0000oi7<o?nAc?co00003_n0_o/00ol0003oDIkd
oe6Nm00:oe6Nm003o`000?oooooooooo02Cooooo00?o0000ooooooooool0;Oooool003Cooooo0_l0
001Aooooo`03o`000?oooooooooo033ooooo0ol00009ohcKo`?o00001?n<fol3o`0000;oUMon0ol0
000BoiGOoP?o00004_nMh_d3o`0000?oWN;m0_l0000;oj?To0?o00002onSi?`2o`0000GoZ>Gk0_l0
000@ojOTn`?o00003_nZi?X2o`0000SoZ>Ck0_l00006oj_SnP?o00003OnYhoX2o`000003ojcRn_l0
003o0000017oZ>7j0ol0000BojKNn`?o00004_nQf_/00ol0003oW]GkoikEn`04o`0000coVM?l00?o
0000oi7<o?nAc?`03?nAc?`Eo`0000[oDIkd00?o0000ooooooooool08_ooool3o`0002kooooo000d
ooooo`03o`000?oooooooooo057ooooo0_l0000/ooooo`Co00002On<fol3o`0000SoS=_o1?l0000B
oiGOoP?o00000onFgoh3o`0000coWN;m0ol00008oigRo@?o00001_nSi?`2o`00013oXnCl00?o0000
ojSUnol000000_l0000?ojOTn`?o00000onUi?/2o`0000[oZ^Cj0_l0000<ojSTn`;o000000CoZn?j
o`000?l0003o00004OnYhoX3o`0000ooZ>7j0ol00003ojKPn`03o`000?nVg__oY]kk00coY]kk0ol0
0003oj?Mn`03o`000?nQf__oXM[k00koXM[k1?l0000AoiWCo003o`000?nAc?coTLcl00OoTLcl1_l0
00000on:b?co0000ogNjn`0=ogNjn`03o`000?m3UO7o@iGa00Co00001omAW_@00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02cooooo000dooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool09?ooool5o`0000CoP]Oo0ol00003ohcKo`?o00002?n<fol3o`0000CoSMco0ol0000<
oiGOoP?o00002OnFgoh2o`0000OoWN;m0ol0000>oigRo@;o000000CoXnClo`000?l0003o00004_nS
i?`3o`0000ooYnCk0_l00008ojGTn`;o00001OnZi?X3o`0000ooZ>Ck0ol0000@ojWSnP?o00000onW
h_/00ol0003oZ>7jojSQnP0:ojSQnP;o00001onVh?/2o`0000WoY]kk0ol00007oj?Mn`;o00002onQ
f_/3o`0000CoWMSl00?o0000oiWCo?nIdo`03onIdo`01?l0003oTLcloi7<o?nAc?`5o`0000KoR/Sl
00?o0000oh[8o?l000003_mg^_/00ol0003o@iGaod>El@03od>El@Co00000omAW_@00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02_ooooo000dooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool07_ooool5o`0000coP]Oo0ol00007ohcKo`Co00002_n=g?l2o`0000OoUMon0ol0
000>oiKOoP?o000000CoWN;mo`000?l0003o00004_nMh_d3o`00017oXnCl0ol00003oj;So0;o0000
2_nWi?/3o`0000coYNCk0_l000000onZi?[o0000o`00000?ojSTn`?o00000onVho/00ol0003oZN?j
ojWSnP0;ojWSnP;o00001onWh_/2o`0000SoZ>7j0_l0000;ojKPn`03o`000?nVg__oY]kk00?oY]kk
0ol0000<oj?Mn`03o`000?nQf__oXM[k00CoXM[k1?l00008oigHo003o`000?nIdocoVM?l00goVM?l
1Ol0000;oh[8o004o`000?n:b?coR/Slo`0000koMk[k00?o0000od>ElOm3UO401_m3UO45o`0002Ko
oooo00?o0000ooooooooool0:_ooool003Cooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Hooooo`Go00003on2eol2o`0000;oP]Oo0ol00002ohcKo`?o00004?n=g?l3o`000004oiGO
o_l0003o0000o`0001?oU]on0ol0000AoigRo@?o00000onMh_d2o`0000coXnCl0ol00008oj;So0;o
00001_nWi?/2o`00013oYNCk0ol0000>ojSTn`;o00001onVho/2o`0000SoZN?j0ol0000;ojORn`03
o`000?nXhO[oZ>7j00;oZ>7j0ol0000>ojKPn`03o`000?nVg__o000000;o00004?nSgO/00ol0003o
XM[koj7Jn`03o`0000goWMSl00?o0000oiWCo?nIdo`01onIdo`5o`0000CoTm7m00?o0000oh[8o?n:
b?`02_n:b?`01?l0003oR/Sloh[8o?l0000>ogNjn`03o`000?m3UO7o@iGa00Wo@iGa0_l0000Uoooo
o`03o`000?oooooooooo02[ooooo0002ooooo`Go000000Coooooo`000?l0003o0000:Oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo01;ooooo1Ol00004ogSAo`?o00002_n2eol3o`00
00GoP]Oo1?l0000DohgLo`Co00004_nFgoh3o`0000?oU]on0_l0000<oigRo@?o00002?nMh_d3o`00
00KoXnCl0ol0000=oj;So0;o000000CoYnCko`000?l0003o00003onUi?/3o`0000?oY>?l0_l00009
ojSTn`?o00002onVho/00ol0003oZN?jojWSnP03ojWSnP;o00003onWh_/01?l0003oZ>7jo`000?l0
000AojKPn`?o00004OnSgO/4o`00017oWMSl00Co0000oiWCo?nIdocoVM?l1Ol0000:oi?Ao@03o`00
0?n:b?coR/Sl00[oR/Sl00Co0000oh[8o?n:b?co00003_mg^_/00ol0003o@iGaod>El@09od>El@03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
3?ooool5o`0000coN=7o0_l00005oh;Go`?o00000on2eol5o`0000CoQ=So0_l0000>ohgLo`Co0000
1?n>g?l2o`0000goU]on0ol00008oiKOoP?o00001_nMh_d3o`0000koWN;m0_l000001?nSi?co0000
o`000?l0000Aoj;So0?o00003onUi?/2o`0000SoY>?l00?o0000ojSTnonXi?/01?nXi?/2o`0000oo
Y^?k00?o0000ojWSn_l000000_l0000AojORn`?o00003onVh?/3o`0000?oXmol00?o0000oj?MnonS
gO/02_nSgO/4o`0000CoWmcl00?o0000oigHo?nMf?`03OnMf?`5o`00013oTm7m00?o0000oh[8o?n:
b?`02On:b?`01Ol0003oR/Sloh[8o?n:b?co000000koMk[k00?o0000od>ElOm3UO402Om3UO400ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Sooooo0003ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool09oooool01?l0003oooooo`000?l0001Hooooo`03o`000?oooooooooo
00Kooooo1Ol0000CogSAo`Go000000?oP]Ooo`000?l000000ol0000;ohCHo`?o00002?n=g?l3o`00
00[oS]co0ol00007oiKOoP?o00003_nFgoh2o`000004oigRoOl0003o0000o`0001;oWN;m0ol0000@
oj;So0?o00000onQho`2o`0000[oYNCk0ol0000;ojCSo0;o000000CoZ>Cko`000?l0003o00004OnV
ho/3o`00013oYn;k0ol00003ojCQo0;o00002_nVh?/3o`0000OoXmol0_l00007oj?Mn`?o00002OnO
g?`00ol0003oWMSloigHo009oigHo0?o00001?nHe_d00ol0003oTm7moi?Ao@0?oi?Ao@03o`000?n:
b?coR/Sl00KoR/Sl6Ol00009od>El@03o`000?oooooooooo02?ooooo0_l0000Yooooo`001?ooool0
0ol0003oooooooooo`02ooooo`?o00009oooool2o`0005_ooooo2?l00005ofg;oP?o00003omhdOl7
o`0001?oQ=So0_l00002ohgLo`Co00004?n>g?l2o`0000;oU]on0ol0000BoiKOoP?o00004OnMh_d3
o`0000?oW>;m0_l0000;oj;So0?o00002?nQho`2o`0000KoYNCk0_l0000?ojCSo0?o00004?nVho/3
o`0000?oY>?l0_l0000;ojORn`?o00002?nThO`00ol0003oY^3kojKPn`04ojKPn`?o00003?nSgo`0
0ol0003oXmgkoj?Mn`04o`0000goWmcl00?o0000oigHo?nMf?`01?nMf?`4o`0000SoV=Km0_l0000>
oi?Ao@[o00001?n2aOd01Ol0003oP/Gmoh;5oOn2aOgo000000goKKGk00?o0000ocB;kOldRnd00ol0
0007od>El@03o`000?oooooooooo027ooooo00?o0000ooooool00000:Oooool000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Woooooa?o0000@?ooool;o`0000ooKL_n0_l0000:
ogSAo`Go00001?mkd_l2o`0001;oQ=So1?l0000DohkLo`Co00004_nFgoh3o`0000?oU]on0_l0000<
oigRo@?o00002?nLh_d2o`0000KoX^?l0ol0000=oj7So0;o000000CoYNCko`000?l0003o00003_nT
ho`3o`0000?oXn?l0_l0000;ojKSn`?o00002?nTho`00ol0003oYn;kojORn`05ojORn`?o00003?nT
hO`2o`000004ojKPnol0003o0000o`0000ooXmol0ol0000BoioLo003o`000?nMf?coWMSl00?o0000
3_nHe_d00ol0003oTm7moi?Ao@06oi?Ao@Go00000on=c_h00ol0003oP/Gmoh;5o@09oh;5o@05o`00
0?n2aOgoP/Gmoh;5oOl000003Om]]O/00ol0003o=8_]ocB;k@02ocB;k@?o00001?m3UO400ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00007?ooool2o`0000Sooooo00?o0000ooooool000002omZ[_P00ol0003o
Dj[ioe>Zn@02oe>ZnA[o00003?oooolJo`0000WoI<Gm0ol0000@ofg;oP?o00000_mhdOl5o`0000_o
Nm;o0_l0000=ohCHo`?o00001?n6f?l3o`0000koS]co0ol00004ohoLoP;o00003OnFgoh3o`0000So
U]on0_l00007oigRo@?o00003OnLh_d2o`000004oj;So?l0003o0000o`00017oXN?l0ol0000>ojCS
o0;o00002?nSho`2o`0000KoY^?k0ol0000<ojCSo0;o00000_nWh_/3o`00013oY>7l0ol0000>oj?O
o0?o00000onOg_`00ol0003oWmcloioLo00>oioLo0Co00004_nHe_d00ol0003oTm7moi?Ao@05o`00
00WoSLkn00?o0000oh;5oOn2aOd02?n2aOd00ol0003oP/Gmoh;5o@02oh;5o@03o`000?m]]O_oKKGk
00_oKKGk00?o0000ocB;kOldRnd01?ldRnd3o`0000;o@iGa00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Vooooo`002?ooool5o`0001_ooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0000;ofZ^n0;o00002OmCZ_T2o`0000_oCJci0_l00004odjanPco00002?mC]o/2
o`0000_oFkkl0_l0000?ofC5o@;o00003_m]boh7o`00013oNm;o0_l00007ohCHo`Co00002_n6f?l2
o`0000SoS]co1?l00009ohoLoP?o00001onFgoh3o`0000goU]on0_l00002oigRo@?o00004OnLh_d3
o`00013oXN?l0ol00003oj3So0;o00002_nTho`2o`0000coXn?l0_l000001?nVho_o0000o`000?l0
000@ojCSo0?o00004?nThO`3o`0000?oX^7l00?o0000oj?Oo?nSgo`02?nSgo`3o`0000OoWmkl0_l0
000;oioLo0?o00001?nKf_d00ol0003oV=KmoiSFo@0>oiSFo@Co00003on=c_h00ol0003oP/Gmoh;5
o@08oh;5o@03o`000?n2aOgoP/Gm00;oP/Gm00?o0000offenom]]O/02om]]O/00ol0003o=8_]ocB;
k@06ocB;k@Co00009Oooool00ol0003oooooooooo`0Uooooo`00:?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000003?mZ[_P00ol0003oDj[ioe>Zn@08oe>Zn@;o0000
2om=[?T00ol0003oC[7jodjanP08odjanP;o00003OmC]o/00ol0003oFkkloe^no00:oe^no0?o0000
3_mTaOd3o`0000CoKL_n1ol00002og;=o`;o000000CoL/goo`000?l0003o00004Omkd_l2o`0000;o
Q=So0ol0000@ohKHo`?o00000_n>g?l3o`00013oSmcn0_l00002oiKOoP?o00004OnFgoh3o`00017o
W>;m0ol00003oicRo@;o00002onQho`3o`0000SoX>?l0_l00005ojCSo0?o00003onSho`3o`0000oo
Y>?l0ol00003oj;Ro0;o00002onThO`3o`0000OoX^7l0_l00005oj?Oo0?o00003?nOg_`00ol0003o
WmcloioLo004oioLo0Co00002?nKf_d2o`0000WoV=Km1Ol00004oi?DoP03o`000?n=c_koSLkn00go
SLkn00?o0000oh;5oOn2aOd02?n2aOd00ol0003oP/Gmoh;5o@02oh;5o@03o`000?m]]O_oKKGk00_o
KKGk00?o0000ocB;kOldRnd02?ldRnd2o`0002Cooooo00?o0000ooooooooool09Oooool002Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`;o00002omZ[_P00ol0003o
Dj[ioe>Zn@09oe>Zn@03o`000?m=[?WoCJci00WoCJci0_l0000:odjanP;o00003?mC]o/2o`0000go
Fkkl0_l0000<ofC5o@Oo00001_mbcOl3o`0000KoL/go0_l0000>og_Bo`Go00005?n6f?l4o`0001?o
Smcn1?l0000AoiKOoP?o00000onGh?h2o`0000coW>;m0ol00008oicRo@;o00001_nQho`3o`0000go
X>?l0_l000000onThoco0000o`00000?oj?So0?o00000onQho`2o`0000[oY>?l0ol00008oj;Ro003
o`000?nThOcoY>7l00GoY>7l0ol0000<oj;Qo003o`000?nSgoco000000;o00004?nOg_`00ol0003o
WmcloioLo003o`0000koVm[m00Co0000oiSFoOnHe_goV=Km1Ol0000:oi?DoP03o`000?n=c_koSLkn
00goSLkn00?o0000oh;5oOn2aOd01_n2aOd@o`0000GoKKGk00?o0000ocB;kOldRnd02?ldRnd00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo000Xooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oJZkhofZ^n009ofZ^n0;o00002_mCZ_T2o`00
00_oCJci0_l0000:odjanP;o00003?mC]o/2o`0000goFkkl0_l00003ofC5o@Oo00001OmYaoh2o`00
00?oL/go0ol0000;og;=o`?o00001?mkd_l7o`0000GoO]Co0ol0000>ohKHo`?o00001?n8fOl2o`00
00koSmcn0ol00004oi3MoP;o00003?nFgoh3o`0000SoUn3n0ol00006oicRo@?o00003OnLh_d2o`00
0004oj7So?l0003o0000o`00017oX>?l0ol0000=oj?So0?o00002?nQho`00ol0003oY>?lojCSo004
ojCSo0?o00003?nRh_`2o`0000;oY>7l0ol0000?oj;Qo0?o00004OnOg_`4o`00013oVm[m1Ol0000@
oi?DoP03o`000?n=c_koSLkn00[oSLkn2ol00002og_1o@03o`000?mk`OgoNl7m00;oNl7m00?o0000
of>_n_mS[oX01_mS[oX8o`0000Wo=8_]00?o0000ooooooooool08oooool00ol0003oooooooooo`0S
ooooo`00:?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo00?o0000
ofZ^n?mZ[_P02_mZ[_P00ol0003oDj[ioe>Zn@09oe>Zn@;o00002om=[?T00ol0003oC[7jodjanP09
odjanP;o00003?mC]o/00ol0003oFkkloe^no005oe^no0[o00003_mYaoh3o`0000ooL/go1_l0000?
ogkDo`;o00002?n6f?l4o`0000WoR=Wo0ol00007ohoLoPCo00002On@gOh3o`0000KoU]on0ol0000>
oiOPoP;o000000CoW>;mo`000?l0003o00004OnLh_d3o`00013oX>?l0ol00003oioRo0?o00001onS
ho`3o`0000coXN?l0_l000001?nThoco0000o`000?l0000@oj;Ro0?o00003onRhO`3o`0000?oWn3m
0_l0000<oioNo0?o00001?nLgOd00ol0003oVm[moi_Jo@0:oi_Jo@?o00001?nGfOh00ol0003oTmCn
oi?DoP0?oi?DoP03o`000?n=c_koSLkn00;oSLkn1ol00004ohO<oP03o`000?mk`OgoNl7m00OoNl7m
00?o0000og_1oOmk`Od00_mk`Od00ol0003oHjojof>_nP0;of>_nP03o`000?lUPNSo000000;o0000
1oldRnd00ol0003oooooooooo`0Rooooo`;o00009?ooool002Wooooo0_l00007ooooo`;o00002?oo
ool00ol0003oJZkhofZ^n004ofZ^n43o00002OmR`_d3o`0000WoJLOn0ol00002ofW7oP;o00002Omb
cOl5o`0000CoM/oo0_l0000AogkDo`?o00000_n6f?l3o`00013oR=Wo0_l00002ohoLoP?o00004?n@
gOh2o`000004oiKOo_l0003o0000o`0001;oUn3n0ol0000@oicRo@?o00000onLh_d2o`0000_oX>?l
0ol00009oioRo0?o000000CoXn?lo`000?l0003o00004?nQho`3o`0000ooX^;l0ol00003oj3Qo0;o
00002_nRhO`3o`0000SoWn3m00?o0000oioNo?nOg_`01OnOg_`4o`0000SoW=gm0_l00006oi_Jo@Co
00002?nGfOh00ol0003oTmCnoi?DoP0=oi?DoPKo00003?n7c?h00ol0003oNl7mog_1o@07og_1o@03
o`000?mk`OgoNl7m00;oNl7m00?o0000of>_n_mS[oX02omS[oX01?l0003o9H7XobF1j?lUPNP3o`00
00Go=8_]00?o0000ooooooooool08?ooool00ol0003oooooo`00000Tooooo`00<_ooool00ol0003o
ooooooooo`08ooooo`Ko00002?mk]OP00ol0003oHk;kof>bn`0:of>bn`;o00002_mK/o/2o`0000_o
F[Ol0_l0000;oeflo@;o00003omR`_d2o`0000CoJLOn0ol00007ofW7oP;o00000_mbcOl5o`0000_o
M/oo0_l0000@ogkDo`Co00004on8fOl4o`0001?oT=gn1?l0000AoiOPoP?o00000onGh?h2o`0000_o
W>;m0ol00008oicRo@;o00001_nPho`3o`0000koWn;l0ol0000?oj7So0?o00000onPh_`2o`0000[o
X^;l0ol00008oj3Qo003o`000?nRhOcoX^7l00CoX^7l0ol0000<oioPo@;o00000_nOg_`3o`0000ko
W=gm00?o0000oi_JoOnKf_d00ol0000=oiOIoP03o`000?nCe?koTmCn00OoTmCn1Ol00003ohkBoP03
o`000?n7c?koQlcn00goQlcn00?o0000og_1oOmk`Od01_mk`Od00ol0003oNl7mog_1o@03og_1o@03
o`000?mS[o[oHjoj00_oHjoj00?o0000obF1j?lUPNP00olUPNP2o`0000?o=8_]00?o0000oooooooo
ool08oooool00ol0003oooooooooo`08ooooo`?o00000oooool3o`0000Cooooo0_l00004ooooo`;o
00001?ooool003;ooooo00?o0000ooooooooool02_ooool00ol0003oNkGhog^en00:og^en0;o0000
3?mS/_/00ol0003oFk?koe^cn`09oe^cn`;o00002omJ]o`2o`0000_oGKcm0_l0000?of;2o@Co0000
1_mYaoh8o`0001;oM/oo0_l00009ogkDo`Go00001?n1eOl2o`0000koR=Wo0ol00004oh[Jo`;o0000
3_n@gOh3o`0000CoTMgn0_l0000<oiOPoP?o00002?nGh?h2o`0000KoW>;m0ol0000=oicRo@;o0000
00CoX>?lo`000?l0003o00003_nOh_`3o`0000?oW^;m0_l0000:oj7So0?o00002?nPh_`00ol0003o
X^;loj;Ro004oj;Ro0?o00003?nPhO`2o`000004oj;Qo?l0003o0000o`00013oWn3m0ol0000@oicM
o@Co00004OnGfOh01?l0003oTmCnoi?Do_nCe?h5o`0000WoS];n00?o0000ohO<o_n7c?h03On7c?h0
0ol0003oNl7mog_1o@06og_1o@03o`000?mk`OgoNl7m00?oNl7m00?o0000of>_n_mS[oX02omS[oX0
0ol0003o9H7XobF1j004obF1j0?o000000?o=8_]o`000?ooool08oooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00Oooool003;ooooo00?o0000ooooooooool0
2oooool00ol0003oNkGhog^en00;og^en003o`000?mS/__oHk;k00[oHk;k0_l0000;oe^cn`03o`00
0?mJ]ocoF[Ol00[oF[Ol0_l0000;oeflo@;o00002omR`_d<o`0000SoKl[o0ol0000AogK?o`;o0000
0_mne?l5o`0000_oPMGo0ol00007ohSIo`Co00002On:f_l3o`0000OoT=gn1?l00009oi7MoP?o0000
1_nGh?h3o`0000goUn3n0_l000001?nLh_go0000o`000?l0000@oicRo@Co00003OnOh_`3o`0000So
W^;m00?o0000oj7So?nQho`01?nQho`3o`0000coX>;l0_l000001?nRh_co0000o`000?l0000?oj3Q
o0Co00003onOh?d3o`0000?oW=om00?o0000oicMoOnLgOd02_nLgOd3o`0000CoVMcn00?o0000oiOI
o_nGfOh03OnGfOh5o`0000ooS];n00?o0000ohO<o_n7c?h03On7c?h00ol0003oNl7mog_1o@05og_1
o@co00002?mS[oX00ol0003o9H7XobF1j007obF1j0?o00009?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo007ooooo000aooooo`03o`000?oooooooooo00gooooo00?o0000
og^en?mk]OP02omk]OP00ol0003oHk;kof>bn`0;of>bn`;o00002_mK/o/2o`0000coF[Ol0_l0000;
oeflo@;o00001?mR`_d7o`0000GoJLGn0_l0000>ofo:o`;o00003_mfcol5o`0001?oPMGo0_l00002
ohSIo`?o00004?n:f_l2o`0000;oT=gn0ol0000@oi7MoP;o000000CoUn3no`000?l0003o00004?nG
h?h4o`0000ooW>;m0ol00004oi_Ro@?o00001onOh_`3o`0000coW^;m0_l000001?nQhoco0000o`00
0?l0000@oj3Ro0?o00003_nPhO`3o`0000CoW^7m0_l0000:oioPo@?o00001onLgod2o`0000KoW=gm
1?l00008oiWLoP;o00002?nGfOh5o`0000CoT]On00?o0000ohkBo_n>d_h03_n>d_h00ol0003oQlcn
ohO<oP06ohO<oPko00000_mb_Od00ol0003oL[gmog:mo@03og:mo@04o`000?mIZOSoFJWhoeVYn0Oo
00000_mS[oX00ol0003o9H7XobF1j009obF1j003o`000?oooooooooo02;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`01ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`;o00003?mk]OP2o`0000goHk;k00?o0000oe^cnomK/o/02OmK/o/2o`0000KoF[Ol6_l0000;ofW5
oP;o00003_m_b_l3o`0000CoM/oo1ol00005og[Ao`;o00004On1eOl5o`0001;oR][o1?l0000Coi7M
oPCo00003onGh?h3o`0000CoUn3n0ol00008oicRo@Co00002_nKh_d3o`000004oioRo?l0003o0000
o`00013oW^;m0ol0000?oj3Ro0?o00000onNh_d3o`0000OoX>7l1?l00009oikQo@03o`000?nOh?go
Wn3m00CoWn3m0ol0000<oicOo@03o`000?nLgOgoW=gm00?o00003_nIg?h00ol0003oUmWnoiOIoP05
o`0000[oT]On00?o0000ohkBo_n>d_h03?n>d_h:o`0000SoP<Sn00?o0000og:moOmb_Od01Omb_Od0
0ol0003oL[gmog:mo@04og:mo@03o`000?mIZOSoFJWh00OoFJWh1Ol00009obF1j003o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool4o`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`00<Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?mk]OSoNkGh00_oNkGh00?o0000of>bnomS/_/01OmS/_/Io`0000SoI;cm
0_l0000:ofK1oP?o00004?mYaOh2o`0000coKl[o1ol0000>og[Ao`?o00002On1eOl5o`0000GoQ=Ko
0ol0000:oh[Jo`Go00001?n<f_l2o`0000koTMgn0ol00004oi;NoP?o00002?nGh?h4o`0000[oUn3n
0ol00002oicRo@?o00004?nKh_d3o`0000ooW^;m0ol00003oigRo@;o00002_nPh_`3o`0000WoW^;m
0_l00002oj3Qo0?o00003_nNhOd2o`000004oioPoOl0003o0000o`0000koW=om1?l0000@oiWLoPCo
00004?nBeoh00ol0003oS];nohkBoP06ohkBoPGo00001?n9d?l00ol0003oP<Snoh38oP0<oh38oP03
o`000?mb_OgoL[gm00GoL[gm00?o0000og:moOmb_Od01?mb_Od00ol0003oFJWhoeVYn009oeVYn004
o`000?lFM^?o0000o`0000So9H7X00?o0000ooooooooool08_ooool00ol0003oooooooooo`05oooo
o`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool0037ooooo00?o0000ooooooooool04Oooool00ol0003oNkGhog^en008
og^en0[o00002?ma^?/00ol0003oIkWmofNio@0:ofNio@03o`000?mT_?goI;cm00_oI;cm00?o0000
ofK1o_mV`Oh01?mV`Oh3o`0000?oI/7n0_l0000@ofW5oP;o00000om_b_l7o`0000GoMLgo0ol0000@
og[Ao`;o00000_n1eOl5o`0000goQ=Ko0ol00002oh[Jo`Go00002on<f_l3o`0000OoTMgn1?l0000:
oi;NoP?o00000_nGh?h3o`00013oUn3n0ol0000@oi_Ro@?o00000onKhOd2o`0000[oW^;m0ol00008
oigRo@;o00001_nPh_`2o`0000goW^;m0ol0000AoikQo@Co00003OnLgod3o`0000CoV]kn0_l0000;
oiWLoP?o00001?nEf_h00ol0003oT]Onoi;GoP0>oi;GoP03o`000?n>d_koS];n00Go00002_n9d?l0
0ol0003oP<Snoh38oP0<oh38oP03o`000?mb_OgoL[gm00GoL[gm00?o0000og:moOmb_Od01?mb_Od0
0ol0003oFJWhoeVYn009oeVYn003o`000?lFM^?o5WKS00?o00001_lUPNP00ol0003oooooooooo`0P
ooooo`?o00001oooool01?l0003oooooooooooooool5o`0000?ooooo0_l00004ooooo`;o00001?oo
ool0037ooooo00?o0000ooooooooool04_ooool01?l0003oNkGhog^en?mk]OP6o`0000GoR[_f00?o
0000og6hnoma^?/02oma^?/2o`0000_oIkWm0_l0000<ofBlo@;o000000CoI/7no`000?l0003o0000
2?mV`Oh2o`0000goJLGn1_l0000?ogG=o`;o00003OmjdOl5o`0001?oQ=Ko1?l0000CohcJo`;o0000
0_nAgOh3o`0000ooT]kn1?l0000@oiOPoP?o00000onHh?h2o`0000_oVn;m0ol00008oi_Qo@03o`00
0?nNh_goW^;m00CoW^;m0ol0000=oigRo@;o000000CoX>;lo`000?l0003o00003?nNh_d3o`0000?o
WN7m0_l0000<oikQo@?o00001?nLh?d3o`0000OoW=om0ol00009oi[NoP03o`000?nIg?koVMcn00Go
VMcn0ol00008oiGJoP;o00003OnBeoh4o`00013oRM3o00?o0000oh38o_n0b?h03?n0b?h00ol0003o
L[gmog:mo@05og:mo@03o`000?mb_OgoL[gm00CoL[gm00?o0000oeVYn?mIZOP02OmIZOP00ol0003o
5WKSoaIfh`02oaIfh`;o00001?lUPNP00ol0003oooooooooo`0Mooooo`Co000000?oooooo`000?oo
ool07_ooool0037ooooo0_l0000Dooooo`?o00003?n:^oH2o`0000goLKSk00?o0000ofNioOmW^Od0
2_mW^Od00ol0003oI;cmofBlo@09ofBlo@Co00003?mV`Oh2o`0000CoJLGn1ol00005og38o`;o0000
4?mecOl3o`0000?oN]7o1ol00005ogkCo`;o00003_n4e_l3o`0000CoQmSo0_l0000AohcJo`Co0000
3onBg_h3o`0000CoTmkn0_l0000;oiOPoP?o00002?nHh?h2o`0000KoVn;m0ol0000<oi_Qo@;o0000
00CoW^;mo`000?l0003o00004?nMh_d4o`0000_oW^;m0ol00008oigQo@03o`000?nNhOgoW^7m00Go
W^7m1?l0000:oicPo@;o00000_nLgod3o`0000goV]kn0_l00002oiWLoP?o00003OnEf_h00ol0003o
T]Onoi;GoP05oi;GoPGo00001?n>eOl00ol0003oRM3oohW@o`0>ohW@o`03o`000?n0b?koP<Sn00Go
P<Sn6_l00008oeVYn003o`000?lFM^?o5WKS00?o5WKS0_l00003obF1j003o`000?oooooooooo01Wo
oooo0ol00005ooooo`03o`000?oooooooooo01gooooo000`ooooo`03o`000?oooooooooo01Kooooo
00?o0000ohZkm_n:^oH03?n:^oH00ol0003oLKSkog6hn`0;og6hn`03o`000?mW^OgoIkWm00[oIkWm
0_l00006ofBlo@?o00001?mT_?d00ol0003oI/7nofK1oP05ofK1oP[o00003_m`b?l3o`0000goMLgo
1_l0000>ogkCo`?o00001on4e_l4o`0000WoQmSo0ol00009ohcJo`Go00001?n>fol3o`0000SoT]kn
1?l00009oi?NoP;o00001_nGh?h3o`0000goV>3n0_l000001?nKh_go0000o`000?l0000?oi_Qo@Co
00003onMh_d3o`0000CoW>;m0ol00006oikRo@;o00003?nMhOd2o`0000;oW^7m0ol0000?oicPo@?o
00004?nJg_h4o`00017oUM[n00?o0000oi;Go_nBeoh01?l0000:ohkEo`;o00003?n9d?l:o`0000Wo
N/Gn00?o0000ofZho?mZ^?`00omZ^?`00ol0003oJ[SlofZho005ofZho003o`000?m>X_KoCZ;f00Go
00001?mIZOP00ol0003o5WKSoaIfh`04oaIfh`Co00005oooool4o`0000Sooooo00?o0000oooooooo
ool07Oooool0033ooooo00?o0000ooooooooool05oooool00ol0003oR[_fohZkmP0<ohZkmP03o`00
0?ma^?_oLKSk00_oLKSk0_l0000<ofNio@03o`000?mT_?goI;cm00?o00000_mT_?d=o`0000SoK/Co
0ol0000@og38o`;o00001?mecOl7o`0000GoN/oo0_l0000@ogkCo`;o00000_n4e_l3o`00013oQmSo
0_l00002ohcJo`Go00003?n>fol3o`0000;oT]kn0ol0000?oi?NoP;o000000CoUn3no`000?l0003o
00004?nHh?h4o`0000koVn7m0ol00004oi_Qo@?o00002?nMh_d4o`0000[oW>;m0_l000001?nNh_go
0000o`000?l0000>oigQo@Co00003onLh?d3o`0000?oV]om00?o0000oi[No_nJg_h02_nJg_h3o`00
00CoUmgn00?o0000oiGJo_nEf_h03OnEf_h4o`00013oS]Go00?o0000ohW@oon9d?l00_n9d?l7o`00
00GoPlgo00?o0000og[5o_mjaOh03?mjaOh00ol0003oJ[SlofZho003ofZho003o`000?mZ^?coJ[Sl
00GoJ[Sl00?o0000odjRm_m>X_H01?m>X_H6o`0000So5WKS0_l0000Cooooo`?o00003?ooool00ol0
003oooooooooo`0Mooooo`00<?ooool00ol0003oooooooooo`0Hooooo`03o`000?n:^oKoR[_f00co
R[_f0_l0000=og6hn`03o`000?mW^OgoIkWm00CoIkWm3Ol00008ofo1oP;o00003_m^a?l2o`0000go
L<So1ol0000>og[?o`?o00003?mndol5o`0001?oQmSo1?l0000BohkKo`Co00004_nCg_h4o`0000oo
V>3n0ol00004oiSPoP?o00002?nKhOd3o`0000[oVn7m0ol00002oigRo@?o00003onLh_d3o`0000go
WN7m0ol00004oi_Qo@;o00002_nLh?d3o`0000OoV]om0_l00006oi[NoPCo00002?nGgOh2o`0000So
UM[n1Ol00004oi7Io`03o`000?n>eOooS]Go00coS]Go1_l0000=oh?=o`03o`000?mjaOkoN/Gn00co
N/Gn00?o0000ofZho?mZ^?`00_mZ^?`00ol0003oJ[SlofZho006ofZho003o`000?m>X_KoCZ;f00So
CZ;f0ol00008oaIfh`03o`000?oooooooooo00gooooo0ol0000@ooooo`03o`000?oooooooooo01co
oooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0000>ohZkmP03o`000?ma^?_oLKSk00GoLKSk
3?l00003og>no@;o00000omc__d2o`0000goKl7n0_l0000>ofk4o`?o00000om`b?l7o`0000GoMl_o
0_l0000Aog[?o`;o00000omndol7o`0000GoP]Co0_l0000>ohOHo`?o00001?n9fOl2o`0000goS]_o
0ol00004ohoLo`;o00003OnCg_h3o`0000CoU=kn0ol00008oiSPoPCo00002_nHh?h3o`0000;oVn7m
0ol0000?oi_Qo@?o00003onLh_d3o`0000?oVn7m0ol00007oigQo@?o00002OnKhOd00ol0003oW>3m
oicPo@04oicPo@?o00003?nJgod00ol0003oV]knoi[NoP03o`0000koUmgn00?o0000oiGJo_nEf_h0
1Ol0000:oi7Io`03o`000?n>eOooS]Go00KoS]Go1Ol00004ohWCo`03o`000?n3cOooPlgo00goPlgo
00?o0000og[5o_mjaOh03?mjaOh00ol0003oJ[SlofZho002ofZho003o`000?mZ^?coJ[Sl00KoJ[Sl
00?o0000odjRm_m>X_H02Om>X_H3o`0000Ko5WKS00?o0000ooooooooool02Oooool4o`0001?ooooo
00?o0000ooooooooool07?ooool0033ooooo00?o0000ooooooooool06oooool00ol0003oR[_fohZk
mP0:ohZkmPWo00002?mn_O/01?l0003oLkkmog>noOmc__d3o`0000OoLkkm0_l0000=ofo1oP;o0000
3?m^a?l6o`0000koMl_o0_l0000?og[?o`Go00003_n2e?l3o`0000OoQmSo1?l00009ohWIo`?o0000
1on>fol3o`0000WoSmco0ol00007oi?NoP?o00002_nDg_h3o`0000;oV>3n0ol0000@oiSPoP?o0000
3onKhOd3o`0000?oV^7m0_l0000:oicRo@?o00002OnKhOd2o`0000;oWN7m0ol0000=oi_Qo@;o0000
00CoW>3mo`000?l0003o00003_nJgod4o`00013oUmgn1?l0000@oi7Io`03o`000?n>eOooS]Go00Go
00002_n9dol00ol0003oPlgooh?=o`0=oh?=o`03o`000?mjaOkoN/Gn00GoN/Gn4?l00005ofZho003
o`000?m>X_KoCZ;f00WoCZ;f00Co0000o`M[g?l0003o00001OlFM^<00ol0003oooooooooo`05oooo
o`?o00005oooool00ol0003oooooooooo`0Looooo`00<?ooool00ol0003oooooooooo`0Looooo`03
o`000?n:^oKoR[_f00GoR[_f1?l00004oiNol`03o`000?mn_O_oO[gk00_oO[gk0ol0000<og>no@;o
00003Om_`Oh2o`0000?oK/Co1ol00005ogK8o`;o00003omgbol00ol0003oN/ooog[?o`07og[?o`Go
00001?modOl2o`00013oP]Co0_l00002ohOHo`?o00004?n9fOl2o`0000;oS]_o0ol0000?ohoLo`;o
00000_nCg_h3o`0000koU=kn1?l0000@oiSPoP?o00000onHh?d2o`0000[oVn7m0ol00008oi[Qo@03
o`000?nLh_goW>;m00CoW>;m0ol0000=oi_Qo@?o00004?nKhOd4o`0000goV]om0ol00004oiSNoP03
o`000?nGgOkoUmgn00[oUmgn0ol00004oiCLoP03o`000?nAfOooTMWo00coTMWo1?l0000@ohWCo`03
o`000?n3cOooPlgo00[oPlgo2_l00007og;1oP03o`000?mQ/o_oHK?k00?oHK?k00?o0000of6cnomQ
/o/02_l00008odjRmP03o`000?l7Jmco1f_L00;o00001?lFM^<01?l0003oooooooooooooool3o`00
01[ooooo00?o0000ooooooooool07?ooool0033ooooo00?o0000ooooooooool07Oooool00ol0003o
R[_fohZkmP04o`0000WoUkoc0_l00008ogjmn`?o00000_mn_O/00ol0003oLkkmog>no@0<og>no@;o
00001om_`Oh9o`0000koM/So0_l0000>ogO;o`;o00000_mjcol5o`0000_oOm7o0_l0000>oh;Do`Go
00004_n9fOl4o`0001;oSmco1?l0000>oiCNoP?o00001?nEgoh2o`0000_oV>3n0ol00008oiSPo@03
o`000?nKhOgoVn7m00CoVn7m0ol0000<oi[Qo@;o000000CoW>;mo`000?l0003o00003OnKhOd3o`00
00?oV^7m00?o0000oi_QoOnKhOd02_nKhOd3o`0000CoV^3m0_l00007oi[Oo@Co00002?nHg_h2o`00
00KoUmgn1?l00008oiCLoP;o00001onAfOl5o`0000CoS]Oo00?o0000ohWCoon9dol03_n9dol00ol0
003oPlgooh?=o`02oh?=o`Oo00001?mmbol00ol0003oL/7nog;1oP0;og;1oP03o`000?mQ/o_oHK?k
00;oHK?k00?o0000of6cnomQ/o/01_mQ/o/01?l0003o@Y_dod:Km?m2Vo@5o`0000CoCZ;f00Co0000
o`M[g?l7Jmco1f_L0_l00003oaIfh`?o00007Oooool00ol0003oooooooooo`0Looooo`00;oooool0
0ol0003oooooooooo`0Oooooo`;o00003onG_o<00ol0003oO[gkogjmn`02ogjmn`?o00001_mn_O/2
o`0000_oLkkm2_l00008ogS5oP;o00003omfb?l00ol0003oMl_oogO;o`0:ogO;o`Go00004_modOl0
0ol0003oP]Cooh;Do`06oh;Do`Go00001On6e_l3o`0000[oRMWo1Ol00004ohcJo`;o00003On?g?l3
o`0000CoTMcn0ol00008oiCNoP?o00002OnEgoh2o`0000KoV>3n0ol0000<oiSPo@;o000000CoVn7m
o`000?l0003o00003onJhOd4o`0000coVn7m0ol00007oi[Qo@;o00001_nKhOd4o`0000WoV^3m0_l0
0002oi[Oo@?o00003_nHg_h00ol0003oUmgnoiOMoP03o`0000koU=cn00?o0000oi7IoonAfOl01?l0
000:ohkGo`;o00003?n9dol7o`0000coOL_o00?o0000og;1o_mb`Oh02omb`Oh00ol0003oHK?kof6c
n`02of6cn`03o`000?mQ/o_oHK?k00KoHK?k00?o0000od:Km?m2Vo@01Om2Vo@6o`0000Co1f_L0_l0
00000olFM^?o0000ooooo`0Nooooo`03o`000?oooooooooo01cooooo000_ooooo`?o00008Oooool0
0ol0003oUkocoiNol`0=oiNol`Co00002omn_O/01?l0003oLkkmog>noOmc__d7o`0000GoO/?m0_l0
000=ogS5oP;o00003_mfb?l2o`0000?oMl_o1ol00005ogg>o`?o00004?modOl2o`0000;oP]Co1?l0
000=ohKFo`?o00000_n9fOl5o`0000_oS=[o0_l00007ohoLo`Co00002_nAg?h3o`0000;oU=kn0ol0
000>oiGOoP;o000000CoV>3no`000?l0003o00003onHh?d4o`0000koV^7m0ol00004oi[Qo@?o0000
1_nKhOd3o`0000coV^7m00?o0000oi_QoOnKhOd00ol0000=oi[Po@Co00004?nHg_h4o`00013oU=cn
1?l0000@ohkGo`03o`000?n9doooRM?o00;oRM?o1ol00005ohGAo`03o`000?mmboooOL_o00coOL_o
00?o0000og;1o_mb`Oh02omb`Oh00ol0003oHK?kof6cn`02of6cn`03o`000?mQ/o_oHK?k00KoHK?k
00?o0000od:Km?m2Vo@02Om2Vo@3o`0000Co1f_L0ol0000Nooooo`03o`000?oooooooooo01cooooo
000_ooooo`03o`000?oooooooooo02;ooooo00?o0000oiNolonG_o<02_nG_o<5o`0000[oO[gk1_l0
000>ogk3o@03o`000?mhaOkoN<Gn00coN<Gn00?o0000ogK8oomfb?l02_mfb?l6o`0000ooOLko0_l0
000=ogoAo`Go00004_n6e_l4o`0001;oS=[o0_l00002ohoLo`?o00003onAg?h4o`00017oUMon1?l0
000>oiSPo@?o00001?nIh?d3o`0000SoV^7m0ol0000:oi[Qo@;o000000CoVn7mo`000?l0003o0000
3_nJhOd4o`0000goV^3m0ol00004oiSOoP?o00002?nHg_h5o`0000CoUMkn0_l00009oiCLoPGo0000
1?nAfol00ol0003oS]OoohkGo`0<ohkGo`Ko00003On5dOl2o`0000goOL_o00?o0000og;1o_mb`Oh0
2omb`Oh00ol0003oHK?kof6cn`02of6cn`03o`000?mQ/o_oHK?k00KoHK?k00?o0000od:Km?m2Vo@0
2Om2Vo@01?l0003o063Fo`000?l00004o`M[g0;o00007_ooool00ol0003oooooooooo`0Kooooo`00
;oooool00ol0003oooooooooo`0Sooooo`03o`000?nG_o?oUkoc00KoUkoc0ol00005oiNol`04o`00
0?mn_O_oO[gkogjmn`Ko00001On9`_X2o`0000koO/?m0_l0000=ogS5oP;o00000omfb?l7o`0000Go
OL_o0_l0000@ogg>o`?o00000omodOl7o`0000GoQ=?o0_l0000=ohKFo`?o00001?n:eol2o`00013o
S=[o1?l0000?oi7LoP?o00001?nCgOh2o`0000coUMon0ol00004oiKOoP?o00002?nHh?d3o`0000[o
VN3m0ol00002oi[Qo@?o00003OnJhOd4o`0000goV^7m0ol00004oi[Qo@?o00001onJh?d3o`0000[o
V=on0_l00002oiSNoPCo00002onEg_h2o`0000;oU=cn1Ol0000:oi7Ko`;o00001on>eol5o`0000Co
R]Ko00?o0000ohGAoon5dOl03_n5dOl00ol0003oOL_oogg;o`05ogg;oago00001OmQ/o/00ol0003o
@Y_dod:Km009od:Km004o`000?l0H=Ko063Fo`0000Go1f_L00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`00;oooool00ol0003oooooooooo`0Tooooo`03o`000?nG_o?oUkoc00?o
Ukoc0_l00007oiNol`Go00003On9`_X00ol0003oO/?mogk3o@0=ogk3o@;o00002_mhaOh6o`0000ko
OL_o0_l0000?ogg>o`Go00003_n4dol3o`0000OoQ]Ko0ol00009oh[Go`?o00002?n<f_l5o`0000Co
Sm[o0ol00008oi7LoPCo00002OnCgOh2o`0000OoUMon0ol0000:oiKOoP?o00000_nHh?d3o`0000ko
VN3m1?l0000=oi[Qo@?o00001?nJhOd3o`0000OoV^7m0ol0000:oi[Qo@;o00000_nJh?d3o`0000go
V=on1?l0000?oiGNoPCo00004OnAfol00ol0003oS]OoohkGo`04o`0000[oR]Ko0_l0000<ohGAo`[o
00002?mgb?l00ol0003oJkgnof^moP0;of^moP04o`000?mH[_[oF:kjo`0000?oF:kj2Ol00009od:K
m003o`000?l0H=Ko063F00;o00000ol7Jm`00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo000_ooooo`03o`000?oooooooooo02Gooooo00?o0000oiNolol000000_l00006oiNol`?o
00001?nQ`_000ol0003oRL;johW2nP0<ohW2nP;o00003omn`od01?l0003oN<GnogS5o_mhaOh6o`00
00GoPLSn0_l0000?ogg;o`;o00002?mmc_l5o`0000CoPm3o0_l0000@ohCCo`;o00000_n6e_l3o`00
00ooR]Oo0_l00002ohcJo`Co00003?n?f_l3o`0000;oTMcn0ol0000?oi?MoP;o00000_nEgoh3o`00
00koU]on1?l0000>oiWPo@?o00001?nIhOd3o`0000OoV^7m0ol0000:oi[Qo@;o00000_nJhOd3o`00
00goV^7m1?l0000=oiSOoP?o00001?nGgoh00ol0003oUMknoiGNoP09oiGNoP?o00001?nCgOh00ol0
003oTM_ooi7Ko`0=oi7Ko`Co00004?n:e_l00ol0003oQM7oohGAo`02ohGAo`Oo00001On0col00ol0
003oMlSoogO8o`0;ogO8o`;o00003?m[_Oh01?l0003oF:kjoeR^n_l00008oeR^nP03o`000?lgTo7o
=i?a00Co00001_m2Vo@01?l0003o063Fo`1Pe_l0H=H2o`0000;o1f_L00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Kooooo`00;_ooool00ol0003oooooooooo`0Uooooo`?o00001_nG_o<3
o`0000SoXL;`00?o0000ohW2n_n9`_X03On9`_X2o`0000_oO/?m1_l0000=oh78oP;o00003ommbol2
o`0000;oOLko1?l0000;oh?@o`?o00003?n4dol5o`0001;oR]Oo1?l0000AohoJo`Co00004_nCgOh4
o`0000koU]on0ol00004oiOOoP?o00001onIh?d4o`0000[oVN7m0_l00002oi[Qo@?o00003OnJhOd4
o`0000goV^7m0ol00004oiWPo@?o00001onHgoh3o`0000SoUmon0_l00006oiGNoP?o00002?nCgOh2
o`0000SoTM_o1Ol00004ohkIo`;o00003?n:e_l7o`0000goP<oo00?o0000ogO8oomgb?l03?mgb?l0
0ol0003oJkgnof^moP0:of^moP04o`000?mH[_[oF:kjo`0000SoF:kj00?o0000ocNClOlgTo400olg
To43o`0000?o@Y_d00?o0000o`1Pe_l0H=H00ol0H=H2o`000003o`M[g?l0003ooooo01[ooooo00?o
0000ooooooooool06oooool002kooooo00?o0000ooooooooool08_ooool3o`0000?ooooo00?o0000
oiNolonG_o<00ol0000<oj72l0;o00003on9`_X01?l0003oO/?mogk3oOmn`od7o`0000GoQlKl0_l0
000>oh78oP;o00003?mmbol5o`0001;oPm3o0_l00003ohCCo`Oo00001On9e?l3o`0000[oR]Oo1Ol0
0004ohgHo`;o00003?n?f_l3o`0000CoTM_n0_l0000=oi?MoP?o00001?nEg_h3o`0000OoU]on1?l0
000:oiOOoP;o00000_nIh?d3o`0000koVN7m1?l0000=oi[Qo@?o00001?nIhOd3o`0000OoV^7m0ol0
000:oiWPo@;o00000_nHgoh3o`0000goUmon00?o0000oiGNo_nEg_h00ol0000=oi?MoP03o`000?nA
foooTM_o00Go00002on>fOl2o`0000?oR]Ko1ol00005ohKDo`03o`000?n0coooP<oo00goP<oo00?o
0000ogO8oomgb?l01Omgb?l?o`0000GoJkgn00?o0000oeR^n_l000002OmH[_X00ol0003o=i?aocNC
l@05ocNCl@Go00001_l0H=H3o`0001[ooooo00?o0000ooooooooool06oooool002kooooo00?o0000
ooooooooool07oooool3o`0000Oooooo0_l0000Aoj72l003o`000?n9`_[oRL;j00_oRL;j1Ol0000>
ohO6o0;o00003_n1b?h2o`0000?oOL_o1ol00005ohG>o`;o00004?n3d?l5o`0000ooRMCo0ol00002
oh[Go`Go00002on=f?l2o`0000OoSm[o0ol00009oi7KoP;o00001onCgOh4o`0000[oUMkn0_l00002
oiKOoP?o00003_nGgoh4o`0000koVN7m0ol00004oiWQo@?o00001onJhOd3o`0000[oVN7m0_l00002
oi[Qo@?o00003OnIh?d4o`0000ooUmon1?l0000?oi?MoPCo00004?n>fOl5o`0000goQ]Co00?o0000
oh3?oon0col02_n0col:o`0000SoLLGo00?o0000of>ioOmS^Od01?mS^Od;o`0000OoF:kj00?o0000
ocNClOlgTo402?lgTo43o`0000Ko063F0_l0000Iooooo`03o`000?oooooooooo01_ooooo000^oooo
o`;o00007Oooool3o`0000cooooo00?o0000oj72l?nQ`_003onQ`_000ol0003oRL;johW2nP05ohW2
nPGo00001?nCaOP00ol0003oQlKlohO6o00>ohO6o003o`000?n1b?koPLSn00[oPLSn1_l0000>ohG>
o`?o00002?n3d?l5o`0000CoRM;o0_l0000?ohWDo`Co00004_n=f?l2o`0000;oSm[o0ol0000>oi7K
oP;o00000_nCgOh3o`0000koUMkn1?l0000>oiOOoP?o00001?nHh?h3o`0000SoVN7m0ol0000:oiWQ
o@;o00000_nJhOd3o`0000goVN7m1?l0000=oiWPo@?o00001?nHh?h2o`0000SoUmon1Ol00004oiGN
oP;o00002?nCgOh5o`0000CoTMcn0_l00009ohkIo`Go00001?n:f?l00ol0003oQ]CoohKDo`0<ohKD
o`03o`000?n0coooP<oo00;oP<oo1ol00005og_<o`03o`000?maaOooLLGo00_oLLGo00?o0000of>i
oOmS^Od02_mS^Od01?l0003oCjSho`000?m?Z?P7o`000003oeR^n_l0003o=i?a00Wo=i?a00?o0000
o`1Ec_l000001_l0H=H2o`0001Wooooo00?o0000ooooooooool06_ooool002gooooo0_l0000Koooo
o`?o00004?ooool2o`00013oXL;`00?o0000ohW2n_n9`_X01?l0000:oi?5n0;o00003on7a_`2o`00
00?oPLSn1ol00005ohS;oP;o00004?n5c_l2o`0000;oPm3o1?l0000;ohWBo`;o00002?n9e?l5o`00
00CoSMKo0_l0000@ohgHo`Co00004OnAfoh4o`0000koUMkn0ol00004oiONoP?o00002?nGgoh3o`00
00[oV>3n0ol00002oiWQo@?o00003OnIhOd4o`0000goVN7m0ol00004oiWQo@;o00001onIh?d4o`00
00WoV>3n0_l00002oiOOoPCo00002onEg_h2o`0000;oTmgn1?l0000;oi7LoP;o00000_n>fOl5o`00
00[oR]So00?o0000ohKDoon6e?l02On6e?l7o`0000goNlco00?o0000og75oomaaOl02omaaOl00ol0
003oHkWmof>io@0:of>io@;o00002?m?Z?P5o`0000So=i?a00Co0000o`1Ec_l0003o00001_l0H=H0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo000^ooooo`03o`000?oooooooooo
01Kooooo0ol0000Eooooo`03o`000?nQ`_3oXL;`00goXL;`0ol0000@oi?5n003o`000?n7a_coQlKl
00coQlKl1Ol0000>ohS;oP;o00003_n5c_l4o`00017oRM;o0_l00002ohWDo`Co00002on=e_l3o`00
00SoSMSo1Ol00004oi7Jo`?o00002OnAfoh5o`0000CoU=cn0ol00008oiGNoP?o00002_nGg_h3o`00
00;oUmon0ol0000>oiSPoPCo00003OnIhOd3o`0000CoV^7m0ol00007oiWQo@?o00002OnIhOd2o`00
00;oVN3m0ol0000=oiSPoPCo00003onEg_h4o`0000ooTMcn1?l0000@oh[Ho`04o`000?n6e?ooQ]Co
ohKDo`Oo00001On2d_l2o`0000koNlco00?o0000og75oomaaOl02omaaOl00ol0003oHkWmof>io@0:
of>io@;o00002_m?Z?P00ol0003o:hc]o`000003o`0000Go=i?a00?o0000o`1Ec_l0ELh00_l00004
o`1PeP03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool002gooooo00?o0000oooo
ooooool05?ooool3o`0001Wooooo00?o0000oj72l?nQ`_002OnQ`_03o`0000?oZ/C/0_l0000?oi?5
n0;o00001on7a_`5o`0000CoT<Wk00?o0000ohS;o_n8boh03_n8boh00ol0003oQLkoohG>o`06ohG>
o`Go00001?n;d?h2o`0000ooRM;o1?l0000BohgFo`;o00000_n=f?l4o`0000coTM[o0ol00002oi7K
oPCo00003?nDg?h3o`0000;oUMkn0ol0000>oiONoPCo00003_nHh?h3o`0000CoVN3m0ol00007oiWQ
o@?o00002_nJhOd2o`0000;oVN7m0ol0000<oiWQo@Co00003OnHh?h3o`0000CoUn3n00?o0000oiGN
o_nEg_h02OnEg_h3o`0000CoTmkn0_l00008oi7LoPGo00001?n>fol2o`0000coR]So1_l0000>oh;B
o`;o00001omkc?lLo`0000GoHkWm0_l0000:odnXn003o`000?l[S>go:hc]00;o:hc]0ol00003ocNC
l@05o`000?l0ELko05G>o`1Ec_l000001?l0H=H00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01[ooooo000]ooooo`03o`000?oooooooooo01;ooooo0_l0000Mooooo`;o00001_nQ`_03o`00
00SoZ/C/00?o0000oi?5n?nCaOP03_nCaOP00ol0003oQlKlohO6o004o`0000[oT<Wk0_l0000?ohS;
oP;o00000_n5c_l4o`0000_oRm3n0_l00008ohWBo`Go00001?n>e?l2o`00013oSMKo1?l0000Aoi7J
o`Co00004OnDg?h4o`0000koUmkn0ol00004oiSOoP?o00001onHh?h4o`0000[oVN3m0_l00002oiWQ
o@?o00003OnJhOd4o`0000coVN7m0ol00004oiWQo@?o00001onHh?h3o`0000SoUn3n0_l00006oiGN
oP?o00002OnCg_h2o`0000;oTMcn1?l0000;ohkKo`;o00000on:f?l7o`0000GoQmOo0_l0000<oh;B
o`[o00002?meb_l00ol0003oJl7nof_1oP0;of_1oP03o`000?mL]OcoG;Gl00?oG;Gl2ol00007odnX
n003o`000?l[S>go:hc]00Co:hc]1Ol00003o`1EcP;o00000ol0H=H00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01[ooooo000]ooooo`03o`000?oooooooooo00oooooo0ol0000Qooooo`03
o`000?nQ`_3oXL;`00?o00003?nZa>`2o`0000goTlGh1?l0000@oi39n`03o`000?n8bokoR<_n00co
R<_n1?l0000Aoh_@oP;o00000_n9d_l4o`0000_oS]Co0_l0000;ohgFo`?o00001?nAf?h2o`0000co
TM[o0ol00004oiCKoP;o00003?nDg?h3o`0000CoUmgn0ol00008oiONoP?o00002_nHgoh2o`0000;o
V>3n0ol0000?oiWPo@?o00003OnJhOd3o`0000CoV^7m0_l00007oiWQo@?o00002_nIhOd2o`0000;o
V>3n0ol0000=oiOPoP03o`000?nEg_koUMkn00?o00003?nCg_h4o`0000ooS]_o1Ol0000>ohOGo`;o
00000on2d_l7o`0000GoOM3o00?o0000ogG:oomeb_l02omeb_l2o`0000coJl7n00?o0000oebeo?mL
]O`02OmL]O`01?l0003oAJ;fodFRm_m5X_H7o`000003odnXn?l0003o:hc]00So:hc]0ol00003o`1E
cP04o`000?l0H=Ko063Fo`0001Kooooo00?o0000ooooooooool06_ooool002gooooo00?o0000oooo
ooooool03?ooool3o`0002Gooooo0_l0000Aoj[4k0;o00001onCaOP4o`0000CoW<Of00?o0000oi39
non@bO/03_n@bO/2o`0000OoR<_n1Ol00004oi3>o@;o00003on;d?h4o`00017oS]Co00?o0000ohgF
oon=e_l01On=e_l3o`0000WoTMSn0_l00007oi7Jo`?o00002OnDfoh2o`0000OoU=cn0ol0000:oiOM
oP?o00000_nGg_h3o`0000goV=on1?l0000?oiWPo@?o00000onJh?d3o`0000OoV^7m0ol00009oi[Q
o@;o00000_nIhOd3o`0000goVN7m1?l0000?oiOPoPCo00003?nCg_h3o`0000CoTMgn0_l00008ohkK
o`Go00001?n<f_l2o`0000coQmOo1_l0000=ogg@o`03o`000?meb_ooML[o00coML[o00?o0000of_1
o_m[`Oh02_m[`Oh00ol0003oG;Gloebeo009oebeo003o`000?m5X_KoAJ;f00OoAJ;f1?l00008ob^<
k@03o`000?l0BLKo000000?o05G>0_l000000ol0H=Ko0000ooooo`0Dooooo`03o`000?oooooooooo
01[ooooo000]ooooo`03o`000?oooooooooo00Wooooo0ol0000Zooooo`03o`000?nZa>coZ/C/013o
Z/C/00?o0000oi?5n?nCaOP01?l00009oic7mP;o00004?n@bO/00ol0003oR<_nohS;oP04o`0000_o
T<km0ol00008oh_@oPCo00001?nAd_h2o`00013oS]Co0_l00002ohgFo`?o00003_nAf?h2o`0000;o
TM[o0ol0000>oiCKoP;o00000_nDg?h3o`0000koUmgn1?l0000=oiSOoP?o00001?nJgod2o`0000[o
VN3m0ol00009oi[Po@;o00000_nJhOd3o`0000goV^7m0ol0000=oiWQo@?o00001?nHhOd2o`0000So
Un3n1Ol00004oiKOoP;o00001onCg_h3o`0000WoTMgn0_l00002ohkKo`Co00002on<f_l2o`0000?o
QmOo1ol00005ohCEo`03o`000?mmd?ooOM3o00coOM3o00?o0000ogG:oomeb_l01Omeb_lIo`0000Oo
G;Gl00?o0000odFRm_m5X_H02Om5X_H4o`0000Ko:hc]00Co0000o`19a_l0003o00000ol0ELh2o`00
01Kooooo00?o0000ooooooooool06Oooool002gooooo00?o0000ooooooooool01_ooool3o`0002ko
oooo00?o0000oj[4k?nZa>`03onZa>`3o`0000ooW<Of00?o0000oi39non@bO/03?n@bO/4o`0001;o
T<km0_l00002oh_@oPCo00002_nAd_h2o`0000koS]Co1?l0000Aoi7HoPCo00004OnDfoh4o`0000ko
Umgn0ol00004oiWNoP?o00001onHgoh3o`0000WoV]om0_l00006oiWPo@;o00003OnJh?d3o`0000go
V^7m0ol00003oi[Qo@?o00001onIhOd3o`0000WoV>7m0_l00002oiOPoPCo00002onFgoh2o`0000;o
Tmkn0ol0000<oi7MoPCo00003on<f_l5o`0000goQ=Go00?o0000ogg@oommd?l02Ommd?l:o`0000Wo
L<Oo00?o0000ofBmoOmT_Od02OmT_Od01?l0003oDk3joe>`n_mC/?X7o`000003oebeo?l0003oAJ;f
00[oAJ;f00?o0000oan3jOlOPnT00_l00005ob^<k@04o`000?l0BLKo04W6o`0000Co05G>00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Iooooo`00;Oooool3o`0000?ooooo0ol0000boooo
o`03o`000?nZa>coZ/C/00coZ/C/0_l00003ok;5j@03o`000?nLaoKoW<Of00goW<Of0_l00007oi39
n`Go00001?nHc?X2o`00013oT<km1?l0000@oi7BoP03o`000?n>e?ooS]Co00KoS]Co1Ol00004oi?F
oP?o00002OnAf?h5o`0000CoU]Wn0_l0000<oiCKoP?o00001?nGg?h3o`0000SoUmgn0ol0000:oiWN
oP;o00000_nHgoh3o`0000koV]om0_l000001?nIh?go0000o`000?l0000<oi[Po@?o00000onKhOd3
o`0000OoV^7m0ol00009oi[Qo@;o00000_nIhOd3o`0000coV>7m1?l0000?oiKOoPGo00002OnAgOh5
o`0000CoT=gn0_l00008ohcJo`Go00001?n9fOl00ol0003oQ=GoohCEo`0<ohCEo`04o`000?mmd?oo
OM3oogg@o`Oo00001Omic_l00ol0003oL<Ooog37o`0<og37o`03o`000?mT_OgoI;gm00WoI;gm00?o
0000oe>`n_mC/?X01omC/?X6o`0000SoAJ;f00Co0000oan3jOlOPnWo7h?Y0ol00003ob^<k@03o`00
0?l0BLKo04W600;o00000ol0ELh00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo
000/ooooo`;o00000_ooool3o`0003Kooooo00?o0000oj[4k?nZa>`02OnZa>`2o`0000Ko//GY00?o
0000oic7m_nLaoH03_nLaoH00ol0003oT<Wkoi39n`04o`0000_oV<cj0_l0000;oi3>o@?o00001?nG
d?`00ol0003oTM;noi7BoP0>oi7BoP;o00000_n>e?l4o`0000coTmKn0ol00002oi7HoPCo00002onF
fOh2o`0000OoU=_n0ol0000:oiOLoP?o00000_nGgOh3o`0000koVMkn0ol0000Aoi[Oo@Co00002onJ
h?d3o`0000WoVn7m0_l00002oi[Qo@?o00003?nJhOd4o`0000coV>7m0ol00004oiSPo@;o00002?nF
goh5o`0000GoU=on0ol00002oi7MoPCo00002on@gOh2o`0000;oS=[o1?l0000:ohWIo`03o`000?n4
eOooQ=Go00WoQ=Go1_l0000=ogW>o`03o`000?m`aoooL<Oo00coL<Oo00?o0000ofBmoOmT_Od02OmT
_Od00ol0003oDk3joe>`nP08oe>`nP04o`000?mC/?[o0000oc^Lm0Go00001?m5X_H00ol0003o7h?Y
oan3j@03oan3j@;o000000?o:hc]o`000?l0BLH00ol0BLH01?l0003o05G>o`1Ec_l0000Dooooo`03
o`000?oooooooooo01Wooooo000/ooooo`Co0000>_ooool00ol0003oZ/C/oj[4k005oj[4k0?o0000
2OnbaNT2o`0000koW<Of0ol0000AoiS<nP03o`000?n@c_goT<km00GoT<km0ol00008oiO@o0;o0000
3_nAd_h4o`00017oTmKn1?l0000AoiKIoP;o00000_nDfoh3o`0000koUmcn1?l0000>oiWNoP?o0000
0onKg_d2o`0000coV]om0ol00004oi_Po@?o00001_nJh?d2o`0000goVn7m0ol0000<oi[Qo@?o0000
1?nKhOd2o`0000OoV>7m0ol00009oiSPo@;o00000_nFgoh4o`0000_oU=on1?l0000?oi3MoPCo0000
3on9fOl01?l0003oQ=GoohCEoon4eOl7o`0000GoP=Co0_l0000=ogW>o`03o`000?m`aoooL<Oo00Go
L<Oo3ol00004ofBmo@03o`000?mC/?[oDk3j00SoDk3j00?o0000oe>`n_l000001OlkW?@6o`0000Ko
7h?Y0ol00004o`19aP04o`000?l0ELko05G>o`0001?ooooo00?o0000ooooooooool06Oooool000oo
oooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000?Oooool00ol0003o
Z/C/oj[4k002oj[4k0;o00003_nbaNT00ol0003oW<Ofoic7mP08oic7mP?o00000onTbO<2o`00013o
V<cj0_l00002oi3>o@?o00003OnGd?`2o`0000OoTM;n1Ol00004oiODo@;o00003?nCe_h3o`0000Co
V=Om0_l0000?oiKIoPCo00003_nGg?h3o`0000CoV]cm0_l0000:oiWNoP;o00002?nKg_d2o`0000Oo
V]om0ol0000:oi_Po@;o000000CoV^3mo`000?l0003o00003?nKhOd3o`0000?oW>7m0_l00007oi[Q
o@?o00002OnKhOd2o`0000;oV>7m0ol0000=oiSPo@?o00003?nDgoh3o`0000CoTmkn0_l00008oi3M
oPGo00001?n>g?l2o`0000_oRMWo1_l0000>oh3Do`03o`000?mic_ooNLko00GoNLko3Ol00009of[4
oP03o`000?mM^_coGK[l00?oGK[l3Ol00002oe>`nP04o`000?mC/?[oDk3jo`0000Wo>icd0ol00007
oan3j@;o00000ol0BLH2o`000003o`1Ec_l0003ooooo017ooooo00?o0000ooooooooool06Oooool0
00kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo03_o
oooo00Co0000oj[4k?l0003o00004OnbaNT00ol0003oW<Ofoic7mP04oic7mP?o00002?nTbO<2o`00
00koV<cj1?l0000BoiO@o003o`000?nAd_koTM;n00Co00002onGe?d2o`0000OoTmKn0ol00009oiSG
o@;o00002?nFfOh5o`0000CoVM[m0ol00008oiOLoP?o00002OnJg?d2o`0000KoVMkn0_l0000<oi_N
o@;o00000_nJgod3o`0000goVn3m1?l0000;oi_Qo@?o00002?nLhOd2o`0000;oV^7m0ol0000=oi_Q
o@?o00003OnHh?d3o`0000?oV>3n0_l00007oiCOoP?o00002OnCg_h2o`0000;oT=gn1?l0000;ohkL
o`04o`000?n9fOooRMWoohWIo`Oo00001On6f?l2o`0000_oP=Co2_l00008ogC<o`;o00003OmZa?h0
0ol0003oGK[loefjo009oefjo003o`000?m;ZoWoBj_i00?oBj_i2Ol00008oc^Lm0Co00001OlOPnT2
o`0000Co04W600?o0000o`1Ec_l000004Oooool00ol0003oooooooooo`0Iooooo`004_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo0_l0000Cok;5j@03o`00
0?nLaoKoW<Of00?o00003OnTbO<00ol0003oV<cjoiS<nP06oiS<nPGo00001?nOc_P2o`00013oUm3l
0ol0000AoiODo@;o00000_nCe_h3o`0000koV=Om0_l00002oiKIoPCo00003?nIf_d3o`0000;oUmcn
0ol0000>oi[Lo@;o000000CoVMkno`000?l0003o00003_nKg_d4o`0000goVn3m0ol00004oigPo@?o
00001_nKhOd2o`0000coW>7m0ol0000=oi_Qo@?o00000onKhOd3o`0000OoV>3m0ol00008oiSPoP;o
00000_nDgoh3o`0000coTmkn1?l0000>ohkLo`Go00003_n6f?l2o`0000?oP=Co1_l00005oggBo`;o
00003Omdc?l2o`0000coJ/Cn00?o0000oefjo?mM^_`02OmM^_`00ol0003oBj_iod^[n@06od^[n@05
o`000?m;ZoWoBj_io`000?laU_401?l00005oc^Lm003o`000?lCNnCo4g_T00;o00001?lOPnT3o`00
00?o04W60_l0000Booooo`03o`000?oooooooooo01Sooooo000Booooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0??ooool00ol0003o//GYok;5j@0@ok;5j@?o00004OnT
bO<2o`0000;oV<cj1?l0000;oio>n0;o00002onGd?`3o`0000?oWM;j0_l0000@oiODo@?o00004_nH
eod3o`00017oVM[m1?l0000Aoi[Lo@Co00003OnKg_d3o`0000CoWMom0ol00007oi_Po@?o00002_nM
h?d2o`000004oi_QoOl0003o0000o`0000_oW>7m0ol00003oigQo@?o00001onKhOd3o`0000WoVn7m
0_l00002oiSPo@?o00003?nHh?h3o`0000coTmkn0ol00004oi;NoP;o00002?n>g?l4o`0000CoS=_o
0_l0000<ohKHo`Ko00003Ommd_l2o`0000OoM<co6ol00004oefjo003o`000?m;ZoWoBj_i00KoBj_i
00Co0000od^[nOm;ZoWo00001?laU_43o`0000?o>icd00Co0000oa=ki?lCNnCo4g_T0ol00002oan3
j@03o`000?l0?[go000000Co04W600?o0000ooooooooool03oooool00ol0003oooooooooo`0Hoooo
o`003_ooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000cooooo0_l0000mooooo`03o`000?nbaNWo//GY00go//GY0_l0
0003okS6i@03o`000?nTbO?oY<Wc00ooY<Wc0ol0000Aoio>n003o`000?nGd?coUm3l00GoUm3l0ol0
0008oigBnP;o00002onGe?d3o`0000?oW=Gl0_l0000=oiSGo@?o00000onMf?`2o`0000coVM[m0ol0
0004oigKo@;o00003?nJg?d3o`0000CoWMgm0ol00007oi_No@?o00002_nMgod2o`0000;oVn3m0ol0
000=oigPo@Go00002OnLhOd3o`0000WoWN7m0_l00002oi_Qo@?o00003?nKhOd4o`0000coV>3n0ol0
0003oiSPoP;o00001onCg_h3o`0000WoT]kn0_l00002ohkLo`Co00002_n<fol2o`0000?oQ]So1ol0
0005ohCGo`;o00002ommd_l:o`0001_ooooo2_l00003od^[n@05o`000?m;ZoWoBj_iod^[nOl00000
1_laU_45o`0000Go4g_T0_l000000olOPnWo0000o`0n_@02o`0000?o04W600?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Hooooo`003_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000>oooo
o`03o`000?oooooooooo03_ooooo0_l0000;ok;5j@;o00001_nha^D2o`0000coY<Wc0ol00003oj_;
l@03o`000?nOc_SoWlkh00ooWlkh0_l00002oiO@o0?o00003OnMd_X00ol0003oUmCmoiODo@05oiOD
o@?o00002?nLeO`3o`0000OoV=Om0ol00008oigHo0;o00001onIf_d3o`0000WoWM_m0_l00007oi[L
o@?o00002_nMgOd2o`0000;oVmkm0ol0000=oigOo@Co00003OnMh?d3o`0000GoWn7m0ol00003oicQ
o@?o00003?nMhOd4o`0000coVn7m0ol00004oi_Qo@;o00001onHh?h3o`0000SoV>3n0_l00002oi?N
oP?o00003?nBg_h4o`0000koS=_o1Ol0000>ohCGo`04o`000?mmd_ooOM;ooggBo`Oo0000;oooool7
o`000003od^[nOl0003o<IKa00So<IKa0ol00005oa=ki0?o00000_l0?[d2o`000003o`19a_l0003o
oooo00oooooo00?o0000ooooooooool06?ooool000kooooo1Ol00003ooooo`;o00001?ooool2o`00
00Cooooo0_l0000@ooooo`03o`000?oooooooooo03cooooo00?o0000ok;5jOnbaNT01OnbaNT3o`00
00[o^<KU00?o0000ojC9lonTbO<01onTbO<2o`0000OoZl_a0_l0000?oio>n0Co00004OnMd_X2o`00
00;oUmCm0ol0000>oicEo0;o00000_nHeod3o`0000goWMSl0_l00002oiWJo@?o00003_nMfod2o`00
00;oV]cm0ol0000=oigMo@Co00003OnMgod3o`0000CoX>3l0ol00007oigPo@?o00002onOhOd3o`00
00coWN7m0ol00004oikRo@;o00001onKhOd3o`0000WoVn7m0_l00002oiSPoP?o00002onHh?h5o`00
00WoT]kn1Ol00004oi7NoP;o00001on<fol5o`0000CoR][o0_l0000;ohCGo`Ko0000>oooool00ol0
003oooooo`000004o`0000Oo<IKa00Co0000o`Mbgol0003o00001_lCNn@2o`0000;o03jm00?o0000
o`19a_l000003oooool00ol0003oooooooooo`0Hooooo`00=Oooool00ol0003oooooooooo`0loooo
o`03o`000?nbaNWo//GY00;o//GY0_l0000>okS6i@;o00001OnTbO<2o`0000_oZl_a00?o0000oio>
n?nOc_P02OnOc_P3o`0000CoYLof00?o0000oigBn_nMd_X03_nMd_X4o`00017oW=Gl1?l0000AoigH
o0?o00004OnMfod4o`0000goWMgm0ol00004oj3No0?o00001onMgod3o`0000[oX>3l0_l00002oigP
o@?o00002onOhOd3o`0000?oX>7l0_l00007oigQo@?o00002OnNh_d2o`0000;oVn7m0ol0000<oi_Q
o@Go00002OnHh?h4o`0000GoUn3n0ol00002oi;NoPCo00002onAg_h00ol0003oS=_oohcKo`04o`00
00_oR][o00Co0000ohCGoon4eoooQ=Oo1ol00012ooooo`03o`000?oooooooooo00?ooooo0ol00005
oc6Fl@03o`000?l7L]oo1g;O00;o00001?lCNn@00ol0003o03Beo`000002o`0n_@?o00003_ooool0
0ol0003oooooooooo`0Hooooo`00=_ooool00ol0003oooooooooo`0looooo`04o`000?nbaNWo0000
o`0001;o^<KU00?o0000ojC9lol000000_l0000>oj_;l@;o00001_nOc_P3o`0000SoYLof0_l0000;
oigBnP?o00001?nSdoT2o`0000coW=Gl0ol00004oj;GnP;o00003?nMf?`3o`0000?oXM[k0_l0000<
oigKo@?o00001?nQg?`3o`0000OoWMgm0ol0000:oj3No0;o00000_nMgod3o`0000goX>3l1?l0000;
oioQo@?o00002?nPhO`2o`0000;oWN7m0ol0000=oikRo@?o00003?nKhOd3o`0000GoVn7m0ol00002
oiSPoPCo00002onGh?h3o`0000koTMkn1?l0000>oh[Jo`Go0000BOooool00ol0003oooooooooo`06
ooooo`Co00000_laU_401?l0003o1g;Oo`Mbgol7L]l3o`0000;o4g_T00?o0000o`0d]Ol000000ol0
?[d2o`0000gooooo00?o0000ooooooooool06?ooool003Oooooo0_l0000mooooo`;o00004onha^D3
o`0001;oZl_a00?o0000oio>n?nOc_P00ol0000=ojG?mP;o00001_nMd_X3o`0000WoXm?i0_l00007
oicEo0?o00002OnReoX2o`0000OoWMSl0ol00008oj7Jn`;o00001onMfod3o`0000[oXMcl0_l00002
oigMo@?o00003_nPg_`3o`0000goX>3l0ol00004oj;Po0?o00001_nOhOd2o`0000coX>7l0ol0000=
oikRo@?o00000onOh_d2o`0000OoVn7m0ol0000:oi_Qo@?o00003?nGh?h3o`0000?oUn3n0_l00008
oi7NoPCo00001?n@gOh2o`0000SoR][o1?l0001?ooooo`03o`000?oooooooooo00Wooooo1?l00005
o`Mbg`;o000000Co4g_To`000?l0=;Go00000ol0?[d2o`0000cooooo00?o0000ooooooooool06?oo
ool003Wooooo00?o0000ooooooooool0??ooool00ol0003o^<KUokS6i@0>okS6i@;o00000onnan40
0ol0003oZl_aoj_;l@0?oj_;l@?o00004_nUcoH00ol0003oWM;joigBnP03o`0000koXm?i0_l00002
oicEo0?o00003_nReoX2o`0000;oWMSl0ol0000=oj7Jn`;o00000_nMfod3o`0000koXMcl0ol0000>
oj3No0?o00000onSgo`3o`0000OoX>3l0ol0000:oj;Po0;o000000CoWn7mo`000?l0003o00002onP
hO`3o`0000?oX^;l0ol00007oikRo@?o00002?nOh_d2o`0000;oVn7m0ol0000:oi_Qo@?o00000onL
hOd2o`0000OoUn3n0ol00008oiOPoP;o00000_nAg_h4o`0000[oT=gn0_l00002oh[Jo`Co0000E?oo
ool00ol0003oooooooooo`0;ooooo`?o00001Ol7L]l3o`000003o`0d]Ol0003o000000?o03jm00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`00>_ooool00ol0003oooooooooo`0l
ooooo`03o`000?nha^Go^<KU00_o^<KU0_l00006okk7h@03o`000?n[bo7oZl_a00_oZl_a0ol00003
ok7<kP;o00004?nUcoH3o`0001;oXm?i0ol0000Aoj;GnPCo00004OnQf_/3o`0000koXMcl0ol00003
ojCMn`?o00002?nPg_`3o`0000WoXmol0_l00002oj3Po0?o00003OnRh?`4o`0000_oX>7l0_l00009
oj;Ro0;o00000_nNh_d3o`0000coWn;m1?l00009oi_Qo@?o00002?nLhOd2o`0000;oUn3n0ol0000<
oiOPoP?o00003_n@gOh4o`0005Sooooo00?o0000ooooooooool03_ooool2o`0000Go1g;O0_l00002
o`0d]@05o`000?l0?[go03jmo`0n_Ol000002oooool00ol0003oooooooooo`0Gooooo`00>oooool0
0ol0003oooooooooo`0looooo`;o00002Onha^D2o`0000Wo_/OQ0_l00008oj_;l@?o00002?nac>h2
o`0000_oYLof0ol00003oj_@l`03o`000?nSdoWoXm?i00coXm?i0ol00003ojSDm`;o00003?nReoX3
o`0000CoY]Si0_l0000<oj7Jn`?o00000onUf_X3o`0000SoXMcl0ol00009ojCMn`?o00000_nPg_`3
o`0000goXmol0ol0000=oj;Po0?o00001?nThO`3o`0000KoX>7l0_l0000;oj;Ro0Co00003?nOh_d3
o`0000CoX>;l0ol00003oi_Qo@?o00003?nLhOd3o`0000coUn3n0ol00003oiOPoP;o00001on@gOh5
o`0005gooooo00?o0000ooooooooool03oooool2o`0000Go1g;O0_l000001Ol0=;Go0000o`0n_Ol0
?[go000000_ooooo00?o0000ooooooooool05oooool003cooooo0_l0000nooooo`03o`000?nha^Go
^<KU00Go^<KU00?o0000okk7hOnnan402onnan400ol0003oZl_aoj_;l@03oj_;l@;o00003Onac>h0
0ol0003oYLofojG?mP05ojG?mP?o00001on[d?<2o`0000WoXm?i0ol00008ojSDm`;o00001onReoX3
o`0000WoY]Si0_l00007oj7Jn`?o00002OnUf_X3o`0000;oXMcl0ol0000>ojCMn`?o00003OnSgo`3
o`0000?oY]ok0ol00007oj;Po0?o00002_nThO`2o`000004oj3Qo?l0003o0000o`0000[oX^;l0ol0
0004oj?Ro0;o00001onOh_d3o`0000WoX>;l1?l0000<oicQo@?o00000onLh_d2o`0000OoUn3n0ol0
0008oiOPoP03o`000?n@gOkoT=gn00Co0000Hoooool00ol0003oooooooooo`0@ooooo`;o00000ol7
L]l01Ol0003o02V/o`000?l0=;Go000000;o03jm00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Gooooo`00?_ooool00ol0003oooooooooo`0looooo`03o`000?nha^Go^<KU00;o^<KU0_l0
000?okk7h@03o`000?n[bo7o000000;o00004?nac>h2o`0000;oYLof0ol0000<oj_@l`;o00001OnS
doT2o`0000goZ=Cg0_l00002oj;GnP?o00003_nVf?T2o`0000;oXM[k0ol0000>ojGJnP?o00003_nT
gO/3o`0000?oYmkj0_l00009oj?Oo0;o00002OnVgo/2o`0000;oX^3l0ol0000=ojCQo0Go00002?nR
h_`3o`0000WoXn;l0_l00002oioRo@?o00002OnPh_`3o`0000CoXN;l0_l00007oicQo@?o00002?nL
h_d2o`0000;oUn3n0ol0000:oiOPoPCo0000J?ooool00ol0003oooooooooo`0Aooooo`09o`000?l7
L]oo1g;Oo`Mbgol0003o02V/o`000?l0=;Go000000;o03jm00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Gooooo`00?oooool00ol0003oooooooooo`0looooo`04o`000?nha^Go0000o`00
017o_/OQ0ol0000Cok7<kP?o00004On[d?<00ol0003oXm?io`000002o`00013oZ=Cg0ol0000BojKH
n@?o00003_nUf_X3o`0000?oZM_i0_l00009ojCMn`?o00002?nWg_X00ol0003oXmoloj?Oo004oj?O
o0;o00003?nVgo/3o`0000goY>7l0ol00005ojKQn`?o00000_nRh_`3o`0000goXn;l1?l00008oj3R
o0?o00002OnQh_`2o`0000;oW>7m0ol0000;oicRo@Co00002OnGh?h4o`0006cooooo00?o0000oooo
ooooool04_ooool2o`0000;o1g;O00Co0000o`0Y[?l0003o03Be0ol00009ooooo`03o`000?oooooo
oooo01Oooooo0010ooooo`03o`000?oooooooooo03cooooo0_l0000Aokk7h@05o`000?o2amko`/ON
ol;7g_l000004?nac>h2o`0000?o]/g[00?o0000oj_@lon[d?<03_n[d?<3o`0000ooZ=Cg0ol00003
ojgEm@03o`000?nVf?WoY]Si00coY]Si0ol00003oj_Hn0;o00002OnUf_X3o`0000SoZM_i00?o0000
ojCMnonTgO/01?nTgO/2o`0000coYmkj0_l000001?nSgoco0000o`000?l0000;ojKOn`?o00000onX
h?X3o`0000OoY>7l0ol0000:ojKQn`?o00003OnSh_`3o`0000CoYN;k0ol00002oj3Ro0?o00003?nQ
h_`4o`0000WoW>;m1Ol00004oicRo@?o00000_nGh?h4o`00077ooooo00?o0000ooooooooool04ooo
ool3o`0000;o02V/00?o0000o`0d]Ol0=;D00_l00008ooooo`03o`000?oooooooooo01Oooooo0011
ooooo`;o0000?_ooool00ol0003o_/OQokk7h@0=okk7h@03o`000?o2amko`/ON00?o`/ON0_l0000<
ok7<kP;o00001_nfcN/00ol0003oZm3coj_@l`0:oj_@l`?o00000on`dO42o`0000_oZ=Cg0_l00007
ojgEm@;o00002OnVf?T3o`0000SoZmSh00?o0000ojGJn_nUf_X01?nUf_X2o`0000coZM_i0_l00000
1?nTgO_o0000o`000?l0000?ojONnP?o00002onVgo/2o`0000WoZ>3j0_l00002ojCQo0?o00002_nV
hO/3o`0000?oZ>;k0ol00007oj?Ro0?o00002OnUh_/3o`0000coXN;l0ol00004oj;So0?o00000_nL
h_d4o`0000_oW>;m0ol0001fooooo`03o`000?oooooooooo01Cooooo0_l00002o`0Y[004o`000?l0
=;Go03Beo`0000Wooooo00?o0000ooooooooool05_ooool004?ooooo00?o0000ooooooooool0??oo
ool00ol0003o_/OQokk7h@0:okk7h@;o00002?o2amh00ol0003o/Lc^ok7<kP06ok7<kP?o00002Onf
cN/2o`0000SoZm3c0_l00008ok3Al@?o00001_nXe?L2o`0000_o[MGe0_l00005ojKHn@;o00003?n[
f?P2o`000004ojGJn_l0003o0000o`0000ooZM_i0ol0000>ojONnP?o00000onZg_T3o`0000KoY]ok
0_l0000<ojSPnP?o00002onVhO/2o`0000WoZ>;k0_l00002oj?Ro0?o00002OnUh_/3o`0000?oY^?k
0_l00007oj7Ro0?o00002OnRho`3o`0000coW>;m0ol0001jooooo`03o`000?oooooooooo01Gooooo
0_l000001Ol0:Jco0000o`0d]Ol0=;Go000000Sooooo00?o0000ooooooooool05_ooool004Cooooo
00?o0000ooooooooool0??ooool00ol0003o_/OQokk7h@08okk7h@03o`000?o2amko`/ON00Wo`/ON
0_l00004ok7<kP;o00003_nfcN/00ol0003oZm3coj_@l`03oj_@l`;o00003On`dO42o`000004ojSD
mol0003o0000o`0000oo[MGe00?o0000ojKHnOl000000_l0000?oj_Hn0?o00003_nYfoT3o`0000?o
[=ch0ol00008ojONnP?o00002OnZg_T2o`000004ojKOnol0003o0000o`0000_oZ>3j0ol00003oj_Q
nP?o00001_nVhO/2o`0000coZ>;k0ol0000:ojGRn`;o00002?nVho/2o`0000;oXN;l0ol00009oj;S
o0?o00000onSho`2o`0000OoW>;m0ol0001mooooo`03o`000?oooooooooo01Oooooo00Ko0000o`0Y
[?l0003o0000o`0d]Ol00007ooooo`03o`000?oooooooooo01Kooooo0015ooooo`03o`000?oooooo
oooo03cooooo00?o0000okk7hOnnan401_nnan400ol0003o`/ONol;7gP0<ol;7gP04o`000?nac>ko
0000o`00017o]/g[00?o0000oj_@lol000000_l0000@ok3Al@?o00004On]eOD3o`0000koZmSh0ol0
0003ojkImP;o00002_nYfoT2o`0000Wo[=ch0ol00002ojONnP?o00003OnZg_T3o`0000_oZ>3j0_l0
0009oj_QnP;o000000CoY^7ko`000?l0003o00002onXh_/3o`0000?oZ^;j0_l00006ojGRn`;o0000
2onVho/3o`0000[oX^?l0_l00008oj?So0;o00000_nLh_d3o`00087ooooo00?o0000ooooooooool0
5oooool00ol0003o02V/o`0Y[002o`0000Oooooo00?o0000ooooooooool05_ooool004Kooooo0_l0
000mooooo`03o`000?nnan7o_/OQ00?o_/OQ0_l0000?ol;7gP?o00004_nfcN/3o`00013o/=7a0_l0
0003okGBk`03o`000?n]eOGo[MGe00_o[MGe0ol00003ok7Fl`;o00002_n[f?P2o`0000So[]Wf0_l0
0006ojWKn@;o00003On/g?P3o`0000goZ]ki0ol00003ojgOn0?o00001_nXh?X2o`0000coZn7j0ol0
000;ojSRn`;o00002?nZh_X2o`000004ojGRnol0003o0000o`0000[oY^?k0ol00003ojOSn`;o0000
1_nRho`2o`0000_oXn?l0ol00025ooooo`03o`000?oooooooooo01Oooooo00?o0000o`0Y[?l0:J`0
0_l00006ooooo`03o`000?oooooooooo01Kooooo0018ooooo`03o`000?oooooooooo03_ooooo00Go
0000okk7hOnnan7o_/OQo`00000@ol;7gP05o`000?o6am[oa/OJolK7f_l000003onfcN/2o`0000?o
^lgX00?o0000ok3AlOn`dO402on`dO42o`0000Ko]M;_0_l00009ojgEm@;o00002?nae_<2o`0000Ko
ZmSh0_l0000<ojkImP;o000000CoZM_io`000?l0003o00003?n/g?P3o`0000?o/=gg0_l00009oj[N
n@;o00002On]goP2o`000004ojSPn_l0003o0000o`0000_oZn7j0ol00003ojgQn@?o00001_nXh_/2
o`0000_oZ^;j0ol0000:ojKSn`;o00002?nWho/2o`000004oj;So?l0003o0000o`0000[oXn?l0ol0
0028ooooo`03o`000?oooooooooo01Sooooo00?o0000o`0Y[?l0:J`00_l00005ooooo`03o`000?oo
oooooooo01Kooooo0019ooooo`03o`000?oooooooooo03_ooooo00?o0000okk7hOl000004?o2amh0
0ol0003oa/OJolK7fP03olK7fP03o`000?nfcN_o]/g[00[o]/g[0_l00006ok_=j0;o00002?n`dO43
o`0000[o]M;_0_l00005ojgEm@;o00003?nae_<2o`000004oj_Hn?l0003o0000o`0000oo[]Wf0ol0
000;ojcLn0?o00002?n`gOL00ol0003oZ]kioj[Nn@04oj[Nn@;o00003?n]goP3o`0000_oZn7j0_l0
0009ojgQn@;o000000CoZ>;ko`000?l0003o00002_nZh_X3o`0000?o[>?j0_l00006ojKSn`;o0000
2onWho/4o`0000SoXn?l0ol0002<ooooo`03o`000?oooooooooo01Sooooo00?o0000o`0Y[?l0:J`0
0_l00004ooooo`03o`000?oooooooooo01Kooooo001:ooooo`03o`000?oooooooooo03_ooooo0_l0
000>ol;7gP;o00001oo6amX2o`0000Oo]/g[0ol0000:ok_=j0;o00001?n`dO42o`0000oo]M;_00?o
0000ojgEmOl000000_l0000?ok7Fl`?o00003_n^fOH3o`0000?o/][d0ol00006ojcLn0;o00003?n`
gOL2o`000004oj[NnOl0003o0000o`0000_o[Moh0ol00003ok3Om`?o00001_n[hOX2o`0000co[N7i
0ol0000:oj[RnP;o00002?n/hoX2o`000004ojKSnol0003o0000o`0000[oYn?k0ol00004ojWSnP?o
00000_nSho`3o`00093ooooo00?o0000ooooooooool06?ooool01?l0003o02V/o`0Y[?l00005oooo
o`03o`000?oooooooooo01Gooooo001;ooooo`03o`000?oooooooooo03cooooo00?o0000ol;7g_o2
amh02_o2amh00ol0003oa/OJolK7fP09olK7fP03o`000?nfcN_o]/g[00;o]/g[0_l0000?ok_=j004
o`000?n`dO7o0000o`00017o]M;_0ol0000>ok7Fl`?o00000onee_42o`0000[o[]Wf0_l00009ok;J
m0;o000000Co[=cho`000?l0003o00003on`gOL3o`0000_o[Moh0_l00009ok3Om`;o000000CoZn7j
o`000?l0003o00002on]hOT3o`0000?o[n;h0_l00006oj[RnP;o00002on/hoX4o`0000SoYn?k0ol0
0009ojWSnP?o0000U?ooool00ol0003oooooooooo`0Hooooo`;o000000?o02V/o`000?ooool00ooo
ool00ol0003oooooooooo`0Eooooo`00C?ooool2o`0003gooooo00?o0000ol;7g_o2amh02?o2amh0
0ol0003oa/OJolK7fP0;olK7fP04o`000?nfcN_o0000o`00017o^lgX0ol0000@okGBk`;o00000oni
d^d2o`0000[o/MKc0_l00008okGFl@;o00001_n^fOH2o`0000co/][d0ol0000>ok3Mm`?o00000onc
gOD3o`0000Ko[Moh0_l0000<ok3Om`?o00002on]hOT2o`0000So[n;h0_l000001?nZh_[o0000o`00
0?l0000:ojcSnP?o00001?n^hoT3o`0000;oYn?k0ol00009ojWSnP?o0000Uoooool00ol0003ooooo
ooooo`0Jooooo`03o`000?l0:Jco000000?ooooo00?o0000ooooooooool05Oooool004kooooo00?o
0000ooooooooool0>oooool00ol0003o`/ONol;7gP06ol;7gP03o`000?o6am[oa/OJ00coa/OJ0ol0
000@ok_=j0;o00000onocND00ol0003o]M;_okGBk`0;okGBk`;o00001onid^d2o`0000Ko/MKc0_l0
000<okGFl@;o000000Co[]Wfo`000?l0003o00003?nbf_@2o`0000?o]][c0_l0000:ok3Mm`;o0000
2OncgOD2o`000004ojgOn?l0003o0000o`0000_o/=og0ol00003ok?PmP?o00001_n]hOT2o`0000_o
[n;h1?l00008ojcSnP?o00002On^hoT3o`0000[oZN?j0_l0002Kooooo`03o`000?oooooooooo01[o
oooo0_l00003ooooo`03o`000?oooooooooo01Gooooo001?ooooo`03o`000?oooooooooo03_ooooo
00?o0000ol;7g_o2amh00oo2amh2o`0000koa/OJ00Go0000ol[7eoo:amOob/OGo`00000>ok_=j003
o`000?nocNGo_lgU00Co_lgU0_l00008okGBk`?o00002onid^d2o`000004ok7Flol0003o0000o`00
00oo]MKa0ol0000<ok;Jm0;o00001onff_<2o`0000Ko/=gg0_l0000<ok?Mm@?o00002on`goL2o`00
00Wo/n3f0_l000001?n]hOWo0000o`000?l0000:ojoRn0?o00001?nah_L3o`0000;o[>?j0ol0000:
ojkSn@;o00000on_hoP2o`0000KoZN?j0_l0002Nooooo`03o`000?oooooooooo01[ooooo0_l00002
ooooo`03o`000?oooooooooo01Gooooo001@ooooo`03o`000?oooooooooo03_ooooo00Go0000ol;7
g_o2amko`/ONo`00000?olK7fP03o`000?o:amOob/OG00?ob/OG0_l0000:ok_=j0;o00002OnocND2
o`0000Co]M;_0_l0000?okWBk@?o00003onee_42o`0000?o^MO_0_l00008ok;Jm0;o00002onff_<2
o`000004ok3Mmol0003o0000o`0000co/mge0_l00003okKMm0?o00001_n`goL2o`0000co/n3f0ol0
000:ojoRn0;o00002Onah_L3o`0000[o[^?i0ol00007ojoSn0;o000000CoZN?jo`000?l0003o0000
XOooool00ol0003oooooooooo`0Jooooo`;o000000?oooooo`000?ooool05_ooool0057ooooo0_l0
000looooo`03o`000?o2amko000000ooa/OJ00?o0000ol[7eoo:amL01_o:amL00ol0003o^lgXok_=
j005ok_=j0;o00003OnocND01?l0003o]M;_o`000?l0000?okWBk@;o00000onmd^X00ol0003o]MKa
okGFl@0:okGFl@;o00001onienl00ol0003o/][dok;Jm003ok;Jm0;o00003_nff_<3o`0000co/mge
0_l00008okKMm0;o000000Co/=ogo`000?l0003o00002onch?H3o`0000?o]N3e0_l00006ojoRn0;o
00002Onah_L2o`0000?o]>;f0ol00005ojkSn@;o00002on_hoP2o`000:Cooooo00?o0000oooooooo
ool06oooool3o`0001Oooooo001Cooooo`03o`000?oooooooooo03[ooooo0_l0000>olK7fP03o`00
0?o:amOob/OG00Sob/OG0_l00004ok_=j003o`000?nocNGo_lgU00go_lgU0ol0000>okWBk@;o0000
1_nmd^X2o`0000Oo]MKa0ol0000:okWGk`;o000000?o/][do`000?l000003_nff_<2o`0000?o^M[a
0_l00008ok?Mm@;o00002onfgO@3o`0000_o/n3f0_l00008okGPm@;o000000Co[n;ho`000?l0003o
00002Onah_L2o`0000So]>;f0_l000000on^hoWo0000o`00000;ojoSn0;o0000Yoooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooo000001Kooooo001Dooooo`03o`000?oooooooooo03_ooooo
00?o0000olK7f_o6amX02Oo6amX2o`0000gob/OG00Co0000ok_=j?l0003o00003onocND01Ol0003o
`lkRol?>h_o3c^;o000000_o^M;]0_l0000:okgBjP03o`000?nee_7o]MKa00;o]MKa0_l0000>okWG
k`?o00003Onff_<2o`0000Oo^M[a00?o0000ok?MmOncgOD00oncgOD2o`0000_o]]gd0_l00003okWN
l`?o00001_nch?H2o`0000_o]N3e0ol0000:ok7Rm`03o`000?ndh_Ko]>;f00Wo]>;f0ol00009ojoS
n0?o0000Z_ooool00ol0003oooooooooo`0Kooooo`;o00005_ooool005Gooooo00?o0000oooooooo
ool0>oooool2o`0000Soa/OJ00?o0000ol[7eoo:amL03Oo:amL3o`0000ko_lgU0_l00005ol?>hP;o
00002?nid^d00ol0003o_M;ZokgBjP0;okgBjP04o`000?nee_7o0000o`0000ko^MO_0_l00003okcG
k@;o00002?nff_<3o`0000[o^M[a0_l000000oncgOGo0000o`00000;okKMm0;o00002?nig_<2o`00
0004ok?Pm_l0003o0000o`0000_o]N3e0_l00003okSPm0?o00001Onah_L2o`0000[o]>;f0_l00003
okKRmP;o00001On_hoP2o`000:gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`00E_ooool2o`0003gooooo00?o0000olK7f_o6amX01?o6amX00ol0003ob/OGol[7e`0=ol[7
e`05o`000?o=amCocLODolg7e?l000003?nocND00ol0003o`lkRol?>hP07ol?>hP;o00001?nid^d2
o`0000ko_M;Z0ol0000=okWGk`;o00001onlend00ol0003o]][cokKJl`03okKJl`;o00003_nif_43
o`0000[o]]gd0_l0000;okWNl`?o00002oneh?D2o`0000So^>3d0_l000000onah_Oo0000o`00000:
okCRmP;o00001onfh_H2o`000003ojoSn?l0003o00000;3ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Dooooo`00F?ooool00ol0003oooooooooo`0kooooo`;o00000oo6amX00ol0
003ob/OGol[7e`0=ol[7e`03o`000?o=amCocLOD00?ocLOD00?o0000oko=iOnocND01onocND2o`00
00co`lkR00Co0000okWBkOl0003o00003_nmd^X2o`0000?o`M?X0_l00009okWGk`;o00002_nlend2
o`000003okKJlol0003o000000ko^M[a0_l00003okcKk`?o00001OnfgO@2o`0000_o^Mkc0_l00003
ok_Nl@03o`000?neh?Go]N3e00Ko]N3e0_l0000;okSPm0?o00002Ondh_H2o`0000[o]^;f0_l0002c
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000oooo
ooooool0??ooool00ol0003oa/OJo`00000?ol[7e`03o`000?o=amCocLOD00GocLOD0_l00006oko=
i@03o`000?o3c^;o`lkR00co`lkR0ol0000>okgBjP03o`000?o1dnSo`M?X00Go`M?X0_l00005okWG
k`;o00003Onlend3o`0000go^M[a0_l00008okcKk`;o000000?o]]gdo`000?l000003?nig_<00ol0
003o^mkaok_Nl@04ok_Nl@;o00001?neh?D2o`0000_o^>3d0_l00003ok[Ql`;o00001Ondh_H2o`00
00Wo]^;f0ol0002fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool005[o
oooo00?o0000ooooooooool0??ooool2o`0000kob/OG00?o0000olg7e?o=am@02?o=am@01?l0003o
_lgUoko=iOnocND2o`0000ko`lkR00Go0000olK>h?o6c^3oa/kPo`00000;okgBjP;o00002_o1dnP2
o`000003okWGkol0003o000000go_=O]0_l00003okoGj`;o00002Onif_42o`0000_o_=__0ol0000;
okWNl`;o00002Onkg_401?l0003o]N3eo`000?l0000;okSPm0;o00001onjhO<2o`000003okCRm_l0
003o000000Wo]^;f0_l0002iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?oo
ool005_ooooo0_l0000nooooo`03o`000?o:amOob/OG00Wob/OG0_l0000<olg7e003o`000?nocNGo
000000oo`lkR00?o0000olK>h?o6c^000oo6c^02o`0000Oo_M;Z0_l0000=ol7Cj0?o00003Onlend0
0ol0003o_mO[okoGj`05okoGj`;o00001Onif_42o`0000_o_=__0_l00003okoKkP;o00001onig_<2
o`0000_o^mka0ol0000:okSPm0;o00002_njhO<4o`0000Oo]^;f0_l0002looooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool04oooool005gooooo00?o0000ooooooooool0??ooool00ol0
003ob/OGol[7e`07ol[7e`03o`000?o=amCocLOD00cocLOD0ol0000=ol?>hP;o00002?o6c^02o`00
00Co_M;Z00?o0000ol7Cj?o1dnP03?o1dnP01Ol0003oa=?UolCCiOo4dnGo000000[o_=O]0_l0000:
okoGj`;o000000?o^M[ao`000?l000003?nlfnl00ol0003o_m_^okoKkP05okoKkP03o`000?nig_?o
^Mkc00?o^Mkc00?o0000ok_NlOnkg_402Onkg_42o`0000?o_]k`0ol00005okSPm0;o00002_njhO<2
o`0000Co_>7b0ol000001?nfh_Ko0000o`000?l0002oooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool04oooool005kooooo00?o0000ooooooooool0??ooool00ol0003ob/OGol[7e`05
ol[7e`03o`000?o=amCocLOD00cocLOD00Go0000om37dOo@am7od<OAo`00000;ol?>hP03o`000?o6
c^3oa/kP00[oa/kP00Co0000okgBj_l0003o00003Oo1dnP2o`0000Goa=?U0_l00006okcGk@;o0000
3Onoen/3o`0000_o_=__0_l00009okoKkP;o000000?o^Mkco`000?l000002_nkg_42o`0000So_]k`
0_l000000onhh?Co0000o`00000:ok[Ql`;o00002?nlhO82o`000<?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Cooooo`00Goooool00ol0003oooooooooo`0looooo`03o`000?o:
amOob/OG00?ob/OG00?o0000olg7e?o=am@03?o=am@00ol0003od<OAom37d@03om37d@03o`000?o3
c^;o`lkR00Oo`lkR00?o0000olK>h?o6c^002oo6c^03o`0000go`M?X00?o0000olCCiOo4dnD01oo4
dnD00ol0003o_=O]okcGk@02okcGk@03o`000?noen_o_mO[00_o_mO[0_l00003ol;Gj@;o00001onl
fnl2o`0000co_m_^0ol00009ok_Nl@;o00002onng_03o`0000Wo^^7c0_l00008okcQlP;o0000aOoo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo001Pooooo`03o`000?oooooo
oooo03cooooo00Go0000ol[7eoo:amOob/OGo`00000>olg7e003o`000?o@am7od<OA00God<OA0_l0
0005ol?>hP;o00003Oo6c^001Ol0003obLgMolW=gOo9cMgo000000[o`M?X0_l0000;olCCi@04o`00
0?nlengo0000o`0000go_mO[00?o0000ol;GjOo2enT01Oo2enT00ol0003o_=__okcKk`03okcKk`03
o`000?nofnko_m_^00[o_m_^0_l00003ol7Kk0;o00001Onkg_42o`0000_o_]k`0_l00003ol3NkP;o
00001OnjhO<2o`0000Wo_>7b00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01?ooooo001Qooooo`;o0000?Oooool00ol0003ob/OGo`00000>olg7e003o`00
0?o@am7od<OA00Sod<OA00Go0000ol?>h_o3c^;o`lkRo`00000>olK>h003o`000?o9cMgobLgM00?o
bLgM0_l00007ol7Cj003o`000?o4dnGoa=?U00_oa=?U0ol0000<okoGj`;o00002Oo2enT2o`000003
okcKkol0003o000000_o_m_^0_l00007ol7Kk0;o000000?o^mkao`000?l000002onng_02o`0000Oo
`=k^0_l000000onjhO?o0000o`000009okcQlP;o0000b_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01?ooooo001Sooooo`03o`000?oooooooooo03_ooooo0_l0000=olg7e003o`00
0?o@am7od<OA00[od<OA00?o0000ol?>h_l000003Oo6c^02o`0000SobLgM0_l00003ol7Cj0;o0000
3Oo4dnD01?l0003oam;SolOBhoo7d^<2o`0000So_mO[0_l0000<ol;Gj@?o00002_nofnh2o`0000[o
`M_/0ol0000:okkNl0;o00002_o0g^h3o`0000So_>7b0_l0003<ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool04oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003ocLOD
olg7e009olg7e003o`000?o@am7od<OA00_od<OA0ol0000<olK>h003o`000?o9cMgobLgM00[obLgM
00?o0000ol7Cj?l000003Oo4dnD2o`0000Koam;S0_l00005okoGj`03o`000?o2enWo`]OY00[o`]OY
0_l00003olGGi`?o00001Onofnh2o`0000_o`M_/00Co0000olCKj_o4fn[oa=_Z0ol00005okkNl0;o
00002_o0g^h2o`0000?o`]k]0_l00005okcQlP03o`000?oooooooooo0<gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Booooo`00IOooool00ol0003oooooooooo`0looooo`03o`00
0?o=amCocLOD00OocLOD00?o0000om37dOo@am402oo@am401Ol0003od/K?om;6cooBa/oo000000[o
a/kP00?o0000olW=gOo9cMd02oo9cMd3o`0000coa=?U00?o0000olOBhoo7d^<02?o7d^<2o`000003
okoGjol0003o000000co`]OY00?o0000olGGioo5enL01_o5enL2o`000003okoKk_l0003o000000_o
`M_/0_l00007olCKjP;o000000?o_]k`o`000?l000002_o0g^h2o`0000Oo`]k]0_l000000onlhO;o
0000o`00003Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool006Kooooo
0_l0000mooooo`03o`000?o=amCocLOD00GocLOD00?o0000om37dOo@am402oo@am400ol0003od/K?
om;6c`03om;6c`;o00001_o6c^02o`0000gobLgM00Go0000olc=foo<cM_oc<gKo`000009olCCi@;o
00003?o7d^<3o`0000_o`]OY0_l0000:olGGi`?o00002_o1fn`2o`0000[oa=_Z0ol00009ol3NkP;o
00002_o2g^d2o`000=Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`00
J?ooool00ol0003oooooooooo`0kooooo`03o`000?o=amCocLOD00?ocLOD00?o0000om37dOo@am40
2oo@am400ol0003od/K?om;6c`06om;6c`;o00000oo6c^000ol0003obLgMolW=g@0<olW=g@03o`00
0?o<cM_oc<gK00?oc<gK0_l00006olCCi@03o`000?o7d^?oam;S00_oam;S00Co0000olWBhOo9d^7o
bM;Q0_l00007ol;Gj@;o00002oo5enL01?l0003oamOUolOGiOo7enD2o`0000Oo`M_/00?o0000olCK
j_o4fnX02Oo4fnX01?l0003oa]_YolKKjOo6fnT2o`0000Go`=k^0_l0000;ol;Nk@03o`000?oooooo
oooo0=Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`00JOooool00ol0
003oooooooooo`0kooooo`05o`000?o=amCocLODolg7e?l000003Oo@am400ol0003od/K?om;6c`09
om;6c`03o`000?o6c^3o000000gobLgM0_l00008olc=f`04o`000?o4dnGoa=?UolCCi@;o00003?o7
d^<2o`0000KobM;Q00?o0000ol;GjOo2enT00oo2enT00ol0003oaMOWolGGi`09olGGi`;o00001_o7
enD00ol0003o`M_/ol7Kk002ol7Kk0;o00002_o4fnX2o`0000Koa]_Y0_l000000oo0g^ko0000o`00
000;ol;Nk@;o0000f?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo001Z
ooooo`03o`000?oooooooooo03_ooooo00?o0000olg7e?l000003Oo@am400ol0003od/K?om;6c`0;
om;6c`;o00003?o9cMd00ol0003oc<gKolc=f`09olc=f`03o`000?o4dnGo000000goam;S00?o0000
olWBhOo9d^401oo9d^42o`000003ol;GjOl0003o000000_oaMOW00?o0000olOGiOo7enD01oo7enD2
o`000003ol7Kk?l0003oa=_Z00[oa=_Z00?o0000olKKjOo6fnT01oo6fnT3o`0000[o`]k]0_l0003K
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool006_ooooo0_l0000loooo
o`;o00003?o@am400ol0003od/K?om;6c`0<om;6c`03o`000?oDa/co000000[obLgM00?o0000olc=
foo<cM/02_o<cM/3o`0000_oam;S0_l0000;olWBh@?o00002_o5enL2o`0000_oamOU0ol00009olCK
jP;o00002Oo6fnT01?l0003ob=_WolSKioo8fnL2o`0000Oo`]k]00?o0000ooooooooool0g?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo001]ooooo`03o`000?oooooooooo
03_ooooo00?o0000om37dOo@am402?o@am400ol0003od/K?om;6c`0<om;6c`05o`000?oDa/coe<K<
omC6c?l000002?o9cMd00ol0003oc<gKolc=f`0:olc=f`04o`000?o>cMSoc/gHolk=f0;o00002?o7
d^<00ol0003obM;QolWBh@0:olWBh@04o`000?o<d]ooc=;OolcBg`;o00001oo5enL00ol0003oamOU
olOGi@0:olOGi@05o`000?o:en?ob]OSol[Ghol000001oo4fnX00ol0003oa]_YolKKj@08olKKj@03
o`000?o8fnOob=_W00Cob=_W00?o0000ol;NkOo2g^d00_o2g^d2o`000=oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Booooo`00K_ooool00ol0003oooooooooo`0kooooo`03o`00
0?o@am7od<OA00Kod<OA00?o0000om;6cooBa/l03?oBa/l00ol0003oe<K<omC6c003omC6c003o`00
0?o9cMgobLgM00?obLgM0_l0000<olc=f`03o`000?o>cMSoc/gH00Coc/gH0_l00004olOBh`;o0000
3?o9d^400ol0003oc=;OolcBg`04olcBg`03o`000?o5enOoaMOW00;oaMOW0_l0000;olOGi@;o0000
1Oo:en<2o`0000?oa=_Z0_l00009olKKj@;o00002?o8fnL2o`000003ol;NkOl0003ooooo0>7ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`00Koooool00ol0003ooooooooo
o`0kooooo`;o00001Oo@am400ol0003od/K?om;6c`0<om;6c`03o`000?oDa/coe<K<00Goe<K<00Go
0000olW=gOo9cMgobLgMo`00000=olc=f`03o`000?o>cMSoc/gH00Ooc/gH0_l000000oo7d^?o0000
olWBh@0;olWBh@;o00002?o<d]l2o`000003olGGiol0003oamOU00_oamOU00?o0000ol[Ghoo:en<0
1oo:en<00ol0003oa=_Zo`00000:olKKj@03o`000?o8fnOob=_W00Wob=_W0_l0003Tooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04Oooool0073ooooo0_l0000mooooo`05o`000?o@
am7od<OAom37dOl000003_oBa/l00ol0003oe<K<omC6c007omC6c003o`000?o9cMgo000000goc<gK
00?o0000olk=f?o>cMP02Oo>cMP3o`0000_obM;Q00?o0000olcBgoo<d]l02Oo<d]l3o`0000[oamOU
0_l0000:ol[Gh`?o00002?o6fnT2o`0000[ob=_W0_l0003Wooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04Oooool007;ooooo00?o0000ooooooooool0>oooool00ol0003od<OAo`00
000>om;6c`03o`000?oDa/coe<K<00Woe<K<0_l0000;olc=f`;o00002oo>cMP01Ol0003od<gFom3=
e_o@cMKo000000WobM;Q00?o0000olcBgoo<d]l02Oo<d]l01?l0003oc];MolkBgOo>d]d2o`0000Oo
amOU00?o0000ol[Ghoo:en<02Oo:en<01?l0003oc=OQolcGhOo<en43o`0000Coa]_Y00?o0000olSK
ioo8fnL02Oo8fnL00ol0003oooooooooo`3Wooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04Oooool007?ooooo00?o0000ooooooooool0>oooool2o`0000god/K?00?o0000omC6c?oD
a/`02_oDa/`00ol0003oe/K:o`000009olc=f`03o`000?o>cMSoc/gH00[oc/gH00?o0000om3=e_o@
cMH00oo@cMH2o`0000GobM;Q0_l0000;olcBg`03o`000?o>d]goc];M00Coc];M00?o0000olOGiOo7
enD00_o7enD2o`0000_ob]OS00?o0000olcGhOo<en401Oo<en42o`000003olKKjOl0003ob=_W00Wo
b=_W0_l0003[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool007Cooooo
00?o0000ooooooooool0??ooool00ol0003od/K?om;6c`09om;6c`03o`000?oDa/coe<K<00[oe<K<
00Co0000omK6b_oFa/[oe/K:0_l00006olc=f`03o`000?o>cMSoc/gH00[oc/gH00?o0000om3=e_o@
cMH01_o@cMH01Ol0003obM;QolWBhOo9d^7o000000coc=;O00?o0000olkBgOo>d]d01_o>d]d2o`00
0003olOGiOl0003ob]OS00[ob]OS0_l00009olcGh@?o00002?o8fnL2o`000>kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Aooooo`00MOooool00ol0003oooooooooo`0looooo`03
o`000?oBa/ood/K?00Ood/K?00?o0000omC6c?oDa/`02_oDa/`00ol0003oe/K:omK6bP04omK6bP;o
00000oo<cM/00ol0003oc/gHolk=f00:olk=f003o`000?o@cMKod<gF00Sod<gF00?o0000olWBhOl0
00003?o<d]l00ol0003oc];MolkBg@08olkBg@?o00002_o:en<00ol0003oc=OQolcGh@08olcGh@04
o`000?o>e]ooc]KOolkFg`;o00001Oo8fnL00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04Oooool007Kooooo0_l0000mooooo`03o`000?oBa/ood/K?00Go
d/K?00?o0000omC6c?oDa/`02_oDa/`00ol0003oe/K:omK6bP07omK6bP03o`000?o<cM_o000000co
c/gH00?o0000om3=e_o@cMH02Oo@cMH3o`0000[oc=;O0_l0000:olkBg@04o`000?o@dM_od=7Kom3A
f`;o00001_o:en<2o`0000[oc=OQ00?o0000olkFgoo>e]l01?o>e]l2o`000003olSKiol0003o0000
0?;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`00N?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oBa/ood/K?00?od/K?00?o0000omC6c?oDa/`02_oDa/`00ol0003o
e/K:omK6bP09omK6bP;o00002oo>cMP00ol0003od<gFom3=eP09om3=eP05o`000?oBc=Cod/cDom;<
e?l000002?o<d]l00ol0003oc];MolkBg@09olkBg@03o`000?o@dM_od=7K00Cod=7K00?o0000ol[G
hoo:en<00_o:en<00ol0003oc=OQolcGh@08olcGh@;o00002?o>e]l2o`000?Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0@ooooo`00NOooool00ol0003oooooooooo`0kooooo`05
o`000?oBa/ood/K?om;6col000003?oDa/`00ol0003oe/K:omK6bP0:omK6bP03o`000?oHaLOo0000
00Woc/gH00?o0000om3=e_o@cMH02Oo@cMH00ol0003od/cDom;<e003om;<e0;o00001Oo<d]l00ol0
003oc];MolkBg@09olkBg@03o`000?o@dM_od=7K00Kod=7K0_l000000oo:en?o0000olcGh@09olcG
h@03o`000?o>e]ooc]KO00Ooc]KO00?o0000ooooooooool0m_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo013ooooo001jooooo`03o`000?oooooooooo03_ooooo00?o0000om;6col0
00003?oDa/`00ol0003oe/K:omK6bP0:omK6bP04o`000?oHaLOof<G7omS5a`;o00001_o>cMP00ol0
003od<gFom3=eP09om3=eP03o`000?oBc=Cod/cD00Kod/cD00Go0000olcBgoo<d]ooc=;Oo`00000;
olkBg@03o`000?o@dM_od=7K00Sod=7K0ol00009olcGh@03o`000?o>e]ooc]KO00Ooc]KO00?o0000
ooooooooool0moooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo001koooo
o`;o0000??ooool2o`0000coe<K<00?o0000omK6b_oFa/X02OoFa/X00ol0003of<G7omS5a`04omS5
a`;o00000oo>cMP00ol0003od<gFom3=eP09om3=eP03o`000?oBc=Cod/cD00Sod/cD00?o0000olcB
gol000002_o>d]d2o`0000[od=7K00Go0000om7AfOoAdMWodM7Io`000006olcGh@;o00002Oo>e]l0
0ol0003oooooooooo`3iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool0
07gooooo00?o0000ooooooooool0>oooool00ol0003oe<K<omC6c008omC6c003o`000?oFa/[oe/K:
00Woe/K:00?o0000omS5aooHaLL01ooHaLL00ol0003oc/gHo`00000;om3=eP03o`000?oBc=Cod/cD
00Wod/cD0ol00009olkBg@03o`000?o@dM_od=7K00Wod=7K00?o0000om7AfOoAdMT00ooAdMT2o`00
00?oc=OQ00?o0000olkFgoo>e]l02?o>e]l00ol0003oooooooooo`3kooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool007kooooo00?o0000ooooooooool0>oooool00ol0003o
e<K<omC6c006omC6c003o`000?oFa/[oe/K:00Woe/K:00?o0000omS5aooHaLL02OoHaLL2o`0000[o
d<gF00?o0000om;<e?oBc=@02OoBc=@01?l0003oe<cBomC<d_oDc=82o`0000Koc];M00?o0000om3A
foo@dM/02Oo@dM/00ol0003odM7Iom7Af@06om7Af@03o`000?o<en7o000000[oc]KO00?o0000oooo
ooooool0oOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo001oooooo`03
o`000?oooooooooo03_ooooo0_l00005omC6c003o`000?oFa/[oe/K:00[oe/K:00?o0000omS5aooH
aLL02OoHaLL00ol0003ofLG5o`000008om3=eP03o`000?oBc=Cod/cD00Wod/cD00?o0000omC<d_oD
c=801?oDc=800ol0003oc];MolkBg@02olkBg@03o`000?o@dM_od=7K00Wod=7K00?o0000om7AfOoA
dMT02?oAdMT2o`0000Woc]KO00?o0000ooooooooool0o_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00oooooo0020ooooo`;o0000?Oooool01Ol0003oe<K<omC6c?oDa/co000000co
e/K:00?o0000omS5aooHaLL02OoHaLL01?l0003ofLG5omW5aOoIaLD2o`0000God<gF00?o0000om;<
e?oBc=@02OoBc=@00ol0003oe<cBomC<dP06omC<dP;o000000?oc];Mo`000?o@dM/02Oo@dM/2o`00
00[odM7I00?o0000om?AeooCdML00_l00006olkFg`03o`000?oooooooooo0?oooooo0Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0022ooooo`03o`000?oooooooooo03_o
oooo00?o0000omC6c?l000003?oFa/X00ol0003of<G7omS5a`09omS5a`03o`000?oIaLGofLG500Co
fLG500Go0000om3=e_o@cMKod<gFo`00000;om;<e003o`000?oDc=;oe<cB00Woe<cB0_l00009om3A
f`03o`000?oAdMWodM7I00WodM7I00?o0000om?AeooCdML00ooCdML00ol0003oc]KOolkFg`02olkF
g`03o`000?oooooooooo0?oooooo0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00oooooo0023ooooo`03o`000?oooooooooo03_ooooo0_l0000;omK6bP03o`000?oHaLOof<G700Wo
f<G700?o0000omW5aOoIaLD01_oIaLD00ol0003od<gFo`00000;om;<e003o`000?oDc=;oe<cB00Wo
e<cB00?o0000omK;d?oFbm000_l00006om3Af`03o`000?oAdMWodM7I00WodM7I00?o0000om?AeooC
dML01OoCdML2o`000003olkFgol0003ooooo0?oooooo1Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00oooooo0024ooooo`03o`000?oooooooooo03cooooo00?o0000omK6b_oFa/X0
1ooFa/X00ol0003of<G7omS5a`09omS5a`03o`000?oIaLGofLG500SofLG50_l0000:om;<e003o`00
0?oDc=;oe<cB00Woe<cB00?o0000omK;d?oFbm000ooFbm000ol0003od=7Kom3Af`02om3Af`03o`00
0?oAdMWodM7I00WodM7I00?o0000om?AeooCdML01ooCdML2o`000?oooooo2?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00oooooo0025ooooo`;o0000?Oooool00ol0003oe/K:omK6
bP06omK6bP03o`000?oHaLOof<G700Wof<G700?o0000omW5aOoIaLD02?oIaLD00ol0003oflC3o`00
0008om;<e003o`000?oDc=;oe<cB00Woe<cB00?o0000omK;d?oFbm001OoFbm02o`000003om3Afol0
003odM7I00[odM7I00?o0000om?AeooCdML01ooCdML00ol0003oooooooooo`3oooooo`Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00Qoooool00ol0003oooooooooo`0k
ooooo`;o00001OoFa/X00ol0003of<G7omS5a`09omS5a`03o`000?oIaLGofLG500SofLG500Co0000
om_4`ooKa<?oflC30_l00005om;<e003o`000?oDc=;oe<cB00Woe<cB00?o0000omK;d?oFbm002?oF
bm02o`0000[odM7I00?o0000om?AeooCdML01ooCdML00ol0003oooooooooo`3oooooo`_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`00R?ooool00ol0003oooooooooo`0l
ooooo`05o`000?oFa/[oe/K:omK6b_l000002ooHaLL00ol0003ofLG5omW5a@08omW5a@03o`000?oK
a<?oflC300CoflC300Go0000om;<e?oBc=Cod/cDo`00000;omC<dP03o`000?oFbm3oe/_@00Woe/_@
00?o0000omO;c_l000002?oAdMT00ol0003odm7Gom?Ae`07om?Ae`03o`000?oooooooooo0?oooooo
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo0029ooooo`03o`000?oo
oooooooo03cooooo00?o0000omK6b_l000002ooHaLL00ol0003ofLG5omW5a@08omW5a@03o`000?oK
a<?oflC300KoflC300?o0000om;<e?l000002ooDc=800ol0003oe/_@omK;d009omK;d004o`000?oG
blkoel_>omO;cP;o00001OoAdMT00ol0003odm7Gom?Ae`07om?Ae`03o`000?oooooooooo0?oooooo
3_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo002:ooooo`03o`000?oo
oooooooo03cooooo0_l0000:omS5a`03o`000?oIaLGofLG500WofLG500?o0000om_4`ooKa<<01ooK
a<<2o`0000[oe<cB00?o0000omK;d?oFbm002OoFbm000ol0003oel_>omO;cP04omO;cP05o`000?oA
dMWodM7Iom7AfOl000002OoCdML00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`00Roooool2o`0003kooooo00?o0000omS5aooHaLL01_oH
aLL00ol0003ofLG5omW5a@09omW5a@03o`000?oKa<?oflC300SoflC300?o0000omc4`_l000002?oD
c=800ol0003oe/_@omK;d009omK;d003o`000?oGblkoel_>00Koel_>00?o0000om7AfOl000002OoC
dML00ol0003oooooooooo`3ooooooa;ooooo00Go0000ooooooooooooooooo`00000@ooooo`00SOoo
ool00ol0003oooooooooo`0looooo`03o`000?oHaLOof<G700Gof<G700?o0000omW5aOoIaLD02?oI
aLD00ol0003oflC3om_4``08om_4``04o`000?oLa<;og<C2omc4`P;o00001OoDc=800ol0003oe/_@
omK;d009omK;d003o`000?oGblkoel_>00Soel_>0_l00008om?Ae`03o`000?oooooooooo0?oooooo
4oooool01Ol0003ooooooooooooooooo0000013ooooo002>ooooo`03o`000?oooooooooo03cooooo
00?o0000omS5aooHaLL00ooHaLL00ol0003ofLG5omW5a@08omW5a@03o`000?oKa<?oflC300SoflC3
00?o0000omc4`_oLa<801?oLa<801Ol0003oe<cBomC<d_oDc=;o000000_oe/_@00?o0000omO;c_oG
blh02OoGblh00ol0003ofL_<o`000006om?Ae`03o`000?oooooooooo0?oooooo5Oooool01?l0003o
ooooooooool0000@ooooo`00Soooool00ol0003oooooooooo`0looooo`05o`000?oHaLOof<G7omS5
aol000002_oIaLD00ol0003oflC3om_4``09om_4``03o`000?oLa<;og<C200Gog<C200?o0000omC<
d_l000002ooFbm000ol0003oel_>omO;cP09omO;cP04o`000?oIblcofL_<omW;c0;o00000ooCdML0
0ol0003oooooooooo`3ooooooaOooooo00?o0000ooooool000004?ooool0093ooooo0_l0000moooo
o`03o`000?oHaLOo000000_ofLG500?o0000om_4`ooKa<<02?oKa<<00ol0003og<C2omc4`P07omc4
`P;o00002_oFbm000ol0003oel_>omO;cP09omO;cP03o`000?oIblcofL_<00CofL_<00?o0000om?A
eol00000oooooolJooooo`04o`000?ooooooooooo`0000oooooo002Booooo`03o`000?oooooooooo
03_ooooo0_l0000:omW5a@03o`000?oKa<?oflC300SoflC300?o0000omc4`_oLa<802?oLa<800ol0
003ogL?0o`000008omK;d003o`000?oGblkoel_>00Woel_>00?o0000omW;c?oIbl`01_oIbl`00ol0
003oooooooooo`3ooooooa[ooooo00?o0000ooooool000003oooool009?ooooo00?o0000oooooooo
ool0??ooool00ol0003ofLG5omW5a@06omW5a@03o`000?oKa<?oflC300WoflC300?o0000omc4`_oL
a<801ooLa<801?l0003ogL?0omg3`?oM`l02o`0000Goe/_@00?o0000omO;c_oGblh02OoGblh00ol0
003ofL_<omW;c007omW;c003o`000?oooooooooo0?oooooo6oooool2o`0000oooooo002Dooooo`03
o`000?oooooooooo03cooooo00?o0000omW5aOoIaLD01?oIaLD00ol0003oflC3om_4``09om_4``03
o`000?oLa<;og<C200Oog<C200?o0000omg3`?oM`l001?oM`l001Ol0003oe/_@omK;d?oFbm3o0000
00_oel_>00?o0000omW;c?oIbl`01ooIbl`00ol0003oooooooooo`3ooooooa_ooooo0ol0000?oooo
o`00UOooool2o`0003gooooo00?o0000omW5aOoIaLD00ooIaLD00ol0003oflC3om_4``08om_4``03
o`000?oLa<;og<C200Sog<C200?o0000omg3`?oM`l001OoM`l000ol0003oe/_@o`00000;omO;cP03
o`000?oIblcofL_<00OofL_<00?o0000ooooooooool0oooooolHooooo`Co00004_ooool009Oooooo
00?o0000ooooooooool0>oooool01Ol0003ofLG5omW5aOoIaLGo000000_oflC300?o0000omc4`_oL
a<801ooLa<800ol0003ogL?0omg3`007omg3`0;o00002_oGblh00ol0003ofL_<omW;c007omW;c003
o`000?oooooooooo0?oooooo5_ooool3o`0001Kooooo002Hooooo`03o`000?oooooooooo03_ooooo
00?o0000omW5aOl000002ooKa<<00ol0003og<C2omc4`P08omc4`P03o`000?oM`l3ogL?000OogL?0
00?o0000omk3__l000002?oGblh00ol0003ofL_<omW;c007omW;c003o`000?oooooooooo0?oooooo
4oooool4o`0001Wooooo002Iooooo`03o`000?oooooooooo03_ooooo0_l0000:om_4``03o`000?oL
a<;og<C200Sog<C200?o0000omg3`?oM`l001ooM`l001?l0003og/>nomk3__oN`kh2o`0000Goel_>
00?o0000omW;c?oIbl`02?oIbl`00ol0003oooooooooo`3oooooo`oooooo1?l0000Mooooo`00V_oo
ool2o`0003gooooo00?o0000om_4`ooKa<<01ooKa<<00ol0003og<C2omc4`P07omc4`P03o`000?oM
`l3ogL?000OogL?000?o0000omk3__oN`kh01?oN`kh01Ol0003oel_>omO;c_oGblko000000[ofL_<
00?o0000ooooooooool0ooooool<ooooo`Co00008Oooool009cooooo00?o0000ooooooooool0>ooo
ool00ol0003oflC3om_4``05om_4``03o`000?oLa<;og<C200Sog<C200?o0000omg3`?oM`l001ooM
`l000ol0003og/>nomk3_P05omk3_P03o`000?oGblko000000[ofL_<00?o0000ooooooooool0oooo
ool9ooooo`Co00009Oooool009gooooo00?o0000ooooooooool0>oooool2o`0000CoflC300?o0000
omc4`_oLa<802?oLa<800ol0003ogL?0omg3`007omg3`003o`000?oN`kkog/>n00Oog/>n0_l00009
omW;c003o`000?oooooooooo0?oooooo1oooool3o`0002Wooooo002Nooooo`03o`000?oooooooooo
03cooooo00Go0000om_4`ooKa<?oflC3o`000009omc4`P03o`000?oM`l3ogL?000SogL?000?o0000
omk3__oN`kh01ooN`kh00ol0003ogl>lo`000008omW;c003o`000?oooooooooo0?oooooo0oooool4
o`0002cooooo002Oooooo`03o`000?oooooooooo03cooooo00?o0000om_4`ol000002_oLa<800ol0
003ogL?0omg3`007omg3`003o`000?oN`kkog/>n00Oog/>n00Co0000omo3_?oO`kcogl>l0_l00005
omW;c003o`000?oooooooooo0?oooooo1?l0000`ooooo`00X?ooool2o`0003gooooo0_l00009omc4
`P03o`000?oM`l3ogL?000OogL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_004omo3
_005o`000?oIblcofL_<omW;c?l00000o_ooool4o`0003Cooooo002Rooooo`03o`000?oooooooooo
03cooooo00?o0000omc4`_oLa<801OoLa<800ol0003ogL?0omg3`008omg3`003o`000?oN`kkog/>n
00Oog/>n00?o0000omo3_?oO`k`01OoO`k`00ol0003ofL_<o`00003kooooo`Co0000>?ooool00:?o
oooo00?o0000ooooooooool0??ooool00ol0003og<C2omc4`P04omc4`P03o`000?oM`l3ogL?000Oo
gL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_007omo3_003o`000?oooooooooo0?Oo
oooo0ol0000looooo`00Y?ooool00ol0003oooooooooo`0looooo`03o`000?oLa<;og<C200;og<C2
00?o0000omg3`?oM`l002?oM`l000ol0003og/>nomk3_P07omk3_P03o`000?oO`kcogl>l00Oogl>l
00?o0000ooooooooool0loooool4o`0003oooooo002Uooooo`;o0000?Oooool01Ol0003og<C2omc4
`_oLa<;o000000WogL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_007omo3_003o`00
0?oooooooooo0?3ooooo1?l00013ooooo`00Yoooool00ol0003oooooooooo`0kooooo`03o`000?oL
a<;o000000WogL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_008omo3_003o`000?oo
oooooooo0>cooooo1?l00017ooooo`00Z?ooool00ol0003oooooooooo`0kooooo`;o00002OoM`l00
0ol0003og/>nomk3_P07omk3_P03o`000?oO`kcogl>l00Oogl>l00?o0000ooooooooool0jOooool4
o`0004_ooooo002Yooooo`03o`000?oooooooooo03cooooo00?o0000omg3`?oM`l001OoM`l000ol0
003og/>nomk3_P07omk3_P03o`000?oO`kcogl>l00Oogl>l00?o0000ooooooooool0ioooool3o`00
04oooooo002Zooooo`;o0000?Oooool00ol0003ogL?0omg3`004omg3`003o`000?oN`kkog/>n00Oo
g/>n00?o0000omo3_?oO`k`01ooO`k`00ol0003oooooooooo`3Sooooo`Co0000D_ooool00:cooooo
00?o0000ooooooooool0>oooool00ol0003ogL?0omg3`002omg3`003o`000?oN`kkog/>n00Oog/>n
00?o0000omo3_?oO`k`01ooO`k`00ol0003oooooooooo`3Pooooo`Co0000E_ooool00:gooooo00?o
0000ooooooooool0>oooool01?l0003ogL?0omg3`?l00009omk3_P03o`000?oO`kcogl>l00Sogl>l
00?o0000ooooooooool0g?ooool4o`0005[ooooo002^ooooo`03o`000?oooooooooo03_ooooo00?o
0000omg3`?l000002OoN`kh00ol0003ogl>lomo3_007omo3_003o`000?oooooooooo0=Wooooo1?l0
001Nooooo`00[oooool2o`0003cooooo0_l00008omk3_P03o`000?oO`kcogl>l00Sogl>l00?o0000
ooooooooool0e_ooool3o`0006;ooooo002aooooo`03o`000?oooooooooo03_ooooo00?o0000omk3
__oN`kh01OoN`kh00ol0003ogl>lomo3_007omo3_003o`000?oooooooooo0=?ooooo1?l0001Uoooo
o`00/_ooool00ol0003oooooooooo`0kooooo`;o00001?oN`kh00ol0003ogl>lomo3_007omo3_003
o`000?oooooooooo0=3ooooo1?l0001Yooooo`00/oooool00ol0003oooooooooo`0looooo`04o`00
0?oN`kkog/>no`0000[ogl>l00?o0000ooooooooool0c?ooool4o`0006gooooo002dooooo`03o`00
0?oooooooooo03cooooo00?o0000omk3__l000002OoO`k`00ol0003oooooooooo`39ooooo`Co0000
LOooool00;Gooooo0_l0000mooooo`;o00002OoO`k`00ol0003oooooooooo`36ooooo`?o0000MOoo
ool00;Oooooo00?o0000ooooooooool0??ooool00ol0003ogl>lomo3_005omo3_003o`000?oooooo
oooo0<?ooooo1?l0001hooooo`00^?ooool00ol0003oooooooooo`0looooo`03o`000?oO`kcogl>l
00Cogl>l00?o0000ooooooooool0_oooool4o`0007cooooo002iooooo`03o`000?oooooooooo03co
oooo00?o0000omo3_?oO`k`00_oO`k`00ol0003oooooooooo`2looooo`Co0000P?ooool00;[ooooo
0_l0000mooooo`04o`000?oO`kcogl>lo`000;cooooo0ol00024ooooo`00_?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oO`kco00000;Sooooo1?l00027ooooo`00_Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;?ooooo1?l0002;ooooo`00__ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo0:oooooo1?l0002?ooooo`00_oooool2o`0003[ooooo00?o0000oooo
ooooool0Zoooool4o`0009?ooooo0031ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Z?ooool3o`0009Oooooo0032ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
Y?ooool4o`0009[ooooo0033ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0X?oo
ool4o`0009kooooo0034ooooo`;o0000=Oooool00ol0003oooooooooo`2Looooo`Co0000X_ooool0
0<Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Hooooo`Co0000Y_ooool00<Oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Eooooo`?o0000Z_ooool00<Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Booooo`Co0000[Oooool00<Wooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2>ooooo`Co0000/Oooool00<[ooooo0_l0000^
ooooo`03o`000?oooooooooo08[ooooo1?l0002eooooo`00c?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo08Kooooo1?l0002iooooo`00cOooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo08?ooooo0ol0002mooooo`00c_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo07oooooo1?l00030ooooo`00coooool2o`0002Wooooo00?o0000ooooooooool0Nooo
ool4o`000<Cooooo003Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4
o`000<Sooooo003Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00
0<cooooo003Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool3o`000=3o
oooo003Dooooo`;o00009?ooool00ol0003oooooooooo`1/ooooo`Co0000doooool00=Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000eoooool00=Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000foooool00=Sooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000goooool00=Wooooo0_l0000Oooooo`03
o`000?oooooooooo05gooooo1?l0003Rooooo`00foooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05Wooooo1?l0003Vooooo`00g?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Gooooo1?l0003Zooooo`00gOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo057ooooo1?l0003^ooooo`00g_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04kooooo0ol0003booooo`00goooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`000?Go
oooo003Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`000?Wooooo
003Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`000?gooooo003S
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`000?oooooo0_ooool0
0>Cooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo0ol0003oooooo`Kooooo003Vooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`000?oooooo2Oooool00>Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000ooooool=ooooo`00j?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo1?l0003ooooooa7ooooo003Y
ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`Co0000oooooolEooooo`00joooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0003ooooooaWooooo003/ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`000?oooooo7?ooool00>gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000oooooolPooooo`00k_oo
ool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000?oooooo9?ooool00?3ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000oooooolXooooo`00lOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0003oooooobcooooo003booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000?oooooo;oooool00??ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000oooooolcooooo`00m?oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000?oooooo=oooool00?Kooooo00Co0000
oooooooooooo00002?ooool4o`000?oooooo>oooool00?Oooooo00?o0000ooooool000001Oooool3
o`000?oooooo?oooool00?Sooooo0_l000000ooooooo0000o`000002o`000?oooooo@_ooool00?Wo
oooo0_l0003oooooodKooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.081516, 0.0209008, \
0.00184551, 0.00184551}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s FindRoot function can be used to map out the miscibility gap. Note that \
the common tangent in this symmetric free energy model will have zero slope. \
FindRoot needs an initial guess and I start from 990 K and work downward \
along one branch of the curve."
}], "Text"],

Cell["\<\
First, initialize an array for storing pairs of values (T, XB) that \
will form the coexistence curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoexCurvePts = {}\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell["\<\
Here's the general procedure for calculating and extracting the \
value of a point on the coexistence curve:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(T = 990\), "\[IndentingNewLine]", 
    \(XBCoex = 
      FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 0, {XB, 
          0.6}]\), "\[IndentingNewLine]", 
    \(XBCoex[\([1, 2]\)]\)}], "Input"],

Cell[BoxData[
    \(990\)], "Output"],

Cell[BoxData[
    \({XB \[Rule] 0.5862555349875236`}\)], "Output"],

Cell[BoxData[
    \(0.5862555349875236`\)], "Output"]
}, Open  ]],

Cell["Now calculate a whole lot of points:", "Text"],

Cell[BoxData[{
    \(\(CoexCurvePts = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]XBCoex = 
        FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 0, {XB, 
            XBCoex[\([1, 2]\)]}]; \[IndentingNewLine]CoexCurvePts = 
        Append[CoexCurvePts, {XBCoex[\([1, 2]\)], T}], {T, 990, 
        300, \(-10\)}]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BSide = 
      ListPlot[CoexCurvePts, 
        AxesLabel \[Rule] {"\<Atom Fraction,XB\>", "\<Temperature,K\>"}]\)], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.3299 2.30907 -0.2412 0.000853049 [
[.05555 .00222 -9 -9 ]
[.05555 .00222 9 0 ]
[.28645 .00222 -9 -9 ]
[.28645 .00222 9 0 ]
[.51736 .00222 -9 -9 ]
[.51736 .00222 9 0 ]
[.74827 .00222 -9 -9 ]
[.74827 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.96668 .10002 -18 -4.5 ]
[.96668 .10002 0 4.5 ]
[.96668 .18532 -18 -4.5 ]
[.96668 .18532 0 4.5 ]
[.96668 .27063 -18 -4.5 ]
[.96668 .27063 0 4.5 ]
[.96668 .35593 -18 -4.5 ]
[.96668 .35593 0 4.5 ]
[.96668 .44124 -18 -4.5 ]
[.96668 .44124 0 4.5 ]
[.96668 .52654 -18 -4.5 ]
[.96668 .52654 0 4.5 ]
[.96668 .61185 -24 -4.5 ]
[.96668 .61185 0 4.5 ]
[.97918 .64303 -41 0 ]
[.97918 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05555 .01472 m
.05555 .02097 L
s
[(0.6)] .05555 .00222 0 1 Mshowa
.28645 .01472 m
.28645 .02097 L
s
[(0.7)] .28645 .00222 0 1 Mshowa
.51736 .01472 m
.51736 .02097 L
s
[(0.8)] .51736 .00222 0 1 Mshowa
.74827 .01472 m
.74827 .02097 L
s
[(0.9)] .74827 .00222 0 1 Mshowa
.125 Mabswid
.10173 .01472 m
.10173 .01847 L
s
.14791 .01472 m
.14791 .01847 L
s
.19409 .01472 m
.19409 .01847 L
s
.24027 .01472 m
.24027 .01847 L
s
.33264 .01472 m
.33264 .01847 L
s
.37882 .01472 m
.37882 .01847 L
s
.425 .01472 m
.425 .01847 L
s
.47118 .01472 m
.47118 .01847 L
s
.56354 .01472 m
.56354 .01847 L
s
.60972 .01472 m
.60972 .01847 L
s
.65591 .01472 m
.65591 .01847 L
s
.70209 .01472 m
.70209 .01847 L
s
.79445 .01472 m
.79445 .01847 L
s
.84063 .01472 m
.84063 .01847 L
s
.88681 .01472 m
.88681 .01847 L
s
.93299 .01472 m
.93299 .01847 L
s
.00937 .01472 m
.00937 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97918 .10002 m
.98543 .10002 L
s
[(400)] .96668 .10002 1 0 Mshowa
.97918 .18532 m
.98543 .18532 L
s
[(500)] .96668 .18532 1 0 Mshowa
.97918 .27063 m
.98543 .27063 L
s
[(600)] .96668 .27063 1 0 Mshowa
.97918 .35593 m
.98543 .35593 L
s
[(700)] .96668 .35593 1 0 Mshowa
.97918 .44124 m
.98543 .44124 L
s
[(800)] .96668 .44124 1 0 Mshowa
.97918 .52654 m
.98543 .52654 L
s
[(900)] .96668 .52654 1 0 Mshowa
.97918 .61185 m
.98543 .61185 L
s
[(1000)] .96668 .61185 1 0 Mshowa
.125 Mabswid
.97918 .03178 m
.98293 .03178 L
s
.97918 .04884 m
.98293 .04884 L
s
.97918 .0659 m
.98293 .0659 L
s
.97918 .08296 m
.98293 .08296 L
s
.97918 .11708 m
.98293 .11708 L
s
.97918 .13414 m
.98293 .13414 L
s
.97918 .1512 m
.98293 .1512 L
s
.97918 .16826 m
.98293 .16826 L
s
.97918 .20239 m
.98293 .20239 L
s
.97918 .21945 m
.98293 .21945 L
s
.97918 .23651 m
.98293 .23651 L
s
.97918 .25357 m
.98293 .25357 L
s
.97918 .28769 m
.98293 .28769 L
s
.97918 .30475 m
.98293 .30475 L
s
.97918 .32181 m
.98293 .32181 L
s
.97918 .33887 m
.98293 .33887 L
s
.97918 .373 m
.98293 .373 L
s
.97918 .39006 m
.98293 .39006 L
s
.97918 .40712 m
.98293 .40712 L
s
.97918 .42418 m
.98293 .42418 L
s
.97918 .4583 m
.98293 .4583 L
s
.97918 .47536 m
.98293 .47536 L
s
.97918 .49242 m
.98293 .49242 L
s
.97918 .50948 m
.98293 .50948 L
s
.97918 .54361 m
.98293 .54361 L
s
.97918 .56067 m
.98293 .56067 L
s
.97918 .57773 m
.98293 .57773 L
s
.97918 .59479 m
.98293 .59479 L
s
.25 Mabswid
.97918 0 m
.97918 .61803 L
s
gsave
.97918 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.10517 .59479 Mdot
.16682 .58626 Mdot
.21814 .57773 Mdot
.26277 .5692 Mdot
.30259 .56067 Mdot
.33872 .55214 Mdot
.37189 .54361 Mdot
.40262 .53507 Mdot
.43127 .52654 Mdot
.45812 .51801 Mdot
.48341 .50948 Mdot
.50729 .50095 Mdot
.52993 .49242 Mdot
.55142 .48389 Mdot
.57188 .47536 Mdot
.59138 .46683 Mdot
.61 .4583 Mdot
.6278 .44977 Mdot
.64484 .44124 Mdot
.66115 .43271 Mdot
.67679 .42418 Mdot
.69179 .41565 Mdot
.70618 .40712 Mdot
.72 .39859 Mdot
.73327 .39006 Mdot
.74602 .38153 Mdot
.75826 .373 Mdot
.77003 .36447 Mdot
.78133 .35593 Mdot
.79219 .3474 Mdot
.80261 .33887 Mdot
.81263 .33034 Mdot
.82224 .32181 Mdot
.83147 .31328 Mdot
.84032 .30475 Mdot
.84881 .29622 Mdot
.85694 .28769 Mdot
.86473 .27916 Mdot
.87219 .27063 Mdot
.87932 .2621 Mdot
.88613 .25357 Mdot
.89263 .24504 Mdot
.89883 .23651 Mdot
.90474 .22798 Mdot
.91036 .21945 Mdot
.9157 .21092 Mdot
.92077 .20239 Mdot
.92557 .19386 Mdot
.93011 .18532 Mdot
.9344 .17679 Mdot
.93844 .16826 Mdot
.94224 .15973 Mdot
.9458 .1512 Mdot
.94913 .14267 Mdot
.95224 .13414 Mdot
.95513 .12561 Mdot
.95782 .11708 Mdot
.9603 .10855 Mdot
.96258 .10002 Mdot
.96467 .09149 Mdot
.96658 .08296 Mdot
.96831 .07443 Mdot
.96988 .0659 Mdot
.97128 .05737 Mdot
.97254 .04884 Mdot
.97364 .04031 Mdot
.97462 .03178 Mdot
.97546 .02325 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{402.875, 248.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000n2000`400?l00000o`00003ooooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`002Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003Kooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0003Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0002`ooooo`002?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000003Cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2]
ooooo`002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000=?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000003Cooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`2/ooooo`002?ooool01?l0003oooooooooool00007ooooo`Co0000=Oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo0000
2?ooool3o`0003Gooooo00Co0000oooooooooooo00002?ooool4o`000:kooooo0008ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool0000;oooo
o`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000003Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000:ko
oooo0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0=Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool00000[_ooool000Wooooo0_l0000:ooooo`;o0000=_ooool2o`0000So
oooo1Ol0000eooooo`;o00002Oooool3o`0003Kooooo0_l00009ooooo`?o0000[oooool00?oooooo
8Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo013ooooo003oooooob7ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0?ooooo`00oooooolQooooo`03o`000?oooooo
oooo00cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool3o`0000;ooooo00Go
0000ooooool0003oooooo`000007ooooo`?o00000oooool3o`0000Cooooo1?l00002ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool4o`0000Gooooo003oooooob7ooooo
00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`07o`000?oooooo0000ooooool0003oooooo`000008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00004ooooo`00ool0000Xo`0000Sooooo
1Ol00002ooooo`03o`000?oooooooooo00;ooooo00_o0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000oo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`0;o`000?oooooooooooooo
ool0003oooooo`000?oooooo0000ooooool000002?ooool3o`0000?ooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`?o00001Oooool0013ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000;ooooo1?l00003
ooooo`?o00000_ooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000_ooool4o`0000;ooooo0ol00004
ooooo`?o00000_ooool4o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`00oooooolOooooo`?o00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00001?ooool00?oooooo7oooool3o`0000oooooo0_l0
0004ooooo`03o`000?oooooooooo01Cooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool2o`000004ooooool0003o0000ooooo`Co00001Oooool00?oooooo7ooo
ool4o`00073ooooo003ooooooaoooooo0ol0001aooooo`00oooooolQooooo`03o`000?oooooooooo
06oooooo003ooooooaoooooo0ol0001aooooo`00oooooolOooooo`?o0000LOooool00?oooooo7_oo
ool2o`000003ooooool0003o0000073ooooo003ooooooakooooo0_l000000ooooooo0000ooooo`1`
ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003ooooooakooooo0_l000000ooooooo
0000ooooo`1`ooooo`00oooooolNooooo`;o000000?oooooo`000?ooool0L?ooool00?oooooo7Ooo
ool2o`0000;ooooo0_l0001`ooooo`00oooooolMooooo`;o00000_ooool00ol0003oooooooooo`1_
ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003ooooooagooooo0_l00002ooooo`03
o`000?oooooooooo06oooooo003ooooooagooooo0_l00002ooooo`03o`000?oooooooooo06oooooo
003ooooooacooooo0_l00003ooooo`;o0000L?ooool00?oooooo7?ooool2o`0000?ooooo00?o0000
ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00ooooool=ooooo`?o
00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo06oo
oooo003oooooo`kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo0ol00003ooooo`03o`000?oooooooooo06oooooo003oooooo`_ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_l00004ooooo`?o0000Koooool00?oo
oooo2oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_l00004ooooo`03o`000?oooooooooo06oooooo003oooooo`cooooo00?o0000oooo
ool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0Koooool00?oooooo3Oooool2o`0000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool0Koooool00?oooooo3_ooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool4o`0000Cooooo00?o0000ooooooooool0Koooool0
0?oooooo6_ooool2o`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo6_ooool2o`0000Go
oooo0_l0001`ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003ooooooaWooooo0_l0
0006ooooo`03o`000?oooooooooo06oooooo003ooooooaWooooo0_l00006ooooo`03o`000?oooooo
oooo06oooooo003ooooooaSooooo0_l00007ooooo`03o`000?oooooooooo06oooooo003ooooooaSo
oooo0_l00007ooooo`;o0000L?ooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00oooo
oolGooooo`;o00002?ooool00ol0003oooooooooo`1_ooooo`00oooooolGooooo`;o00002?ooool0
0ol0003oooooooooo`1_ooooo`00oooooolFooooo`;o00002Oooool00ol0003oooooooooo`1_oooo
o`00oooooolFooooo`;o00002Oooool2o`00073ooooo003oooooob7ooooo00?o0000ooooooooool0
Koooool00?oooooo5Oooool2o`0000[ooooo00?o0000ooooooooool0Koooool00?oooooo5Oooool2
o`0000[ooooo00?o0000ooooooooool0Koooool00?oooooo5?ooool2o`0000_ooooo00?o0000oooo
ooooool0Koooool00?oooooo5?ooool2o`0000_ooooo0_l0001`ooooo`00oooooolQooooo`03o`00
0?oooooooooo06oooooo003oooooo`cooooo0ol00004ooooo`;o00001?ooool2o`0000Kooooo00?o
0000ooooooooool0Koooool00?oooooo2oooool01Ol0003ooooooooooooooooo000000;ooooo1?l0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo3ooo
ool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool000000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06oooooo003oooooo`oooooo00?o0000ooooooooool00_l0
00001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooooooool00oooool3o`0006oooooo
003oooooo`_ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`1_ooooo`00ooooool;ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1_ooooo`00ooooool;ooooo`Oo000000?oooooo`000?l000001?ooool2o`0000Kooooo
00?o0000ooooooooool0Koooool00?oooooo3oooool2o`00013ooooo00?o0000ooooooooool0Kooo
ool00?oooooo3oooool2o`00013ooooo0_l0001`ooooo`00oooooolQooooo`03o`000?oooooooooo
06oooooo003oooooo`gooooo0_l0000Booooo`03o`000?oooooooooo06oooooo003oooooo`gooooo
0_l0000Booooo`03o`000?oooooooooo06oooooo003oooooo`cooooo0_l0000Cooooo`03o`000?oo
oooooooo06oooooo003oooooo`cooooo0_l0000Cooooo`;o0000L?ooool00?oooooo8Oooool00ol0
003oooooooooo`1_ooooo`00ooooool:ooooo`;o00005Oooool00ol0003oooooooooo`1_ooooo`00
ooooool:ooooo`;o00005Oooool00ol0003oooooooooo`1_ooooo`00ooooool8ooooo`;o00005ooo
ool00ol0003oooooooooo`1_ooooo`00ooooool8ooooo`;o00005oooool2o`00073ooooo003ooooo
ob7ooooo00?o0000ooooooooool0Koooool00?oooooo1oooool2o`0001Sooooo00?o0000oooooooo
ool0Koooool00?oooooo1oooool2o`0001Sooooo00?o0000ooooooooool0Koooool00?oooooo1Ooo
ool2o`0001[ooooo00?o0000ooooooooool0Koooool00?oooooo1Oooool2o`0001[ooooo0_l0001`
ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003oooooo`?ooooo0_l00007ooooo`?o
00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo003oooooo`?ooooo
0_l00006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo0Oooool2o`00
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00ooooool1ooooo`;o00002?oo
ool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`?o
0000Koooool00?oooooo2oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00oOooool2o`0000co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0Koooool00?gooooo0_l0000=ooooo`;o00001?ooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo003kooooo`;o00008oooool00ol0003o
ooooooooo`1_ooooo`00noooool2o`0002?ooooo0_l0001`ooooo`00oooooolQooooo`03o`000?oo
oooooooo06oooooo003iooooo`;o00009Oooool00ol0003oooooooooo`1_ooooo`00nOooool2o`00
02Gooooo00?o0000ooooooooool0Koooool00?Kooooo0_l0000Xooooo`03o`000?oooooooooo06oo
oooo003fooooo`;o0000:?ooool2o`00073ooooo003oooooob7ooooo00?o0000ooooooooool0Kooo
ool00?Cooooo0_l0000Zooooo`03o`000?oooooooooo06oooooo003dooooo`;o0000:_ooool00ol0
003oooooooooo`1_ooooo`00lOooool2o`0002gooooo00?o0000ooooooooool0Koooool00?7ooooo
0_l0000]ooooo`;o0000L?ooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00k_ooool2
o`00033ooooo00?o0000ooooooooool0Koooool00>kooooo0_l0000`ooooo`03o`000?oooooooooo
06oooooo003[ooooo`;o0000<oooool00ol0003oooooooooo`1_ooooo`00joooool2o`0003?ooooo
0_l0001`ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003Xooooo`;o00008_ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0Koooool0
0>Sooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo003Uooooo`;o00009_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06oooooo003Uooooo`;o00009_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`?o
0000Koooool00?oooooo3oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1_ooooo`00h_ooool2o`0002Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00h_ooool2o`0002Kooooo1Ol00003
ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0Koooool00=kooooo0_l00010oooo
o`03o`000?oooooooooo06oooooo003Nooooo`;o0000@?ooool2o`00073ooooo003oooooob7ooooo
00?o0000ooooooooool0Koooool00=[ooooo0_l00014ooooo`03o`000?oooooooooo06oooooo003J
ooooo`;o0000A?ooool00ol0003oooooooooo`1_ooooo`00oooooolQooooo`03o`000?oooooooooo
06oooooo003Gooooo`;o0000Aoooool2o`00073ooooo003Gooooo`;o0000Aoooool00ol0003ooooo
ooooo`1_ooooo`00doooool2o`0004_ooooo00?o0000ooooooooool0Koooool00=?ooooo0_l0001;
ooooo`03o`000?oooooooooo06oooooo003oooooob7ooooo00?o0000ooooooooool0Koooool00<oo
oooo0_l0001?ooooo`;o0000L?ooool00<oooooo0_l0001?ooooo`03o`000?oooooooooo06oooooo
003;ooooo`;o0000Doooool00ol0003oooooooooo`1_ooooo`00boooool2o`0005?ooooo00?o0000
ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00a_ooool2o`0005So
oooo0_l0001`ooooo`00a_ooool2o`0005Sooooo00?o0000ooooooooool0Koooool00<;ooooo0_l0
0017ooooo`?o00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo0032
ooooo`;o0000A_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo003oooooo`_ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00_Oooool2o`0004cooooo0ol00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool3o`0006oooooo002m
ooooo`;o0000Boooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo002hooooo`;o0000
D?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo002hooooo`;o0000DOooool3o`00
00Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`1_ooooo`00oooooolQooooo`03
o`000?oooooooooo06oooooo002booooo`;o0000K?ooool2o`00073ooooo002booooo`;o0000K?oo
ool00ol0003oooooooooo`1_ooooo`00[Oooool2o`00077ooooo00?o0000ooooooooool0Koooool0
0:gooooo0_l0001aooooo`03o`000?oooooooooo06oooooo003oooooob7ooooo00?o0000oooooooo
ool0Koooool00:Oooooo0_l0001gooooo`;o0000L?ooool00:Oooooo0_l0001gooooo`03o`000?oo
oooooooo06oooooo002Qooooo`;o0000OOooool00ol0003oooooooooo`1_ooooo`00XOooool2o`00
07gooooo00?o0000ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00
Voooool2o`0008?ooooo0_l0001`ooooo`00Voooool2o`0008?ooooo00?o0000ooooooooool0Kooo
ool009Cooooo0_l0002:ooooo`03o`000?oooooooooo06oooooo002Dooooo`;o0000R_ooool00ol0
003oooooooooo`1_ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo002=ooooo`;o0000
TOooool2o`00073ooooo002=ooooo`;o0000TOooool00ol0003oooooooooo`1_ooooo`00Q_ooool2
o`0009Sooooo00?o0000ooooooooool0Koooool008Kooooo0_l00023ooooo`;o00001Oooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo003oooooo`kooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1_ooooo`00O_ooool2o`0008kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo0ol0001_ooooo`00O_ooool2
o`0008_ooooo1?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`1_ooooo`00MOooool2o`0009?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`1_ooooo`00MOooool2o`0009?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`1_ooooo`00ooooool<ooooo`?o00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo06oooooo001/ooooo`;o0000/_ooool2o`00073ooooo001/ooooo`;o0000/_ooool00ol0003o
ooooooooo`1_ooooo`00Hoooool2o`000;_ooooo00?o0000ooooooooool0Koooool006?ooooo0_l0
002kooooo`03o`000?oooooooooo06oooooo003oooooob7ooooo00?o0000ooooooooool0Koooool0
05Sooooo0_l00036ooooo`;o0000L?ooool005Sooooo0_l00036ooooo`03o`000?oooooooooo06oo
oooo001<ooooo`;o0000d_ooool00ol0003oooooooooo`1_ooooo`00C?ooool2o`000=;ooooo00?o
0000ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00?oooool2o`00
0=oooooo0_l0001`ooooo`00?oooool2o`000=oooooo00?o0000ooooooooool0Koooool0033ooooo
0_l0003^ooooo`03o`000?oooooooooo06oooooo000`ooooo`;o0000k_ooool00ol0003ooooooooo
o`1_ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo000Nooooo`;o0000ooooool1oooo
o`;o0000L?ooool001kooooo0_l0003oooooo`7ooooo00?o0000ooooooooool0Koooool000Kooooo
0_l0003ooooooaWooooo00?o0000ooooooooool0Koooool000Kooooo0_l0003mooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`1_ooooo`00ooooool7
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo
1oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00005ooooo`?o0000Koooool00?oooooo1oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo003oooooo`Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00ooooool6ooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo0000Moooool00?oooooo1oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l0001hooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooo
oonCooooo`00oooooonCooooo`00oooooonCooooo`00ooooool<ooooo`?o0000;oooool00ol0003o
ooooooooo`1Booooo`00ooooool=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
DOooool00?[ooooo0ol00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo
0ol00003ooooo`?o00000_ooool3o`0000Cooooo1?l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o00001?ooool3o`0000Gooooo00?o0000ooooooooool00ol000000ooooooo0000
o`00001;ooooo`00noooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooool0003o
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0003o
ooooooooool0001<ooooo`00noooool01?l0003oooooooooooooool5o`000006ooooool0003ooooo
o`000?oooooo00000_ooool01Ol0003oooooooooool0003ooooo00Go00000_ooool00ol0003ooooo
ooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool5o`0000Sooooo00?o0000ooooool00000COooool00?_ooooo
00Go0000ooooooooooooooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000?ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0004kooooo003ioooo
o`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo0_l000001?oooooo0000oooooooo
ool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1?l0
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
2Oooool00ol0003oooooo`00001=ooooo`00nOooool01Ol0003oooooo`000?oooooo000002Kooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool0001<ooooo`00nOooool5o`0002Kooooo
00?o0000ooooooooool06_ooool3o`000003ooooool0003o000004_ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 401.875}, {247.938, 0}} -> {0.575944, 173.276, \
0.00147111, 3.98205}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Now do the same for the A-rich compositions, adding the points to \
CoexCurvePts. Note I'm adding the point at the top of the miscibility gap as \
well. Also, I could have made use of the fact that the coexistence curve is \
symmetric about XB = 0.5, but I calculated the points instead.\
\>", "Text"],

Cell[BoxData[{
    \(\(CoexCurvePts = 
        Prepend[CoexCurvePts, {0.5, 1000}];\)\), "\[IndentingNewLine]", 
    \(\(XBCoex[\([1, 2]\)] = 0.4;\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]XBCoex = 
        FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 0, {XB, 
            XBCoex[\([1, 2]\)]}]; \[IndentingNewLine]CoexCurvePts = 
        Prepend[CoexCurvePts, {XBCoex[\([1, 2]\)], T}], {T, 990, 
        300, \(-10\)}]\)}], "Input"],

Cell["Here is the calculated equilibrium diagram", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoexPlot = 
      ListPlot[CoexCurvePts, PlotJoined \[Rule] True, \ 
        AxesLabel \[Rule] {"\<Atom Fraction,XB\>", "\<Temperature,K\>"}, 
        PlotStyle \[Rule] {Thickness[0.005]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.953614 -0.237544 0.000840863 [
[.21453 .00222 -9 -9 ]
[.21453 .00222 9 0 ]
[.40526 .00222 -9 -9 ]
[.40526 .00222 9 0 ]
[.59598 .00222 -9 -9 ]
[.59598 .00222 9 0 ]
[.7867 .00222 -9 -9 ]
[.7867 .00222 9 0 ]
[.97742 .00222 -3 -9 ]
[.97742 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -41 0 ]
[.02381 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21453 .01472 m
.21453 .02097 L
s
[(0.2)] .21453 .00222 0 1 Mshowa
.40526 .01472 m
.40526 .02097 L
s
[(0.4)] .40526 .00222 0 1 Mshowa
.59598 .01472 m
.59598 .02097 L
s
[(0.6)] .59598 .00222 0 1 Mshowa
.7867 .01472 m
.7867 .02097 L
s
[(0.8)] .7867 .00222 0 1 Mshowa
.97742 .01472 m
.97742 .02097 L
s
[(1)] .97742 .00222 0 1 Mshowa
.125 Mabswid
.07149 .01472 m
.07149 .01847 L
s
.11917 .01472 m
.11917 .01847 L
s
.16685 .01472 m
.16685 .01847 L
s
.26221 .01472 m
.26221 .01847 L
s
.30989 .01472 m
.30989 .01847 L
s
.35757 .01472 m
.35757 .01847 L
s
.45294 .01472 m
.45294 .01847 L
s
.50062 .01472 m
.50062 .01847 L
s
.5483 .01472 m
.5483 .01847 L
s
.64366 .01472 m
.64366 .01847 L
s
.69134 .01472 m
.69134 .01847 L
s
.73902 .01472 m
.73902 .01847 L
s
.83438 .01472 m
.83438 .01847 L
s
.88206 .01472 m
.88206 .01847 L
s
.92974 .01472 m
.92974 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0988 m
.03006 .0988 L
s
[(400)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(500)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(600)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(700)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(800)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(900)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.005 w
.02504 .01472 m
.02534 .02312 L
.02569 .03153 L
.02609 .03994 L
.02655 .04835 L
.02707 .05676 L
.02765 .06517 L
.0283 .07358 L
.02901 .08198 L
.0298 .09039 L
.03066 .0988 L
.03161 .10721 L
.03263 .11562 L
.03374 .12403 L
.03493 .13244 L
.03622 .14084 L
.03759 .14925 L
.03907 .15766 L
.04063 .16607 L
.0423 .17448 L
.04407 .18289 L
.04595 .1913 L
.04793 .1997 L
.05002 .20811 L
.05223 .21652 L
.05455 .22493 L
.05699 .23334 L
.05955 .24175 L
.06224 .25016 L
.06505 .25857 L
.06799 .26697 L
.07107 .27538 L
.07429 .28379 L
.07765 .2922 L
.08115 .30061 L
.08481 .30902 L
.08862 .31743 L
.09259 .32583 L
.09673 .33424 L
.10103 .34265 L
.10552 .35106 L
.11019 .35947 L
.11504 .36788 L
.1201 .37629 L
.12536 .38469 L
.13084 .3931 L
.13655 .40151 L
.1425 .40992 L
.14869 .41833 L
.15515 .42674 L
Mistroke
.16189 .43515 L
.16892 .44356 L
.17627 .45196 L
.18396 .46037 L
.19202 .46878 L
.20047 .47719 L
.20934 .4856 L
.21869 .49401 L
.22855 .50242 L
.239 .51082 L
.25009 .51923 L
.26192 .52764 L
.27461 .53605 L
.28831 .54446 L
.30323 .55287 L
.31968 .56128 L
.33811 .56968 L
.3593 .57809 L
.38476 .5865 L
.41836 .59491 L
.50062 .60332 L
.58287 .59491 L
.61647 .5865 L
.64193 .57809 L
.66313 .56968 L
.68156 .56128 L
.698 .55287 L
.71292 .54446 L
.72662 .53605 L
.73931 .52764 L
.75115 .51923 L
.76224 .51082 L
.77268 .50242 L
.78254 .49401 L
.79189 .4856 L
.80077 .47719 L
.80922 .46878 L
.81727 .46037 L
.82496 .45196 L
.83231 .44356 L
.83935 .43515 L
.84608 .42674 L
.85254 .41833 L
.85874 .40992 L
.86468 .40151 L
.87039 .3931 L
.87587 .38469 L
.88113 .37629 L
.88619 .36788 L
.89105 .35947 L
Mistroke
.89572 .35106 L
.9002 .34265 L
.90451 .33424 L
.90864 .32583 L
.91261 .31743 L
.91642 .30902 L
.92008 .30061 L
.92358 .2922 L
.92694 .28379 L
.93016 .27538 L
.93324 .26697 L
.93618 .25857 L
.939 .25016 L
.94168 .24175 L
.94424 .23334 L
.94668 .22493 L
.949 .21652 L
.95121 .20811 L
.9533 .1997 L
.95529 .1913 L
.95716 .18289 L
.95893 .17448 L
.9606 .16607 L
.96217 .15766 L
.96364 .14925 L
.96502 .14084 L
.9663 .13244 L
.96749 .12403 L
.9686 .11562 L
.96963 .10721 L
.97057 .0988 L
.97143 .09039 L
.97222 .08198 L
.97294 .07358 L
.97358 .06517 L
.97416 .05676 L
.97468 .04835 L
.97514 .03994 L
.97554 .03153 L
.97589 .02312 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool007Cooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000A?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0004?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00015ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000B_ooool3o`0007Wooooo
001cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000@oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000004[ooooo00?o0000ooooooooool0N?ooool007?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00012oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo07So
oooo001cooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0@_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0004?ooooo00Co0000oooooooooooo00001ooo
ool4o`0004Cooooo00Co0000oooooooooooo00002?ooool3o`0004_ooooo00?o0000ooooooooool0
N?ooool007?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004?o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000013ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool00000B_ooool00ol0003oooooooooo`1hooooo`00Loooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000@oooool01?l0003oooooooooool00009oooo
o`;o0000@oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo04Cooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004Wooooo0_l0001jooooo`00M?oo
ool2o`0000Wooooo0ol00015ooooo`;o00002oooool00ol0003oooooooooo`12ooooo`;o00002_oo
ool2o`0004Gooooo0_l00009ooooo`?o0000Boooool00ol0003oooooooooo`1hooooo`00:Oooool0
0ol0003oooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooo
oaKooooo000Yooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`03o`000?oooooooooo017o
oooo000Yooooo`03o`000?oooooooooo0?ooooooooooool3ooooo`03o`000?oooooooooo013ooooo
000Yooooo`03o`000?oooooooooo0?oooooo/Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo0ol00003ooooo`?o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000oooo
o`Co00001_ooool002Wooooo00?o0000ooooooooool0oooooonaooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo000Noooooooo0000]?l0000;ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool002Sooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo0ol0000Foooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool02ol0003ooooooooooooooooo
0000ooooool0003oooooo`000?oooooo000000Sooooo0ol00003ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool3o`0000Kooooo000Xooooo`;o00004ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0@ooooo`?o00005_ooool00ol0003oooooo`000002ooooo`Co00000ooo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001?ooool3o`0000;ooooo1?l00002ooooo`?o00001?oo
ool3o`0000;ooooo1?l0000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1Oooool002Sooooo0_l0001Aooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04kooooo0ol0000Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0000Dooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`00
:?ooool2o`000?ooooooVoooool2o`0001Oooooo0_l00004ooooo`03o`000?oooooooooo01Cooooo
1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool2o`000004oooo
ool0003o0000ooooo`Co00001_ooool002Sooooo0_l0003ooooooi_ooooo0_l0001jooooo`00:?oo
ool2o`000?ooooooVoooool2o`0007[ooooo000Xooooo`?o0000oooooonJooooo`;o0000N_ooool0
02Sooooo0_l0003ooooooi_ooooo0_l0001jooooo`00:?ooool2o`000?ooooooVoooool2o`0007[o
oooo000Xooooo`;o0000oooooonKooooo`;o0000N_ooool002Sooooo0_l0003ooooooi_ooooo0_l0
001jooooo`00:?ooool2o`000?ooooooVoooool2o`0007[ooooo000Xooooo`;o0000oooooonKoooo
o`;o0000N_ooool002Sooooo0ol0003ooooooi[ooooo0_l0001jooooo`00:Oooool2o`000?oooooo
V_ooool2o`0007[ooooo000Yooooo`;o0000oooooonJooooo`;o0000N_ooool002Wooooo0_l0003o
oooooiWooooo0ol0001jooooo`00:Oooool2o`000?ooooooVOooool2o`0007_ooooo000Yooooo`;o
0000oooooonIooooo`;o0000Noooool002Wooooo0_l0003ooooooiWooooo0_l0001kooooo`00:Ooo
ool2o`000?ooooooVOooool2o`0007_ooooo000Yooooo`;o0000oooooonIooooo`;o0000Noooool0
02Wooooo0_l0003ooooooiWooooo0_l0001kooooo`00:Oooool2o`000?ooooooVOooool2o`0007_o
oooo000Yooooo`;o0000oooooonIooooo`;o0000Noooool002Wooooo0_l0003ooooooiWooooo0_l0
001kooooo`00:Oooool2o`000?ooooooVOooool2o`0007_ooooo000Yooooo`?o0000oooooonHoooo
o`;o0000Noooool002Wooooo0ol0003ooooooiSooooo0_l0001kooooo`00:Oooool3o`000?oooooo
V?ooool2o`0007_ooooo000Yooooo`?o0000oooooonHooooo`;o0000Noooool002Wooooo0ol0003o
oooooiOooooo0ol0001kooooo`00:Oooool3o`000?ooooooUoooool2o`0007cooooo000Cooooo`?o
00000oooool2o`0000Cooooo0_l00008ooooo`?o0000oooooonGooooo`;o0000O?ooool001Cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool3o`000?ooooooUoooool2o`0007cooooo000Aooooo`Go00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo0ol0003ooooooiOooooo0_l0001l
ooooo`004Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool3o`000?ooooooUoooool2o`0007cooooo000Booooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`?o
0000oooooonGooooo`;o0000O?ooool001?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool4o`000?ooooooUOooool3o`0007cooooo000Dooooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00002?ooool01?l0003oooooo`000?l0003ooooo
oiGooooo0_l0001mooooo`00:Oooool01?l0003oooooo`000?l0003ooooooiGooooo0_l0001moooo
o`00:Oooool01?l0003oooooo`000?l0003ooooooiGooooo0_l0001mooooo`00:Oooool01?l0003o
ooooo`000?l0003ooooooiGooooo0_l0001mooooo`00:Oooool4o`000?ooooooUOooool2o`0007go
oooo000Yooooo`04o`000?oooooo0000o`000?ooooooUOooool2o`0007gooooo000Yooooo`03o`00
0?oooooo000000;o0000oooooonCooooo`?o0000OOooool002Wooooo00?o0000ooooooooool00_l0
003ooooooi?ooooo0_l0001nooooo`00:Oooool00ol0003oooooooooo`02o`000?ooooooToooool2
o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000oooooonCooooo`;o0000O_ooool002Wo
oooo00?o0000ooooooooool00_l0003ooooooi?ooooo0_l0001nooooo`00:Oooool2o`000003oooo
ool0003o00000?ooooooToooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000oooo
oonCooooo`;o0000O_ooool002Wooooo00?o0000ooooooooool00_l0003ooooooi?ooooo0_l0001n
ooooo`00:Oooool00ol0003oooooooooo`03o`000?ooooooTOooool3o`0007kooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000oooooonAooooo`;o0000Ooooool002Wooooo00Co0000oooooooo
oooooooo0_l0003ooooooi7ooooo0_l0001oooooo`00:Oooool01?l0003oooooooooooooool2o`00
0?ooooooTOooool2o`0007oooooo000Yooooo`;o00000_ooool2o`000?ooooooTOooool2o`0007oo
oooo000Yooooo`04o`000?ooooooooooooooo`;o0000oooooonAooooo`;o0000Ooooool002Wooooo
00Co0000oooooooooooooooo0_l0003ooooooi7ooooo0_l0001oooooo`00:Oooool01?l0003ooooo
ooooooooool3o`000?ooooooSoooool3o`0007oooooo000Yooooo`03o`000?oooooooooo00;ooooo
0_l0003oooooohoooooo0_l00020ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000oooo
oon?ooooo`;o0000P?ooool002Wooooo00?o0000ooooooooool00_ooool2o`000?ooooooSoooool2
o`00083ooooo000Yooooo`03o`000?oooooooooo00;ooooo0ol0003oooooohgooooo0ol00020oooo
o`00:Oooool2o`0000Cooooo0_l0003oooooohgooooo0_l00021ooooo`00:Oooool00ol0003ooooo
ooooo`03ooooo`;o0000oooooon=ooooo`;o0000POooool002Wooooo00?o0000ooooooooool00ooo
ool3o`000?ooooooS?ooool2o`00087ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0003o
ooooohcooooo0_l00021ooooo`004_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`;o0000oooooon<ooooo`;o0000POooool0017ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`04ooooo`;o0000oooooon<ooooo`;o0000POooool001Gooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`000?ooooooRoooool3o`00087ooooo000Eooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`?o
00001?ooool2o`000?ooooooRoooool2o`0008;ooooo000Aooooo`Co00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool2o`00
0?ooooooRoooool2o`0008;ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Cooooo0_l0003o
oooooh_ooooo0_l00022ooooo`004Oooool5o`0000?ooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`?o0000oooooon9ooooo`?o0000P_ooool002Wooooo00?o0000oooooooo
ool01Oooool2o`000?ooooooROooool2o`0008?ooooo000Yooooo`03o`000?oooooooooo00Gooooo
0_l0003oooooohWooooo0_l00023ooooo`00:Oooool00ol0003oooooooooo`05ooooo`?o0000oooo
oon7ooooo`?o0000Poooool002Wooooo0_l00007ooooo`;o0000oooooon7ooooo`;o0000Q?ooool0
02Wooooo00?o0000ooooooooool01_ooool2o`000?ooooooQoooool2o`0008Cooooo000Yooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooohOooooo0_l00024ooooo`00:Oooool00ol0003ooooo
ooooo`06ooooo`?o0000oooooon5ooooo`?o0000Q?ooool002Wooooo00?o0000ooooooooool01ooo
ool2o`000?ooooooQOooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0003o
ooooohGooooo0_l00025ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o0000oooooon5oooo
o`;o0000QOooool002Wooooo00?o0000ooooooooool01oooool3o`000?ooooooPoooool3o`0008Go
oooo000Yooooo`;o00002Oooool2o`000?ooooooPoooool2o`0008Kooooo000Yooooo`03o`000?oo
oooooooo00Sooooo0_l0003ooooooh?ooooo0_l00026ooooo`00:Oooool00ol0003oooooooooo`08
ooooo`?o0000oooooon1ooooo`?o0000Q_ooool002Wooooo00?o0000ooooooooool02Oooool2o`00
0?ooooooPOooool2o`0008Oooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0003ooooooh7o
oooo0_l00027ooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000oooooon1ooooo`;o0000
Qoooool002Wooooo00?o0000ooooooooool02Oooool3o`000?ooooooOoooool3o`0008Oooooo000Y
ooooo`;o00002oooool2o`000?ooooooOoooool2o`0008Sooooo000Yooooo`03o`000?oooooooooo
00[ooooo0_l0003oooooogoooooo0_l00028ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`?o
0000oooooommooooo`?o0000R?ooool002Wooooo00?o0000ooooooooool02oooool2o`000?oooooo
OOooool2o`0008Wooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0003ooooooggooooo0_l0
0029ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000oooooommooooo`;o0000ROooool0
02Wooooo00?o0000ooooooooool02oooool3o`000?ooooooNoooool3o`0008Wooooo000Yooooo`;o
00003Oooool2o`000?ooooooNoooool2o`0008[ooooo000Yooooo`03o`000?oooooooooo00cooooo
0_l0003oooooog_ooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000oooo
oomkooooo`;o0000R_ooool002Wooooo00?o0000ooooooooool03?ooool3o`000?ooooooNOooool3
o`0008[ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0003oooooogWooooo0_l0002;oooo
o`004_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`;o
0000oooooomiooooo`;o0000Roooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0=
ooooo`?o0000oooooomgooooo`?o0000Roooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3o`0000kooooo
0ol0003oooooogKooooo0_l0002<ooooo`004Oooool4o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00oooooo0_l0003oooooogKo
oooo0_l0002<ooooo`004Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0?ooooo`;o0000oooooomeoooo
o`?o0000S?ooool001;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool03oooool3o`000?ooooooM?ooool2
o`0008gooooo000Cooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
013ooooo0_l0003oooooog?ooooo0ol0002=ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o
0000oooooomcooooo`;o0000S_ooool002Wooooo00?o0000ooooooooool04?ooool2o`000?oooooo
Loooool2o`0008kooooo000Yooooo`03o`000?oooooooooo013ooooo0ol0003oooooog7ooooo0ol0
002>ooooo`00:Oooool2o`0001;ooooo0_l0003oooooog7ooooo0_l0002?ooooo`00:Oooool00ol0
003oooooooooo`0Aooooo`;o0000oooooomaooooo`;o0000Soooool002Wooooo00?o0000oooooooo
ool04Oooool3o`000?ooooooKoooool3o`0008oooooo000Yooooo`03o`000?oooooooooo01;ooooo
0ol0003oooooofgooooo0ol0002@ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o0000oooo
oom]ooooo`;o0000TOooool002Wooooo00?o0000ooooooooool04oooool2o`000?ooooooKOooool2
o`00097ooooo000Yooooo`03o`000?oooooooooo01?ooooo0ol0003oooooof_ooooo0ol0002Aoooo
o`00:Oooool2o`0001Gooooo0_l0003oooooof_ooooo0_l0002Booooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`;o0000oooooom[ooooo`;o0000T_ooool002Wooooo00?o0000ooooooooool05?oo
ool3o`000?ooooooJOooool3o`0009;ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0003o
ooooofWooooo0_l0002Cooooo`00:Oooool00ol0003oooooooooo`0Eooooo`?o0000oooooomWoooo
o`?o0000Toooool002Wooooo00?o0000ooooooooool05_ooool2o`000?ooooooIoooool2o`0009Co
oooo000Yooooo`03o`000?oooooooooo01Kooooo0ol0003oooooofGooooo0ol0002Dooooo`00:Ooo
ool2o`0001Sooooo0ol0003oooooofCooooo0_l0002Eooooo`00:Oooool00ol0003oooooooooo`0H
ooooo`;o0000oooooomTooooo`;o0000UOooool002Wooooo00?o0000ooooooooool06?ooool2o`00
0?ooooooHoooool3o`0009Gooooo000Yooooo`03o`000?oooooooooo01Sooooo0ol0003oooooof;o
oooo0_l0002Fooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000oooooomQooooo`?o0000
U_ooool002Wooooo00?o0000ooooooooool06Oooool2o`000?ooooooHOooool2o`0009Oooooo000Y
ooooo`03o`000?oooooooooo01Wooooo0ol0003ooooooeoooooo0ol0002Gooooo`00:Oooool00ol0
003oooooooooo`0Jooooo`;o0000oooooomOooooo`;o0000V?ooool002Wooooo0_l0000Kooooo`?o
0000oooooomMooooo`?o0000V?ooool002Wooooo00?o0000ooooooooool06oooool2o`000?oooooo
GOooool2o`0009Wooooo000Yooooo`03o`000?oooooooooo01_ooooo0ol0003ooooooe_ooooo0ol0
002Iooooo`00:Oooool00ol0003oooooooooo`0Looooo`?o0000oooooomIooooo`?o0000V_ooool0
01?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
01gooooo0_l0003ooooooeWooooo0_l0002Kooooo`004oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0M
ooooo`?o0000oooooomGooooo`?o0000Voooool001Cooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Nooooo`;o0000oooooomGooooo`;o0000W?ooool001Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool3o`0001kooooo
0ol0003ooooooeGooooo0ol0002Looooo`005Oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`;o
0000oooooomEooooo`;o0000WOooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0O
ooooo`?o0000oooooomCooooo`?o0000WOooool0017ooooo1Ol00003ooooo`;o00001?ooool2o`00
00Sooooo00?o0000ooooooooool08?ooool3o`000?ooooooDOooool3o`0009kooooo000Yooooo`03
o`000?oooooooooo027ooooo0_l0003ooooooe7ooooo0_l0002Oooooo`00:Oooool00ol0003ooooo
ooooo`0Qooooo`?o0000oooooom?ooooo`?o0000Woooool002Wooooo00?o0000ooooooooool08_oo
ool2o`000?ooooooCoooool2o`000:3ooooo000Yooooo`;o00008oooool3o`000?ooooooCOooool3
o`000:3ooooo000Yooooo`03o`000?oooooooooo02?ooooo0_l0003oooooodgooooo0_l0002Qoooo
o`00:Oooool00ol0003oooooooooo`0Sooooo`?o0000oooooom;ooooo`?o0000XOooool002Wooooo
00?o0000ooooooooool09?ooool2o`000?ooooooBoooool2o`000:;ooooo000Yooooo`03o`000?oo
oooooooo02Cooooo0ol0003oooooodWooooo0ol0002Rooooo`00:Oooool00ol0003oooooooooo`0U
ooooo`?o0000oooooom8ooooo`;o0000Xoooool002Wooooo00?o0000ooooooooool09_ooool3o`00
0?ooooooA_ooool3o`000:?ooooo000Yooooo`;o0000:?ooool3o`000?ooooooA?ooool3o`000:Co
oooo000Yooooo`03o`000?oooooooooo02Sooooo0_l0003oooooodCooooo0_l0002Uooooo`00:Ooo
ool00ol0003oooooooooo`0Xooooo`?o0000oooooom2ooooo`?o0000YOooool002Wooooo00?o0000
ooooooooool0:Oooool2o`000?oooooo@Oooool3o`000:Kooooo000Yooooo`03o`000?oooooooooo
02Wooooo0ol0003oooooocoooooo0ol0002Wooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o
0000ooooooloooooo`;o0000Z?ooool002Wooooo00?o0000ooooooooool0:_ooool3o`000?oooooo
?Oooool3o`000:Sooooo000Yooooo`03o`000?oooooooooo02_ooooo0_l0003oooooocgooooo0_l0
002Yooooo`00:Oooool2o`0002cooooo0ol0003ooooooc_ooooo0ol0002Yooooo`00:Oooool00ol0
003oooooooooo`0/ooooo`?o0000ooooooliooooo`?o0000Z_ooool002Wooooo00?o0000oooooooo
ool0;Oooool3o`000?oooooo=oooool3o`000:_ooooo000Yooooo`03o`000?oooooooooo02kooooo
0ol0003oooooocGooooo0ol0002/ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o0000oooo
ooleooooo`;o0000[Oooool002Wooooo00?o0000ooooooooool0;oooool3o`000?oooooo<oooool3
o`000:gooooo000Yooooo`03o`000?oooooooooo033ooooo0ol0003ooooooc;ooooo0_l0002^oooo
o`00:Oooool2o`0003;ooooo0ol0003ooooooc3ooooo0ol0002^ooooo`00:Oooool00ol0003ooooo
ooooo`0booooo`;o0000ooooool`ooooo`;o0000[oooool002Wooooo00?o0000ooooooooool0<_oo
ool3o`000?oooooo;_ooool3o`000:oooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l0003o
ooooobgooooo0ol0002`ooooo`00:Oooool00ol0003oooooooooo`0cooooo`?o0000ooooool[oooo
o`?o0000/Oooool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000oooooooo
ool0=?ooool3o`000?oooooo:Oooool3o`000;;ooooo000Aooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0=Oooool3o`000?oooooo9oooool3o`000;?ooooo000Aooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo
0ol0000fooooo`?o0000oooooolUooooo`?o0000]?ooool001;ooooo0ol00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0gooooo`;o
0000oooooolUooooo`;o0000]Oooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0g
ooooo`?o0000oooooolSooooo`?o0000]Oooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0hooooo`?o0000oooooolQooooo`?o0000]_ooool001;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Sooooo00?o0000ooooooooool0>Oooool3o`000?oooooo7oooool3o`000;Oooooo000Y
ooooo`03o`000?oooooooooo03[ooooo0ol0003ooooooakooooo0_l0002hooooo`00:Oooool00ol0
003oooooooooo`0kooooo`?o0000oooooolLooooo`?o0000^?ooool002Wooooo00?o0000oooooooo
ool0??ooool3o`000?oooooo6_ooool3o`000;Wooooo000Yooooo`;o0000?_ooool3o`000?oooooo
5oooool4o`000;[ooooo000Yooooo`03o`000?oooooooooo03kooooo0ol0003ooooooaGooooo1?l0
002kooooo`00:Oooool00ol0003oooooooooo`0oooooo`?o0000oooooolCooooo`?o0000_Oooool0
02Wooooo00?o0000ooooooooool0@?ooool3o`000?oooooo4Oooool3o`000;kooooo000Yooooo`03
o`000?oooooooooo047ooooo0_l0003ooooooa7ooooo0_l0002oooooo`00:Oooool00ol0003ooooo
ooooo`11ooooo`?o0000ooooool?ooooo`?o0000_oooool002Wooooo00?o0000ooooooooool0@_oo
ool3o`000?oooooo3Oooool3o`000<3ooooo000Yooooo`;o0000A?ooool3o`000?oooooo2oooool3
o`000<7ooooo000Yooooo`03o`000?oooooooooo04Cooooo0ol0003oooooo`Wooooo0ol00032oooo
o`00:Oooool00ol0003oooooooooo`15ooooo`?o0000ooooool7ooooo`?o0000`oooool002Wooooo
00?o0000ooooooooool0A_ooool3o`000?oooooo1Oooool3o`000<Cooooo000Yooooo`03o`000?oo
oooooooo04Oooooo1?l0003oooooo`7ooooo1?l00035ooooo`00:Oooool00ol0003oooooooooo`18
ooooo`Co0000o_ooool4o`000<Kooooo000Yooooo`03o`000?oooooooooo04[ooooo0ol0003loooo
o`?o0000b?ooool002Wooooo0_l0001<ooooo`?o0000n_ooool3o`000<Wooooo000Yooooo`03o`00
0?oooooooooo04cooooo0ol0003hooooo`?o0000b_ooool002Wooooo00?o0000ooooooooool0COoo
ool3o`000?Kooooo0ol0003;ooooo`00:Oooool00ol0003oooooooooo`1>ooooo`?o0000m?ooool3
o`000<cooooo000Yooooo`03o`000?oooooooooo04oooooo1?l0003`ooooo`Co0000cOooool002Wo
oooo00?o0000ooooooooool0D?ooool4o`000>kooooo1?l0003>ooooo`00:Oooool00ol0003ooooo
ooooo`1Booooo`?o0000k?ooool3o`000=3ooooo000Yooooo`;o0000E?ooool4o`000>Wooooo0ol0
003Aooooo`00:Oooool00ol0003oooooooooo`1Dooooo`Co0000ioooool3o`000=;ooooo000Yoooo
o`03o`000?oooooooooo05Kooooo0ol0003Uooooo`?o0000doooool002Wooooo00?o0000oooooooo
ool0Eoooool3o`000>?ooooo0ol0003Dooooo`00:Oooool00ol0003oooooooooo`1Hooooo`Co0000
goooool4o`000=Gooooo000Booooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`03o`000?oo
oooooooo05Wooooo1?l0003Mooooo`Co0000e_ooool001Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Kooooo`?o0000foooool3o`000=Sooooo000Eooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05co
oooo0ol0003Iooooo`?o0000fOooool001;ooooo1?l00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool3o`0005gooooo1?l0003Eooooo`Co0000f_ooool0017o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`1Nooooo`Go0000dOooool5o`000=_ooooo000A
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0H?ooool4o`000<oooooo1?l0003Mooooo`00
4_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`1Rooooo`Co0000
boooool4o`000=oooooo000Yooooo`03o`000?oooooooooo06?ooooo1?l00039ooooo`Co0000h?oo
ool002Wooooo00?o0000ooooooooool0IOooool3o`000<Kooooo1?l0003Rooooo`00:Oooool00ol0
003oooooooooo`1Vooooo`?o0000a?ooool4o`000>?ooooo000Yooooo`;o0000J?ooool4o`000<3o
oooo1?l0003Uooooo`00:Oooool00ol0003oooooooooo`1Xooooo`Co0000__ooool4o`000>Kooooo
000Yooooo`03o`000?oooooooooo06[ooooo1?l0002jooooo`Co0000j?ooool002Wooooo00?o0000
ooooooooool0Joooool4o`000;Sooooo1?l0003Yooooo`00:Oooool00ol0003oooooooooo`1]oooo
o`Co0000]?ooool4o`000>_ooooo000Yooooo`03o`000?oooooooooo06kooooo1_l0002_ooooo`Go
0000k?ooool002Wooooo00?o0000ooooooooool0L?ooool6o`000:_ooooo1Ol0003^ooooo`00:Ooo
ool2o`0007Cooooo1Ol0002Wooooo`Go0000l?ooool002Wooooo00?o0000ooooooooool0MOooool5
o`000:?ooooo1Ol0003booooo`00:Oooool00ol0003oooooooooo`1gooooo`Co0000XOooool4o`00
0?Cooooo000Yooooo`03o`000?oooooooooo07Wooooo1?l0002Mooooo`Co0000m_ooool002Wooooo
00?o0000ooooooooool0N_ooool5o`0009Wooooo1Ol0003gooooo`00:Oooool00ol0003ooooooooo
o`1looooo`Go0000UOooool5o`000?Wooooo000Yooooo`03o`000?oooooooooo07kooooo1Ol0002A
ooooo`Go0000noooool002Wooooo00?o0000ooooooooool0P?ooool5o`0008gooooo1Ol0003moooo
o`00:Oooool2o`0008?ooooo1_l00027ooooo`Ko0000ooooool002Wooooo00?o0000ooooooooool0
Q?ooool7o`00087ooooo1ol0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo08Oooooo1ol0
001kooooo`Oo0000ooooool5ooooo`00:Oooool00ol0003oooooooooo`2:ooooo`Ko0000M_ooool7
o`000?oooooo2?ooool002Wooooo00?o0000ooooooooool0SOooool6o`00073ooooo1ol0003ooooo
o`_ooooo000Yooooo`03o`000?oooooooooo08oooooo1ol0001Zooooo`Oo0000ooooool>ooooo`00
:Oooool00ol0003oooooooooo`2Booooo`Oo0000I?ooool7o`000?oooooo4Oooool002Wooooo0_l0
002Fooooo`Oo0000G_ooool7o`000?oooooo5?ooool002Wooooo00?o0000ooooooooool0V?ooool7
o`0005Sooooo1ol0003ooooooaOooooo000Yooooo`03o`000?oooooooooo09_ooooo2?l0001@oooo
o`So0000oooooolJooooo`00:Oooool00ol0003oooooooooo`2Nooooo`So0000B_ooool8o`000?oo
oooo7Oooool002Wooooo00?o0000ooooooooool0X_ooool<o`0003[ooooo3?l0003oooooob7ooooo
000<ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003ooooooooo
o`2UoooooaGo00008_oooolEo`000?oooooo9?ooool000gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`2]oooooaWo00002_oooolIo`000?oooooo;?ooool000gooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001oooool3o`000;Wooooo9?l0003oooooocSooooo000=oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0aOooool<o`000?oooooo
A?ooool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3ooooo
oooooooo5_ooool000cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oooooooooo
oolFooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00008
ooooo`03o`000?oooooooooo0?oooooooooooolFooooo`00:Oooool00ol0003oooooooooo`3ooooo
oooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooooaKooooo000Yooooo`03o`00
0?oooooooooo0?oooooooooooolFooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool001Cooooo0ol0000_ooooo`03o`000?oooooo
oooo0?oooooon?ooool001Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3ooooo
ooOooooo0003ooooo`?o00000oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002oooo
o`?o00000oooool3o`0000;ooooo0ol00004ooooo`Co00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo00?o000000?oooooo`00
0?l00000oooooooaooooo`001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ool0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
1?l0003oooooooooool0003ooooooo;ooooo0004ooooo`04o`000?ooooooooooooooo`Go000000Ko
ooooo`000?oooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool01Ol00002oooo
o`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00002?ooool00ol0003oooooo`00003o
oooooo?ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo
0_l0003oooooooCooooo0002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo
0_l000001?oooooo0000ooooooooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002ooooo`?o00002Oooool00ol0003oooooo`00003ooooooo?ooooo0002ooooo`05
o`000?oooooo0000ooooool000009_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`000?ooooool_ooool000;ooooo1Ol0000Vooooo`03o`000?oooooooooo01[ooooo0ol000000ooo
oooo0000o`00003ooooooo7ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;o
oooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooo
oooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_oo
ool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0992175, 183.273, \
0.00241982, 2.7443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The same basic process can be used to calculate and plot the \
spinodals. I collect the two branches of the curve in separate arrays.\
\>", \
"Text"],

Cell[BoxData[{
    \(\(SpinodalCurvePtsR = {};\)\), "\[IndentingNewLine]", 
    \(\(SpinodalCurvePtsL = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]XBSpin = 
        Flatten[Solve[\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, T] == 
              0, {XB}]]; \[IndentingNewLine]SpinodalCurvePtsR = 
        Append[SpinodalCurvePtsR, {XBSpin[\([2, 2]\)], 
            T}]; \[IndentingNewLine]SpinodalCurvePtsL = 
        Append[SpinodalCurvePtsL, {XBSpin[\([1, 2]\)], T}], {T, 990, 
        300, \(-10\)}]\)}], "Input"],

Cell["\<\
Now add in the point at the top of the spinodal curve, join the two \
branches of the curve into a single ordered list, and plot the results.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SpinodalCurvePts = 
        Prepend[SpinodalCurvePtsR, {0.5, 1000}];\)\), "\[IndentingNewLine]", 
    \(\(SpinodalCurvePts = 
        Join[Reverse[SpinodalCurvePtsL], 
          SpinodalCurvePts];\)\), "\[IndentingNewLine]", 
    \(SpinodalPlot = 
      ListPlot[SpinodalCurvePts, 
        AxesLabel \[Rule] {"\<Atom Fraction,XB\>", "\<Temperature,K\>"}, 
        PlotJoined \[Rule] True]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.03708 -0.237544 0.000840863 [
[.23123 .00222 -9 -9 ]
[.23123 .00222 9 0 ]
[.43864 .00222 -9 -9 ]
[.43864 .00222 9 0 ]
[.64606 .00222 -9 -9 ]
[.64606 .00222 9 0 ]
[.85347 .00222 -9 -9 ]
[.85347 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -41 0 ]
[.02381 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23123 .01472 m
.23123 .02097 L
s
[(0.2)] .23123 .00222 0 1 Mshowa
.43864 .01472 m
.43864 .02097 L
s
[(0.4)] .43864 .00222 0 1 Mshowa
.64606 .01472 m
.64606 .02097 L
s
[(0.6)] .64606 .00222 0 1 Mshowa
.85347 .01472 m
.85347 .02097 L
s
[(0.8)] .85347 .00222 0 1 Mshowa
.125 Mabswid
.07566 .01472 m
.07566 .01847 L
s
.12752 .01472 m
.12752 .01847 L
s
.17937 .01472 m
.17937 .01847 L
s
.28308 .01472 m
.28308 .01847 L
s
.33493 .01472 m
.33493 .01847 L
s
.38679 .01472 m
.38679 .01847 L
s
.4905 .01472 m
.4905 .01847 L
s
.54235 .01472 m
.54235 .01847 L
s
.5942 .01472 m
.5942 .01847 L
s
.69791 .01472 m
.69791 .01847 L
s
.74976 .01472 m
.74976 .01847 L
s
.80162 .01472 m
.80162 .01847 L
s
.90533 .01472 m
.90533 .01847 L
s
.95718 .01472 m
.95718 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0988 m
.03006 .0988 L
s
[(400)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(500)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(600)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(700)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(800)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(900)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.10851 .01472 m
.11162 .02312 L
.11475 .03153 L
.11791 .03994 L
.12109 .04835 L
.12429 .05676 L
.12752 .06517 L
.13077 .07358 L
.13405 .08198 L
.13736 .09039 L
.14069 .0988 L
.14405 .10721 L
.14744 .11562 L
.15086 .12403 L
.15431 .13244 L
.15779 .14084 L
.1613 .14925 L
.16485 .15766 L
.16842 .16607 L
.17204 .17448 L
.17569 .18289 L
.17937 .1913 L
.18309 .1997 L
.18686 .20811 L
.19066 .21652 L
.1945 .22493 L
.19839 .23334 L
.20232 .24175 L
.2063 .25016 L
.21032 .25857 L
.2144 .26697 L
.21852 .27538 L
.2227 .28379 L
.22693 .2922 L
.23123 .30061 L
.23558 .30902 L
.23999 .31743 L
.24447 .32583 L
.24902 .33424 L
.25364 .34265 L
.25833 .35106 L
.26311 .35947 L
.26796 .36788 L
.27291 .37629 L
.27794 .38469 L
.28308 .3931 L
.28832 .40151 L
.29367 .40992 L
.29913 .41833 L
.30472 .42674 L
Mistroke
.31045 .43515 L
.31632 .44356 L
.32235 .45196 L
.32855 .46037 L
.33493 .46878 L
.34152 .47719 L
.34833 .4856 L
.35539 .49401 L
.36272 .50242 L
.37037 .51082 L
.37837 .51923 L
.38679 .52764 L
.39568 .53605 L
.40516 .54446 L
.41533 .55287 L
.4264 .56128 L
.43864 .56968 L
.45254 .57809 L
.46902 .5865 L
.4905 .59491 L
.54235 .60332 L
.5942 .59491 L
.61568 .5865 L
.63216 .57809 L
.64606 .56968 L
.6583 .56128 L
.66936 .55287 L
.67954 .54446 L
.68901 .53605 L
.69791 .52764 L
.70633 .51923 L
.71433 .51082 L
.72198 .50242 L
.72931 .49401 L
.73637 .4856 L
.74318 .47719 L
.74976 .46878 L
.75615 .46037 L
.76235 .45196 L
.76838 .44356 L
.77425 .43515 L
.77997 .42674 L
.78557 .41833 L
.79103 .40992 L
.79638 .40151 L
.80162 .3931 L
.80675 .38469 L
.81179 .37629 L
.81673 .36788 L
.82159 .35947 L
Mistroke
.82636 .35106 L
.83106 .34265 L
.83568 .33424 L
.84023 .32583 L
.84471 .31743 L
.84912 .30902 L
.85347 .30061 L
.85776 .2922 L
.862 .28379 L
.86618 .27538 L
.8703 .26697 L
.87438 .25857 L
.8784 .25016 L
.88238 .24175 L
.88631 .23334 L
.8902 .22493 L
.89404 .21652 L
.89784 .20811 L
.9016 .1997 L
.90533 .1913 L
.90901 .18289 L
.91266 .17448 L
.91627 .16607 L
.91985 .15766 L
.9234 .14925 L
.92691 .14084 L
.93039 .13244 L
.93384 .12403 L
.93726 .11562 L
.94065 .10721 L
.94401 .0988 L
.94734 .09039 L
.95065 .08198 L
.95393 .07358 L
.95718 .06517 L
.96041 .05676 L
.96361 .04835 L
.96679 .03994 L
.96995 .03153 L
.97308 .02312 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool007_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000Boooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0004_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol0001<ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000ZOooool007[ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool0001:ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool00000B_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
0000Z?ooool007[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1:ooooo`04
o`000?ooooooooooo`0000Oooooo1Ol0001:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00001:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00002Xooooo`00N_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo04Wo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0001;ooooo`04o`000?oooooo
ooooo`0000Oooooo1?l0001;ooooo`04o`000?ooooooooooo`0000Sooooo0ol0002Yooooo`00N_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000B_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000004_ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`1<ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00002Xooooo`00N_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
0000B_ooool01?l0003oooooooooool00009ooooo`;o0000Boooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo00000:Sooooo001kooooo`;o00002Oooool3o`0004cooooo0_l0000;ooooo`03o`000?oo
oooooooo04[ooooo0_l0000:ooooo`;o0000C?ooool2o`0000Wooooo0ol0002Yooooo`00:Oooool0
0ol0003oooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooo
oaKooooo000Yooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`03o`000?oooooooooo017o
oooo000Yooooo`03o`000?oooooooooo0?ooooooooooool3ooooo`03o`000?oooooooooo013ooooo
000Yooooo`03o`000?oooooooooo0?oooooo/Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo0ol00003ooooo`?o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000oooo
o`Co00001_ooool002Wooooo00?o0000ooooooooool0oooooonaooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo000Noooooooo0000]?l0000;ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool002Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02oooo
o`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool3o`0000?o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`?o0000
1_ooool002Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooool000000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?ooool02?ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co00002_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo000Yooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool06oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000Gooooo000Yooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
oooooomcooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`03o`000?oooooooooo01Cooooo
1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool2o`000004oooo
ool0003o0000ooooo`Co00001_ooool002Wooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`3oooooog?ooooo00?o0000ooooooooool0NOooool002Wooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`3oooooog7ooooo00?o0000ooooooooool0N_ooool002Wooooo0_l0000U
ooooo`03o`000?oooooooooo0?ooooooLOooool00ol0003oooooooooo`1jooooo`00:Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo0?ooooooLOooool00ol0003oooooooooo`1joooo
o`00:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?ooooooL?ooool00ol0003o
ooooooooo`1kooooo`00:Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo
Koooool00ol0003oooooooooo`1kooooo`00:Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo0?ooooooK_ooool00ol0003oooooooooo`1looooo`00:Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo0?ooooooK_ooool00ol0003oooooooooo`1looooo`00:Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo0?ooooooKOooool00ol0003oooooooooo`1loooo
o`00:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?ooooooK?ooool00ol0003o
ooooooooo`1mooooo`00:Oooool2o`0002Sooooo00?o0000ooooooooool0oooooom[ooooo`03o`00
0?oooooooooo07gooooo000Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0oooo
oom[ooooo`03o`000?oooooooooo07gooooo000Yooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0oooooomYooooo`03o`000?oooooooooo07kooooo000Yooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0oooooomXooooo`03o`000?oooooooooo07oooooo000Yooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0oooooomXooooo`03o`000?oooooooooo07oo
oooo000Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0oooooomXooooo`03o`00
0?oooooooooo07oooooo000Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0oooo
oomVooooo`03o`000?oooooooooo083ooooo000Yooooo`;o0000:_ooool00ol0003oooooooooo`3o
ooooofKooooo00?o0000ooooooooool0P?ooool002Wooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3oooooofKooooo00?o0000ooooooooool0P?ooool002Wooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`3oooooofGooooo00?o0000ooooooooool0P?ooool002Wooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3oooooofCooooo00?o0000ooooooooool0
POooool002Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3oooooof?ooooo00?o
0000ooooooooool0POooool002Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3o
ooooof?ooooo00?o0000ooooooooool0POooool002Wooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`3oooooof7ooooo00?o0000ooooooooool0P_ooool002Wooooo0_l0000]ooooo`03
o`000?oooooooooo0?ooooooH?ooool00ol0003oooooooooo`23ooooo`00:Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo0?ooooooH?ooool00ol0003oooooooooo`23ooooo`00:Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?ooooooGoooool00ol0003ooooooooo
o`23ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?ooooooG_ooool0
0ol0003oooooooooo`24ooooo`00:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0?ooooooGOooool00ol0003oooooooooo`24ooooo`004oooool3o`0000?ooooo0_l00004ooooo`;o
00002?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0?ooooooGOooool00ol0003o
ooooooooo`24ooooo`005?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0oooooomLooooo`03o`000?oooooooooo08Gooooo000Aooooo`Go00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`3ooooooe_ooooo00?o0000ooooooooool0QOooool0017ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo
0ol0000_ooooo`03o`000?oooooooooo0?ooooooF_ooool00ol0003oooooooooo`26ooooo`004_oo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0?ooooooF_ooool00ol0003o
ooooooooo`26ooooo`004oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0oooooomHoooo
o`03o`000?oooooooooo08Oooooo000Dooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o
00002?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?ooooooEoooool00ol0003o
ooooooooo`27ooooo`00:Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo
Eoooool00ol0003oooooooooo`27ooooo`00:Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo0?ooooooE_ooool00ol0003oooooooooo`28ooooo`00:Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo0?ooooooEOooool00ol0003oooooooooo`28ooooo`00:Oooool2o`00
03?ooooo00?o0000ooooooooool0oooooomDooooo`03o`000?oooooooooo08Wooooo000Yooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooomDooooo`03o`000?oooooooooo08Wo
oooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0oooooomBooooo`03o`00
0?oooooooooo08[ooooo000Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0oooo
oomAooooo`03o`000?oooooooooo08[ooooo000Yooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0oooooomAooooo`03o`000?oooooooooo08[ooooo000Yooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0oooooom@ooooo`03o`000?oooooooooo08_ooooo000Yooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0oooooom?ooooo`03o`000?oooooooooo08_o
oooo000Yooooo`;o0000=_ooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0
S?ooool002Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0S?ooool002Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3o
ooooodgooooo00?o0000ooooooooool0S?ooool002Wooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`3oooooodcooooo00?o0000ooooooooool0SOooool002Wooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool0SOooool002Wooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool0
SOooool002Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3oooooodWooooo00?o
0000ooooooooool0S_ooool002Wooooo0_l0000iooooo`03o`000?oooooooooo0?ooooooB?ooool0
0ol0003oooooooooo`2?ooooo`00:Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
0?ooooooB?ooool00ol0003oooooooooo`2?ooooo`00:Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0?ooooooAoooool00ol0003oooooooooo`2?ooooo`00:Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`2@ooooo`00:Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0?ooooooAOooool00ol0003ooooooooo
o`2@ooooo`00:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0?ooooooAOooool0
0ol0003oooooooooo`2@ooooo`00:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
0?ooooooA?ooool00ol0003oooooooooo`2Aooooo`00:Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0?oooooo@oooool00ol0003oooooooooo`2Aooooo`00:Oooool2o`0003cooooo
00?o0000ooooooooool0oooooom2ooooo`03o`000?oooooooooo09;ooooo000Yooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0oooooom2ooooo`03o`000?oooooooooo09;ooooo000Y
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0oooooom0ooooo`03o`000?oooooo
oooo09?ooooo000Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0oooooolooooo
o`03o`000?oooooooooo09?ooooo000Booooo`?o00001?ooool2o`0000Cooooo0_l00008ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0ooooooloooooo`03o`000?oooooooooo09?o
oooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`3o
ooooockooooo00?o0000ooooooooool0U?ooool001Gooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3oooooocgooooo00?o0000ooooooooool0U?ooool001Gooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo
0ol0000nooooo`03o`000?oooooooooo0?oooooo??ooool00ol0003oooooooooo`2Eooooo`004Ooo
ool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0oooooollooooo`03o`000?oooooooooo09Go
oooo000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0oooooolkoooo
o`03o`000?oooooooooo09Gooooo000Aooooo`Go00000oooool2o`0000Cooooo0_l00008ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0ooooooljooooo`03o`000?oooooooooo09Ko
oooo000Yooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0ooooooliooooo`03o`00
0?oooooooooo09Kooooo000Yooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0oooo
ooliooooo`03o`000?oooooooooo09Kooooo000Yooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0oooooolgooooo`03o`000?oooooooooo09Oooooo000Yooooo`;o0000@oooool00ol0
003oooooooooo`3oooooocGooooo00?o0000ooooooooool0V?ooool002Wooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool0V?ooool002Wooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool0
VOooool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3ooooooc?ooooo00?o
0000ooooooooool0VOooool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3o
oooooc;ooooo00?o0000ooooooooool0V_ooool002Wooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool0V_ooool002Wooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`3ooooooc7ooooo00?o0000ooooooooool0V_ooool002Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
Voooool002Wooooo0_l00016ooooo`03o`000?oooooooooo0?oooooo;oooool00ol0003ooooooooo
o`2Kooooo`00:Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0?oooooo;oooool0
0ol0003oooooooooo`2Kooooo`00:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
0?oooooo;Oooool00ol0003oooooooooo`2Looooo`00:Oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`2Mooooo`00:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`2Mooooo`00:Ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003ooooooooo
o`2Nooooo`00:Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0?oooooo:_ooool0
0ol0003oooooooooo`2Nooooo`00:Oooool2o`0004Wooooo00?o0000ooooooooool0oooooolXoooo
o`03o`000?oooooooooo09oooooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0oooooolXooooo`03o`000?oooooooooo09oooooo000Yooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo0:3ooooo000Yooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo0:3ooooo000Y
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooo
oooo0:3ooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0oooooolSoooo
o`03o`000?oooooooooo0:7ooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0oooooolSooooo`03o`000?oooooooooo0:7ooooo000Yooooo`;o0000COooool00ol0003ooooo
ooooo`3oooooob7ooooo00?o0000ooooooooool0X_ooool002Wooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool0X_ooool002Wooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool0Xoooool0
02Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3ooooooaoooooo00?o0000oooo
ooooool0Xoooool002Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3ooooooako
oooo00?o0000ooooooooool0Y?ooool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0
Y?ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
0?oooooo7?ooool00ol0003oooooooooo`2Uooooo`004Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`?o0000Cooo
ool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0Y_ooool0017ooooo1?l00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`2Vooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003o
ooooooooo`2Vooooo`004_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
0?oooooo6?ooool00ol0003oooooooooo`2Wooooo`004oooool2o`0000Cooooo0_l00004ooooo`;o
00002?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003o
ooooooooo`2Wooooo`00:Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0?oooooo
5oooool00ol0003oooooooooo`2Wooooo`00:Oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo0?oooooo5Oooool00ol0003oooooooooo`2Xooooo`00:Oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`2Xooooo`00:Oooool2o`00
05Cooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo0:Wooooo000Yooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo0:Wo
oooo000Yooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0oooooolAooooo`03o`00
0?oooooooooo0:[ooooo000Yooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0oooo
ool?ooooo`03o`000?oooooooooo0:_ooooo000Yooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0ooooool?ooooo`03o`000?oooooooooo0:_ooooo000Yooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo0:cooooo000Yooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooooooo0:co
oooo000Yooooo`;o0000Eoooool00ol0003oooooooooo`3oooooo`cooooo00?o0000ooooooooool0
[Oooool002Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3oooooo`cooooo00?o
0000ooooooooool0[Oooool002Wooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3o
ooooo`[ooooo00?o0000ooooooooool0[_ooool002Wooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0[_ooool002Wooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0[oooool002Wooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0
[oooool002Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`3oooooo`Kooooo00?o
0000ooooooooool0/?ooool002Wooooo0_l0001Kooooo`03o`000?oooooooooo0?oooooo1?ooool0
0ol0003oooooooooo`2aooooo`00:Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
0?oooooo1?ooool00ol0003oooooooooo`2aooooo`00:Oooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`2booooo`00:Oooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`2booooo`00:Ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo0?oooooo00?o0000ooooooooool0/ooo
ool002Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`3oooooo`03o`000?oooooo
oooo0;?ooooo000Yooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0oOooool00ol0
003oooooooooo`2dooooo`00:Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0?go
oooo00?o0000ooooooooool0]?ooool002Wooooo0_l0001Oooooo`03o`000?oooooooooo0?_ooooo
00?o0000ooooooooool0]Oooool002Wooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`3kooooo`03o`000?oooooooooo0;Gooooo000Yooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0nOooool00ol0003oooooooooo`2fooooo`00:Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool0]oooool001?ooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0moooool00ol0003oooooooooo`2gooooo`004oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool0^?ooool001Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool0^?ooool0
01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01Oooool3o`0006;ooooo00?o0000ooooooooool0loooool00ol0003ooooooooo
o`2iooooo`005Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0??ooooo
00?o0000ooooooooool0^Oooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo0?7ooooo00?o0000ooooooooool0^_ooool0017ooooo1Ol00003ooooo`;o
00001?ooool2o`0000Sooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`3_ooooo`03
o`000?oooooooooo0;_ooooo000Yooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
koooool00ol0003oooooooooo`2kooooo`00:Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool0_?ooool002Wooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`3]ooooo`03o`000?oooooooooo0;cooooo000Yooooo`;o0000Ioooool00ol0
003oooooooooo`3[ooooo`03o`000?oooooooooo0;gooooo000Yooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0joooool00ol0003oooooooooo`2mooooo`00:Oooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool0__ooool002Wooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo0;kooooo000Y
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`2o
ooooo`00:Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo0>Kooooo00?o0000oooo
ooooool0_oooool002Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`3Tooooo`03
o`000?oooooooooo0<3ooooo000Yooooo`;o0000K?ooool00ol0003oooooooooo`3Rooooo`03o`00
0?oooooooooo0<7ooooo000Yooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0h_oo
ool00ol0003oooooooooo`31ooooo`00:Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo0>3ooooo00?o0000ooooooooool0`_ooool002Wooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`3Pooooo`03o`000?oooooooooo0<;ooooo000Yooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0g_ooool00ol0003oooooooooo`33ooooo`00:Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0`oooool002Wooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`3Looooo`03o`000?oooooooooo0<Cooooo000Y
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`35
ooooo`00:Oooool2o`00073ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`36oooo
o`00:Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0=Wooooo00?o0000oooooooo
ool0a_ooool002Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`3Gooooo`03o`00
0?oooooooooo0<Oooooo000Yooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0eOoo
ool00ol0003oooooooooo`38ooooo`00:Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo0=Gooooo00?o0000ooooooooool0b?ooool002Wooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`3Cooooo`03o`000?oooooooooo0<Wooooo000Yooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool0d_ooool00ol0003oooooooooo`39ooooo`00:Oooool2o`0007Gooooo
00?o0000ooooooooool0d?ooool00ol0003oooooooooo`3:ooooo`00:Oooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0b_ooool002Wooooo00?o0000
ooooooooool0MOooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo0<_ooooo000Yoooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0cOooool00ol0003oooooooooo`3<oooo
o`00:Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool0cOooool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo0<gooooo000Aooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo
0<kooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Oooooo0ol0001iooooo`03o`000?oooooooooo0<Kooooo00?o
0000ooooooooool0coooool001;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo0<Kooooo
00?o0000ooooooooool0coooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo0<Cooooo00?o0000ooooooooool0d?ooool0017ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0dOoo
ool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`31ooooo`03o`000?oooooooooo0=;ooooo000Yooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`3Booooo`00:Oooool00ol0003o
ooooooooo`1looooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0doooool002Wooooo
00?o0000ooooooooool0OOooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo0=?ooooo
000Yooooo`;o0000Ooooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo0=Cooooo000Y
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`3E
ooooo`00:Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0;Sooooo00?o0000oooo
ooooool0e_ooool002Wooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo0=Oooooo000Yooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
]_ooool00ol0003oooooooooo`3Gooooo`00:Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo0;Cooooo00?o0000ooooooooool0f?ooool002Wooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`2cooooo`03o`000?oooooooooo0=Wooooo000Yooooo`;o0000Q?ooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo0=[ooooo000Yooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`3Jooooo`00:Oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0foooool002Wooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo0=cooooo000Y
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`3M
ooooo`00:Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo0:Wooooo00?o0000oooo
ooooool0g_ooool002Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo0=oooooo000Yooooo`;o0000R_ooool00ol0003oooooooooo`2Uooooo`03o`00
0?oooooooooo0>3ooooo000Yooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0YOoo
ool00ol0003oooooooooo`3Pooooo`00:Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo
oooo0:?ooooo00?o0000ooooooooool0hOooool002Wooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo0>;ooooo000Yooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`3Sooooo`00:Oooool00ol0003ooooo
ooooo`2=ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0i?ooool002Wooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo0>Gooooo000Y
ooooo`;o0000T?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo0>Kooooo000Yoooo
o`03o`000?oooooooooo093ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`3Voooo
o`00:Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo09Kooooo00?o0000oooooooo
ool0ioooool002Wooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`2Dooooo`03o`00
0?oooooooooo0>Sooooo000Yooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`3Yooooo`004_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool0
0ol0003oooooooooo`2Cooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0j_ooool0
01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo08oooooo00?o
0000ooooooooool0joooool001Gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0UOooool00ol0003ooooo
ooooo`2=ooooo`03o`000?oooooooooo0>cooooo000Booooo`Co00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Oooooo0ol0002Fooooo`;o0000S?ooool00ol0003o
ooooooooo`3]ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool0R?ooool00ol0003oooooooooo`3^ooooo`004Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo09Wooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`3_ooooo`004_oo
ool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool0l?ooool002Wooooo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo0?7ooooo000Yooooo`03o`000?oooooooooo
09cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`3booooo`00:Oooool00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0loooool002Wooooo
0_l0002Oooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0m?ooool002Wooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?Gooooo000Y
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`3f
ooooo`00:Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool0moooool002Wooooo00?o0000ooooooooool0X_ooool2o`0007Cooooo0_l0003jooooo`00
:Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo06oooooo0_l0003looooo`00:Ooo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0o?oo
ool002Wooooo0_l0002Wooooo`;o0000Joooool2o`000?oooooo000Yooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`3oooooo`00:Oooool00ol0003o
ooooooooo`2Yooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0ooooool1ooooo`00
:Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
ooooool2ooooo`00:Oooool00ol0003oooooooooo`2[ooooo`;o0000HOooool2o`000?oooooo1Ooo
ool002Wooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0?oooooo1Oooool002Wooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo0?oooooo1_ooool002Wooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo0?oooooo1oooool002Wooooo0_l0002aooooo`;o0000
Eoooool2o`000?oooooo2_ooool002Wooooo00?o0000ooooooooool0/_ooool2o`0005?ooooo0_l0
003oooooo`cooooo000Yooooo`03o`000?oooooooooo0;Cooooo0_l0001?ooooo`;o0000ooooool>
ooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Boooool2o`000?oooooo4?ooool002Wo
oooo00?o0000ooooooooool0^?ooool2o`0004Oooooo0_l0003ooooooa;ooooo000Yooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3ooooooa;ooooo
000Yooooo`03o`000?oooooooooo0;_ooooo0_l00011ooooo`;o0000oooooolEooooo`00:Oooool2
o`000;kooooo0_l0000mooooo`;o0000oooooolGooooo`00:Oooool00ol0003oooooooooo`2ooooo
o`?o0000>?ooool2o`000?oooooo6Oooool002Wooooo00?o0000ooooooooool0`_ooool2o`0003?o
oooo0ol0003ooooooa_ooooo000Yooooo`03o`000?oooooooooo0<Cooooo0ol0000^ooooo`;o0000
oooooolNooooo`00:Oooool00ol0003oooooooooo`37ooooo`Go00009?ooool5o`000?oooooo8?oo
ool000cooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooo
oooo0<cooooo1ol0000Eooooo`So0000oooooolUooooo`003Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo0=?ooooo1ol00007ooooo`Oo0000ooooool]ooooo`003Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00007ooooo`?o0000f_ooool7o`000?oooooo=?ooool000go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3ooooooooooooo5_oo
ool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3ooooooooo
oooo5_ooool000cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oooooooooooolF
ooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00008oooo
o`03o`000?oooooooooo0?oooooooooooolFooooo`00:Oooool00ol0003oooooooooo`3ooooooooo
oooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooooaKooooo000Yooooo`03o`000?oo
oooooooo0?oooooooooooolFooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool001Cooooo0ol0000_ooooo`03o`000?oooooooooo
0?oooooon?ooool001Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3oooooooOo
oooo0003ooooo`?o00000oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o
00000oooool3o`0000;ooooo0ol00004ooooo`Co00000oooool2o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l0
0000oooooooaooooo`001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooool0
003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool0003ooooooo;ooooo0004ooooo`04o`000?ooooooooooooooo`Go000000Kooooo
o`000?oooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`Go00002?ooool00ol0003oooooo`00003ooooo
oo?ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0
003oooooooCooooo0002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo0_l0
00001?oooooo0000ooooooooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002ooooo`?o00002Oooool00ol0003oooooo`00003ooooooo?ooooo0002ooooo`05o`00
0?oooooo0000ooooool000009_ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`00
0?ooooool_ooool000;ooooo1Ol0000Vooooo`03o`000?oooooooooo01[ooooo0ol000000ooooooo
0000o`00003ooooooo7ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0912323, 183.273, \
0.00222507, 2.7443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here is a combined equilibrium showing the coexistence curve and \
the spinodal superposed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[CoexPlot, SpinodalPlot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.953614 -0.237544 0.000840863 [
[.21453 .00222 -9 -9 ]
[.21453 .00222 9 0 ]
[.40526 .00222 -9 -9 ]
[.40526 .00222 9 0 ]
[.59598 .00222 -9 -9 ]
[.59598 .00222 9 0 ]
[.7867 .00222 -9 -9 ]
[.7867 .00222 9 0 ]
[.97742 .00222 -3 -9 ]
[.97742 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -41 0 ]
[.02381 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21453 .01472 m
.21453 .02097 L
s
[(0.2)] .21453 .00222 0 1 Mshowa
.40526 .01472 m
.40526 .02097 L
s
[(0.4)] .40526 .00222 0 1 Mshowa
.59598 .01472 m
.59598 .02097 L
s
[(0.6)] .59598 .00222 0 1 Mshowa
.7867 .01472 m
.7867 .02097 L
s
[(0.8)] .7867 .00222 0 1 Mshowa
.97742 .01472 m
.97742 .02097 L
s
[(1)] .97742 .00222 0 1 Mshowa
.125 Mabswid
.07149 .01472 m
.07149 .01847 L
s
.11917 .01472 m
.11917 .01847 L
s
.16685 .01472 m
.16685 .01847 L
s
.26221 .01472 m
.26221 .01847 L
s
.30989 .01472 m
.30989 .01847 L
s
.35757 .01472 m
.35757 .01847 L
s
.45294 .01472 m
.45294 .01847 L
s
.50062 .01472 m
.50062 .01847 L
s
.5483 .01472 m
.5483 .01847 L
s
.64366 .01472 m
.64366 .01847 L
s
.69134 .01472 m
.69134 .01847 L
s
.73902 .01472 m
.73902 .01847 L
s
.83438 .01472 m
.83438 .01847 L
s
.88206 .01472 m
.88206 .01847 L
s
.92974 .01472 m
.92974 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0988 m
.03006 .0988 L
s
[(400)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(500)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(600)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(700)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(800)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(900)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.005 w
.02504 .01472 m
.02534 .02312 L
.02569 .03153 L
.02609 .03994 L
.02655 .04835 L
.02707 .05676 L
.02765 .06517 L
.0283 .07358 L
.02901 .08198 L
.0298 .09039 L
.03066 .0988 L
.03161 .10721 L
.03263 .11562 L
.03374 .12403 L
.03493 .13244 L
.03622 .14084 L
.03759 .14925 L
.03907 .15766 L
.04063 .16607 L
.0423 .17448 L
.04407 .18289 L
.04595 .1913 L
.04793 .1997 L
.05002 .20811 L
.05223 .21652 L
.05455 .22493 L
.05699 .23334 L
.05955 .24175 L
.06224 .25016 L
.06505 .25857 L
.06799 .26697 L
.07107 .27538 L
.07429 .28379 L
.07765 .2922 L
.08115 .30061 L
.08481 .30902 L
.08862 .31743 L
.09259 .32583 L
.09673 .33424 L
.10103 .34265 L
.10552 .35106 L
.11019 .35947 L
.11504 .36788 L
.1201 .37629 L
.12536 .38469 L
.13084 .3931 L
.13655 .40151 L
.1425 .40992 L
.14869 .41833 L
.15515 .42674 L
Mistroke
.16189 .43515 L
.16892 .44356 L
.17627 .45196 L
.18396 .46037 L
.19202 .46878 L
.20047 .47719 L
.20934 .4856 L
.21869 .49401 L
.22855 .50242 L
.239 .51082 L
.25009 .51923 L
.26192 .52764 L
.27461 .53605 L
.28831 .54446 L
.30323 .55287 L
.31968 .56128 L
.33811 .56968 L
.3593 .57809 L
.38476 .5865 L
.41836 .59491 L
.50062 .60332 L
.58287 .59491 L
.61647 .5865 L
.64193 .57809 L
.66313 .56968 L
.68156 .56128 L
.698 .55287 L
.71292 .54446 L
.72662 .53605 L
.73931 .52764 L
.75115 .51923 L
.76224 .51082 L
.77268 .50242 L
.78254 .49401 L
.79189 .4856 L
.80077 .47719 L
.80922 .46878 L
.81727 .46037 L
.82496 .45196 L
.83231 .44356 L
.83935 .43515 L
.84608 .42674 L
.85254 .41833 L
.85874 .40992 L
.86468 .40151 L
.87039 .3931 L
.87587 .38469 L
.88113 .37629 L
.88619 .36788 L
.89105 .35947 L
Mistroke
.89572 .35106 L
.9002 .34265 L
.90451 .33424 L
.90864 .32583 L
.91261 .31743 L
.91642 .30902 L
.92008 .30061 L
.92358 .2922 L
.92694 .28379 L
.93016 .27538 L
.93324 .26697 L
.93618 .25857 L
.939 .25016 L
.94168 .24175 L
.94424 .23334 L
.94668 .22493 L
.949 .21652 L
.95121 .20811 L
.9533 .1997 L
.95529 .1913 L
.95716 .18289 L
.95893 .17448 L
.9606 .16607 L
.96217 .15766 L
.96364 .14925 L
.96502 .14084 L
.9663 .13244 L
.96749 .12403 L
.9686 .11562 L
.96963 .10721 L
.97057 .0988 L
.97143 .09039 L
.97222 .08198 L
.97294 .07358 L
.97358 .06517 L
.97416 .05676 L
.97468 .04835 L
.97514 .03994 L
.97554 .03153 L
.97589 .02312 L
.97619 .01472 L
Mfstroke
.5 Mabswid
.10169 .01472 m
.10455 .02312 L
.10743 .03153 L
.11033 .03994 L
.11326 .04835 L
.1162 .05676 L
.11917 .06517 L
.12216 .07358 L
.12518 .08198 L
.12822 .09039 L
.13128 .0988 L
.13437 .10721 L
.13749 .11562 L
.14064 .12403 L
.14381 .13244 L
.14701 .14084 L
.15024 .14925 L
.1535 .15766 L
.15679 .16607 L
.16011 .17448 L
.16346 .18289 L
.16685 .1913 L
.17027 .1997 L
.17373 .20811 L
.17723 .21652 L
.18076 .22493 L
.18434 .23334 L
.18795 .24175 L
.19161 .25016 L
.19531 .25857 L
.19906 .26697 L
.20285 .27538 L
.20669 .28379 L
.21059 .2922 L
.21453 .30061 L
.21853 .30902 L
.22259 .31743 L
.22671 .32583 L
.23089 .33424 L
.23514 .34265 L
.23946 .35106 L
.24385 .35947 L
.24831 .36788 L
.25286 .37629 L
.25749 .38469 L
.26221 .3931 L
.26703 .40151 L
.27195 .40992 L
.27697 .41833 L
.28212 .42674 L
Mistroke
.28738 .43515 L
.29278 .44356 L
.29832 .45196 L
.30402 .46037 L
.30989 .46878 L
.31595 .47719 L
.32221 .4856 L
.3287 .49401 L
.33545 .50242 L
.34248 .51082 L
.34984 .51923 L
.35757 .52764 L
.36576 .53605 L
.37447 .54446 L
.38382 .55287 L
.394 .56128 L
.40526 .56968 L
.41803 .57809 L
.43319 .5865 L
.45294 .59491 L
.50062 .60332 L
.5483 .59491 L
.56805 .5865 L
.5832 .57809 L
.59598 .56968 L
.60723 .56128 L
.61741 .55287 L
.62677 .54446 L
.63548 .53605 L
.64366 .52764 L
.6514 .51923 L
.65876 .51082 L
.66579 .50242 L
.67253 .49401 L
.67902 .4856 L
.68528 .47719 L
.69134 .46878 L
.69721 .46037 L
.70291 .45196 L
.70845 .44356 L
.71385 .43515 L
.71912 .42674 L
.72426 .41833 L
.72929 .40992 L
.7342 .40151 L
.73902 .3931 L
.74374 .38469 L
.74837 .37629 L
.75292 .36788 L
.75738 .35947 L
Mistroke
.76177 .35106 L
.76609 .34265 L
.77034 .33424 L
.77452 .32583 L
.77864 .31743 L
.7827 .30902 L
.7867 .30061 L
.79065 .2922 L
.79454 .28379 L
.79838 .27538 L
.80218 .26697 L
.80592 .25857 L
.80962 .25016 L
.81328 .24175 L
.81689 .23334 L
.82047 .22493 L
.824 .21652 L
.8275 .20811 L
.83096 .1997 L
.83438 .1913 L
.83777 .18289 L
.84112 .17448 L
.84445 .16607 L
.84774 .15766 L
.851 .14925 L
.85423 .14084 L
.85743 .13244 L
.8606 .12403 L
.86374 .11562 L
.86686 .10721 L
.86995 .0988 L
.87301 .09039 L
.87605 .08198 L
.87907 .07358 L
.88206 .06517 L
.88503 .05676 L
.88798 .04835 L
.8909 .03994 L
.8938 .03153 L
.89668 .02312 L
.89954 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool007Cooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000A?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0004?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00015ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000B_ooool3o`0007Wooooo
001cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000@oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000004[ooooo00?o0000ooooooooool0N?ooool007?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00012oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo07So
oooo001cooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0@_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0004?ooooo00Co0000oooooooooooo00001ooo
ool4o`0004Cooooo00Co0000oooooooooooo00002?ooool3o`0004_ooooo00?o0000ooooooooool0
N?ooool007?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004?o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000013ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool00000B_ooool00ol0003oooooooooo`1hooooo`00Loooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000@oooool01?l0003oooooooooool00009oooo
o`;o0000@oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo04Cooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004Wooooo0_l0001jooooo`00M?oo
ool2o`0000Wooooo0ol00015ooooo`;o00002oooool00ol0003oooooooooo`12ooooo`;o00002_oo
ool2o`0004Gooooo0_l00009ooooo`?o0000Boooool00ol0003oooooooooo`1hooooo`00:Oooool0
0ol0003oooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooo
oaKooooo000Yooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`03o`000?oooooooooo017o
oooo000Yooooo`03o`000?oooooooooo0?ooooooooooool3ooooo`03o`000?oooooooooo013ooooo
000Yooooo`03o`000?oooooooooo0?oooooo/Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo0ol00003ooooo`?o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000oooo
o`Co00001_ooool002Wooooo00?o0000ooooooooool0oooooonaooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo000Noooooooo0000]?l0000;ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool002Sooooo0_l0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0@ooooo`?o00005_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003o
ooooo`000008ooooo`?o00000oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo0ol00006ooooo`00:?ooool2o`0001?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo0ol0000Fooooo`03o`000?oo
oooo000000;ooooo1?l00003ooooo`?o00000_ooool2o`000003ooooool0003ooooo00Sooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000_oo
ool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`0000[ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`00:?ooool2o`00027ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01kooooo0ol0000Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0000Dooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`00
:?ooool2o`00027ooooo00?o0000ooooooooool0oooooomFooooo`03o`000?oooooooooo01kooooo
0_l0000Gooooo`;o00001?ooool00ol0003oooooooooo`0Dooooo`Go00005?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Ko
oooo000Xooooo`;o00008Oooool00ol0003oooooooooo`3ooooooeKooooo00?o0000ooooooooool0
7_ooool2o`0007[ooooo000Xooooo`;o00008_ooool00ol0003oooooooooo`3ooooooeCooooo00?o
0000ooooooooool07oooool2o`0007[ooooo000Xooooo`?o00008_ooool00ol0003oooooooooo`3o
oooooe?ooooo00?o0000ooooooooool07oooool2o`0007[ooooo000Xooooo`;o00008oooool00ol0
003oooooooooo`3ooooooe?ooooo00?o0000ooooooooool07oooool2o`0007[ooooo000Xooooo`;o
00008oooool00ol0003oooooooooo`3ooooooe;ooooo00?o0000ooooooooool08?ooool2o`0007[o
oooo000Xooooo`;o00009?ooool00ol0003oooooooooo`3ooooooe7ooooo00?o0000ooooooooool0
8?ooool2o`0007[ooooo000Xooooo`;o00009?ooool00ol0003oooooooooo`3ooooooe3ooooo00?o
0000ooooooooool08Oooool2o`0007[ooooo000Xooooo`;o00009?ooool00ol0003oooooooooo`3o
oooooe3ooooo00?o0000ooooooooool08Oooool2o`0007[ooooo000Xooooo`;o00009?ooool00ol0
003oooooooooo`3ooooooe3ooooo00?o0000ooooooooool08Oooool2o`0007[ooooo000Xooooo`?o
00009?ooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool08_ooool2o`0007[o
oooo000Yooooo`;o00009?ooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0
8_ooool2o`0007[ooooo000Yooooo`;o00009?ooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool08_ooool2o`0007[ooooo000Yooooo`;o00009Oooool00ol0003oooooooooo`3o
ooooodcooooo00?o0000ooooooooool08_ooool3o`0007[ooooo000Yooooo`;o00009_ooool00ol0
003oooooooooo`3ooooood_ooooo00?o0000ooooooooool08_ooool2o`0007_ooooo000Yooooo`;o
00009_ooool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool08_ooool2o`0007_o
oooo000Yooooo`;o00009_ooool00ol0003oooooooooo`3ooooood[ooooo00?o0000ooooooooool0
8oooool2o`0007_ooooo000Yooooo`;o00009oooool00ol0003oooooooooo`3oooooodWooooo00?o
0000ooooooooool08oooool2o`0007_ooooo000Yooooo`;o00009oooool00ol0003oooooooooo`3o
ooooodSooooo00?o0000ooooooooool09?ooool2o`0007_ooooo000Yooooo`;o00009oooool00ol0
003oooooooooo`3oooooodSooooo00?o0000ooooooooool09?ooool2o`0007_ooooo000Yooooo`;o
00009oooool00ol0003oooooooooo`3oooooodSooooo00?o0000ooooooooool09?ooool2o`0007_o
oooo000Yooooo`;o0000:?ooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0
9Oooool2o`0007_ooooo000Yooooo`;o0000:?ooool00ol0003oooooooooo`3oooooodKooooo00?o
0000ooooooooool09Oooool2o`0007_ooooo000Yooooo`;o0000:?ooool00ol0003oooooooooo`3o
ooooodKooooo00?o0000ooooooooool09Oooool2o`0007_ooooo000Yooooo`?o0000:?ooool00ol0
003oooooooooo`3oooooodCooooo00?o0000ooooooooool09_ooool2o`0007_ooooo000Yooooo`?o
0000:?ooool00ol0003oooooooooo`3oooooodCooooo00?o0000ooooooooool09_ooool2o`0007_o
oooo000Yooooo`?o0000:?ooool00ol0003oooooooooo`3oooooodCooooo00?o0000ooooooooool0
9_ooool2o`0007_ooooo000Yooooo`?o0000:Oooool00ol0003oooooooooo`3ooooood?ooooo00?o
0000ooooooooool09_ooool2o`0007_ooooo000Yooooo`?o0000:Oooool00ol0003oooooooooo`3o
oooood;ooooo00?o0000ooooooooool09_ooool3o`0007_ooooo000Yooooo`?o0000:_ooool00ol0
003oooooooooo`3ooooood7ooooo00?o0000ooooooooool09_ooool2o`0007cooooo000Cooooo`?o
00000oooool2o`0000Cooooo0_l00008ooooo`?o0000:_ooool00ol0003oooooooooo`3ooooood7o
oooo00?o0000ooooooooool09_ooool2o`0007cooooo000Dooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo0ol0000Zoooo
o`03o`000?oooooooooo0?oooooo@?ooool00ol0003oooooooooo`0Wooooo`;o0000O?ooool0017o
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3
o`0002_ooooo00?o0000ooooooooool0ooooooloooooo`03o`000?oooooooooo02Oooooo0_l0001l
ooooo`004Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool3o`0002_ooooo00?o0000ooooooooool0oooooolnooooo`03o`00
0?oooooooooo02Sooooo0_l0001looooo`004_ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3o`0002_ooooo00?o0000oooooooo
ool0oooooolnooooo`03o`000?oooooooooo02Sooooo0_l0001looooo`004oooool2o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`Co0000:oooool00ol0
003oooooooooo`3ooooooccooooo00?o0000ooooooooool0:?ooool3o`0007cooooo000Dooooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00002?ooool01?l0003oooooo`000?l0000[oooo
o`03o`000?oooooooooo0?oooooo??ooool00ol0003oooooooooo`0Xooooo`;o0000OOooool002Wo
oooo00Co0000ooooool0003o0000:oooool00ol0003oooooooooo`3ooooooccooooo00?o0000oooo
ooooool0:?ooool2o`0007gooooo000Yooooo`04o`000?oooooo0000o`0002cooooo00?o0000oooo
ooooool0ooooooljooooo`03o`000?oooooooooo02Wooooo0_l0001mooooo`00:Oooool01?l0003o
ooooo`000?l0000/ooooo`03o`000?oooooooooo0?oooooo>_ooool00ol0003oooooooooo`0Yoooo
o`;o0000OOooool002Wooooo1?l0000]ooooo`03o`000?oooooooooo0?oooooo>?ooool00ol0003o
ooooooooo`0Zooooo`;o0000OOooool002Wooooo00Co0000ooooool0003o0000;Oooool00ol0003o
ooooooooo`3oooooocSooooo00?o0000ooooooooool0:_ooool2o`0007gooooo000Yooooo`03o`00
0?oooooo000000;o0000;Oooool00ol0003oooooooooo`3oooooocKooooo00?o0000ooooooooool0
:_ooool3o`0007gooooo000Yooooo`03o`000?oooooooooo00;o0000;Oooool00ol0003ooooooooo
o`3oooooocKooooo00?o0000ooooooooool0:_ooool2o`0007kooooo000Yooooo`03o`000?oooooo
oooo00;o0000;Oooool00ol0003oooooooooo`3oooooocKooooo00?o0000ooooooooool0:_ooool2
o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000;_ooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool0:_ooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00;o
0000;_ooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool0:oooool2o`0007ko
oooo000Yooooo`;o000000?oooooo`000?l00000;oooool00ol0003oooooooooo`3ooooooc?ooooo
00?o0000ooooooooool0:oooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000;ooo
ool00ol0003oooooooooo`3ooooooc?ooooo00?o0000ooooooooool0:oooool2o`0007kooooo000Y
ooooo`03o`000?oooooooooo00;o0000;oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000
ooooooooool0;?ooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00?o0000;oooool00ol0
003oooooooooo`3ooooooc7ooooo00?o0000ooooooooool0:oooool3o`0007kooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000;oooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooo
ooooool0;?ooool2o`0007oooooo000Yooooo`04o`000?ooooooooooooooo`;o0000;oooool00ol0
003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0;?ooool2o`0007oooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000<?ooool00ol0003oooooooooo`3oooooobkooooo00?o0000oooo
ooooool0;Oooool2o`0007oooooo000Yooooo`;o00000_ooool2o`00033ooooo00?o0000oooooooo
ool0ooooool^ooooo`03o`000?oooooooooo02gooooo0_l0001oooooo`00:Oooool01?l0003ooooo
ooooooooool2o`00033ooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo02go
oooo0_l0001oooooo`00:Oooool01?l0003oooooooooooooool2o`00037ooooo00?o0000oooooooo
ool0ooooool]ooooo`03o`000?oooooooooo02gooooo0_l0001oooooo`00:Oooool01?l0003ooooo
ooooooooool3o`00033ooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo02go
oooo0ol0001oooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000<Oooool00ol0003ooooo
ooooo`3oooooob_ooooo00?o0000ooooooooool0;Oooool2o`00083ooooo000Yooooo`03o`000?oo
oooooooo00;ooooo0_l0000aooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003ooooooooo
o`0]ooooo`;o0000P?ooool002Wooooo00?o0000ooooooooool00_ooool2o`00037ooooo00?o0000
ooooooooool0oooooolZooooo`03o`000?oooooooooo02kooooo0_l00020ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`?o0000<Oooool00ol0003oooooooooo`3oooooobWooooo00?o0000oooo
ooooool0;Oooool3o`00083ooooo000Yooooo`;o00001?ooool2o`00037ooooo00?o0000oooooooo
ool0oooooolXooooo`03o`000?oooooooooo02kooooo0_l00021ooooo`00:Oooool00ol0003ooooo
ooooo`03ooooo`;o0000<Oooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool0
;_ooool2o`00087ooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol0000aooooo`03o`000?oo
oooooooo0?oooooo9_ooool00ol0003oooooooooo`0_ooooo`;o0000POooool002Wooooo00?o0000
ooooooooool01?ooool2o`0003;ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooo
oooo02oooooo0_l00021ooooo`004_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`;o0000<_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000oooo
ooooool0;oooool2o`00087ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?oo
ool2o`0003;ooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo033ooooo0_l0
0021ooooo`005Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o0000<oooool00ol0003ooooo
ooooo`3oooooob?ooooo00?o0000ooooooooool0;oooool3o`00087ooooo000Eooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`?o
00001?ooool2o`0003?ooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo033o
oooo0_l00022ooooo`004Oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Cooooo0_l0000cooooo`03o`000?oooooooooo
0?oooooo8_ooool00ol0003oooooooooo`0`ooooo`;o0000P_ooool0017ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01?ooool2o`0003?ooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooo
oooo033ooooo0_l00022ooooo`004Oooool5o`0000?ooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`?o0000<oooool00ol0003oooooooooo`3oooooob3ooooo00?o0000oooo
ooooool0<?ooool3o`0008;ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000cooooo`03
o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0`ooooo`;o0000Poooool002Wooooo
00?o0000ooooooooool01Oooool2o`0003?ooooo00?o0000ooooooooool0oooooolPooooo`03o`00
0?oooooooooo033ooooo0_l00023ooooo`00:Oooool00ol0003oooooooooo`05ooooo`?o0000<ooo
ool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0<?ooool3o`0008?ooooo000Y
ooooo`;o00001oooool2o`0003Cooooo00?o0000ooooooooool0oooooolLooooo`03o`000?oooooo
oooo037ooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o0000=?ooool00ol0
003oooooooooo`3ooooooacooooo00?o0000ooooooooool0<Oooool2o`0008Cooooo000Yooooo`03
o`000?oooooooooo00Kooooo0_l0000dooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0003o
ooooooooo`0aooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool01_ooool3o`0003Cooooo
00?o0000ooooooooool0oooooolJooooo`03o`000?oooooooooo037ooooo0ol00024ooooo`00:Ooo
ool00ol0003oooooooooo`07ooooo`;o0000=?ooool00ol0003oooooooooo`3ooooooa[ooooo00?o
0000ooooooooool0<Oooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000d
ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0aooooo`;o0000QOooool0
02Wooooo00?o0000ooooooooool01oooool2o`0003Gooooo00?o0000ooooooooool0oooooolHoooo
o`03o`000?oooooooooo03;ooooo0_l00025ooooo`00:Oooool00ol0003oooooooooo`07ooooo`?o
0000=?ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0<Oooool3o`0008Go
oooo000Yooooo`;o00002Oooool2o`0003Gooooo00?o0000ooooooooool0oooooolFooooo`03o`00
0?oooooooooo03;ooooo0_l00026ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o0000=Ooo
ool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool0<_ooool2o`0008Kooooo000Y
ooooo`03o`000?oooooooooo00Sooooo0ol0000eooooo`03o`000?oooooooooo0?oooooo5?ooool0
0ol0003oooooooooo`0booooo`?o0000Q_ooool002Wooooo00?o0000ooooooooool02Oooool2o`00
03Kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo0_l00027oooo
o`00:Oooool00ol0003oooooooooo`09ooooo`;o0000=_ooool00ol0003oooooooooo`3ooooooa?o
oooo00?o0000ooooooooool0<_ooool2o`0008Oooooo000Yooooo`03o`000?oooooooooo00Wooooo
0_l0000fooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003oooooooooo`0cooooo`;o0000
Qoooool002Wooooo00?o0000ooooooooool02Oooool3o`0003Kooooo00?o0000ooooooooool0oooo
oolAooooo`03o`000?oooooooooo03;ooooo0ol00027ooooo`00:Oooool2o`0000_ooooo0_l0000f
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0cooooo`;o0000R?ooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0003Kooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo03?ooooo0_l00028ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`?o
0000=_ooool00ol0003oooooooooo`3oooooo`kooooo00?o0000ooooooooool0<oooool3o`0008So
oooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0000gooooo`03o`000?oooooooooo0?oooooo
3Oooool00ol0003oooooooooo`0cooooo`;o0000ROooool002Wooooo00?o0000ooooooooool02ooo
ool2o`0003Oooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooooooo03?ooooo0_l0
0029ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000=oooool00ol0003oooooooooo`3o
ooooo`cooooo00?o0000ooooooooool0=?ooool2o`0008Wooooo000Yooooo`03o`000?oooooooooo
00_ooooo0ol0000gooooo`03o`000?oooooooooo0?oooooo2oooool00ol0003oooooooooo`0coooo
o`?o0000ROooool002Wooooo0_l0000=ooooo`;o0000=oooool00ol0003oooooooooo`3oooooo`[o
oooo00?o0000ooooooooool0=?ooool2o`0008[ooooo000Yooooo`03o`000?oooooooooo00cooooo
0_l0000gooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0dooooo`;o0000
R_ooool002Wooooo00?o0000ooooooooool03?ooool2o`0003Sooooo00?o0000ooooooooool0oooo
ool8ooooo`03o`000?oooooooooo03Gooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`0<
ooooo`?o0000=oooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0=?ooool3
o`0008[ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000hooooo`03o`000?oooooooooo
0?oooooo1_ooool00ol0003oooooooooo`0eooooo`;o0000Roooool001;ooooo0ol00004ooooo`;o
00001?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool2o`0003Sooooo00?o0000oooooooo
ool0ooooool6ooooo`03o`000?oooooooooo03Gooooo0_l0002;ooooo`004Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00gooooo0ol0000hooooo`03o`000?oooooooooo0?oooooo1?ooool0
0ol0003oooooooooo`0eooooo`?o0000Roooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3o`0000kooooo
0ol0000gooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0eooooo`;o0000
S?ooool0017ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0?ooooo`;o0000=oooool00ol0003oooooooooo`3oooooo`Co
oooo00?o0000ooooooooool0=Oooool2o`0008cooooo000Aooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00oooooo0_l0000hooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`0eoooo
o`?o0000S?ooool001;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool03oooool3o`0003Oooooo00?o0000
ooooooooool0ooooool2ooooo`03o`000?oooooooooo03Gooooo0_l0002=ooooo`004oooool2o`00
00Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`;o0000>?ooool00ol0
003oooooooooo`3oooooo`03o`000?oooooooooo03Gooooo0ol0002=ooooo`00:Oooool00ol0003o
ooooooooo`0@ooooo`;o0000>?ooool00ol0003oooooooooo`3oooooo`03o`000?oooooooooo03Go
oooo0_l0002>ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o0000>Oooool00ol0003ooooo
ooooo`3nooooo`03o`000?oooooooooo03Gooooo0_l0002>ooooo`00:Oooool00ol0003ooooooooo
o`0@ooooo`?o0000>?ooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo03Gooooo0ol0
002>ooooo`00:Oooool2o`0001;ooooo0_l0000iooooo`03o`000?oooooooooo0?cooooo00?o0000
ooooooooool0=Oooool2o`0008oooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0000ioooo
o`03o`000?oooooooooo0?cooooo00?o0000ooooooooool0=Oooool2o`0008oooooo000Yooooo`03
o`000?oooooooooo017ooooo0ol0000iooooo`03o`000?oooooooooo0?[ooooo00?o0000oooooooo
ool0=Oooool3o`0008oooooo000Yooooo`03o`000?oooooooooo01;ooooo0ol0000hooooo`03o`00
0?oooooooooo0?Wooooo00?o0000ooooooooool0=Oooool3o`00093ooooo000Yooooo`03o`000?oo
oooooooo01?ooooo0_l0000hooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool0=Ooo
ool2o`00097ooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000iooooo`03o`000?oooooo
oooo0?Oooooo00?o0000ooooooooool0=_ooool2o`00097ooooo000Yooooo`03o`000?oooooooooo
01?ooooo0ol0000hooooo`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool0=Oooool3o`00
097ooooo000Yooooo`;o00005Oooool2o`0003Wooooo00?o0000ooooooooool0mOooool00ol0003o
ooooooooo`0fooooo`;o0000T_ooool002Wooooo00?o0000ooooooooool05?ooool2o`0003Wooooo
00?o0000ooooooooool0mOooool00ol0003oooooooooo`0fooooo`;o0000T_ooool002Wooooo00?o
0000ooooooooool05?ooool3o`0003Wooooo00?o0000ooooooooool0loooool00ol0003ooooooooo
o`0fooooo`?o0000T_ooool002Wooooo00?o0000ooooooooool05Oooool2o`0003Wooooo00?o0000
ooooooooool0loooool00ol0003oooooooooo`0fooooo`;o0000Toooool002Wooooo00?o0000oooo
ooooool05Oooool3o`0003Wooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`0foooo
o`?o0000Toooool002Wooooo00?o0000ooooooooool05_ooool2o`0003Wooooo00?o0000oooooooo
ool0lOooool00ol0003oooooooooo`0fooooo`;o0000U?ooool002Wooooo00?o0000ooooooooool0
5_ooool3o`0003Wooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`0fooooo`?o0000
U?ooool002Wooooo0_l0000Hooooo`?o0000>Oooool00ol0003oooooooooo`3^ooooo`03o`000?oo
oooooooo03Kooooo0_l0002Eooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o0000>Oooool0
0ol0003oooooooooo`3^ooooo`03o`000?oooooooooo03Kooooo0_l0002Eooooo`00:Oooool00ol0
003oooooooooo`0Hooooo`;o0000>Oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
03Kooooo0ol0002Eooooo`00:Oooool00ol0003oooooooooo`0Hooooo`?o0000>Oooool00ol0003o
ooooooooo`3/ooooo`03o`000?oooooooooo03Kooooo0_l0002Fooooo`00:Oooool00ol0003ooooo
ooooo`0Iooooo`;o0000>Oooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo03Kooooo
0ol0002Fooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000>Oooool00ol0003ooooooooo
o`3[ooooo`03o`000?oooooooooo03Kooooo0_l0002Gooooo`00:Oooool00ol0003oooooooooo`0I
ooooo`?o0000>Oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo03Kooooo0ol0002G
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000>Oooool00ol0003oooooooooo`3Yoooo
o`03o`000?oooooooooo03Kooooo0_l0002Hooooo`00:Oooool2o`0001_ooooo0ol0000iooooo`03
o`000?oooooooooo0>Oooooo00?o0000ooooooooool0=_ooool3o`0009Sooooo000Yooooo`03o`00
0?oooooooooo01_ooooo0_l0000iooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0
=_ooool2o`0009Wooooo000Yooooo`03o`000?oooooooooo01_ooooo0ol0000iooooo`03o`000?oo
oooooooo0>Gooooo00?o0000ooooooooool0=_ooool3o`0009Wooooo000Yooooo`03o`000?oooooo
oooo01cooooo0ol0000iooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool0=_ooool3
o`0009[ooooo000Cooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`0Mooooo`;o0000>Oooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo
03Kooooo0_l0002Kooooo`004oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Mooooo`?o0000>Oooool0
0ol0003oooooooooo`3Qooooo`03o`000?oooooooooo03Kooooo0ol0002Kooooo`005?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01kooooo0_l0000iooooo`03o`000?oooooooooo0>7ooooo00?o
0000ooooooooool0=_ooool2o`0009cooooo000Dooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo0ol0000Nooooo`?o0000
>Oooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo03Kooooo0ol0002Looooo`005Ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Oooooo`;o0000>Oooool00ol0003oooooooooo`3Oooooo`03
o`000?oooooooooo03Kooooo0_l0002Mooooo`004Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo01oooooo0ol0000iooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool0=_ooool3
o`0009gooooo000Aooooo`Go00000oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
023ooooo0ol0000iooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool0=_ooool3o`00
09kooooo000Yooooo`03o`000?oooooooooo027ooooo0_l0000iooooo`03o`000?oooooooooo0=_o
oooo00?o0000ooooooooool0=_ooool2o`0009oooooo000Yooooo`03o`000?oooooooooo027ooooo
0ol0000iooooo`03o`000?oooooooooo0=Wooooo00?o0000ooooooooool0=_ooool3o`0009oooooo
000Yooooo`03o`000?oooooooooo02;ooooo0_l0000iooooo`03o`000?oooooooooo0=Wooooo00?o
0000ooooooooool0=_ooool2o`000:3ooooo000Yooooo`;o00008oooool3o`0003Wooooo00?o0000
ooooooooool0eoooool00ol0003oooooooooo`0fooooo`?o0000X?ooool002Wooooo00?o0000oooo
ooooool08oooool2o`0003Wooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`0foooo
o`;o0000XOooool002Wooooo00?o0000ooooooooool08oooool3o`0003Wooooo00?o0000oooooooo
ool0eOooool00ol0003oooooooooo`0fooooo`?o0000XOooool002Wooooo00?o0000ooooooooool0
9?ooool2o`0003Wooooo00?o0000ooooooooool0eOooool00ol0003oooooooooo`0fooooo`;o0000
X_ooool002Wooooo00?o0000ooooooooool09?ooool3o`0003Wooooo00?o0000ooooooooool0dooo
ool00ol0003oooooooooo`0fooooo`?o0000X_ooool002Wooooo00?o0000ooooooooool09Oooool3
o`0003Sooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`0fooooo`;o0000Xoooool0
02Wooooo00?o0000ooooooooool09_ooool3o`0003Sooooo00?o0000ooooooooool0dOooool00ol0
003oooooooooo`0fooooo`?o0000Xoooool002Wooooo0_l0000Xooooo`?o0000>?ooool00ol0003o
ooooooooo`3?ooooo`03o`000?oooooooooo03Kooooo0ol0002Tooooo`00:Oooool00ol0003ooooo
ooooo`0Xooooo`;o0000>?ooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo03Kooooo
0_l0002Uooooo`00:Oooool00ol0003oooooooooo`0Xooooo`?o0000>?ooool00ol0003ooooooooo
o`3=ooooo`03o`000?oooooooooo03Kooooo0ol0002Uooooo`00:Oooool00ol0003oooooooooo`0Y
ooooo`;o0000>?ooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo03Gooooo0ol0002V
ooooo`00:Oooool00ol0003oooooooooo`0Yooooo`?o0000>?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo03Gooooo0ol0002Wooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o
0000>?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo03Gooooo0_l0002Xooooo`00
:Oooool00ol0003oooooooooo`0Zooooo`?o0000>?ooool00ol0003oooooooooo`39ooooo`03o`00
0?oooooooooo03Gooooo0ol0002Xooooo`00:Oooool00ol0003oooooooooo`0[ooooo`;o0000>?oo
ool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo03Gooooo0_l0002Yooooo`00:Oooool2
o`0002cooooo0ol0000hooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0=Oooool3
o`000:Wooooo000Yooooo`03o`000?oooooooooo02cooooo0ol0000gooooo`03o`000?oooooooooo
0<Oooooo00?o0000ooooooooool0=?ooool3o`000:[ooooo000Yooooo`03o`000?oooooooooo02go
oooo0ol0000gooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0=?ooool3o`000:_o
oooo000Yooooo`03o`000?oooooooooo02kooooo0ol0000gooooo`03o`000?oooooooooo0<?ooooo
00?o0000ooooooooool0=?ooool3o`000:cooooo000Yooooo`03o`000?oooooooooo02oooooo0_l0
000gooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0=?ooool2o`000:gooooo000Y
ooooo`03o`000?oooooooooo02oooooo0ol0000gooooo`03o`000?oooooooooo0<7ooooo00?o0000
ooooooooool0=?ooool3o`000:gooooo000Yooooo`03o`000?oooooooooo033ooooo0ol0000foooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0=?ooool2o`000:kooooo000Yooooo`;o
0000<_ooool3o`0003Kooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0dooooo`?o
0000[_ooool002Wooooo00?o0000ooooooooool0<_ooool2o`0003Kooooo00?o0000ooooooooool0
_oooool00ol0003oooooooooo`0dooooo`;o0000[oooool002Wooooo00?o0000ooooooooool0<_oo
ool3o`0003Kooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0dooooo`?o0000[ooo
ool002Wooooo00?o0000ooooooooool0<oooool2o`0003Kooooo00?o0000ooooooooool0_Oooool0
0ol0003oooooooooo`0cooooo`?o0000/?ooool002Wooooo00?o0000ooooooooool0<oooool3o`00
03Kooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`?o0000/Oooool001;o
oooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0=?ooool3o`0003Ko
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0booooo`?o0000/_ooool0017ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0eooooo`?o0000=_ooool00ol0003oooooooooo`2h
ooooo`03o`000?oooooooooo03;ooooo0ol0002cooooo`004Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`?o0000
=_ooool3o`0003Kooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0booooo`?o0000
]?ooool001;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0gooooo`;o0000=_ooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo03;ooooo0_l0002eooooo`004Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo03Oooooo0ol0000fooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0<_ooool3
o`000;Gooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0>?ooool3o`0003Gooooo
00?o0000ooooooooool0/oooool00ol0003oooooooooo`0booooo`?o0000]_ooool001;ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0>Oooool3o`0003Gooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`0booooo`?o0000]oooool002Wooooo00?o0000
ooooooooool0>_ooool3o`0003Cooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0b
ooooo`;o0000^?ooool002Wooooo00?o0000ooooooooool0>oooool3o`0003Cooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`0booooo`?o0000^?ooool002Wooooo00?o0000oooooooo
ool0??ooool3o`0003?ooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0aooooo`?o
0000^Oooool002Wooooo0_l0000nooooo`?o0000<oooool00ol0003oooooooooo`2]ooooo`03o`00
0?oooooooooo033ooooo1?l0002jooooo`00:Oooool00ol0003oooooooooo`0nooooo`?o0000<ooo
ool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo033ooooo1?l0002kooooo`00:Oooool0
0ol0003oooooooooo`0oooooo`?o0000<oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo033ooooo0ol0002mooooo`00:Oooool00ol0003oooooooooo`10ooooo`?o0000<oooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo033ooooo0ol0002nooooo`00:Oooool00ol0003o
ooooooooo`11ooooo`;o0000<oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo033o
oooo0_l0002oooooo`00:Oooool00ol0003oooooooooo`11ooooo`?o0000<oooool00ol0003ooooo
ooooo`2Uooooo`03o`000?oooooooooo033ooooo0ol0002oooooo`00:Oooool00ol0003ooooooooo
o`12ooooo`?o0000<_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo02oooooo0ol0
0030ooooo`00:Oooool2o`0004Cooooo0ol0000booooo`03o`000?oooooooooo0:?ooooo00?o0000
ooooooooool0;oooool3o`000<7ooooo000Yooooo`03o`000?oooooooooo04Cooooo0ol0000aoooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;_ooool3o`000<;ooooo000Yooooo`03
o`000?oooooooooo04Gooooo0ol0000aooooo`03o`000?oooooooooo0:7ooooo00?o0000oooooooo
ool0;_ooool3o`000<?ooooo000Yooooo`03o`000?oooooooooo04Kooooo0ol0000aooooo`03o`00
0?oooooooooo09oooooo00?o0000ooooooooool0;_ooool3o`000<Cooooo000Yooooo`03o`000?oo
oooooooo04Oooooo1?l0000`ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0;Ooo
ool4o`000<Gooooo000Yooooo`03o`000?oooooooooo04Sooooo1?l0000`ooooo`03o`000?oooooo
oooo09_ooooo00?o0000ooooooooool0;Oooool4o`000<Kooooo000Yooooo`03o`000?oooooooooo
04[ooooo0ol0000`ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0;Oooool3o`00
0<Sooooo000Yooooo`;o0000C?ooool3o`00033ooooo00?o0000ooooooooool0Uoooool00ol0003o
ooooooooo`0]ooooo`?o0000bOooool002Wooooo00?o0000ooooooooool0C?ooool3o`0002oooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0/ooooo`?o0000b_ooool002Wooooo00?o
0000ooooooooool0COooool3o`0002oooooo00?o0000ooooooooool0UOooool00ol0003ooooooooo
o`0/ooooo`?o0000boooool002Wooooo00?o0000ooooooooool0C_ooool3o`0002oooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`0[ooooo`?o0000c?ooool002Wooooo00?o0000oooo
ooooool0Coooool4o`0002kooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Zoooo
o`Co0000cOooool002Wooooo00?o0000ooooooooool0D?ooool4o`0002kooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`0Zooooo`Co0000c_ooool002Wooooo00?o0000ooooooooool0
D_ooool3o`0002kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Zooooo`?o0000
d?ooool002Wooooo0_l0001Dooooo`Co0000;Oooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo02[ooooo0ol0003Aooooo`00:Oooool00ol0003oooooooooo`1Dooooo`Co0000;?ooool0
0ol0003oooooooooo`2<ooooo`03o`000?oooooooooo02Wooooo0ol0003Booooo`00:Oooool00ol0
003oooooooooo`1Fooooo`?o0000;?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
02Wooooo0ol0003Cooooo`00:Oooool00ol0003oooooooooo`1Gooooo`?o0000;?ooool00ol0003o
ooooooooo`28ooooo`03o`000?oooooooooo02Wooooo0ol0003Dooooo`00:Oooool00ol0003ooooo
ooooo`1Hooooo`Co0000:oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02Sooooo
1?l0003Eooooo`004_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool00ol0003ooooooooo
o`1Iooooo`Co0000:_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02Sooooo1?l0
003Fooooo`005?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo0ol0000Zooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0:?ooool3o`000=Sooooo000Eooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo05cooooo0ol0000Zooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool0:?ooool3o`000=Wooooo000Booooo`Co00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Oooooo0ol0001Mooooo`Co0000:Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo02Oooooo1?l0003Jooooo`004Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo05kooooo1Ol0000Xooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09_oo
ool5o`000=_ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0H?ooool4o`0002So
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Vooooo`Co0000gOooool001;ooooo
0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0H_ooool4o`0002Oooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Uooooo`Co0000goooool002Wooooo00?o
0000ooooooooool0Hoooool4o`0002Oooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`0Tooooo`Co0000h?ooool002Wooooo00?o0000ooooooooool0IOooool3o`0002Oooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0Sooooo`Co0000h_ooool002Wooooo00?o0000oooo
ooooool0I_ooool3o`0002Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Soooo
o`Co0000hoooool002Wooooo0_l0001Xooooo`Co00009_ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo02;ooooo1?l0003Uooooo`00:Oooool00ol0003oooooooooo`1Xooooo`Co0000
9Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02;ooooo1?l0003Vooooo`00:Ooo
ool00ol0003oooooooooo`1Zooooo`Co00009?ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo027ooooo1?l0003Xooooo`00:Oooool00ol0003oooooooooo`1[ooooo`Co00009?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo027ooooo1?l0003Yooooo`00:Oooool00ol0
003oooooooooo`1]ooooo`Co00008oooool2o`0006_ooooo0_l0000Rooooo`Co0000joooool002Wo
oooo00?o0000ooooooooool0K_ooool6o`0002;ooooo0_l0001Xooooo`03o`000?oooooooooo023o
oooo1Ol0003/ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`Ko00008_ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo01oooooo1Ol0003^ooooo`00:Oooool2o`0007Cooooo1Ol0
000Qooooo`03o`000?oooooooooo067ooooo0_l0000Pooooo`Go0000l?ooool002Wooooo00?o0000
ooooooooool0MOooool5o`00023ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0N
ooooo`Go0000l_ooool002Wooooo00?o0000ooooooooool0Moooool4o`00023ooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`0Nooooo`Co0000m?ooool002Wooooo00?o0000oooooooo
ool0NOooool4o`0001oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Mooooo`Co
0000m_ooool002Wooooo00?o0000ooooooooool0N_ooool5o`0001kooooo0_l0001Iooooo`;o0000
7_ooool5o`000?Oooooo000Yooooo`03o`000?oooooooooo07cooooo1Ol0000Nooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool07?ooool5o`000?Wooooo000Yooooo`03o`000?oooooo
oooo07kooooo1Ol0000Mooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool06oooool5
o`000?_ooooo000Yooooo`03o`000?oooooooooo083ooooo1Ol0000Looooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool06_ooool5o`000?gooooo000Yooooo`;o0000Poooool6o`0001[o
oooo0_l0001?ooooo`;o00006_ooool6o`000?oooooo000Yooooo`03o`000?oooooooooo08Cooooo
1ol0000Iooooo`;o0000Boooool2o`0001Wooooo1ol0003oooooo`;ooooo000Yooooo`03o`000?oo
oooooooo08Oooooo1ol0000Hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_oo
ool7o`000?oooooo1Oooool002Wooooo00?o0000ooooooooool0R_ooool6o`0001Oooooo0_l00015
ooooo`;o00005_ooool7o`000?oooooo2?ooool002Wooooo00?o0000ooooooooool0SOooool6o`00
01Kooooo0_l00011ooooo`;o00005Oooool7o`000?oooooo2oooool002Wooooo00?o0000oooooooo
ool0Soooool7o`0001Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`Oo
0000ooooool>ooooo`00:Oooool00ol0003oooooooooo`2Booooo`Oo00004oooool2o`0003_ooooo
0_l0000Booooo`Oo0000oooooolAooooo`00:Oooool2o`0009Kooooo1ol0000Booooo`;o0000=ooo
ool2o`00017ooooo1ol0003ooooooaCooooo000Yooooo`03o`000?oooooooooo09Sooooo1ol0000A
ooooo`;o0000<oooool2o`00013ooooo1ol0003ooooooaOooooo000Yooooo`03o`000?oooooooooo
09_ooooo2?l0000?ooooo`;o0000;oooool2o`0000kooooo2?l0003ooooooa[ooooo000Yooooo`03
o`000?oooooooooo09kooooo2?l0000>ooooo`;o0000:oooool2o`0000gooooo2?l0003ooooooago
oooo000Yooooo`03o`000?oooooooooo0:;ooooo3?l00008ooooo`Go00008_ooool4o`0000Oooooo
3?l0003oooooob7ooooo000<ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00002?oo
ool00ol0003oooooooooo`2UoooooaGo000000?oooooo`000?l000001Ol0000Doooooa_o0000oooo
oolTooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0:go
oooo7?l00006oooooa[o0000ooooool/ooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007
ooooo`?o0000^OoooolTo`000?oooooo>?ooool000gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`35ooooo`co0000oooooom4ooooo`003Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo0?oooooooooooolFooooo`003?ooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool0oooooooooooooaKooooo000=ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0oooooooo
oooooaKooooo000Yooooo`03o`000?oooooooooo0?oooooooooooolFooooo`00:Oooool00ol0003o
ooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooooaKooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`005?ooool3o`0002oooooo00?o0000ooooooooool0ooooooohooooo`005Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo0?oooooomoooool000?ooooo0ol00003ooooo`?o
00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`?o00000_ooool3o`00
00Cooooo1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001?ooool3o`00
00Gooooo00?o0000ooooooooool00ol000000ooooooo0000o`00003ooooooo7ooooo0004ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003oooooo`000?oooooo000000;ooooo00Ko0000
oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`000?ooooool_oo
ool000Cooooo00Co0000oooooooooooooooo1Ol000001_oooooo0000ooooool0003oooooo`0000;o
oooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo00?o0000ooooooooool00oooool3o`00
00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo1Ol00008ooooo`03o`000?oooooo00000?ooooooloooool000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooom?ooool000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`?o00000_ooool2o`000004ooooool0003oooooooooo`Co
00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0ol00009oooo
o`03o`000?oooooo00000?ooooooloooool000;ooooo00Go0000ooooool0003oooooo`00000Voooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000ooooooobooooo`000_ooool5o`00
02Kooooo00?o0000ooooooooool06_ooool3o`000003ooooool0003o00000?oooooolOooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;o
oooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooo
oooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_oo
ool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0992175, 183.273, \
0.00241982, 2.7443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diffuse Interfaces in the Bragg-Williams approximation", "Subsection"],

Cell["\<\
The gradient-energy coefficient Kc is related to W and \
\[CapitalDelta]U and the lattice constant a of the crystal. Assuming a \
reasonable value for the lattice constant I calculate Kc for the system \
as\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 0.29\[Times]10\^\(-9\);\)\), "\[IndentingNewLine]", 
    \(\(VMolar\  = \ a\^3\/2\ N0;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]U50 = \[CapitalDelta]U[0.5, 
          0];\)\), "\[IndentingNewLine]", 
    \(Kc = \(2\/3\) \[CapitalDelta]U50 \(\(\ \)\(\((\@3/2  \
a)\)\^2\)\)\/VMolar\)}], "Input"],

Cell[BoxData[
    \(4.760863103448276`*^-11\)], "Output"]
}, Open  ]],

Cell["\<\
We will look at the energy of the interface between equilibrium \
phases at T = 900 K. We need the expression for the free energy density \
\[CapitalDelta]fhom(XB) as illustrated in KoM Fig. 18.1. First calculate the \
free energy density of the equilibrium phases. Note again that \
\[CapitalDelta]F is symmetric about XB = 0.5 and the common tangent has zero \
slope.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(T = 900;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha]Root = 
        FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 
            0, {XB,  .2}];\)\), "\[IndentingNewLine]", 
    \(XBEq\[Alpha] = \[Alpha]Root[\([1, 2]\)]\), "\[IndentingNewLine]", 
    \(\(XBEq\[Beta] = 1 - XBEq\[Alpha];\)\), "\[IndentingNewLine]", 
    \(\[CapitalDelta]FEq[T_] = \[CapitalDelta]F[XBEq\[Alpha], 0, 
        T]\)}], "Input"],

Cell[BoxData[
    \(0.2372852436709955`\)], "Output"],

Cell[BoxData[
    \(\(-2181.308904178689`\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now calculating \[CapitalDelta]fhom(XB) on a per unit volume basis (units \
are thus Joule/",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\^3\)\()\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]fHom[XB_, 
        T_] := \(\[CapitalDelta]F[XB, 0, T] - \[CapitalDelta]FEq[T]\)\/VMolar\
\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\[CapitalDelta]fHom[XB, T], {XB, XBEq\[Alpha], 
        XBEq\[Beta]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.406288 1.81258 0.0147151 3.53997e-08 [
[.31874 .00222 -9 -9 ]
[.31874 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.68126 .00222 -9 -9 ]
[.68126 .00222 9 0 ]
[.86252 .00222 -9 -9 ]
[.86252 .00222 9 0 ]
[.12498 .10321 -40.5 -6.25 ]
[.12498 .10321 0 6.25 ]
[.12498 .19171 -28.5 -6.25 ]
[.12498 .19171 0 6.25 ]
[.12498 .28021 -40.5 -6.25 ]
[.12498 .28021 0 6.25 ]
[.12498 .36871 -28.5 -6.25 ]
[.12498 .36871 0 6.25 ]
[.12498 .45721 -46.5 -6.25 ]
[.12498 .45721 0 6.25 ]
[.12498 .54571 -40.5 -6.25 ]
[.12498 .54571 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.31874 .01472 m
.31874 .02097 L
s
[(0.4)] .31874 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.5)] .5 .00222 0 1 Mshowa
.68126 .01472 m
.68126 .02097 L
s
[(0.6)] .68126 .00222 0 1 Mshowa
.86252 .01472 m
.86252 .02097 L
s
[(0.7)] .86252 .00222 0 1 Mshowa
.125 Mabswid
.17374 .01472 m
.17374 .01847 L
s
.20999 .01472 m
.20999 .01847 L
s
.24624 .01472 m
.24624 .01847 L
s
.28249 .01472 m
.28249 .01847 L
s
.35499 .01472 m
.35499 .01847 L
s
.39125 .01472 m
.39125 .01847 L
s
.4275 .01472 m
.4275 .01847 L
s
.46375 .01472 m
.46375 .01847 L
s
.53625 .01472 m
.53625 .01847 L
s
.5725 .01472 m
.5725 .01847 L
s
.60875 .01472 m
.60875 .01847 L
s
.64501 .01472 m
.64501 .01847 L
s
.71751 .01472 m
.71751 .01847 L
s
.75376 .01472 m
.75376 .01847 L
s
.79001 .01472 m
.79001 .01847 L
s
.82626 .01472 m
.82626 .01847 L
s
.10123 .01472 m
.10123 .01847 L
s
.06498 .01472 m
.06498 .01847 L
s
.02873 .01472 m
.02873 .01847 L
s
.89877 .01472 m
.89877 .01847 L
s
.93502 .01472 m
.93502 .01847 L
s
.97127 .01472 m
.97127 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.13748 .10321 m
.14373 .10321 L
s
gsave
.12498 .10321 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.13748 .19171 m
.14373 .19171 L
s
gsave
.12498 .19171 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.13748 .28021 m
.14373 .28021 L
s
gsave
.12498 .28021 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.13748 .36871 m
.14373 .36871 L
s
gsave
.12498 .36871 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.13748 .45721 m
.14373 .45721 L
s
gsave
.12498 .45721 -46.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.25) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.13748 .54571 m
.14373 .54571 L
s
gsave
.12498 .54571 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.125 Mabswid
.13748 .03241 m
.14123 .03241 L
s
.13748 .05011 m
.14123 .05011 L
s
.13748 .06781 m
.14123 .06781 L
s
.13748 .08551 m
.14123 .08551 L
s
.13748 .12091 m
.14123 .12091 L
s
.13748 .13861 m
.14123 .13861 L
s
.13748 .15631 m
.14123 .15631 L
s
.13748 .17401 m
.14123 .17401 L
s
.13748 .20941 m
.14123 .20941 L
s
.13748 .22711 m
.14123 .22711 L
s
.13748 .24481 m
.14123 .24481 L
s
.13748 .26251 m
.14123 .26251 L
s
.13748 .29791 m
.14123 .29791 L
s
.13748 .31561 m
.14123 .31561 L
s
.13748 .33331 m
.14123 .33331 L
s
.13748 .35101 m
.14123 .35101 L
s
.13748 .38641 m
.14123 .38641 L
s
.13748 .40411 m
.14123 .40411 L
s
.13748 .42181 m
.14123 .42181 L
s
.13748 .43951 m
.14123 .43951 L
s
.13748 .47491 m
.14123 .47491 L
s
.13748 .49261 m
.14123 .49261 L
s
.13748 .51031 m
.14123 .51031 L
s
.13748 .52801 m
.14123 .52801 L
s
.13748 .56341 m
.14123 .56341 L
s
.13748 .58111 m
.14123 .58111 L
s
.13748 .59881 m
.14123 .59881 L
s
.13748 .61651 m
.14123 .61651 L
s
.25 Mabswid
.13748 0 m
.13748 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01473 L
.02605 .01477 L
.02729 .01486 L
.02846 .01497 L
.03053 .01524 L
.03279 .01565 L
.03527 .01623 L
.0379 .01698 L
.04262 .0187 L
.05205 .02348 L
.06244 .03065 L
.0842 .05139 L
.10458 .07673 L
.14335 .13657 L
.18458 .21062 L
.22428 .28588 L
.26248 .3572 L
.30312 .42783 L
.34225 .48748 L
.38383 .53911 L
.4047 .55974 L
.4239 .57536 L
.44265 .58737 L
.45221 .59222 L
.46245 .59646 L
.46773 .59825 L
.47272 .59969 L
.47759 .60087 L
.48209 .60176 L
.48635 .60241 L
.48852 .60268 L
.49087 .60291 L
.49321 .6031 L
.49426 .60316 L
.49541 .60322 L
.49669 .60327 L
.49738 .60329 L
.49803 .6033 L
.49919 .60332 L
.50042 .60332 L
.50166 .60331 L
.50236 .60329 L
.50301 .60328 L
.50433 .60323 L
.50575 .60316 L
.50832 .60298 L
.51067 .60276 L
.51339 .60244 L
.51636 .60201 L
Mistroke
.52177 .60101 L
.53223 .59826 L
.54192 .59477 L
.56248 .5844 L
.5811 .57161 L
.62122 .53355 L
.65983 .48456 L
.70088 .42122 L
.74042 .35191 L
.77844 .28069 L
.81892 .20409 L
.85788 .13449 L
.87773 .10243 L
.89929 .07153 L
.91865 .04827 L
.92925 .03771 L
.93919 .0294 L
.94838 .02322 L
.95679 .01895 L
.96134 .01723 L
.96613 .01588 L
.96862 .01538 L
.97094 .01504 L
.97227 .0149 L
.97348 .0148 L
.97415 .01476 L
.97488 .01474 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo002booooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000Eoooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0005Sooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol0001Hooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04gooooo002aooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0EOooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000E_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000E_ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo04gooooo002aooooo`04o`000?ooooooooooo`0000Oooooo1Ol0001Foooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0E?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool00000E_ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo04cooooo002aooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo0000Eoooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo05Cooooo00Co0000
oooooooooooo00001oooool4o`0005Oooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`1<ooooo`00/Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000005Oooooo
00Co0000oooooooooooo00001oooool4o`0005Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`1Hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0Boooool0
0;7ooooo00Co0000oooooooooooo00002Oooool2o`0005Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`1Hooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
Eoooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000COooool005?o
oooo00?o0000ooooooooool0G?ooool2o`0000_ooooo00?o0000ooooooooool0E_ooool2o`0000So
oooo1Ol0001Gooooo`;o00002_ooool2o`0005Sooooo0_l00008ooooo`Go0000COooool005?ooooo
00?o0000ooooooooool0ooooooo[ooooo`00Doooool00ol0003oooooooooo`3oooooon_ooooo001C
ooooo`03o`000?oooooooooo0?oooooojoooool005?ooooo00?o0000ooooooooool0ooooooo[oooo
o`00Doooool00ol0003oooooooooo`3oooooon_ooooo001Cooooo`03o`000?oooooooooo0?oooooo
joooool005?ooooo00?o0000ooooooooool0ooooooo[ooooo`00Doooool00ol0003oooooooooo`3o
ooooon_ooooo0006oooooooo0000ool0000eo`0000Oooooo000Fooooo`03o`000?oooooooooo00;o
oooo0ol0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo0ol00004ooooo`03o`000?oooooooooo01Go
oooo000Fooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo
0_l00007ooooo`03o`000?oooooooooo01Gooooo000Pooooo`;o0000<Oooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo02kooooo0ol0000Qooooo`008_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo0?ooooooaOooool2o`0002Cooooo000Sooooo`;o0000;_ooool00ol0
003oooooooooo`3oooooolCooooo00?o0000ooooooooool09?ooool002Gooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`3ooooool?ooooo00?o0000ooooooooool09Oooool002Kooooo
0_l0000[ooooo`03o`000?oooooooooo0?oooooo`_ooool00ol0003oooooooooo`0Vooooo`00:?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo`?ooool2o`0002Wooooo000Y
ooooo`;o0000:?ooool00ol0003oooooooooo`3ooooookoooooo00?o0000ooooooooool0:Oooool0
02_ooooo00?o0000ooooooooool09Oooool3o`000?oooooo_Oooool2o`0002cooooo000/ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0oooooonlooooo`03o`000?oooooooooo02co
oooo000]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0oooooonkooooo`03o`00
0?oooooooooo02gooooo000^ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0oooo
oonjooooo`03o`000?oooooooooo02kooooo000_ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0ooooooniooooo`03o`000?oooooooooo02oooooo000`ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0oooooonhooooo`03o`000?oooooooooo033ooooo000aooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0oooooongooooo`03o`000?oooooooooo037o
oooo000booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooonfooooo`03o`00
0?oooooooooo03;ooooo000cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooo
ooneooooo`03o`000?oooooooooo03?ooooo000dooooo`03o`000?oooooooooo01cooooo0ol0003o
oooookGooooo00?o0000ooooooooool0<oooool003Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`3ooooookCooooo00?o0000ooooooooool0=?ooool003Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`3ooooook?ooooo00?o0000ooooooooool0=Oooool003Kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooook;ooooo00?o0000ooooooooool0
=_ooool003Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3ooooook7ooooo00?o
0000ooooooooool0=oooool003Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3o
oooook3ooooo00?o0000ooooooooool0>?ooool003Wooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`3oooooojoooooo00?o0000ooooooooool0>Oooool003[ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`3oooooojoooooo00?o0000ooooooooool0>Oooool003_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`3oooooojkooooo00?o0000ooooooooool0
>_ooool003_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3oooooojgooooo00?o
0000ooooooooool0>oooool003cooooo00?o0000ooooooooool05?ooool3o`000?oooooo[?ooool0
0ol0003oooooooooo`0looooo`00?Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
0?ooooooZoooool00ol0003oooooooooo`0mooooo`00?_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0?ooooooZ_ooool00ol0003oooooooooo`0nooooo`00?oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo0?ooooooZ_ooool00ol0003oooooooooo`0nooooo`00@?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?ooooooZOooool00ol0003ooooooooo
o`0oooooo`00@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?ooooooZ?ooool0
0ol0003oooooooooo`10ooooo`00@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0?ooooooZ?ooool00ol0003oooooooooo`10ooooo`00@_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo0?ooooooYoooool00ol0003oooooooooo`11ooooo`00@oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0?ooooooY_ooool00ol0003oooooooooo`12ooooo`00@ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?ooooooY_ooool00ol0003ooooooooo
o`12ooooo`00A?ooool00ol0003oooooooooo`0<ooooo`?o0000oooooonUooooo`03o`000?oooooo
oooo04?ooooo0015ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooonToooo
o`03o`000?oooooooooo04Cooooo0015ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0oooooonTooooo`03o`000?oooooooooo04Cooooo0016ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0oooooonSooooo`03o`000?oooooooooo04Gooooo0017ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0oooooonRooooo`03o`000?oooooooooo04Kooooo0017
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooonRooooo`03o`000?oooooo
oooo04Kooooo0018ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooonQoooo
o`03o`000?oooooooooo04Oooooo000Tooooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o
00000oooool01Ol0003ooooooooooooooooo000000Oooooo0ol00002ooooo`04o`000?oooooo0000
o`0000Oooooo00?o0000ooooooooool0oooooonPooooo`03o`000?oooooooooo04Sooooo000Uoooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo0?ooooooX?ooool00ol0003oooooooooo`18ooooo`009_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`3ooooooioooooo00?o
0000ooooooooool0BOooool002Oooooo00?o0000ooooooooool02_ooool01ol0003ooooooooooooo
oooo0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool0
1Oooool5o`000?ooooooW?ooool00ol0003oooooooooo`1:ooooo`009?ooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l00003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool0oooooonNoooo
o`03o`000?oooooooooo04[ooooo000Tooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`0@ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`;o000000?ooooo
o`000?ooool0oooooonNooooo`03o`000?oooooooooo04_ooooo000Uooooo`?o00002?ooool5o`00
00oooooo00?o0000ooooooooool00oooool3o`0000;ooooo00Go0000ooooool0003oooooo`00003o
oooooikooooo00?o0000ooooooooool0C?ooool004gooooo00?o0000ooooool000000_l000000ooo
oooo0000ooooo`3ooooooigooooo00?o0000ooooooooool0C?ooool004kooooo0_l00003ooooo`03
o`000?oooooooooo0?ooooooVoooool00ol0003oooooooooo`1=ooooo`00C_ooool01_l0003ooooo
o`000?l0003oooooo`000?ooooooWOooool00ol0003oooooooooo`1=ooooo`00Coooool01Ol0003o
oooooooooooooooo00000?ooooooW?ooool00ol0003oooooooooo`1>ooooo`00D?ooool01?l0003o
ooooooooool0003ooooooi_ooooo00?o0000ooooooooool0Coooool0053ooooo00Co0000oooooooo
oooo0000oooooonKooooo`03o`000?oooooooooo04oooooo001Aooooo`03o`000?oooooo000000;o
0000oooooonHooooo`03o`000?oooooooooo053ooooo001Booooo`;o0000oooooonJooooo`03o`00
0?oooooooooo053ooooo001Booooo`;o0000oooooonIooooo`03o`000?oooooooooo057ooooo001C
ooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`1Booooo`00Doooool00ol0
003oooooooooo`3ooooooiKooooo00?o0000ooooooooool0D_ooool005?ooooo0_l0003ooooooiKo
oooo00?o0000ooooooooool0Doooool005?ooooo00?o0000ooooool00000oooooonEooooo`03o`00
0?oooooooooo05?ooooo001Cooooo`03o`000?oooooo00000?ooooooU?ooool00ol0003ooooooooo
o`1Dooooo`00Doooool01?l0003oooooooooool0003ooooooi;ooooo00?o0000ooooooooool0EOoo
ool005?ooooo00Go0000ooooooooooooooooo`00003ooooooi7ooooo00?o0000ooooooooool0EOoo
ool005?ooooo0ol000000ooooooo0000ooooo`3oooooohoooooo00?o0000ooooooooool0E_ooool0
05?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooohgooooo00?o0000oooo
ooooool0E_ooool005?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooohco
oooo00?o0000ooooooooool0Eoooool005?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooooh[ooooo00?o0000ooooooooool0F?ooool005?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3ooooooh[ooooo00?o0000ooooooooool0F?ooool005?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooohSooooo00?o0000ooooooooool0FOooool0
05?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooohOooooo00?o0000oooo
ooooool0FOooool005?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooohKo
oooo00?o0000ooooooooool0F_ooool005?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3oooooohGooooo00?o0000ooooooooool0F_ooool005?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooohCooooo00?o0000ooooooooool0Foooool005?ooooo0ol00007
ooooo`03o`000?oooooooooo0?ooooooPoooool00ol0003oooooooooo`1Kooooo`00Doooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?ooooooP_ooool00ol0003oooooooooo`1Loooo
o`00Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?ooooooP?ooool00ol0003o
ooooooooo`1Mooooo`00Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo
P?ooool00ol0003oooooooooo`1Mooooo`00Doooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0?ooooooO_ooool00ol0003oooooooooo`1Nooooo`00Doooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0?ooooooO_ooool00ol0003oooooooooo`1Nooooo`00Doooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0?ooooooO?ooool00ol0003oooooooooo`1Ooooo
o`00Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?ooooooNoooool00ol0003o
ooooooooo`1Oooooo`00Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo
N_ooool00ol0003oooooooooo`1Pooooo`00Doooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0?ooooooN?ooool00ol0003oooooooooo`1Qooooo`00Doooool3o`0000cooooo00?o0000
ooooooooool0oooooomhooooo`03o`000?oooooooooo067ooooo001Cooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0oooooomfooooo`03o`000?oooooooooo06;ooooo001Cooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0oooooomfooooo`03o`000?oooooooooo06;o
oooo001Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooomdooooo`03o`00
0?oooooooooo06?ooooo001Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooo
oomdooooo`03o`000?oooooooooo06?ooooo001Cooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0oooooombooooo`03o`000?oooooooooo06Cooooo001Cooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0oooooom`ooooo`03o`000?oooooooooo06Gooooo000aooooo`?o
00000oooool01Ol0003ooooooooooooooooo000000Oooooo0ol00004ooooo`;o00001oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0?ooooooL?ooool00ol0003oooooooooo`1Uoooo
o`00<?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`3oooooofkooooo00?o0000ooooooooool0I_ooool003Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0?ooooooK_ooool0
0ol0003oooooooooo`1Vooooo`00=?ooool01ol0003ooooooooooooooooo0000ooooool000002Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo1Ol0000@ooooo`03o`00
0?oooooooooo0?ooooooK?ooool00ol0003oooooooooo`1Wooooo`00<?ooool4o`0000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?ooooooK?ooool00ol0003o
ooooooooo`1Wooooo`00<?ooool00ol0003oooooooooo`0@ooooo`;o00001?ooool01?l0003ooooo
ooooool00003ooooo`;o000000?oooooo`000?ooool05?ooool00ol0003oooooooooo`3oooooof[o
oooo00?o0000ooooooooool0J?ooool0033ooooo1Ol0000?ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`05o`000?oooooo0000ooooool000005Oooool00ol0003oooooooooo`3oooooof[o
oooo00?o0000ooooooooool0J?ooool004oooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`00
0?oooooooooo0?ooooooJ?ooool00ol0003oooooooooo`1Yooooo`00Coooool01Ol0003ooooooooo
oooooooo000001Kooooo00?o0000ooooooooool0oooooomWooooo`03o`000?oooooooooo06[ooooo
001@ooooo`;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`3oooooofKooooo00?o
0000ooooooooool0J_ooool005?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3o
ooooofCooooo00?o0000ooooooooool0Joooool005?ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`3oooooofCooooo00?o0000ooooooooool0Joooool005?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`3oooooof;ooooo00?o0000ooooooooool0K?ooool005?ooooo
0ol0000Gooooo`03o`000?oooooooooo0?ooooooH_ooool00ol0003oooooooooo`1/ooooo`00Dooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?ooooooH?ooool00ol0003ooooooooo
o`1]ooooo`00Doooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?ooooooH?ooool0
0ol0003oooooooooo`1]ooooo`00Doooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
0?ooooooG_ooool00ol0003oooooooooo`1^ooooo`00Doooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0?ooooooG_ooool00ol0003oooooooooo`1^ooooo`00Doooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo0?ooooooG?ooool00ol0003oooooooooo`1_ooooo`00Dooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0?ooooooFoooool00ol0003ooooooooo
o`1`ooooo`00Doooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0?ooooooF_ooool0
0ol0003oooooooooo`1`ooooo`00Doooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
0?ooooooFOooool00ol0003oooooooooo`1aooooo`00Doooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo0?ooooooF?ooool00ol0003oooooooooo`1aooooo`00Doooool3o`0001cooooo
00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo07;ooooo001Cooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0oooooomFooooo`03o`000?oooooooooo07;ooooo001C
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooomDooooo`03o`000?oooooo
oooo07?ooooo001Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooomDoooo
o`03o`000?oooooooooo07?ooooo001Cooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0oooooomBooooo`03o`000?oooooooooo07Cooooo001Cooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0oooooomBooooo`03o`000?oooooooooo07Cooooo001Cooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0oooooom@ooooo`03o`000?oooooooooo07Gooooo001C
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0oooooom@ooooo`03o`000?oooooo
oooo07Gooooo001Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0oooooom>oooo
o`03o`000?oooooooooo07Kooooo001Cooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0oooooom=ooooo`03o`000?oooooooooo07Oooooo001Cooooo`?o00008_ooool00ol0003ooooo
ooooo`3oooooodcooooo00?o0000ooooooooool0Moooool005?ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool0N?ooool005?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`3ooooood[ooooo00?o0000ooooooooool0N?ooool0
05?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3oooooodWooooo00?o0000oooo
ooooool0NOooool005?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`3oooooodSo
oooo00?o0000ooooooooool0NOooool005?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`3oooooodOooooo00?o0000ooooooooool0N_ooool005?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0N_ooool005?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`3oooooodGooooo00?o0000ooooooooool0Noooool0
05?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`3oooooodCooooo00?o0000oooo
ooooool0Noooool005?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`3ooooood?o
oooo00?o0000ooooooooool0O?ooool005?ooooo0ol0000Wooooo`03o`000?oooooooooo0?oooooo
@_ooool00ol0003oooooooooo`1looooo`00Doooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo0?oooooo@Oooool00ol0003oooooooooo`1mooooo`00Doooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0?oooooo@?ooool00ol0003oooooooooo`1mooooo`00Doooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0?oooooo?_ooool00ol0003oooooooooo`1noooo
o`00Doooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0?oooooo?Oooool00ol0003o
ooooooooo`1oooooo`00Doooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0?oooooo
??ooool00ol0003oooooooooo`1oooooo`009_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0ol00003ooooo`05o`000?ooooooooooooooool000001oooool3o`0000Cooooo
0_l00007ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0oooooolkooooo`03o`00
0?oooooooooo083ooooo000Vooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0ooooooljooooo`03
o`000?oooooooooo083ooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo>Oooool00ol0003o
ooooooooo`21ooooo`009oooool00ol0003oooooooooo`0:ooooo`07o`000?ooooooooooooooool0
003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo>?ooool00ol0003oooooooooo`21
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`Co00000oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`Go0000:_oo
ool00ol0003oooooooooo`3oooooocOooooo00?o0000ooooooooool0P_ooool002Cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3oooooocKooooo
00?o0000ooooooooool0P_ooool002Cooooo1Ol00007ooooo`Go00003oooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`000003ooooool0003ooooo02kooooo00?o0000ooooooooool0oooo
ooleooooo`03o`000?oooooooooo08?ooooo001?ooooo`05o`000?oooooo0000ooooool00000<?oo
ool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool0Poooool004oooooo0ol00000
0ooooooo0000ooooo`0_ooooo`03o`000?oooooooooo0?oooooo<oooool00ol0003oooooooooo`24
ooooo`00Coooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0oooooolb
ooooo`03o`000?oooooooooo08Cooooo001@ooooo`;o000000?oooooo`000?ooool0<?ooool00ol0
003oooooooooo`3ooooooc7ooooo00?o0000ooooooooool0QOooool005?ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0QOooool005?ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3ooooooboooooo00?o0000ooooooooool0
Q_ooool005?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3oooooobkooooo00?o
0000ooooooooool0Q_ooool005?ooooo0ol0000booooo`03o`000?oooooooooo0?oooooo;?ooool0
0ol0003oooooooooo`27ooooo`00Doooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
0?oooooo:oooool00ol0003oooooooooo`28ooooo`00Doooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`28ooooo`00Doooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`29ooooo`00Dooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003ooooooooo
o`29ooooo`00Doooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0?oooooo9oooool0
0ol0003oooooooooo`2:ooooo`00Doooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
0?oooooo9_ooool00ol0003oooooooooo`2:ooooo`00Doooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`2;ooooo`00Doooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`2;ooooo`00Dooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003ooooooooo
o`2<ooooo`00Doooool3o`0003Oooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooo
oooo08cooooo001Cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0oooooolPoooo
o`03o`000?oooooooooo08gooooo001Cooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0oooooolPooooo`03o`000?oooooooooo08gooooo001Cooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo08kooooo001Cooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo08kooooo001C
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0oooooolLooooo`03o`000?oooooo
oooo08oooooo001Cooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0oooooolLoooo
o`03o`000?oooooooooo08oooooo001Cooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0oooooolJooooo`03o`000?oooooooooo093ooooo001Cooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0oooooolJooooo`03o`000?oooooooooo093ooooo001Cooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo097ooooo001C
ooooo`?o0000?Oooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0TOooool0
05?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`3ooooooaKooooo00?o0000oooo
ooooool0T_ooool005?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3ooooooaCo
oooo00?o0000ooooooooool0Toooool005?ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`3ooooooaCooooo00?o0000ooooooooool0Toooool005?ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0U?ooool005?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0U?ooool0
05?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooo
ooooool0UOooool005?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`3ooooooa3o
oooo00?o0000ooooooooool0UOooool005?ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`3oooooo`kooooo00?o0000ooooooooool0U_ooool005?ooooo0ol00012ooooo`03o`000?oo
oooooooo0?oooooo3Oooool00ol0003oooooooooo`2Fooooo`00Doooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003oooooooooo`2Gooooo`00Doooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo0?oooooo2oooool00ol0003oooooooooo`2Goooo
o`00Doooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003o
ooooooooo`2Hooooo`00Doooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?oooooo
2Oooool00ol0003oooooooooo`2Hooooo`00Doooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo0?oooooo2?ooool00ol0003oooooooooo`2Iooooo`00Doooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo0?oooooo1_ooool00ol0003oooooooooo`2Jooooo`00<Oooool3o`00
00?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o00001?ooool2o`0000Oooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0V_ooool0
03;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo0?oooooo1?ooool00ol0003oooooooooo`2Kooooo`00<_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0ooooool4ooooo`03o`000?oooooo
oooo09_ooooo000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo1Ol00015ooooo`03o`000?oooooo
oooo0?oooooo0_ooool00ol0003oooooooooo`2Looooo`00<_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3oooooo`7ooooo00?o
0000ooooooooool0W?ooool0037ooooo0_l0000@ooooo`;o00001?ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0ooooool00ol0003ooooo
ooooo`2Mooooo`00<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool0o_ooool00ol0003ooooo
ooooo`2Mooooo`00D?ooool01?l0003oooooooooool0001;ooooo`03o`000?oooooooooo0?gooooo
00?o0000ooooooooool0W_ooool0057ooooo00?o0000ooooool00000C?ooool00ol0003ooooooooo
o`3kooooo`03o`000?oooooooooo09oooooo001?ooooo`?o000000?oooooo`000?ooool0Boooool0
0ol0003oooooooooo`3kooooo`03o`000?oooooooooo09oooooo001Cooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0nOooool00ol0003oooooooooo`2Pooooo`00Doooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool0X?ooool005?ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo0:7ooooo
001Cooooo`?o0000COooool00ol0003oooooooooo`3fooooo`03o`000?oooooooooo0:7ooooo001C
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0mOooool00ol0003oooooooooo`2R
ooooo`00Doooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0??ooooo00?o0000oooo
ooooool0Xoooool005?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`3cooooo`03
o`000?oooooooooo0:?ooooo001Cooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
lOooool00ol0003oooooooooo`2Tooooo`00Doooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo0?7ooooo00?o0000ooooooooool0Y?ooool005?ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`3_ooooo`03o`000?oooooooooo0:Gooooo001Cooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`2Uooooo`00Doooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool0Y_ooool005?ooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo0:Oooooo
001Cooooo`?o0000D_ooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo0:Oooooo001C
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0jOooool00ol0003oooooooooo`2X
ooooo`00Doooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo0>Wooooo00?o0000oooo
ooooool0Z?ooool005?ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`3Wooooo`03
o`000?oooooooooo0:Wooooo001Cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
ioooool00ol0003oooooooooo`2Yooooo`00Doooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo0>Gooooo00?o0000ooooooooool0Z_ooool005?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`3Uooooo`03o`000?oooooooooo0:[ooooo001Cooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`2[ooooo`00Doooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo0>;ooooo00?o0000ooooooooool0[?ooool005?ooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo0:cooooo
001Cooooo`?o0000F?ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo0:gooooo001C
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0goooool00ol0003oooooooooo`2]
ooooo`00Doooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0=gooooo00?o0000oooo
ooooool0[_ooool005?ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`3Looooo`03
o`000?oooooooooo0:oooooo001Cooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
foooool00ol0003oooooooooo`2_ooooo`00Doooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo0=[ooooo00?o0000ooooooooool0/?ooool005?ooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`3Hooooo`03o`000?oooooooooo0;7ooooo001Cooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`2aooooo`00Doooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo0=Kooooo00?o0000ooooooooool0/_ooool005?ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo0;;ooooo
001Cooooo`?o0000G_ooool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo0;?ooooo001C
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0d_ooool00ol0003oooooooooo`2d
ooooo`00Doooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo0=7ooooo00?o0000oooo
ooooool0]?ooool005?ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`3?ooooo`03
o`000?oooooooooo0;Gooooo001Cooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
c_ooool00ol0003oooooooooo`2fooooo`00Doooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo0<gooooo00?o0000ooooooooool0]_ooool005?ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo0;Oooooo000Oooooo`?o00001?ooool01?l0
003oooooooooooooool5o`0000;ooooo0ol00003ooooo`05o`000?ooooooooooooooool000001ooo
ool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0b_oo
ool00ol0003oooooooooo`2hooooo`008?ooool00ol0003oooooooooo`08ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01ol0003ooooooooooooooooo0000ooooool000002Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`39ooooo`03o`000?oooooooooo0;Sooooo000Pooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`2iooooo`008?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`Go0000
H_ooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo0;Wooooo000Pooooo`03o`000?oo
oooooooo00Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000?ooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0^_ooool0
01oooooo0_l00009ooooo`07o`000?ooooooooooooooool0003oooooo`00000Booooo`;o00001?oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0006Sooooo00?o0000oooooooo
ool0`oooool00ol0003oooooooooo`2kooooo`008?ooool00ol0003oooooooooo`08ooooo`?o0000
0_ooool5o`0000oooooo00?o0000ooooooooool00oooool2o`0000Cooooo00Co0000oooooooooooo
0000J?ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo0;_ooooo001@ooooo`04o`00
0?ooooooooooo`0006Wooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`2looooo`00
DOooool00ol0003oooooo`00001Zooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0
_Oooool004oooooo0ol000000ooooooo0000ooooo`1Yooooo`03o`000?oooooooooo0;oooooo00?o
0000ooooooooool0_Oooool005?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2m
ooooo`03o`000?oooooooooo0;kooooo001Cooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0^oooool00ol0003oooooooooo`2oooooo`00Doooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo0;_ooooo00?o0000ooooooooool0_oooool005?ooooo0ol0001[ooooo`03o`00
0?oooooooooo0;Wooooo00?o0000ooooooooool0`?ooool005?ooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo0<3ooooo001Cooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`31ooooo`00Doooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0`_ooool005?o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo0<;o
oooo001Cooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0/oooool00ol0003ooooo
ooooo`33ooooo`00Doooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0;7ooooo00?o
0000ooooooooool0a?ooool005?ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo0<Cooooo001Cooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`35ooooo`00Doooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo0:gooooo00?o0000ooooooooool0a_ooool005?ooooo0ol0001booooo`03o`00
0?oooooooooo0:_ooooo00?o0000ooooooooool0aoooool005?ooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo0<Sooooo001Cooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`38ooooo`00Doooool00ol0
003oooooooooo`1eooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0bOooool005?o
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo0<[o
oooo001Cooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0Xoooool00ol0003ooooo
ooooo`3;ooooo`00Doooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0c?ooool005?ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2O
ooooo`03o`000?oooooooooo0<gooooo001Cooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0W_ooool00ol0003oooooooooo`3=ooooo`00Doooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo09cooooo00?o0000ooooooooool0c_ooool005?ooooo0ol0001jooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0coooool005?ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo0=3ooooo001Cooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`3Aooooo`00Doooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0dOooool005?o
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo0=;o
oooo001Cooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Toooool00ol0003ooooo
ooooo`3Cooooo`00Doooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo097ooooo00?o
0000ooooooooool0e?ooool005?ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`2?
ooooo`03o`000?oooooooooo0=Gooooo001Cooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`3Fooooo`00Doooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo08cooooo00?o0000ooooooooool0e_ooool005?ooooo0ol00023ooooo`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool0eoooool005?ooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0=Sooooo001Cooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`3Iooooo`00Doooool00ol0
003oooooooooo`25ooooo`03o`000?oooooooooo08Cooooo0_l0003Looooo`00Doooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0g?ooool005?ooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0=gooooo
001Cooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`3Nooooo`009Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00Go0000
ooooooooooooooooo`000007ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool0R?oo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo0=oooooo000Vooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`3Pooooo`009_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo0>7ooooo000Vooooo`03o`000?oooooooooo00_ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00006ooooo`Go0000ROooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo
0>;ooooo000Vooooo`03o`000?oooooooooo00Oooooo1?l00003ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo0>?ooooo000Uoooo
o`;o00002Oooool00ol0003oooooooooo`0@ooooo`;o00001?ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0008oooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`3Tooooo`009_ooool00ol0003oooooooooo`07ooooo`Go00003oooool00ol0003oooooooooo`03
ooooo`;o00001?ooool01?l0003oooooooooool0002@ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0iOooool0053ooooo00Co0000oooooooooooo0000TOooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo0>Kooooo001Aooooo`03o`000?oooooo000009;ooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`3Wooooo`00Coooool3o`000003ooooool0003ooooo
09;ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`3Xooooo`00Doooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0jOooool005?ooooo
00?o0000ooooooooool0Toooool2o`0006Sooooo00?o0000ooooooooool0j_ooool005?ooooo00?o
0000ooooooooool0UOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0>_ooooo001C
ooooo`?o0000U_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0>cooooo001Coooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`3]oooo
o`00Doooool00ol0003oooooooooo`2Hooooo`;o0000Goooool00ol0003oooooooooo`3^ooooo`00
Doooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
koooool005?ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`1Hooooo`;o0000l_oo
ool005?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo0?;ooooo001Cooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`3cooooo`00Doooool00ol0003oooooooooo`2Nooooo`;o0000D_ooool2o`000?Ko
oooo001Cooooo`03o`000?oooooooooo0:3ooooo0_l0001?ooooo`03o`000?oooooooooo0?Kooooo
001Cooooo`03o`000?oooooooooo0:;ooooo0_l0001;ooooo`;o0000nOooool005?ooooo0ol0002T
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0nOooool005?ooooo00?o0000oooo
ooooool0YOooool2o`0004Kooooo00?o0000ooooooooool0n_ooool005?ooooo00?o0000oooooooo
ool0Yoooool2o`0004;ooooo0_l0003mooooo`00Doooool00ol0003oooooooooo`2Yooooo`;o0000
?_ooool2o`000?oooooo001Cooooo`03o`000?oooooooooo0:_ooooo0_l0000iooooo`?o0000oooo
ool2ooooo`00Doooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo03Cooooo0_l0003o
ooooo`Gooooo001Cooooo`03o`000?oooooooooo0:kooooo0ol0000aooooo`;o0000ooooool7oooo
o`00Doooool00ol0003oooooooooo`2aooooo`?o0000;?ooool2o`000?oooooo2Oooool005?ooooo
00?o0000ooooooooool0]?ooool3o`0002Kooooo0ol0003oooooo`_ooooo001Cooooo`03o`000?oo
oooooooo0;Oooooo0ol0000Pooooo`?o0000ooooool>ooooo`00Doooool3o`000;[ooooo0_l0000K
ooooo`?o0000oooooolAooooo`00Doooool00ol0003oooooooooo`2looooo`Go00004Oooool5o`00
0?oooooo5?ooool005?ooooo00?o0000ooooooooool0`OoooolAo`000?oooooo6Oooool005?ooooo
00?o0000ooooooooool0ooooooo[ooooo`00Doooool00ol0003oooooooooo`3oooooon_ooooo001C
ooooo`03o`000?oooooooooo0?oooooojoooool005?ooooo00?o0000ooooooooool0ooooooo[oooo
o`00Doooool00ol0003oooooooooo`3oooooon_ooooo001Cooooo`03o`000?oooooooooo0?oooooo
joooool005?ooooo00?o0000ooooooooool0ooooooo[ooooo`00Doooool3o`000?oooooojoooool0
0001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {0.217645, -805640, \
0.000982101, 50286.8}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The excess free energy per unit area of the interface in J/",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Gamma] = 
      2  NIntegrate[\@\(\(\ \)\(Kc\ \[CapitalDelta]fHom[XB, T]\)\), {XB, 
            XBEq\[Alpha], XBEq\[Beta]}]\)], "Input"],

Cell[BoxData[
    \(0.019961880029250454`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is reasonable--about 20 mJ/",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1148}, {0, 746}},
WindowSize->{877, 618},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 71, 2, 112, "Title"],
Cell[1828, 55, 29, 0, 48, "Subtitle"],

Cell[CellGroupData[{
Cell[1882, 59, 53, 0, 65, "Subsection"],
Cell[1938, 61, 109, 2, 70, "Input"],
Cell[2050, 65, 66, 0, 46, "Text"],
Cell[2119, 67, 138, 2, 74, "Input"],
Cell[2260, 71, 141, 1, 77, "Subsubtitle"],
Cell[2404, 74, 307, 6, 74, "Text"],
Cell[2714, 82, 187, 4, 66, "Text"],
Cell[2904, 88, 630, 11, 132, "Input"],
Cell[3537, 101, 158, 4, 66, "Text"],

Cell[CellGroupData[{
Cell[3720, 109, 256, 4, 91, "Input"],
Cell[3979, 115, 196, 3, 79, "Output"],
Cell[4178, 120, 312, 4, 143, "Output"],
Cell[4493, 126, 83, 1, 54, "Output"]
}, Open  ]],
Cell[4591, 130, 632, 15, 133, "Text"],
Cell[5226, 147, 42, 0, 48, "Subtitle"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5305, 152, 120, 3, 65, "Subsection"],
Cell[5428, 157, 127, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[5580, 164, 56, 1, 50, "Input"],
Cell[5639, 167, 63, 1, 54, "Output"]
}, Open  ]],
Cell[5717, 171, 72, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[5814, 175, 218, 5, 70, "Input"],
Cell[6035, 182, 115, 2, 76, "Output"],
Cell[6153, 186, 79, 1, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6269, 192, 59, 1, 50, "Input"],
Cell[6331, 195, 66, 1, 52, "Output"]
}, Open  ]],
Cell[6412, 199, 140, 3, 66, "Text"],
Cell[6555, 204, 85, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[6665, 211, 434, 6, 110, "Input"],
Cell[7102, 219, 73516, 1827, 437, 21114, 1175, "GraphicsData", "PostScript", \
"Graphics"],
Cell[80621, 2048, 130, 3, 52, "Output"]
}, Open  ]],
Cell[80766, 2054, 104, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[80895, 2061, 153, 2, 50, "Input"],
Cell[81051, 2065, 189122, 3375, 496, 55807, 1725, "GraphicsData", \
"PostScript", "Graphics"],
Cell[270176, 5442, 137, 3, 52, "Output"]
}, Open  ]],
Cell[270328, 5448, 345, 7, 86, "Text"],
Cell[270676, 5457, 126, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[270827, 5464, 50, 1, 50, "Input"],
Cell[270880, 5467, 36, 1, 52, "Output"]
}, Open  ]],
Cell[270931, 5471, 132, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[271088, 5478, 230, 5, 90, "Input"],
Cell[271321, 5485, 37, 1, 52, "Output"],
Cell[271361, 5488, 66, 1, 52, "Output"],
Cell[271430, 5491, 53, 1, 52, "Output"]
}, Open  ]],
Cell[271498, 5495, 52, 0, 46, "Text"],
Cell[271553, 5497, 358, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[271936, 5507, 146, 4, 70, "Input"],
Cell[272085, 5513, 28055, 700, 277, 8287, 451, "GraphicsData", "PostScript", \
"Graphics"],
Cell[300143, 6215, 130, 3, 52, "Output"]
}, Open  ]],
Cell[300288, 6221, 311, 5, 86, "Text"],
Cell[300602, 6228, 463, 8, 150, "Input"],
Cell[301068, 6238, 58, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[301151, 6242, 221, 4, 90, "Input"],
Cell[301375, 6248, 38740, 893, 384, 9268, 525, "GraphicsData", "PostScript", \
"Graphics"],
Cell[340118, 7143, 130, 3, 52, "Output"]
}, Open  ]],
Cell[340263, 7149, 159, 4, 66, "Text"],
Cell[340425, 7155, 535, 9, 170, "Input"],
Cell[340963, 7166, 167, 4, 66, "Text"],

Cell[CellGroupData[{
Cell[341155, 7174, 425, 9, 110, "Input"],
Cell[341583, 7185, 45487, 969, 384, 9134, 516, "GraphicsData", "PostScript", \
"Graphics"],
Cell[387073, 8156, 130, 3, 52, "Output"]
}, Open  ]],
Cell[387218, 8162, 115, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[387358, 8169, 61, 1, 50, "Input"],
Cell[387422, 8172, 53686, 1195, 384, 11529, 670, "GraphicsData", \
"PostScript", "Graphics"],
Cell[441111, 9369, 130, 3, 52, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[441290, 9378, 76, 0, 65, "Subsection"],
Cell[441369, 9380, 230, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[441624, 9389, 332, 6, 189, "Input"],
Cell[441959, 9397, 57, 1, 54, "Output"]
}, Open  ]],
Cell[442031, 9401, 393, 7, 106, "Text"],

Cell[CellGroupData[{
Cell[442449, 9412, 444, 8, 130, "Input"],
Cell[442896, 9422, 53, 1, 52, "Output"],
Cell[442952, 9425, 57, 1, 52, "Output"]
}, Open  ]],
Cell[443024, 9429, 187, 5, 48, "Text"],
Cell[443214, 9436, 138, 3, 74, "Input"],

Cell[CellGroupData[{
Cell[443377, 9443, 107, 2, 50, "Input"],
Cell[443487, 9447, 45215, 897, 384, 6334, 412, "GraphicsData", "PostScript", \
"Graphics"],
Cell[488705, 10346, 130, 3, 52, "Output"]
}, Open  ]],
Cell[488850, 10352, 151, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[489026, 10361, 158, 3, 60, "Input"],
Cell[489187, 10366, 55, 1, 52, "Output"]
}, Open  ]],
Cell[489257, 10370, 122, 5, 48, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

