(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    962335,      20031]*)
(*NotebookOutlinePosition[    963007,      20054]*)
(*  CellTagsIndexPosition[    962963,      20050]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
BCC Alloys in the Bragg-Williams Approximation\
\>", "Title"],

Cell["The Model", "Subtitle"],

Cell[CellGroupData[{

Cell["Samuel M. Allen\tApril 19, 2006", "Subsection"],

Cell[BoxData[{
    \(Clear["\<Global`*\>"]\), "\[IndentingNewLine]", 
    \(<< Graphics`Legend`\)}], "Input"],

Cell["Define values for Agogadro and Boltzmann constants", "Text"],

Cell[BoxData[{
    \(\(N0 = 6.02214\[Times]10\^23;\)\), "\[IndentingNewLine]", 
    \(\(kB = 1.3806503\[Times]10\^\(-23\);\)\)}], "Input"],

Cell[TextData[StyleBox["Bragg-Williams model for b.c.c. alloys with \
first-neighbor pairwise interactions. ", "Subsection"]], "Subsubtitle"],

Cell[TextData[StyleBox["Order parameters are the atom fraction of B, XB, and \
the long-range order parameter, \[Eta] (see KoM Fig. 17.4 and Eqs. \
17.7\[Dash]8 for definitions).", "Subsection",
  FontSize->16,
  FontWeight->"Plain",
  Background->None,
  FontVariations->{"CompatibilityType"->0}]], "Text"],

Cell["\<\
Enter expressions for internal energy,entropy, and free energy as \
in KoM Eqs. 17.13\[Dash]14. In the formuation below \[CapitalDelta]F has \
units of energy/mole\
\>", "Text"],

Cell[BoxData[{
    \(\(\[CapitalDelta]U[
          XB_, \[Eta]_] := \(-4\)\ N0\ W\ \((XB \((1 - 
                    XB)\) + \[Eta]\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]S\ [
          XB_, \[Eta]_] := \(-N0\)\ kB \((\((XB + \[Eta])\) 
                Log[XB + \[Eta]] + \((XB - \[Eta])\) 
                Log[XB - \[Eta]] + \((1 - XB + \[Eta])\) 
                Log[1 - XB + \[Eta]] + \((1 - XB - \[Eta])\) 
                Log[1 - XB - \[Eta]])\);\)\), "\[IndentingNewLine]", 
    \(\[CapitalDelta]F[XB_, \[Eta]_, T_] := \[CapitalDelta]U[XB, \[Eta]] - 
        T\ \[CapitalDelta]S[XB, \[Eta]]\)}], "Input"],

Cell["\<\
Look first at the possibility for order-disorder transitions by \
calculating the order-disorder transition temperature at XB = 0.5:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SecDerivEta = \[PartialD]\_\(\[Eta], \[Eta]\)\[CapitalDelta]F[
          XB, \[Eta], T]\), "\[IndentingNewLine]", 
    \(Fetaeta = Limit[SecDerivEta, \[Eta] -> 0]\), "\[IndentingNewLine]", 
    \(Fetaeta /. XB \[Rule] 0.5\)}], "Input"],

Cell[BoxData[
    \(\(-4.817712`*^24\)\ W + 
      8.314469397642002`\ T\ \((1\/\(1 - XB - \[Eta]\) + 1\/\(XB - \[Eta]\) + 
            1\/\(1 - XB + \[Eta]\) + 1\/\(XB + \[Eta]\))\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(16.628938795284004`\ T\)\/\((\(-1.`\) + XB)\)\^2\)\) - \
\(4.817712`*^24\ W\)\/\((\(-1.`\) + XB)\)\^2 + \(16.628938795284004`\ T\)\/\(\
\((\(-1.`\) + XB)\)\^2\ XB\) + \(9.635424`*^24\ W\ XB\)\/\((\(-1.`\) + \
XB)\)\^2 - \(4.817712`*^24\ W\ XB\^2\)\/\((\(-1.`\) + XB)\)\^2\)], "Output"],

Cell[BoxData[
    \(66.51575518113602`\ T - 4.817712000000002`*^24\ W\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We see that there will only be order-disorder transitions (i.e., a \
positive-temperature solution to \n\tLimit",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            RowBox[{"(", 
              FormBox[\(F\_\[Eta]\[Eta]\),
                "TraditionalForm"], ")"}], \(\[Eta] \[Rule] 0\)], "=", "0"}], 
        TraditionalForm]]],
  " \nwhen W>0. With this result, we can explore the simpler case of phase \
equilibria with miscibility gaps by considering only W<0 and setting \[Eta]=0 \
in the free energy model. (In this way, we recover the regular solution \
model.)"
}], "Text"],

Cell["Spinodal Decomposition", "Subtitle"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculation of Miscibility Gap and Chemical Spinodal in the \
Bragg-Williams Approximation\
\>", "Subsection"],

Cell["\<\
We'll need to make calculations and draw graphs so I begin by \
picking a suitable negative value for W\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(W = \(-1000\)\[Times]kB\)], "Input"],

Cell[BoxData[
    \(\(-1.3806503000000003`*^-20\)\)], "Output"]
}, Open  ]],

Cell["Begin by evaluating the spinodal temperature at XB = 0.5", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, 
        T]\), "\[IndentingNewLine]", 
    \(FXBXB = 
      Limit[\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, T], 
        XB -> 0.5]\)}], "Input"],

Cell[BoxData[
    \(\(-66515.755181136`\) + 
      8.314469397642002`\ T\ \((2\/\(1 - XB\) + 2\/XB)\)\)], "Output"],

Cell[BoxData[
    \(\(-66515.755181136`\) + 66.51575518113602`\ T\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[FXBXB \[Equal] 0, T]\)], "Input"],

Cell[BoxData[
    \({{T \[Rule] 999.9999999999998`}}\)], "Output"]
}, Open  ]],

Cell["\<\
So the top of the miscibility gap (remember, this free-energy model \
is symmetric about XB = 0.5) is at T = 1000 K.\
\>", "Text"],

Cell["\<\
Plot \[CapitalDelta]F vs. XB for T = 800, 900, 1000, 1100 K\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\[CapitalDelta]F[XB, 0, 800], \[CapitalDelta]F[XB, 0, 
          900], \[CapitalDelta]F[XB, 0, 1000], \[CapitalDelta]F[XB, 0, 
          1100]}, {XB, 0.0, 1}, AxesLabel \[Rule] {XB, \[CapitalDelta]F}, 
      PlotStyle \[Rule] {{Hue[ .3]}, {Hue[ .5]}, {Hue[ .7]}, {Hue[ .9]}}, 
      PlotLegend \[Rule] {"\<800 K\>", "\<900 K\>", "\<1000 K\>", "\<1100 \
K\>"}, LegendPosition \[Rule] {1, \(-1\)}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64023 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.389355 0.365545 0.399066 0.365545 [
[ 0 0 0 0 ]
[ 1 .64023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.173147 0.7549 0.624985 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603319 0.000134863 [
[.21429 .59082 -9 -9 ]
[.21429 .59082 9 0 ]
[.40476 .59082 -9 -9 ]
[.40476 .59082 9 0 ]
[.59524 .59082 -9 -9 ]
[.59524 .59082 9 0 ]
[.78571 .59082 -9 -9 ]
[.78571 .59082 9 0 ]
[.97619 .59082 -3 -9 ]
[.97619 .59082 3 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 16 6 ]
[.01131 .06387 -30 -4.5 ]
[.01131 .06387 0 4.5 ]
[.01131 .19873 -30 -4.5 ]
[.01131 .19873 0 4.5 ]
[.01131 .33359 -30 -4.5 ]
[.01131 .33359 0 4.5 ]
[.01131 .46846 -30 -4.5 ]
[.01131 .46846 0 4.5 ]
[.02381 .64303 -8 0 ]
[.02381 .64303 8 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(0.2)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(0.4)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(0.6)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(0.8)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(1)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
1.000 setlinewidth
grestore
.02381 .06387 m
.03006 .06387 L
s
[(-4000)] .01131 .06387 1 0 Mshowa
.02381 .19873 m
.03006 .19873 L
s
[(-3000)] .01131 .19873 1 0 Mshowa
.02381 .33359 m
.03006 .33359 L
s
[(-2000)] .01131 .33359 1 0 Mshowa
.02381 .46846 m
.03006 .46846 L
s
[(-1000)] .01131 .46846 1 0 Mshowa
.125 Mabswid
.02381 .09084 m
.02756 .09084 L
s
.02381 .11781 m
.02756 .11781 L
s
.02381 .14479 m
.02756 .14479 L
s
.02381 .17176 m
.02756 .17176 L
s
.02381 .2257 m
.02756 .2257 L
s
.02381 .25268 m
.02756 .25268 L
s
.02381 .27965 m
.02756 .27965 L
s
.02381 .30662 m
.02756 .30662 L
s
.02381 .36057 m
.02756 .36057 L
s
.02381 .38754 m
.02756 .38754 L
s
.02381 .41451 m
.02756 .41451 L
s
.02381 .44148 m
.02756 .44148 L
s
.02381 .49543 m
.02756 .49543 L
s
.02381 .5224 m
.02756 .5224 L
s
.02381 .54937 m
.02756 .54937 L
s
.02381 .57635 m
.02756 .57635 L
s
.02381 .0369 m
.02756 .0369 L
s
.02381 .00992 m
.02756 .00992 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.5 Mabswid
.02381 .60332 m
.02499 .5918 L
.02605 .58405 L
.02846 .56977 L
.03279 .54949 L
.04262 .51601 L
.05281 .49119 L
.06244 .47336 L
.07295 .45826 L
.08265 .44736 L
.09329 .43802 L
.10458 .43051 L
.11399 .4258 L
.12411 .42203 L
.12901 .42063 L
.13367 .41952 L
.13817 .41865 L
.14241 .41799 L
.14483 .41768 L
.14744 .4174 L
.14962 .41721 L
.152 .41703 L
.15459 .41689 L
.156 .41684 L
.15732 .41679 L
.15856 .41676 L
.15969 .41675 L
.16099 .41673 L
.16222 .41673 L
.16327 .41674 L
.16444 .41676 L
.16565 .41678 L
.1668 .41681 L
.16883 .41688 L
.17103 .41698 L
.17603 .41731 L
.18061 .41772 L
.19041 .4189 L
.19953 .42032 L
.22023 .4245 L
.25928 .43467 L
.30077 .44674 L
.34076 .45794 L
.37922 .46726 L
.39871 .47122 L
.42014 .47487 L
.4405 .47759 L
.45954 .47945 L
.46995 .48017 L
.47508 .48044 L
Mistroke
.47983 .48065 L
.48413 .48081 L
.4887 .48093 L
.49132 .48098 L
.4926 .481 L
.49377 .48102 L
.49483 .48103 L
.49598 .48104 L
.49714 .48105 L
.49837 .48105 L
.49968 .48106 L
.50089 .48106 L
.50152 .48105 L
.50222 .48105 L
.50294 .48105 L
.50363 .48104 L
.50488 .48103 L
.50602 .48102 L
.5086 .48098 L
.51077 .48094 L
.51314 .48089 L
.51792 .48074 L
.52317 .48053 L
.52877 .48024 L
.53885 .47957 L
.54911 .47869 L
.56023 .47751 L
.5804 .47479 L
.62137 .46714 L
.66082 .45752 L
.69876 .44687 L
.73915 .43512 L
.77803 .4249 L
.78819 .42266 L
.79924 .42054 L
.8088 .41901 L
.81388 .41833 L
.81936 .41772 L
.82467 .41726 L
.82699 .4171 L
.82954 .41696 L
.83071 .4169 L
.83195 .41685 L
.83303 .41681 L
.8342 .41678 L
.83552 .41676 L
.83677 .41674 L
.83799 .41673 L
.83911 .41674 L
.84032 .41675 L
Mistroke
.84162 .41677 L
.84284 .4168 L
.84396 .41683 L
.8467 .41696 L
.8493 .41712 L
.85198 .41735 L
.85447 .4176 L
.86011 .41836 L
.86519 .41928 L
.87069 .42055 L
.88065 .42365 L
.89034 .42781 L
.89926 .43282 L
.909 .43983 L
.9181 .44811 L
.92807 .45957 L
.93877 .47536 L
.94798 .49286 L
.95799 .51775 L
.96258 .53211 L
.96745 .55046 L
.9716 .57009 L
.97274 .5765 L
.97397 .58422 L
.97619 .60332 L
Mfstroke
0 1 1 r
.02381 .60332 m
.02605 .58033 L
.02846 .56285 L
.03279 .53753 L
.04262 .49425 L
.053 .46008 L
.06244 .43529 L
.07283 .41292 L
.0841 .39301 L
.10458 .3654 L
.12442 .34629 L
.13455 .33873 L
.14545 .33194 L
.15565 .32667 L
.16498 .32266 L
.18328 .31667 L
.19313 .31433 L
.20227 .31262 L
.2123 .3112 L
.21791 .31058 L
.22299 .31013 L
.22786 .30979 L
.23301 .30951 L
.23741 .30934 L
.23991 .30927 L
.24224 .30921 L
.24353 .30919 L
.24494 .30917 L
.24558 .30916 L
.24626 .30916 L
.24749 .30915 L
.24867 .30914 L
.24977 .30914 L
.25098 .30914 L
.25228 .30915 L
.25359 .30916 L
.25502 .30917 L
.25652 .30919 L
.2579 .30922 L
.26306 .30934 L
.26811 .30951 L
.27358 .30974 L
.28351 .31029 L
.3021 .31164 L
.34302 .3155 L
.38242 .31941 L
.42031 .3226 L
.43976 .32386 L
.4506 .32442 L
.46065 .32485 L
Mistroke
.47078 .32519 L
.47613 .32533 L
.48183 .32545 L
.48444 .32549 L
.48726 .32553 L
.48975 .32556 L
.49237 .32558 L
.49475 .3256 L
.4961 .3256 L
.49735 .32561 L
.49851 .32561 L
.49956 .32561 L
.50078 .32561 L
.50193 .32561 L
.50307 .3256 L
.5043 .3256 L
.50547 .32559 L
.50653 .32559 L
.50901 .32557 L
.51161 .32554 L
.51651 .32547 L
.52188 .32537 L
.53143 .32512 L
.54031 .32481 L
.56081 .32383 L
.57941 .32262 L
.61944 .31924 L
.65796 .3154 L
.67748 .31347 L
.69893 .31156 L
.70877 .3108 L
.71933 .31012 L
.72444 .30984 L
.72929 .30961 L
.73398 .30943 L
.73839 .3093 L
.74059 .30925 L
.74296 .3092 L
.74425 .30918 L
.7456 .30917 L
.74676 .30916 L
.74802 .30915 L
.74871 .30914 L
.74937 .30914 L
.75059 .30914 L
.7519 .30914 L
.75264 .30915 L
.75333 .30915 L
.75447 .30916 L
.75573 .30918 L
Mistroke
.75827 .30922 L
.76066 .30928 L
.76285 .30935 L
.76778 .30955 L
.77234 .3098 L
.77668 .31011 L
.78628 .31103 L
.7965 .31242 L
.80615 .31418 L
.8149 .3162 L
.83416 .32232 L
.84501 .32698 L
.85498 .33218 L
.87382 .34488 L
.89449 .36435 L
.91401 .39005 L
.92496 .4087 L
.93493 .42922 L
.9442 .45219 L
.95403 .48224 L
.95916 .5011 L
.96482 .52558 L
.96997 .55295 L
.97249 .56932 L
.9748 .58766 L
.97619 .60332 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.02605 .5766 L
.02846 .55594 L
.03279 .52557 L
.04262 .47248 L
.053 .42935 L
.06244 .39722 L
.0841 .34009 L
.10458 .30028 L
.12455 .27047 L
.14299 .2488 L
.16331 .22991 L
.18234 .21596 L
.20174 .20471 L
.22018 .19625 L
.24043 .18901 L
.25895 .1839 L
.27876 .17972 L
.29714 .17681 L
.31767 .17444 L
.33627 .17291 L
.3463 .17228 L
.35552 .17181 L
.36629 .17136 L
.37634 .17104 L
.38543 .1708 L
.39517 .17061 L
.40597 .17045 L
.41583 .17035 L
.42063 .17031 L
.42574 .17027 L
.43491 .17023 L
.44 .17021 L
.44478 .1702 L
.45002 .17018 L
.45275 .17018 L
.45567 .17018 L
.45827 .17017 L
.46063 .17017 L
.46524 .17017 L
.46783 .17017 L
.47063 .17016 L
.47328 .17016 L
.47571 .17016 L
.47824 .17016 L
.48059 .17016 L
.48195 .17016 L
.48318 .17016 L
.48461 .17016 L
.48596 .17016 L
Mistroke
.48727 .17016 L
.48798 .17016 L
.48866 .17016 L
.48997 .17016 L
.49115 .17016 L
.49184 .17016 L
.49257 .17016 L
.49387 .17016 L
.4946 .17016 L
.49528 .17016 L
.49602 .17016 L
.49681 .17016 L
.49804 .17016 L
.49873 .17016 L
.49939 .17016 L
.5007 .17016 L
.50144 .17016 L
.50211 .17016 L
.50326 .17016 L
.5045 .17016 L
.5058 .17016 L
.50701 .17016 L
.50771 .17016 L
.50846 .17016 L
.50917 .17016 L
.50982 .17016 L
.51106 .17016 L
.51237 .17016 L
.51378 .17016 L
.5151 .17016 L
.51654 .17016 L
.51809 .17016 L
.52068 .17016 L
.52214 .17016 L
.5235 .17016 L
.52598 .17016 L
.52862 .17016 L
.53097 .17017 L
.53318 .17017 L
.5358 .17017 L
.53823 .17017 L
.54291 .17017 L
.54804 .17018 L
.55304 .17019 L
.55838 .1702 L
.56337 .17022 L
.56807 .17024 L
.57688 .17029 L
.5815 .17032 L
.58659 .17037 L
Mistroke
.59687 .17049 L
.6064 .17064 L
.61532 .17082 L
.62571 .1711 L
.63558 .17143 L
.65411 .1723 L
.6637 .1729 L
.67393 .17368 L
.69232 .17549 L
.71375 .17844 L
.73392 .18226 L
.75402 .18734 L
.77249 .19341 L
.79133 .2013 L
.812 .2124 L
.83153 .2258 L
.85244 .24414 L
.8737 .2682 L
.89383 .29761 L
.91375 .33538 L
.93218 .38117 L
.95085 .44423 L
.96149 .49273 L
.96669 .52229 L
.96902 .53743 L
.97146 .5553 L
.97619 .60332 L
Mfstroke
1 0 .6 r
.02381 .60332 m
.02605 .57287 L
.02846 .54902 L
.03279 .5136 L
.04262 .45072 L
.06244 .35916 L
.08451 .28602 L
.10458 .23516 L
.12534 .19333 L
.14451 .16197 L
.18292 .11439 L
.20165 .09678 L
.22227 .08063 L
.24331 .06706 L
.26256 .05676 L
.30133 .04094 L
.32032 .0351 L
.34104 .02988 L
.36236 .02557 L
.38169 .02244 L
.40207 .01983 L
.42082 .01797 L
.44006 .01654 L
.45019 .01597 L
.46088 .01548 L
.47036 .01515 L
.47558 .01501 L
.48052 .0149 L
.48512 .01482 L
.48754 .01479 L
.49011 .01476 L
.49227 .01474 L
.49342 .01474 L
.49465 .01473 L
.49578 .01472 L
.49682 .01472 L
.49781 .01472 L
.49886 .01472 L
.50009 .01472 L
.50079 .01472 L
.50143 .01472 L
.50261 .01472 L
.50386 .01472 L
.50497 .01473 L
.50602 .01473 L
.5084 .01475 L
.51097 .01477 L
.51332 .0148 L
.5186 .01489 L
.52311 .01498 L
Mistroke
.52802 .01511 L
.53696 .0154 L
.54731 .01584 L
.55668 .01634 L
.57766 .01784 L
.59695 .01972 L
.61778 .02236 L
.63776 .02559 L
.65884 .02986 L
.69686 .04034 L
.71641 .04746 L
.73734 .05671 L
.75719 .06735 L
.77875 .08136 L
.81865 .11601 L
.83846 .1387 L
.85948 .16801 L
.89728 .2394 L
.91667 .2894 L
.93754 .3591 L
.95638 .44518 L
.96585 .50369 L
.96844 .52295 L
.97121 .546 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.77318 .01524 m
.77318 .30768 L
.97619 .30768 L
.97619 .01524 L
F
1 g
.7549 .03352 m
.7549 .32596 L
.95791 .32596 L
.95791 .03352 L
F
0 g
.001 w
[ ] 0 setdash
.7549 .03352 m
.95791 .03352 L
.95791 .32596 L
.7549 .32596 L
.7549 .03352 L
s
% Start of sub-graphic
p
0.7549 0.0335208 0.957913 0.325957 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 1.44048 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.44048 L
0 1.44048 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 .6 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1100) show
93.000 13.000 moveto
(K) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
93.000 13.000 moveto
(K) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(900) show
87.000 13.000 moveto
(K) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.08929 0.35119 1.3869 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.2381 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
87.000 13.000 moveto
(K) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .64023 L
0 .64023 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{622, 398.188},
  ImageMargins->{{14, 0}, {0, 10}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009^0001SR000`400?l00000o`00003ooooooooo
ooooog3ooooo003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo
003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003ooooooooo
ooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool0
0?ooooooh?oooomno`00017ooooo003oooooon3oooooO_l0000Aooooo`00oooooooPooooogko0000
4Oooool00?ooooooh?oooomno`00017ooooo003oooooon3oooooO_l0000Aooooo`00oooooooPoooo
ogko00004Oooool00?ooooooh?oooomno`00017ooooo003oooooon3oooooO_l0000Aooooo`00oooo
oooPooooogko00004Oooool00?ooooooh?oooomno`00017ooooo003oooooomGoooooROl0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo037ooooo0ol00003ooooo`?o00001?ooool2
o`0000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000009oooool;o`00017ooooo003ooooo
omGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0002Sooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo00Gooooo9?oo
09T9ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000:Oooool;o`00017o
oooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008oooo
o`;o0000:_ooool;o`00017ooooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000002Wooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000:?ooool;o`00017ooooo
003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00002?ooool3o`000003ooooool0003o000002Oooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEoooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooo
oooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo037ooooo0ol00004oooo
o`;o00001?ooool2o`0000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000009oooool;o`00
017ooooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0002Sooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oo
oooooooo00Gooooo9?lc0?l9ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000:Oooool;o`00017ooooo003oooooomGooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00008ooooo`;o0000:_ooool;o`00017ooooo003oooooomGooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002Wo
oooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0002Sooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool3
o`000003ooooool0003o000002Oooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00
oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oo
oooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000A
ooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03
o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooE
ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00
oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oo
oooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000A
ooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03
o`000?oooooooooo07_ooooo2ol0000Aooooo`00oooooooEooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`3ooooooj3ooooo00?o0000ooooooooool0Nooo
ool;o`00017ooooo000booooo`03o`000?oooooooooo0?ooooooX?ooool00ol0003oooooooooo`1k
ooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0oooooonPooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`3ooooooj3ooooo00?o0000oooooooo
ool0Noooool;o`00017ooooo000booooo`;o0000oooooonQooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`3ooooooj3ooooo00?o0000ooooooooool0Nooo
ool;o`00017ooooo000booooo`03o`000?oooooooooo0:3ooooo>?oo09W7ooooo`03o`000?oooooo
oooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`2Iooooo`Ooo`2I>?ooool8ool0
VKoooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo097o
oooo2?oo09U7ooooo`Soo`2I]oooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo
00?o0000ooooooooool0ROooool8ool0VEOooooo2?oo09V_ooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`23ooooo`Koo`2IIoooool6ool0VJWooooo00?o
0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo07kooooo1Ooo09Uc
ooooo`Goo`2IY?ooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000oooo
ooooool0N_ooool4ool0VGgooooo1?oo09VPooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00<_ooool00ol0003oooooooooo`1fooooo`Coo`2IQOooool4ool0VIcooooo00?o0000oooooooo
ool0Noooool;o`00017ooooo000booooo`;o0000Loooool4ool0VHgooooo0ooo09VIooooo`03o`00
0?oooooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`1^ooooo`Coo`2IU?oo
ool4ool0VIGooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooo
oooo06_ooooo0ooo09VLooooo`?oo`2IT_ooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo00?o0000ooooooooool0J?ooool3ool0VJ;ooooo0ooo09V?ooooo`03o`000?oooooooooo
07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`1Vooooo`;oo`2IZ?ooool3ool0VHco
oooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo06?ooooo
0ooo09V]ooooo`;oo`2IR_ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000Cooooo
0_l00008ooooo`?o000000?oooooo`000?l00000;Oooool;o`00017ooooo000booooo`03o`000?oo
oooooooo067ooooo0_oo09Vbooooo`?oo`2IQoooool00ol0003oooooooooo`0cooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo0000;_ooool;o`00017ooooo000booooo`03o`000?oooooooooo05ko
oooo0ooo09Vgooooo`?oo`2IQ?ooool00ol0003oooooooooo`05ooooobCo0?oo2oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooo`00000_ooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0G?ooool2ool0
VKgooooo0_oo09V2ooooo`03o`000?oooooooooo037ooooo1?l00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool2o`00033ooooo2ol0000Aooooo`005oooool3
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0Foooool0
0ooo09Woooooooooo`2oooooo`03ool0VOoooooooooo07oooooo00?o0000ooooooooool0<?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000002oooooo2ol0000Aooooo`006?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool2ool0VL?ooooo0_oo09Uo
ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000^oooo
o`_o00004Oooool000oooooo1Ol000000ooooooo0000o`000003o`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo0ol0
001Gooooo`;oo`2Iaoooool2ool0VGgooooo00?o0000ooooooooool0<Oooool3o`0000Cooooo0_l0
0004ooooo`;o00002?ooool3o`000003ooooool0003o000002gooooo2ol0000Aooooo`005Oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05Kooooo00?oo`2Ioooo
ooooool0bOooool00ooo09Woooooooooo`1jooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`005_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo05Cooooo0_oo
09W=ooooo`;oo`2IN_ooool00ol0003oooooooooo`1kooooo`_o00004Oooool001Oooooo0_l00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo05;ooooo0_oo09WAooooo`;oo`2IN?ooool00ol0003o
ooooooooo`1kooooo`_o00004Oooool001Sooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
0_l00004ooooo`;o00001oooool00ol0003oooooooooo`1@ooooo`;oo`2IeOooool2ool0VGKooooo
00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04oooooo00?o
o`2Iooooooooool0eoooool00ooo09Woooooooooo`1cooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00<_ooool00ol0003oooooooooo`1=ooooo`;oo`2Ifoooool2ool0VG?ooooo00?o0000
ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04_ooooo0_oo09WOoooo
o`;oo`2ILOooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000oooooooo
ool0B_ooool00ooo09Woooooooooo`3Qooooo`03ool0VOoooooooooo06kooooo00?o0000oooooooo
ool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04Wooooo00?oo`2Iooooooooool0
hoooool00ooo09Woooooooooo`1]ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_oo
ool00ol0003oooooooooo`18ooooo`03ool0VOoooooooooo0>Gooooo00?oo`2Iooooooooool0K?oo
ool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo0_l00018ooooo`03ool0VOoooooo
oooo0>Oooooo00?oo`2Iooooooooool0Joooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo00?o0000ooooooooool0A_ooool00ooo09Woooooooooo`3Yooooo`03ool0VOoooooooooo
06[ooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo04Go
oooo00?oo`2Iooooooooool0joooool00ooo09Woooooooooo`1Yooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`14ooooo`03ool0VOoooooooooo0>gooooo
0_oo09UYooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003ooooooooo
o`13ooooo`03ool0VOoooooooooo0?3ooooo00?oo`2Iooooooooool0I_ooool00ol0003ooooooooo
o`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0@_ooool00ooo09Woooooooooo`3b
ooooo`03ool0VOoooooooooo06Gooooo00?o0000ooooooooool0Noooool;o`00017ooooo000boooo
o`03o`000?oooooooooo047ooooo00?oo`2Iooooooooool0m?ooool00ooo09Woooooooooo`1Toooo
o`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`10ooooo`03
ool0VOoooooooooo0?Kooooo00?oo`2Iooooooooool0Hoooool00ol0003oooooooooo`1kooooo`_o
00004Oooool003;ooooo00?o0000ooooooooool0?oooool00ooo09Woooooooooo`3hooooo`03ool0
VOoooooooooo06;ooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oo
oooooooo03kooooo00?oo`2Iooooooooool0n_ooool00ooo09Woooooooooo`1Qooooo`03o`000?oo
oooooooo07_ooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0mooooo`03ool0VOoooooo
oooo0?cooooo00?oo`2Iooooooooool0H?ooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo0_l0000nooooo`03ool0VOoooooooooo0?cooooo00?oo`2Iooooooooool0H?ooool00ol0
003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0??ooool00ooo09Wo
ooooooooo`3nooooo`03ool0VOoooooooooo05oooooo00?o0000ooooooooool0Noooool;o`00017o
oooo000booooo`03o`000?oooooooooo03_ooooo00?oo`2Iooooooooool0ooooool1ooooo`03ool0
VOoooooooooo05kooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oo
oooooooo03[ooooo00?oo`2Iooooooooool0ooooool3ooooo`03ool0VOoooooooooo05gooooo00?o
0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo03Wooooo00?oo`2I
ooooooooool0ooooool5ooooo`03ool0VOoooooooooo05cooooo00?o0000ooooooooool0Noooool;
o`00017ooooo000booooo`03o`000?oooooooooo03Sooooo00?oo`2Iooooooooool0ooooool7oooo
o`03ool0VOoooooooooo05_ooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03
o`000?oooooooooo03Sooooo00?oo`2Iooooooooool0ooooool8ooooo`03ool0VOoooooooooo05[o
oooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo03Oooooo
00?oo`2Iooooooooool0ooooool:ooooo`03ool0VOoooooooooo05Wooooo00?o0000ooooooooool0
Noooool;o`00017ooooo000booooo`03o`000?oooooooooo03Kooooo00?oo`2Iooooooooool0oooo
ool<ooooo`03ool0VOoooooooooo05Sooooo00?o0000ooooooooool0Noooool;o`00017ooooo000b
ooooo`03o`000?oooooooooo03Gooooo00?oo`2Iooooooooool0ooooool=ooooo`03ool0VOoooooo
oooo05Sooooo00?o0000ooooooooool0Noooool;o`00017ooooo000booooo`03o`000?oooooooooo
03Cooooo00?oo`2Iooooooooool0ooooool?ooooo`03ool0VOoooooooooo05Oooooo00?o0000oooo
ooooool0Noooool;o`00017ooooo000booooo`;o0000=?ooool00ooo09Woooooooooo`3ooooooa7o
oooo00?oo`2Iooooooooool0E_ooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo
00?o0000ooooooooool0<_ooool00ooo09Woooooooooo`3ooooooa?ooooo00?oo`2Iooooooooool0
EOooool00ol0003oooooooooo`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0<_oo
ool00ooo09Woooooooooo`3ooooooa?ooooo00?oo`2Iooooooooool0EOooool00ol0003ooooooooo
o`1kooooo`_o00004Oooool003;ooooo00?o0000ooooooooool0<Oooool00ooo09Woooooooooo`3o
oooooaGooooo00?oo`2Iooooooooool0E?ooool00ol0003oooooooooo`1kooooo`_o00004Oooool0
03;ooooo00?o0000ooooooooool0<?ooool00ooo09Woooooooooo`3ooooooaOooooo00?oo`2Ioooo
ooooool0Doooool00ol0003oooooooooo`0aooooo`?o00001?ooool2o`0000Cooooo0_l00008oooo
o`?o000000?oooooo`000?l00000;Oooool;o`00017ooooo000booooo`03o`000?oooooooooo02oo
oooo00?oo`2Iooooooooool0oooooolIooooo`03ool0VOoooooooooo05;ooooo00?o0000oooooooo
ool0<?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0002kooooo2ol0000Aooooo`00<_oo
ool00ol0003oooooooooo`0^ooooo`03ool0VOoooooooooo0?oooooo6_ooool00ooo09Wooooooooo
o`1Booooo`03o`000?oooooooooo00Gooooo9?lco`07ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000;oooool;o`00017ooooo000booooo`03o`000?oooooooooo02gooooo00?oo`2Ioooooooo
ool0oooooolLooooo`03ool0VOoooooooooo057ooooo00?o0000ooooooooool0<Oooool3o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`;o0000<?ooool;
o`00017ooooo000booooo`03o`000?oooooooooo02gooooo00?oo`2Iooooooooool0oooooolMoooo
o`03ool0VOoooooooooo053ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000002oooooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0/ooooo`03ool0VOoo
oooooooo0?oooooo7oooool00ooo09Woooooooooo`1?ooooo`03o`000?oooooooooo033ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0000^ooooo`_o00004Oooool003;ooooo00?o0000oooo
ooooool0:oooool00ooo09Woooooooooo`1Jooooof[o<`3oFoooool00ooo09Woooooooooo`1?oooo
o`03o`000?oooooooooo037ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo0ol000000ooo
oooo0000o`00000]ooooo`_o00004Oooool003;ooooo0_l0000/ooooo`03ool0VOoooooooooo04Wo
oooo4Olc0?mZoooooaGo<`3oAoooool00ooo09Woooooooooo`1>ooooo`03o`000?oooooooooo07_o
oooo2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0Zooooo`03ool0VOoooooooooo04;ooooo
2?lc0?n@ooooo`So<`3o?oooool00ooo09Woooooooooo`1>ooooo`03o`000?oooooooooo07_ooooo
2ol0000Aooooo`00<_ooool00ol0003oooooooooo`0Yooooo`03ool0VOoooooooooo03_ooooo2?lc
0?nPooooo`Ko<`3o>_ooool00ooo09Woooooooooo`1=ooooo`03o`000?oooooooooo07_ooooo2ol0
000Aooooo`00<_ooool00ol0003oooooooooo`0Yooooo`03ool0VOoooooooooo03Gooooo1_lc0?n^
ooooo`Co<`3o=_ooool00ooo09Woooooooooo`1=ooooo`03o`000?oooooooooo07_ooooo2ol0000A
ooooo`00<_ooool00ol0003oooooooooo`0Xooooo`03ool0VOoooooooooo03;ooooo1?lc0?nhoooo
o`Co<`3o<oooool00ooo09Woooooooooo`1<ooooo`03o`000?oooooooooo07_ooooo2ol0000Aoooo
o`00<_ooool00ol0003oooooooooo`0Wooooo`03ool0VOoooooooooo02oooooo1?lc0?o0ooooo`Co
<`3o;oooool00ooo09Woooooooooo`1<ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00
<_ooool00ol0003oooooooooo`0Wooooo`03ool0VOoooooooooo02cooooo0olc0?o8ooooo`Co<`3o
;?ooool00ooo09Woooooooooo`1;ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`00<_oo
ool00ol0003oooooooooo`0Vooooo`03ool0VOoooooooooo02[ooooo0olc0?o?ooooo`Co<`3o:?oo
ool00ooo09Woooooooooo`1;ooooo`03o`000?oooooooooo07_ooooo2ol0000Aooooo`005_ooool3
o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool09Oooool0
0ooo09Woooooooooo`0Xooooo`?o<`3oe_ooool3oc<0obKooooo00?oo`2Iooooooooool0B_ooool0
0ol0003oooooooooo`1kooooo`_o00004Oooool001Gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo02Gooooo00?oo`2Iooooooooool09Oooool3oc<0omco
oooo0_lc0?lTooooo`03ool0VOoooooooooo04[ooooo00?o0000ooooooooool0Noooool;o`00017o
oooo000?ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Cooooo00?oo`2Iooooooooool09?ooool2oc<0on7ooooo00?o<`3oooooooooool08_ooool0
0ooo09Woooooooooo`19ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06Oooool0
01Oooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00006ooooo`?o00009?ooool00ooo09Woooooooooo`0Qooooo`?o<`3o
i?ooool2oc<0ob;ooooo00?oo`2Iooooooooool0BOooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo01Wooooo000Iooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08oooool00ooo09Woooooooooo`0Oooooo`?o<`3ojOooool2oc<0ob7ooooo00?oo`2Ioooo
ooooool0B?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01Wooooo000Eooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Sooooo`03ool0
VOoooooooooo01gooooo0_lc0?o^ooooo`;o<`3o8?ooool00ooo09Woooooooooo`17ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool06Oooool001Kooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo02;ooooo00?oo`2Iooooooooool07?oo
ool2oc<0oo;ooooo0_lc0?lNooooo`03ool0VOoooooooooo04Oooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0Iooooo`00<_ooool00ol0003oooooooooo`0Rooooo`03ool0VOoooooo
oooo01[ooooo0_lc0?ofooooo`;o<`3o7Oooool00ooo09Woooooooooo`16ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool06Oooool003;ooooo00?o0000ooooooooool08Oooool00ooo
09Woooooooooo`0Iooooo`;o<`3on_ooool2oc<0oa_ooooo00?oo`2Iooooooooool0A_ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo01Wooooo000booooo`03o`000?oooooooooo027o
oooo00?oo`2Iooooooooool05oooool2oc<0ookooooo00?o<`3oooooooooool06Oooool00ooo09Wo
ooooooooo`15ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06Oooool003;ooooo
00?o0000ooooooooool08Oooool00ooo09Woooooooooo`0Fooooo`03oc<0oooooooooooo0?oooooo
0_lc0?lIooooo`03ool0VOoooooooooo04Gooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0Iooooo`00<_ooool00ol0003oooooooooo`0Pooooo`03ool0VOoooooooooo01Kooooo00?o
<`3oooooooooool0ooooool3ooooo`;o<`3o6?ooool00ooo09Woooooooooo`14ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool06Oooool003;ooooo00?o0000ooooooooool08?ooool0
0ooo09Woooooooooo`0Eooooo`03oc<0oooooooooooo0?oooooo1_ooool00olc0?ooooooooooo`0E
ooooo`03ool0VOoooooooooo04Cooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0I
ooooo`00<_ooool2o`00023ooooo00?oo`2Iooooooooool05Oooool00olc0?ooooooooooo`3ooooo
o`Sooooo0_lc0?lFooooo`03ool0VOoooooooooo04?oooooOol0000Kooooo`00<_ooool00ol0003o
ooooooooo`0Oooooo`03ool0VOoooooooooo01Cooooo00?o<`3oooooooooool0ooooool;ooooo`03
oc<0oooooooooooo01?ooooo00?oo`2Iooooooooool0gOooool003;ooooo00?o0000ooooooooool0
7_ooool00ooo09Woooooooooo`0Dooooo`03oc<0oooooooooooo0?oooooo3Oooool00olc0?oooooo
ooooo`0Cooooo`03ool0VOoooooooooo0=cooooo000booooo`03o`000?oooooooooo01kooooo00?o
o`2Iooooooooool04oooool00olc0?ooooooooooo`3oooooo`oooooo00?o<`3oooooooooool04_oo
ool00ooo09Woooooooooo`3Looooo`00<_ooool00ol0003oooooooooo`0Mooooo`03ool0VOoooooo
oooo01?ooooo00?o<`3oooooooooool0oooooolAooooo`03oc<0oooooooooooo01;ooooo00?oo`2I
ooooooooool0foooool003;ooooo00?o0000ooooooooool07Oooool00ooo09Woooooooooo`0Boooo
o`03oc<0oooooooooooo0?oooooo4oooool00olc0?ooooooooooo`0Aooooo`03ool0VOoooooooooo
0=_ooooo000booooo`03o`000?oooooooooo01cooooo00?oo`2Iooooooooool04_ooool00olc0?oo
ooooooooo`3ooooooaGooooo00?o<`3oooooooooool04Oooool00ooo09Woooooooooo`3Jooooo`00
<_ooool00ol0003oooooooooo`0Looooo`03ool0VOoooooooooo017ooooo00?o<`3oooooooooool0
oooooolGooooo`03oc<0oooooooooooo013ooooo00?oo`2Iooooooooool0f_ooool003;ooooo00?o
0000ooooooooool07?ooool00ooo09Woooooooooo`0@ooooo`03oc<0oooooooooooo0?oooooo6Ooo
ool00olc0?ooooooooooo`0@ooooo`03ool0VOoooooooooo0=Wooooo000booooo`03o`000?oooooo
oooo01_ooooo00?oo`2Iooooooooool04?ooool00olc0?ooooooooooo`3ooooooa[ooooo00?o<`3o
ooooooooool04?ooool00ooo09Woooooooooo`3Iooooo`00<_ooool00ol0003oooooooooo`0Koooo
o`03ool0VOoooooooooo00oooooo00?o<`3oooooooooool0oooooolLooooo`03oc<0oooooooooooo
00oooooo00?oo`2Iooooooooool0fOooool003;ooooo0_l0000Looooo`03ool0VOoooooooooo00ko
oooo00?o<`3oooooooooool0oooooolNooooo`03oc<0oooooooooooo00oooooo00?oo`2Ioooooooo
ool0f?ooool003;ooooo00?o0000ooooooooool06_ooool00ooo09Woooooooooo`0>ooooo`03oc<0
oooooooooooo0?oooooo8?ooool00olc0?ooooooooooo`0>ooooo`03ool0VOoooooooooo0=Sooooo
000booooo`03o`000?oooooooooo01[ooooo00?oo`2Iooooooooool03Oooool00olc0?oooooooooo
o`3oooooob;ooooo00?o<`3oooooooooool03_ooool00ooo09Woooooooooo`3Gooooo`00<_ooool0
0ol0003oooooooooo`0Iooooo`03ool0VOoooooooooo00gooooo00?o<`3oooooooooool0oooooolT
ooooo`03oc<0oooooooooooo00gooooo00?oo`2Iooooooooool0eoooool003;ooooo00?o0000oooo
ooooool06Oooool00ooo09Woooooooooo`0<ooooo`03oc<0oooooooooooo0?oooooo9_ooool00olc
0?ooooooooooo`0<ooooo`03ool0VOoooooooooo0=Oooooo000booooo`03o`000?oooooooooo01Wo
oooo00?oo`2Iooooooooool02oooool00olc0?ooooooooooo`3oooooobSooooo00?o<`3ooooooooo
ool03?ooool00ooo09Woooooooooo`3Fooooo`00<_ooool00ol0003oooooooooo`0Hooooo`03ool0
VOoooooooooo00_ooooo00?o<`3oooooooooool0oooooolZooooo`03oc<0oooooooooooo00_ooooo
00?oo`2Iooooooooool0e_ooool003;ooooo00?o0000ooooooooool06?ooool00ooo09Wooooooooo
o`0:ooooo`03oc<0oooooooooooo0?oooooo:oooool00olc0?ooooooooooo`0<ooooo`03ool0VOoo
oooooooo0=Gooooo000booooo`03o`000?oooooooooo01Oooooo00?oo`2Iooooooooool02oooool0
0olc0?ooooooooooo`3oooooobcooooo00?o<`3oooooooooool02oooool00ooo09Woooooooooo`3E
ooooo`00<_ooool00ol0003oooooooooo`0Gooooo`03ool0VOoooooooooo00[ooooo00?o<`3ooooo
ooooool0ooooool^ooooo`03oc<0oooooooooooo00[ooooo00?oo`2Iooooooooool0eOooool003;o
oooo00?o0000ooooooooool05oooool00ooo09Woooooooooo`09ooooo`03oc<0oooooooooooo0?oo
oooo;oooool00olc0?ooooooooooo`0;ooooo`03ool0VOoooooooooo0=Cooooo000booooo`;o0000
5oooool00ooo09Woooooooooo`0:ooooo`03oc<0oooooooooooo0?oooooo<?ooool00olc0?oooooo
ooooo`0:ooooo`03ool0VOoooooooooo0=Cooooo000booooo`03o`000?oooooooooo01Kooooo00?o
o`2Iooooooooool02Oooool00olc0?ooooooooooo`3ooooooc;ooooo00?o<`3oooooooooool02_oo
ool00ooo09Woooooooooo`3Cooooo`00<_ooool00ol0003oooooooooo`0Fooooo`03ool0VOoooooo
oooo00Sooooo00?o<`3oooooooooool0oooooolcooooo`03oc<0oooooooooooo00[ooooo00?oo`2I
ooooooooool0doooool003;ooooo00?o0000ooooooooool05Oooool00ooo09Woooooooooo`09oooo
o`03oc<0oooooooooooo0?oooooo=?ooool00olc0?ooooooooooo`09ooooo`03ool0VOoooooooooo
0=?ooooo000booooo`03o`000?oooooooooo01Gooooo00?oo`2Iooooooooool02?ooool00olc0?oo
ooooooooo`3oooooocKooooo00?o<`3oooooooooool02Oooool00ooo09Woooooooooo`3Booooo`00
<_ooool00ol0003oooooooooo`0Eooooo`03ool0VOoooooooooo00Oooooo00?o<`3oooooooooool0
oooooolgooooo`03oc<0oooooooooooo00Wooooo00?oo`2Iooooooooool0d_ooool003;ooooo00?o
0000ooooooooool05?ooool00ooo09Woooooooooo`08ooooo`03oc<0oooooooooooo0?oooooo>?oo
ool00olc0?ooooooooooo`08ooooo`03ool0VOoooooooooo0=;ooooo000booooo`03o`000?oooooo
oooo01Cooooo00?oo`2Iooooooooool01oooool00olc0?ooooooooooo`3ooooooc[ooooo00?o<`3o
ooooooooool02?ooool00ooo09Woooooooooo`3Aooooo`00<_ooool00ol0003oooooooooo`0Doooo
o`03ool0VOoooooooooo00Kooooo00?o<`3oooooooooool0oooooolkooooo`03oc<0oooooooooooo
00Sooooo00?oo`2Iooooooooool0dOooool003;ooooo00?o0000ooooooooool04oooool00ooo09Wo
ooooooooo`07ooooo`03oc<0oooooooooooo0?oooooo??ooool00olc0?ooooooooooo`07ooooo`03
ool0VOoooooooooo0=7ooooo000booooo`03o`000?oooooooooo01?ooooo00?oo`2Iooooooooool0
1_ooool00olc0?ooooooooooo`3oooooocgooooo00?o<`3oooooooooool02?ooool00ooo09Wooooo
ooooo`3@ooooo`00<_ooool2o`0001Cooooo00?oo`2Iooooooooool01_ooool00olc0?oooooooooo
o`3oooooockooooo00?o<`3oooooooooool01oooool00ooo09Woooooooooo`3@ooooo`00<_ooool0
0ol0003oooooooooo`0Booooo`03ool0VOoooooooooo00Kooooo00?o<`3oooooooooool0;_oooolN
o`3oojSooooo7?l0ool^ooooo`03oc<0oooooooooooo00Oooooo00?oo`2Iooooooooool0d?ooool0
03;ooooo00?o0000ooooooooool04_ooool00ooo09Woooooooooo`06ooooo`03oc<0oooooooooooo
02Gooooo2Ol0oolNooooo`co0?ooT_ooool:o`3ooacooooo2?l0oolWooooo`03oc<0oooooooooooo
00Kooooo00?oo`2Iooooooooool0d?ooool003;ooooo00?o0000ooooooooool04_ooool00ooo09Wo
ooooooooo`05ooooo`03oc<0oooooooooooo02;ooooo1?l0oolcooooo`co0?ooM_ooool@o`3oobko
oooo1?l0oolSooooo`03oc<0oooooooooooo00Oooooo00?oo`2Iooooooooool0coooool003;ooooo
00?o0000ooooooooool04Oooool00ooo09Woooooooooo`06ooooo`03oc<0oooooooooooo01kooooo
1?l0oom3ooooo`So0?ooI_ooool8o`3ood;ooooo1?l0oolPooooo`03oc<0oooooooooooo00Kooooo
00?oo`2Iooooooooool0coooool003;ooooo00?o0000ooooooooool04Oooool00ooo09Wooooooooo
o`05ooooo`03oc<0oooooooooooo01_ooooo1?l0oom?ooooo`co0?ooC_ooool<o`3oodkooooo0ol0
oolNooooo`03oc<0oooooooooooo00Gooooo00?oo`2Iooooooooool0coooool003;ooooo00?o0000
ooooooooool04Oooool00ooo09Woooooooooo`05ooooo`03oc<0oooooooooooo01Sooooo0ol0oomO
ooooo`_o0?oo=oooool<o`3ooegooooo0ol0oolKooooo`03oc<0oooooooooooo00Kooooo00?oo`2I
ooooooooool0c_ooool003;ooooo00?o0000ooooooooool04?ooool00ooo09Woooooooooo`05oooo
o`03oc<0oooooooooooo01Sooooo00?o0?ooooooooooool0JooooolEo`3oo`cooooo5_l0oom/oooo
o`?o0?oo6Oooool00olc0?ooooooooooo`05ooooo`03ool0VOoooooooooo0<kooooo000Eooooo`Go
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`0@ooooo`03
ool0VOoooooooooo00Gooooo00?o<`3oooooooooool05_ooool2o`3ooh?ooooo3?l0oon5ooooo`;o
0?oo5oooool00olc0?ooooooooooo`05ooooo`03ool0VOoooooooooo0<kooooo000Fooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04?ooool00ooo09Wooooooooo
o`04ooooo`03oc<0oooooooooooo01Cooooo0ol0oooooooooaWooooo0_l0oolFooooo`03oc<0oooo
oooooooo00Cooooo00?oo`2Iooooooooool0c_ooool000oooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool04?ooool00ooo09Woooooooooo`04ooooo`03
oc<0oooooooooooo01;ooooo0_l0oooooooooakooooo0_l0oolDooooo`03oc<0oooooooooooo00Go
oooo00?oo`2Iooooooooool0cOooool001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04
ooooo`?o00003oooool00ooo09Woooooooooo`04ooooo`03oc<0oooooooooooo01;ooooo00?o0?oo
ooooooooool0oooooolPooooo`03o`3ooooooooooooo01;ooooo00?o<`3oooooooooool01?ooool0
0ooo09Woooooooooo`3=ooooo`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool03oooool00ooo09Woooooooooo`04ooooo`03oc<0oooooooooooo017o
oooo00?o0?ooooooooooool0oooooolRooooo`;o0?oo4_ooool00olc0?ooooooooooo`04ooooo`03
ool0VOoooooooooo0<gooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0?ooooo`03ool0VOoooooooooo00?ooooo00?o<`3oooooooooool04?oo
ool2o`3ooooooooo9oooool00ol0ooooooooooooo`0@ooooo`03oc<0oooooooooooo00Cooooo00?o
o`2Iooooooooool0c?ooool001Kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007
ooooo`03o`000?oooooooooo00kooooo00?oo`2Iooooooooool01?ooool00olc0?ooooooooooo`0?
ooooo`03o`3ooooooooooooo0?oooooo:?ooool00ol0ooooooooooooo`0?ooooo`03oc<0oooooooo
oooo00Cooooo00?oo`2Iooooooooool0c?ooool003;ooooo00?o0000ooooooooool03_ooool00ooo
09Woooooooooo`03ooooo`03oc<0oooooooooooo00oooooo00?o0?ooooooooooool0oooooolZoooo
o`;o0?oo3oooool00olc0?ooooooooooo`04ooooo`03ool0VOoooooooooo0<cooooo000booooo`03
o`000?oooooooooo00kooooo00?oo`2Iooooooooool00oooool00olc0?ooooooooooo`0>ooooo`03
o`3ooooooooooooo0?oooooo;Oooool00ol0ooooooooooooo`0=ooooo`03oc<0oooooooooooo00?o
oooo00?oo`2Iooooooooool0c?ooool003;ooooo00?o0000ooooooooool03Oooool00ooo09Wooooo
ooooo`04ooooo`03oc<0oooooooooooo00gooooo00?o0?ooooooooooool0ooooool_ooooo`03o`3o
oooooooooooo00cooooo00?o<`3oooooooooool01?ooool00ooo09Woooooooooo`3;ooooo`00<_oo
ool00ol0003oooooooooo`0=ooooo`03ool0VOoooooooooo00?ooooo00?o<`3oooooooooool03Ooo
ool00ol0ooooooooooooo`3ooooooc7ooooo00?o0?ooooooooooool03?ooool00olc0?oooooooooo
o`03ooooo`03ool0VOoooooooooo0<_ooooo000booooo`03o`000?oooooooooo00gooooo00?oo`2I
ooooooooool00oooool00olc0?ooooooooooo`0<ooooo`03o`3ooooooooooooo0?oooooo<oooool0
0ol0ooooooooooooo`0;ooooo`03oc<0oooooooooooo00?ooooo00?oo`2Iooooooooool0boooool0
03;ooooo00?o0000ooooooooool03?ooool00ooo09Woooooooooo`03ooooo`03oc<0oooooooooooo
00cooooo00?o0?ooooooooooool0ooooooleooooo`03o`3ooooooooooooo00_ooooo00?o<`3ooooo
ooooool00oooool00ooo09Woooooooooo`3:ooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03
ool0VOoooooooooo00?ooooo00?o<`3oooooooooool02oooool00ol0ooooooooooooo`3oooooocOo
oooo00?o0?ooooooooooool02_ooool00olc0?ooooooooooo`03ooooo`03ool0VOoooooooooo0<[o
oooo000booooo`;o00003Oooool00ooo09Woooooooooo`03ooooo`03oc<0oooooooooooo00[ooooo
00?o0?ooooooooooool0ooooooliooooo`03o`3ooooooooooooo00Wooooo00?o<`3oooooooooool0
0oooool00ooo09Woooooooooo`3:ooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03ool0VOoo
oooooooo00;ooooo00?o<`3oooooooooool02_ooool00ol0ooooooooooooo`3ooooooc_ooooo00?o
0?ooooooooooool02Oooool00olc0?ooooooooooo`02ooooo`03ool0VOoooooooooo0<[ooooo000b
ooooo`03o`000?oooooooooo00_ooooo00?oo`2Iooooooooool00oooool00olc0?ooooooooooo`09
ooooo`03o`3ooooooooooooo0?oooooo??ooool00ol0ooooooooooooo`09ooooo`03oc<0oooooooo
oooo00?ooooo00?oo`2Iooooooooool0bOooool003;ooooo00?o0000ooooooooool02oooool00ooo
09Woooooooooo`02ooooo`03oc<0oooooooooooo00[ooooo00?o0?ooooooooooool0oooooolmoooo
o`03o`3ooooooooooooo00Wooooo00?o<`3oooooooooool00_ooool00ooo09Woooooooooo`39oooo
o`00<_ooool00ol0003oooooooooo`0;ooooo`03ool0VOoooooooooo00;ooooo00?o<`3ooooooooo
ool02Oooool00ol0ooooooooooooo`3oooooocoooooo00?o0?ooooooooooool02?ooool00olc0?oo
ooooooooo`02ooooo`03ool0VOoooooooooo0<Wooooo000booooo`03o`000?oooooooooo00_ooooo
00?oo`2Iooooooooool00_ooool00olc0?ooooooooooo`08ooooo`03o`3ooooooooooooo0?oooooo
@Oooool00ol0ooooooooooooo`08ooooo`05oc<0oooooooooooooooooooo09T0boooool003;ooooo
00?o0000ooooooooool02oooool01Ooo09Wooooooooooooooooo<`3o00[ooooo00?o0?oooooooooo
ool0oooooom3ooooo`03o`3ooooooooooooo00Oooooo00Go<`3oooooooooooooooooool0V@3;oooo
o`00<_ooool00ol0003oooooooooo`0:ooooo`03ool0VOoooooooooo00;ooooo00?o<`3ooooooooo
ool02?ooool00ol0ooooooooooooo`3ooooood?ooooo00?o0?ooooooooooool01oooool00olc0?oo
ooooooooo`02ooooo`03ool0VOoooooooooo0<Sooooo000booooo`03o`000?oooooooooo00[ooooo
00?oo`2Iooooooooool00_ooool00olc0?ooooooooooo`07ooooo`03o`3ooooooooooooo0?oooooo
AOooool00ol0ooooooooooooo`07ooooo`05oc<0oooooooooooooooooooo09T0b_ooool003;ooooo
00?o0000ooooooooool02_ooool01Ooo09Wooooooooooooooooo<`3o00Wooooo00?o0?oooooooooo
ool0oooooom7ooooo`03o`3ooooooooooooo00Kooooo00Go<`3oooooooooooooooooool0V@3:oooo
o`00<_ooool2o`0000_ooooo00Goo`2Ioooooooooooooooooc<0o`09ooooo`03o`3ooooooooooooo
0?ooooooB?ooool00ol0ooooooooooooo`05ooooo`05oc<0oooooooooooooooooooo09T0b_ooool0
03;ooooo00?o0000ooooooooool02_ooool01?oo09Wooooooooooolc0?l9ooooo`03o`3ooooooooo
oooo0?ooooooB_ooool00ol0ooooooooooooo`05ooooo`05oc<0oooooooooooooooooooo09T0bOoo
ool003;ooooo00?o0000ooooooooool02Oooool01Ooo09Wooooooooooooooooo<`3o00Sooooo00?o
0?ooooooooooool0oooooom;ooooo`03o`3ooooooooooooo00Gooooo00Go<`3ooooooooooooooooo
ool0V@39ooooo`00<_ooool00ol0003oooooooooo`09ooooo`05ool0VOoooooooooooooooolc0?l0
1oooool00ol0ooooooooooooo`3oooooodgooooo00?o0?ooooooooooool01?ooool01Olc0?oooooo
ooooooooooooo`2I0<Wooooo000booooo`03o`000?oooooooooo00Wooooo00Coo`2Ioooooooooooo
<`3o2?ooool00ol0ooooooooooooo`3oooooodgooooo00?o0?ooooooooooool01Oooool01?lc0?oo
oooooooooooo09W9ooooo`00<_ooool00ol0003oooooooooo`09ooooo`04ool0VOoooooooooooc<0
o`Oooooo00?o0?ooooooooooool0oooooom?ooooo`03o`3ooooooooooooo00Cooooo00Go<`3ooooo
ooooooooooooool0V@38ooooo`00<_ooool00ol0003oooooooooo`08ooooo`05ool0VOoooooooooo
oooooolc0?l01_ooool00ol0ooooooooooooo`3ooooooe3ooooo00?o0?ooooooooooool01?ooool0
1Olc0?ooooooooooooooooooo`2I0<Sooooo000booooo`03o`000?oooooooooo00Sooooo00Coo`2I
oooooooooooo<`3o1oooool00ol0ooooooooooooo`3ooooooe7ooooo00?o0?ooooooooooool00ooo
ool01Olc0?ooooooooooooooooooo`2I0<Sooooo000booooo`03o`000?oooooooooo00Sooooo00Co
o`2Ioooooooooooo<`3o1_ooool00ol0ooooooooooooo`3ooooooe;ooooo00?o0?ooooooooooool0
1?ooool01?lc0?oooooooooooooo09W8ooooo`00<_ooool00ol0003oooooooooo`08ooooo`04ool0
VOoooooooooooc<0o`Kooooo00?o0?ooooooooooool0oooooomCooooo`03o`3ooooooooooooo00?o
oooo00Co<`3oooooooooooooo`2Ib?ooool003;ooooo00?o0000ooooooooool02?ooool00ooo09Wo
oooooc<0o`06ooooo`03o`3ooooooooooooo0?ooooooE?ooool00ol0ooooooooooooo`03ooooo`05
oc<0oooooooooooooooooooo09T0aoooool003;ooooo0_l00008ooooo`04ool0VOoooooooooooc<0
o`Gooooo00?o0?ooooooooooool0oooooomFooooo`03o`3ooooooooooooo00?ooooo00Co<`3ooooo
ooooooooo`2Iaoooool003;ooooo00?o0000ooooooooool01oooool01?oo09Wooooooooooolc0?l5
ooooo`03o`3ooooooooooooo01_ooooo3_lco`3oooooo`?ooooo3Olco`0Mooooo`03o`3ooooooooo
oooo00?ooooo00Co<`3oooooooooooooo`2Iaoooool003;ooooo00?o0000ooooooooool01oooool0
0ooo09Wooooooc<0o`05ooooo`03o`3ooooooooooooo01Kooooo1_lco`0>ooooo`Oo<ol0loooool8
oc?o00gooooo1_lco`0Hooooo`03o`3ooooooooooooo00;ooooo00Co<`3oooooooooooooo`2Iaooo
ool003;ooooo00?o0000ooooooooool01oooool00ooo09Wooooooc<0o`05ooooo`03o`3ooooooooo
oooo01;ooooo1?lco`0Kooooo`Ko<ol0jOooool4oc?o01_ooooo0olco`0Eooooo`03o`3ooooooooo
oooo00;ooooo00Go<`3oooooooooooooooooool0V@36ooooo`00<_ooool00ol0003oooooooooo`06
ooooo`04ool0VOoooooooooooc<0o`Cooooo00?o0?ooooooooooool04Oooool2oc?o02Gooooo1_lc
o`3Kooooo`So<ol08_ooool3oc?o01?ooooo00?o0?ooooooooooool00_ooool01?lc0?oooooooooo
oooo09W6ooooo`00<_ooool00ol0003oooooooooo`06ooooo`03ool0VOoooooo<`3o00Gooooo00?o
0?ooooooooooool03oooool2oc?o02gooooo1?lco`3Dooooo`?o<ol0;Oooool2oc?o017ooooo00?o
0?ooooooooooool00_ooool01?lc0?oooooooooooooo09W6ooooo`00<_ooool00ol0003ooooooooo
o`06ooooo`03ool0VOoooooo<`3o00Gooooo00?o0?ooooooooooool03Oooool2oc?o03?ooooo0olc
o`3>ooooo`?o<ol0<_ooool2oc?o013ooooo00Go0?oooooooooooooooooooc<0o`02ooooo`03ool0
VOoooooooooo0<Cooooo000booooo`03o`000?oooooooooo00Kooooo00?oo`2Ioooooolc0?l01?oo
ool00ol0ooooooooooooo`0<ooooo`;o<ol0>?ooool4oc?o0<Oooooo0olco`0gooooo`;o<ol03_oo
ool01Ol0oooooooooooooooooooo<`3o00?ooooo00?oo`2Iooooooooool0`oooool003;ooooo00?o
0000ooooooooool01_ooool00ooo09Wooooooc<0o`04ooooo`03o`3ooooooooooooo00_ooooo00?o
<ol0ooooooooool0??ooool4oc?o0<3ooooo0olco`0looooo`;o<ol03Oooool01Ol0oooooooooooo
oooooooo<`3o00;ooooo00?oo`2Iooooooooool0`oooool003;ooooo00?o0000ooooooooool01Ooo
ool00ooo09Wooooooc<0o`04ooooo`03o`3ooooooooooooo00_ooooo00?o<ol0ooooooooool0@Ooo
ool3oc?o0;Wooooo1?lco`11ooooo`03oc?o0?oooooooooo00[ooooo00Go0?oooooooooooooooooo
oc<0o`02ooooo`03ool0VOoooooooooo0<?ooooo000booooo`03o`000?oooooooooo00Gooooo00?o
o`2Ioooooolc0?l01?ooool00ol0ooooooooooooo`09ooooo`;o<ol0Aoooool4oc?o0;7ooooo1?lc
o`16ooooo`03oc?o0?oooooooooo00[ooooo00Co0?oooooooooooooo<`3o0_ooool00ooo09Wooooo
ooooo`33ooooo`00<_ooool2o`0000Kooooo00?oo`2Ioooooolc0?l00oooool00ol0oooooooooooo
o`09ooooo`03oc?o0?oooooooooo04_ooooo0olco`2Zooooo`Co<ol0Boooool00olco`3ooooooooo
o`09ooooo`07o`3ooooooooooooooooooolc0?ooooooool0V@35ooooo`00<_ooool00ol0003ooooo
ooooo`05ooooo`03ool0VOoooooo<`3o00?ooooo00?o0?ooooooooooool02?ooool00olco`3ooooo
ooooo`1?ooooo`?o<ol0Xoooool4oc?o053ooooo00?o<ol0ooooooooool02?ooool01Ol0oooooooo
oooooooooooo<`3o00;ooooo00?oo`2Iooooooooool0`_ooool003;ooooo00?o0000ooooooooool0
1Oooool00ooo09Wooooooc<0o`03ooooo`03o`3ooooooooooooo00Oooooo00?o<ol0ooooooooool0
Doooool4oc?o09cooooo0olco`1Eooooo`03oc?o0?oooooooooo00Sooooo00Co0?oooooooooooooo
<`3o0_ooool00ooo09Woooooooooo`32ooooo`00<_ooool00ol0003oooooooooo`04ooooo`03ool0
VOoooooo<`3o00?ooooo00?o0?ooooooooooool01oooool00olco`3oooooooooo`1Hooooo`?o<ol0
U_ooool3oc?o05Wooooo00?o<ol0ooooooooool01oooool01?l0oooooooooooooolc0?l2ooooo`03
ool0VOoooooooooo0<;ooooo000booooo`03o`000?oooooooooo00Cooooo00?oo`2Ioooooolc0?l0
0oooool00ol0ooooooooooooo`06ooooo`03oc?o0?oooooooooo05cooooo0olco`2@ooooo`?o<ol0
GOooool00olco`3oooooooooo`07ooooo`06o`3ooooooooooooooc<0ooooooooo`2Ia?ooool003;o
oooo00?o0000ooooooooool01?ooool00ooo09Wooooooc<0o`02ooooo`03o`3ooooooooooooo00Ko
oooo00?o<ol0ooooooooool0H?ooool3oc?o08[ooooo0olco`1Qooooo`03oc?o0?oooooooooo00Ko
oooo00Ko0?oooooooooooooo<`3ooooooooo09W4ooooo`00<_ooool00ol0003oooooooooo`04oooo
o`03ool0VOoooooo<`3o00;ooooo00?o0?ooooooooooool01Oooool00olco`3oooooooooo`1Toooo
o`?o<ol0Q?ooool3oc?o06Gooooo00?o<ol0ooooooooool01Oooool01_l0oooooooooooooolc0?oo
ooooool0VLCooooo000booooo`03o`000?oooooooooo00Cooooo00?oo`2Ioc<0ooooool00_ooool0
0ol0ooooooooooooo`04ooooo`03oc?o0?oooooooooo06Sooooo1?lco`1kooooo`Go<ol0JOooool0
0olco`3oooooooooo`05ooooo`03o`3ooooooooo<`3o00;ooooo00?oo`2Iooooooooool0`Oooool0
01Kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
00?ooooo00?oo`2Ioooooolc0?l00_ooool00ol0ooooooooooooo`05ooooo`03oc?o0?oooooooooo
06cooooo1?lco`1booooo`Go<ol0K_ooool00olco`3oooooooooo`05ooooo`06o`3ooooooooooooo
oc<0ooooooooo`2I`oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`03ooooo`03ool0VOoooooo<`3o00;ooooo00?o0?ooooooooooool01?ooool00olco`3o
ooooooooo`1aooooo`?o<ol0J_ooool5oc?o07Cooooo00?o<ol0ooooooooool01?ooool01_l0oooo
oooooooooolc0?ooooooool0VL?ooooo000?ooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00?ooooo00?oo`2Ioooooolc0?l00_ooool00ol0oooooooo
ooooo`03ooooo`03oc?o0?oooooooooo07Gooooo1?lco`1Qooooo`Go<ol0NOooool00olco`3ooooo
ooooo`05ooooo`05o`3ooooooooo<`3ooooooooo09T0`oooool001Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001_ooool3o`0000?ooooo00Goo`2Ioooooolc0?ooooooo`3oo`06ooooo`03oc?o0?oo
oooooooo07Wooooo1_lco`1Gooooo`Co<ol0Ooooool00olco`3oooooooooo`04ooooo`05o`3ooooo
oooo<`3ooooooooo09T0`oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`03ooooo`05ool0VOlc0?ooooooooooool0ool01Oooool00olco`3oooooooooo`20
ooooo`Ko<ol0C?ooool5oc?o08Cooooo00?o<ol0ooooooooool00oooool01Ol0oooooooooooooolc
0?ooo`2I0<?ooooo000Fooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`05
ool0VOlc0?ooooooooooool0ool01?ooool00olco`3oooooooooo`27ooooo`Go<ol0@oooool4oc?o
08Wooooo00?o<ol0ooooooooool01?ooool01?l0oooooooooc<0oooo09W3ooooo`005oooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
00;ooooo00Goo`2Ioooooolc0?ooooooo`3oo`05ooooo`03oc?o0?oooooooooo08cooooo1_lco`0g
ooooo`Ko<ol0S_ooool00olco`3oooooooooo`03ooooo`05o`3ooooooooo<`3ooooooooo09T0`_oo
ool003;ooooo00?o0000ooooooooool00_ooool01Ooo09Wooooooc<0oooooooo0?oo00Cooooo00?o
<ol0ooooooooool0Toooool>oc?o01_ooooo3_lco`2Dooooo`03oc?o0?oooooooooo00?ooooo00Go
0?oooooooolc0?ooooooool0V@32ooooo`00<_ooool00ol0003oooooooooo`02ooooo`05ool0VOoo
oooo<`3oooooool0ool01?ooool00olco`3oooooooooo`2Qoooooa_o<ol0Xoooool00olco`3ooooo
ooooo`03ooooo`04o`3ooooooooo<`3oool0VL;ooooo000booooo`03o`000?oooooooooo00;ooooo
00Coo`2Ioc<0oooooooo0?oo1?ooool00olco`3oooooooooo`3oooooof7ooooo00?o<ol0oooooooo
ool00oooool01?l0oooooooooc<0oooo09W2ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04
ool0VOlc0?ooooooo`3oo`?ooooo00?o<ol0ooooooooool0oooooomSooooo`03oc?o0?oooooooooo
00;ooooo00Co0?oooooooolc0?ooo`2I`_ooool003;ooooo00?o0000ooooooooool00_ooool01?oo
09Wo<`3oooooool0ool3ooooo`03oc?o0?oooooooooo0?ooooooI?ooool02?lco`3ooooooooooooo
oooo0?oooooooolc0?ooo`2I`_ooool003;ooooo00?o0000ooooooooool00_ooool00ooo09Wo<`3o
o`3oo`03ooooo`03oc?o0?oooooooooo0?ooooooIOooool00olco`3oooooooooo`02ooooo`03o`3o
ooooooooo`2I0<;ooooo000booooo`08o`000?oooooooooooooooooo09Wooooooc<0ool0ool3oooo
o`03oc?o0?oooooooooo0?ooooooI_ooool01olco`3ooooooooooooooooo0?oooooooooo09T0`_oo
ool003;ooooo0_l00002ooooo`04ool0VOlc0?ooooooo`3oo`;ooooo00?o<ol0ooooooooool0oooo
oomWooooo`08oc?o0?ooooooooooooooool0oooooooooc<0oooo09W1ooooo`00<_ooool02?l0003o
ooooooooooooooooo`2Ioc<0oooooooo0?oo0_ooool00olco`3oooooooooo`3oooooofSooooo00Oo
<ol0ooooooooooooooooo`3ooolc0?ooo`2I0<7ooooo000booooo`07o`000?oooooooooooooooooo
09Wo<`3oo`3oo`03ooooo`03oc?o0?oooooooooo0?ooooooJ?ooool01olco`3ooooooooooooooooo
0?oooc<0oooo09T0`Oooool003;ooooo00Oo0000ooooooooooooooooool0VOlc0?oo0?oo00;ooooo
00?o<ol0ooooooooool0oooooomYooooo`07oc?o0?ooooooooooooooool0ooooooooool0V@31oooo
o`00<_ooool01ol0003oooooooooooooooooo`2Ioc<0ool0ool00_ooool00olco`3oooooooooo`3o
ooooof[ooooo00Ko<ol0oooooooooooo0?oooooooooo09W1ooooo`00<_ooool02Ol0003ooooooooo
oooo09Wo<`3oooooool0oooooooooc?o003oooooofgooooo00Ko<ol0ooooooooooooooooo`3ooooo
09W1ooooo`00<_ooool02Ol0003ooooooooooooo09Wo<`3oooooool0oooooooooc?o003oooooofko
oooo00Go<ol0oooooooooooo0?ooool0V@31ooooo`00<_ooool01_l0003ooooooooooooo09Wo<`3o
o`3oo`;ooooo00?o<ol0ooooooooool0oooooom/ooooo`05oc?o0?ooooooooooo`3ooooo09T0`Ooo
ool003;ooooo00So0000ooooooooooooo`2Ioc<0ool0oooooooooc?o0?ooooooKoooool01_lco`3o
ooooooooool0oooo<`3oool0VL3ooooo000booooo`08o`000?ooooooooooool0VOlc0?oo0?oooooo
oolco`3oooooog3ooooo00Go<ol0ooooool0ooooooooool0V@30ooooo`00<_ooool02?l0003ooooo
oooooooo09Woooooo`3ooooooooo<ol0oooooom`ooooo`05oc?o0?ooooooooooo`3ooooo09T0`?oo
ool003;ooooo0_l000001Ooo09Wo<`3oo`3ooooooooo<ol00?ooooooL_ooool01?lco`3oooooo`3o
oooo09W0ooooo`00<_ooool01ol0003oooooool0VOlc0?oo0?oooooooolco`00oooooombooooo`04
oc?o0?oooooo0?ooool0VL3ooooo000booooo`07o`000?ooooooo`2Ioc<0ool0oooooooooc?o003o
ooooog;ooooo00Co<ol0ooooool0ooooo`2I`?ooool003;ooooo00Ko0000oooooooo09Wo<`3oo`3o
oolco`3oooooogCooooo00?o<ol0o`3ooooo09T0`?ooool003;ooooo00Ko0000oooooooo09Wo<`3o
o`3ooolco`3oooooogCooooo00Co<ol0o`3ooooo09Wo<`3o_oooool003;ooooo00Ko0000oooooooo
09Wo0?oooooooolco`3oooooogCooooo00Co<ol0ooooool0ooooo`2I_oooool003;ooooo00Ko0000
oooooooo09Wo0?oooooooolco`3oooooogCooooo00Co<ol0ooooool0ooooo`2I_oooool003;ooooo
00Go0000ool0VOlc0?oo0?oooc?o003oooooogKooooo00?o<ol0o`3ooooo09T0_oooool003;ooooo
00Go0000ool0VOlc0?oo0?oooc?o003oooooogKooooo00?o<ol0o`3ooooo09T0_oooool003;ooooo
00Go0000ool0VOlc0?oooooooc?o003oooooogKooooo00?o<ol0o`3ooooo09T0_oooool003;ooooo
00Co0000ool0VOlc0?oo<ol0oooooomhooooo`03oc?o0?oo09Wo<`3o0;kooooo000booooo`04o`00
0?oo09Wo0?oooc?o0?ooooooN?ooool00olco`3oo`2Ioc<0o`2nooooo`00<_ooool01?l0003oo`2I
o`3ooolco`3oooooogSooooo00?o<ol0ool0VOlc0?l0__ooool003;ooooo00Co0000ool0VOl0oooo
<ol0oooooomhooooo`03oc?o0?oo09Wo<`3o0;kooooo000booooo`03o`000?oo09Wo<ol00?oooooo
N_ooool00ol0ooooo`2Iooooo`2mooooo`00<_ooool00ol0003oo`2Ioc?o003oooooog[ooooo00?o
0?ooool0VOooool0_Oooool003;ooooo00?oo`2Ioc<0oolco`00oooooomjooooo`03oc?o0?oo09Wo
oooo0;gooooo000booooo`03ool0VOlc0?oo<ol00?ooooooN_ooool00olco`3oo`2Iooooo`2moooo
o`00<_ooool00ooo09Wo0?ooooooo`3oooooog_ooooo00?oo`2Iooooooooool0_?ooool003;ooooo
00?oo`2Io`3oooooool0@_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000nooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`?o0000?Oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0003oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00014ooooo`03
ool0VOlc0?oo00000;cooooo000booooo`03ool0VOlco`3ooooo047ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool0000mooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool0>oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
?Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000@oooool00ooo
09Wo<`3oooooo`2looooo`00<_ooool00ooo09Wo<ol0ooooo`11ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0?Oooool01?l0003oooooooooool00007ooooo`Go0000??ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000?Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool00000@oooool00ol0ooooo`2Iooooo`2loooo
o`00<_ooool00ooo09Woooooooooo`11ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool0??ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0003gooooo00Co
0000oooooooooooo00001oooool4o`0003kooooo00Co0000oooooooooooo00002?ooool3o`0004Co
oooo00?o0?ooool0VOooool0_?ooool003;ooooo00?oo`2Iooooooooool0@Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool00000?Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000003gooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0oooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`03
oc?o0?oo09Wooooo0;cooooo000booooo`03ool0VOoooooooooo047ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000003gooooo00Co0000oooooooooooo00002Oooool2
o`0003gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0nooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`03o`000?oo09Wooooo0;co
oooo000booooo`03ool0VOoooooooooo04;ooooo0_l00009ooooo`?o0000?oooool2o`0000_ooooo
00?o0000ooooooooool0??ooool2o`0000[ooooo0_l0000oooooo`;o00002Oooool3o`0004Gooooo
00?oo`2Iooooooooool0^oooool003;ooooo00?oo`2Iooooooooool0oooooomlooooo`03ool0VOoo
oooooooo0;_ooooo000booooo`03ool0VOoooooooooo0?ooooooO?ooool00ooo09Woooooooooo`2k
ooooo`00<_ooool00ooo09Woooooooooo`3oooooogcooooo00?oo`2Ioc<0ooooool0^oooool003;o
oooo00?oo`2Iooooooooool0oooooomlooooo`03o`3ooooo09Wooooo0;_ooooo000booooo`03ool0
VOoooooooooo0?ooooooOOooool00ooo09Woooooooooo`0Booooo`;o000000Coooooo`000?l0003o
oooo1?l0002Nooooo`00<_ooool00ooo09Woooooooooo`3ooooooggooooo00?oo`2Iooooooooool0
4oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0009gooooo000Xooooo`[o0000
00?oo`2Io`000?l00000ool0001mo`000003ool0VOl0003o000000Oo00003Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0009gooooo000booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo
0ol0002Nooooo`00<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0009gooooo
000booooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000WOooool003;ooooo00?o
0000ooooooooool0oooooonBooooo`;o000000Coooooo`000?l0003ooooo1?l0002Nooooo`00<_oo
ool00ol0003oooooooooo`3ooooooooooooo>oooool003;ooooo00?o0000ooooooooool0oooooooo
oooooc_ooooo003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo
003oooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003ooooooooo
ooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool0
0?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool002cooooo1Ol0
00001?oooooo0000o`000?l0003ooooooooooooo>oooool002gooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`3ooooooooooooo>_ooool002gooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`3ooooooooooooo>_ooool002kooooo00?o0000ooooooooool00_ooool3o`00
0?ooooooooooooljooooo`00;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
ooooooooooljooooo`00;_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`000?oo
ooooooooooliooooo`00<_ooool5o`000?ooooooooooooliooooo`00ooooooooooooog3ooooo003o
ooooooooooooL?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003ooooooooooooo
L?ooool00?oooooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool00?oo
oooooooooom`ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool00?oooooooooooom`
ooooo`00ooooooooooooog3ooooo003oooooooooooooL?ooool00?oooooooooooom`ooooo`00oooo
ooooooooog3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 621}, {397.188, 0}} -> {-1.06651, -1.09171, \
0.00440965, 0.00440965}, {{15.0625, 468.625}, {289.75, 9.4375}} -> \
{-0.130814, -6545.18, 0.00261159, 18.4426}, {{468.625, 594.562}, {376.375, \
194.938}} -> {-12.603, -0.655666, 0.0266802, 0.0266802}, {{475.312, 512.812}, \
{369.562, 332.125}} -> {-13.3339, -4.19925, 0.0280003, 0.0906108}, {{475.312, \
512.812}, {326.125, 288.625}} -> {-13.3339, -8.13799, 0.0280003, 0.0906108}, \
{{475.312, 512.812}, {282.625, 245.125}} -> {-13.3339, -12.0796, 0.0280003, \
0.0906108}, {{475.312, 512.812}, {239.125, 201.688}} -> {-13.3339, -16.0183, \
0.0280003, 0.0906108}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here is a 3D representation of the free energy surface \
\[CapitalDelta]F(XB,T):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\[CapitalDelta]F[XB, 0, T], {XB, 0.01, 0.99}, {T, 300, 1500}, 
      AxesLabel \[Rule] {XB, T, \[CapitalDelta]F}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.62961e-17 1.04977 -0.0679587 1.04977 [
[.14227 .20104 -17.9089 -9 ]
[.14227 .20104 .09106 0 ]
[.26884 .15124 -17.1431 -9 ]
[.26884 .15124 .85695 0 ]
[.40182 .09894 -16.3772 -9 ]
[.40182 .09894 1.62284 0 ]
[.54173 .04395 -15.6113 -9 ]
[.54173 .04395 2.38873 0 ]
[.29165 .07573 -14.8979 -12 ]
[.29165 .07573 1.10213 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 18 2.82223 ]
[.82083 .17876 0 -6.08311 ]
[.82083 .17876 18 2.91689 ]
[.87924 .26821 0 -5.99856 ]
[.87924 .26821 24 3.00144 ]
[.93273 .35014 0 -5.92258 ]
[.93273 .35014 24 3.07742 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.0144 .32601 -30 -2.79382 ]
[.0144 .32601 0 6.20618 ]
[.00161 .40612 -6 -2.86188 ]
[.00161 .40612 0 6.13812 ]
[-0.01184 .49043 -24 -2.93388 ]
[-0.01184 .49043 0 6.06612 ]
[-0.05457 .39542 -16 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.1515 .21036 m
.15612 .21503 L
s
[(0.2)] .14227 .20104 .98988 1 Mshowa
.27764 .16097 m
.28204 .16584 L
s
[(0.4)] .26884 .15124 .90478 1 Mshowa
.41014 .10909 m
.4143 .11416 L
s
[(0.6)] .40182 .09894 .81968 1 Mshowa
.5495 .05452 m
.55338 .05981 L
s
[(0.8)] .54173 .04395 .73459 1 Mshowa
.125 Mabswid
.06081 .24588 m
.06366 .24859 L
s
.09068 .23418 m
.09351 .23692 L
s
.12091 .22234 m
.12371 .22511 L
s
.18247 .19824 m
.18521 .20107 L
s
.21381 .18597 m
.21651 .18883 L
s
.24553 .17355 m
.2482 .17644 L
s
.31015 .14824 m
.31276 .15119 L
s
.34306 .13535 m
.34564 .13834 L
s
.37639 .1223 m
.37893 .12532 L
s
.44432 .09571 m
.44677 .09878 L
s
.47893 .08215 m
.48134 .08526 L
s
.51399 .06843 m
.51636 .07157 L
s
.58547 .04044 m
.58776 .04364 L
s
.62192 .02616 m
.62416 .0294 L
s
.65884 .01171 m
.66104 .01497 L
s
gsave
.29165 .07573 -75.8979 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(500)] .75679 .08071 -1 .37284 Mshowa
.80845 .18312 m
.80226 .18529 L
s
[(750)] .82083 .17876 -1 .3518 Mshowa
.86679 .27235 m
.86056 .27443 L
s
[(1000)] .87924 .26821 -1 .33301 Mshowa
.92022 .35409 m
.91397 .35607 L
s
[(1250)] .93273 .35014 -1 .31613 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1500)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75778 .10561 m
.75408 .10697 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.87784 .28927 m
.87411 .2905 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.93037 .36962 m
.92662 .3708 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
.73096 .06459 m
.72728 .06598 L
s
.71716 .04348 m
.71349 .04489 L
s
.70309 .02196 m
.69942 .02338 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02667 .32136 m
.0328 .31903 L
s
[(-5000)] .0144 .32601 1 -0.37915 Mshowa
.01394 .40163 m
.02011 .39939 L
s
[(0)] .00161 .40612 1 -0.36403 Mshowa
.00056 .48612 m
.00675 .48396 L
s
[(5000)] -0.01184 .49043 1 -0.34803 Mshowa
.125 Mabswid
.02417 .33709 m
.02786 .3357 L
s
.02165 .35298 m
.02534 .35161 L
s
.01911 .36904 m
.0228 .36767 L
s
.01654 .38525 m
.02024 .38389 L
s
.01132 .41818 m
.01503 .41685 L
s
.00867 .4349 m
.01238 .43358 L
s
.006 .4518 m
.00971 .45048 L
s
.00329 .46887 m
.007 .46756 L
s
.02913 .30578 m
.03281 .30437 L
s
.03158 .29035 m
.03525 .28894 L
s
.034 .27508 m
.03767 .27366 L
s
.0364 .25996 m
.04006 .25852 L
s
gsave
-0.05457 .39542 -77 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.872 .762 .738 r
.38794 .70565 .40118 .71639 .42424 .67603 .4112 .6668 Metetra
.848 .793 .798 r
.4112 .6668 .42424 .67603 .44676 .64862 .4339 .64044 Metetra
.827 .818 .84 r
.4339 .64044 .44676 .64862 .4691 .62707 .45641 .61972 Metetra
.806 .839 .875 r
.45641 .61972 .4691 .62707 .49139 .60916 .47888 .60248 Metetra
.784 .856 .904 r
.47888 .60248 .49139 .60916 .51371 .59379 .50137 .58765 Metetra
.761 .87 .928 r
.50137 .58765 .51371 .59379 .53609 .58031 .52394 .5746 Metetra
.737 .88 .946 r
.52394 .5746 .53609 .58031 .55859 .56831 .54663 .56293 Metetra
.712 .886 .961 r
.54663 .56293 .55859 .56831 .58122 .5575 .56945 .55237 Metetra
.686 .89 .972 r
.56945 .55237 .58122 .5575 .604 .54769 .59243 .54274 Metetra
.662 .89 .98 r
.59243 .54274 .604 .54769 .62696 .53876 .61558 .53389 Metetra
.637 .888 .986 r
.61558 .53389 .62696 .53876 .65012 .53061 .63893 .52576 Metetra
.613 .883 .99 r
.63893 .52576 .65012 .53061 .67349 .5232 .6625 .5183 Metetra
.59 .876 .993 r
.6625 .5183 .67349 .5232 .69709 .51652 .68629 .51149 Metetra
.566 .867 .996 r
.68629 .51149 .69709 .51652 .72093 .51059 .71032 .50536 Metetra
.542 .855 .997 r
.71032 .50536 .72093 .51059 .74506 .50547 .73463 .49995 Metetra
.517 .841 .999 r
.73463 .49995 .74506 .50547 .76949 .50124 .75924 .49537 Metetra
.489 .822 .999 r
.75924 .49537 .76949 .50124 .79425 .49806 .78417 .49174 Metetra
.457 .799 .999 r
.78417 .49174 .79425 .49806 .81941 .49614 .80948 .48928 Metetra
.417 .768 .996 r
.80948 .48928 .81941 .49614 .84502 .49577 .83523 .48827 Metetra
.365 .727 .988 r
.83523 .48827 .84502 .49577 .87117 .49741 .8615 .48916 Metetra
.295 .67 .973 r
.8615 .48916 .87117 .49741 .898 .50176 .88842 .49262 Metetra
.193 .586 .942 r
.88842 .49262 .898 .50176 .92572 .51001 .9162 .4998 Metetra
.029 .447 .873 r
.9162 .4998 .92572 .51001 .95474 .52455 .94522 .51303 Metetra
0 .163 .675 r
.94522 .51303 .95474 .52455 .98626 .553 .97663 .53967 Metetra
.869 .764 .744 r
.37449 .69475 .38794 .70565 .4112 .6668 .39793 .65741 Metetra
.842 .795 .805 r
.39793 .65741 .4112 .6668 .4339 .64044 .4208 .63212 Metetra
.82 .819 .848 r
.4208 .63212 .4339 .64044 .45641 .61972 .44349 .61224 Metetra
.799 .84 .882 r
.44349 .61224 .45641 .61972 .47888 .60248 .46613 .59567 Metetra
.776 .856 .911 r
.46613 .59567 .47888 .60248 .50137 .58765 .48881 .58138 Metetra
.752 .87 .933 r
.48881 .58138 .50137 .58765 .52394 .5746 .51156 .56877 Metetra
.728 .879 .951 r
.51156 .56877 .52394 .5746 .54663 .56293 .53443 .55745 Metetra
.704 .885 .964 r
.53443 .55745 .54663 .56293 .56945 .55237 .55744 .54714 Metetra
.68 .889 .974 r
.55744 .54714 .56945 .55237 .59243 .54274 .58062 .53768 Metetra
.656 .889 .982 r
.58062 .53768 .59243 .54274 .61558 .53389 .60397 .52893 Metetra
.634 .887 .987 r
.60397 .52893 .61558 .53389 .63893 .52576 .62752 .52082 Metetra
.612 .883 .99 r
.62752 .52082 .63893 .52576 .6625 .5183 .65128 .5133 Metetra
.591 .877 .993 r
.65128 .5133 .6625 .5183 .68629 .51149 .67526 .50636 Metetra
.57 .869 .995 r
.67526 .50636 .68629 .51149 .71032 .50536 .69949 .50001 Metetra
.55 .858 .997 r
.69949 .50001 .71032 .50536 .73463 .49995 .72399 .49432 Metetra
.527 .845 .999 r
.72399 .49432 .73463 .49995 .75924 .49537 .74877 .48937 Metetra
.503 .829 .999 r
.74877 .48937 .75924 .49537 .78417 .49174 .77388 .48529 Metetra
.474 .807 .999 r
.77388 .48529 .78417 .49174 .80948 .48928 .79936 .48228 Metetra
.439 .78 .998 r
.79936 .48228 .80948 .48928 .83523 .48827 .82525 .48062 Metetra
.392 .742 .992 r
.82525 .48062 .83523 .48827 .8615 .48916 .85165 .48074 Metetra
.328 .69 .98 r
.85165 .48074 .8615 .48916 .88842 .49262 .87866 .4833 Metetra
.232 .612 .954 r
.87866 .4833 .88842 .49262 .9162 .4998 .9065 .4894 Metetra
.076 .481 .893 r
.9065 .4894 .9162 .4998 .94522 .51303 .93552 .50129 Metetra
0 .204 .709 r
.93552 .50129 .94522 .51303 .97663 .53967 .96683 .52611 Metetra
.865 .765 .751 r
.36082 .68368 .37449 .69475 .39793 .65741 .38445 .64787 Metetra
.837 .796 .813 r
.38445 .64787 .39793 .65741 .4208 .63212 .40748 .62366 Metetra
.813 .82 .856 r
.40748 .62366 .4208 .63212 .44349 .61224 .43034 .60462 Metetra
.79 .841 .89 r
.43034 .60462 .44349 .61224 .46613 .59567 .45315 .58873 Metetra
.767 .857 .917 r
.45315 .58873 .46613 .59567 .48881 .58138 .476 .575 Metetra
.743 .869 .939 r
.476 .575 .48881 .58138 .51156 .56877 .49894 .56283 Metetra
.719 .878 .955 r
.49894 .56283 .51156 .56877 .53443 .55745 .52199 .55185 Metetra
.695 .884 .968 r
.52199 .55185 .53443 .55745 .55744 .54714 .5452 .54181 Metetra
.673 .887 .977 r
.5452 .54181 .55744 .54714 .58062 .53768 .56857 .53252 Metetra
.651 .888 .983 r
.56857 .53252 .58062 .53768 .60397 .52893 .59212 .52386 Metetra
.63 .886 .987 r
.59212 .52386 .60397 .52893 .62752 .52082 .61586 .51577 Metetra
.611 .882 .991 r
.61586 .51577 .62752 .52082 .65128 .5133 .63982 .50819 Metetra
.592 .877 .993 r
.63982 .50819 .65128 .5133 .67526 .50636 .66401 .50111 Metetra
.574 .87 .995 r
.66401 .50111 .67526 .50636 .69949 .50001 .68844 .49456 Metetra
.556 .861 .997 r
.68844 .49456 .69949 .50001 .72399 .49432 .71312 .48857 Metetra
.538 .849 .998 r
.71312 .48857 .72399 .49432 .74877 .48937 .7381 .48324 Metetra
.516 .835 .999 r
.7381 .48324 .74877 .48937 .77388 .48529 .76338 .4787 Metetra
.491 .815 1 r
.76338 .4787 .77388 .48529 .79936 .48228 .78902 .47514 Metetra
.46 .79 .999 r
.78902 .47514 .79936 .48228 .82525 .48062 .81506 .47282 Metetra
.418 .756 .995 r
.81506 .47282 .82525 .48062 .85165 .48074 .84159 .47216 Metetra
.36 .708 .986 r
.84159 .47216 .85165 .48074 .87866 .4833 .86871 .4738 Metetra
.271 .636 .964 r
.86871 .4738 .87866 .4833 .9065 .4894 .89661 .4788 Metetra
.122 .515 .912 r
.89661 .4788 .9065 .4894 .93552 .50129 .92565 .48934 Metetra
0 .246 .742 r
.92565 .48934 .93552 .50129 .96683 .52611 .95686 .51231 Metetra
.86 .767 .758 r
.34694 .67243 .36082 .68368 .38445 .64787 .37073 .63816 Metetra
.83 .798 .821 r
.37073 .63816 .38445 .64787 .40748 .62366 .39393 .61504 Metetra
.806 .822 .864 r
.39393 .61504 .40748 .62366 .43034 .60462 .41694 .59686 Metetra
.781 .841 .897 r
.41694 .59686 .43034 .60462 .45315 .58873 .43992 .58167 Metetra
.757 .857 .924 r
.43992 .58167 .45315 .58873 .476 .575 .46295 .5685 Metetra
.733 .869 .944 r
.46295 .5685 .476 .575 .49894 .56283 .48607 .55678 Metetra
.71 .877 .96 r
.48607 .55678 .49894 .56283 .52199 .55185 .50931 .54615 Metetra
.687 .883 .971 r
.50931 .54615 .52199 .55185 .5452 .54181 .5327 .53636 Metetra
.665 .886 .979 r
.5327 .53636 .5452 .54181 .56857 .53252 .55627 .52725 Metetra
.645 .886 .984 r
.55627 .52725 .56857 .53252 .59212 .52386 .58002 .51869 Metetra
.627 .885 .988 r
.58002 .51869 .59212 .52386 .61586 .51577 .60397 .51061 Metetra
.609 .882 .991 r
.60397 .51061 .61586 .51577 .63982 .50819 .62813 .50297 Metetra
.594 .878 .993 r
.62813 .50297 .63982 .50819 .66401 .50111 .65252 .49576 Metetra
.578 .871 .995 r
.65252 .49576 .66401 .50111 .68844 .49456 .67714 .48899 Metetra
.563 .864 .996 r
.67714 .48899 .68844 .49456 .71312 .48857 .70203 .4827 Metetra
.547 .853 .998 r
.70203 .4827 .71312 .48857 .7381 .48324 .72719 .47699 Metetra
.53 .84 .999 r
.72719 .47699 .7381 .48324 .76338 .4787 .75266 .47198 Metetra
.508 .823 1 r
.75266 .47198 .76338 .4787 .78902 .47514 .77847 .46784 Metetra
.481 .8 1 r
.77847 .46784 .78902 .47514 .81506 .47282 .80467 .46486 Metetra
.444 .77 .997 r
.80467 .46486 .81506 .47282 .84159 .47216 .83133 .46341 Metetra
.39 .726 .99 r
.83133 .46341 .84159 .47216 .86871 .4738 .85856 .46411 Metetra
.309 .66 .972 r
.85856 .46411 .86871 .4738 .89661 .4788 .88653 .46799 Metetra
.169 .547 .928 r
.88653 .46799 .89661 .4788 .92565 .48934 .91559 .47716 Metetra
0 .289 .775 r
.91559 .47716 .92565 .48934 .95686 .51231 .94672 .49827 Metetra
.856 .769 .765 r
.33283 .66099 .34694 .67243 .37073 .63816 .35678 .62829 Metetra
.823 .799 .829 r
.35678 .62829 .37073 .63816 .39393 .61504 .38013 .60627 Metetra
.797 .823 .872 r
.38013 .60627 .39393 .61504 .41694 .59686 .4033 .58896 Metetra
.772 .842 .905 r
.4033 .58896 .41694 .59686 .43992 .58167 .42644 .57447 Metetra
.747 .857 .93 r
.42644 .57447 .43992 .58167 .46295 .5685 .44964 .56186 Metetra
.723 .868 .95 r
.44964 .56186 .46295 .5685 .48607 .55678 .47294 .5506 Metetra
.7 .876 .964 r
.47294 .5506 .48607 .55678 .50931 .54615 .49637 .54033 Metetra
.678 .881 .974 r
.49637 .54033 .50931 .54615 .5327 .53636 .51995 .53081 Metetra
.658 .884 .981 r
.51995 .53081 .5327 .53636 .55627 .52725 .54371 .52187 Metetra
.639 .885 .986 r
.54371 .52187 .55627 .52725 .58002 .51869 .56766 .51341 Metetra
.623 .884 .989 r
.56766 .51341 .58002 .51869 .60397 .51061 .59182 .50535 Metetra
.608 .882 .991 r
.59182 .50535 .60397 .51061 .62813 .50297 .61619 .49765 Metetra
.595 .878 .993 r
.61619 .49765 .62813 .50297 .65252 .49576 .64078 .49029 Metetra
.582 .873 .994 r
.64078 .49029 .65252 .49576 .67714 .48899 .66561 .48329 Metetra
.57 .866 .996 r
.66561 .48329 .67714 .48899 .70203 .4827 .6907 .47671 Metetra
.557 .857 .997 r
.6907 .47671 .70203 .4827 .72719 .47699 .71606 .47061 Metetra
.542 .846 .999 r
.71606 .47061 .72719 .47699 .75266 .47198 .74171 .46511 Metetra
.524 .83 1 r
.74171 .46511 .75266 .47198 .77847 .46784 .7677 .4604 Metetra
.501 .81 1 r
.7677 .4604 .77847 .46784 .80467 .46486 .79406 .45673 Metetra
.468 .782 .998 r
.79406 .45673 .80467 .46486 .83133 .46341 .82086 .45447 Metetra
.42 .742 .993 r
.82086 .45447 .83133 .46341 .85856 .46411 .84821 .45422 Metetra
.346 .682 .979 r
.84821 .45422 .85856 .46411 .88653 .46799 .87626 .45698 Metetra
.215 .578 .942 r
.87626 .45698 .88653 .46799 .91559 .47716 .90534 .46476 Metetra
0 .333 .806 r
.90534 .46476 .91559 .47716 .94672 .49827 .93639 .48398 Metetra
.85 .77 .773 r
.3185 .64937 .33283 .66099 .35678 .62829 .34259 .61825 Metetra
.816 .801 .838 r
.34259 .61825 .35678 .62829 .38013 .60627 .36608 .59735 Metetra
.788 .824 .88 r
.36608 .59735 .38013 .60627 .4033 .58896 .3894 .58091 Metetra
.761 .842 .913 r
.3894 .58091 .4033 .58896 .42644 .57447 .41271 .56713 Metetra
.736 .856 .937 r
.41271 .56713 .42644 .57447 .44964 .56186 .43607 .5551 Metetra
.712 .867 .955 r
.43607 .5551 .44964 .56186 .47294 .5506 .45954 .5443 Metetra
.689 .874 .968 r
.45954 .5443 .47294 .5506 .49637 .54033 .48316 .53439 Metetra
.669 .879 .977 r
.48316 .53439 .49637 .54033 .51995 .53081 .50694 .52514 Metetra
.65 .882 .983 r
.50694 .52514 .51995 .53081 .54371 .52187 .53089 .51638 Metetra
.634 .883 .987 r
.53089 .51638 .54371 .52187 .56766 .51341 .55505 .50802 Metetra
.619 .883 .989 r
.55505 .50802 .56766 .51341 .59182 .50535 .57941 .49997 Metetra
.607 .881 .991 r
.57941 .49997 .59182 .50535 .61619 .49765 .60399 .49221 Metetra
.596 .878 .992 r
.60399 .49221 .61619 .49765 .64078 .49029 .62879 .4847 Metetra
.586 .874 .994 r
.62879 .4847 .64078 .49029 .66561 .48329 .65383 .47748 Metetra
.577 .869 .995 r
.65383 .47748 .66561 .48329 .6907 .47671 .67912 .47058 Metetra
.567 .861 .996 r
.67912 .47058 .6907 .47671 .71606 .47061 .70468 .46408 Metetra
.555 .851 .998 r
.70468 .46408 .71606 .47061 .74171 .46511 .73053 .4581 Metetra
.54 .837 .999 r
.73053 .4581 .74171 .46511 .7677 .4604 .7567 .4528 Metetra
.52 .819 .999 r
.7567 .4528 .7677 .4604 .79406 .45673 .78323 .44843 Metetra
.492 .793 .999 r
.78323 .44843 .79406 .45673 .82086 .45447 .81018 .44536 Metetra
.449 .757 .995 r
.81018 .44536 .82086 .45447 .84821 .45422 .83764 .44414 Metetra
.381 .703 .984 r
.83764 .44414 .84821 .45422 .87626 .45698 .86578 .44575 Metetra
.26 .607 .955 r
.86578 .44575 .87626 .45698 .90534 .46476 .8949 .45212 Metetra
0 .377 .836 r
.8949 .45212 .90534 .46476 .93639 .48398 .92587 .46942 Metetra
.845 .772 .781 r
.30393 .63757 .3185 .64937 .34259 .61825 .32815 .60803 Metetra
.807 .802 .847 r
.32815 .60803 .34259 .61825 .36608 .59735 .35178 .58826 Metetra
.778 .824 .889 r
.35178 .58826 .36608 .59735 .3894 .58091 .37524 .57271 Metetra
.75 .842 .92 r
.37524 .57271 .3894 .58091 .41271 .56713 .3987 .55965 Metetra
.724 .855 .943 r
.3987 .55965 .41271 .56713 .43607 .5551 .42223 .5482 Metetra
.7 .865 .96 r
.42223 .5482 .43607 .5551 .45954 .5443 .44588 .53787 Metetra
.678 .873 .972 r
.44588 .53787 .45954 .5443 .48316 .53439 .46968 .52833 Metetra
.659 .877 .98 r
.46968 .52833 .48316 .53439 .50694 .52514 .49365 .51935 Metetra
.642 .88 .985 r
.49365 .51935 .50694 .52514 .53089 .51638 .5178 .51078 Metetra
.628 .882 .988 r
.5178 .51078 .53089 .51638 .55505 .50802 .54216 .50251 Metetra
.616 .882 .99 r
.54216 .50251 .55505 .50802 .57941 .49997 .56673 .49448 Metetra
.606 .881 .991 r
.56673 .49448 .57941 .49997 .60399 .49221 .59152 .48665 Metetra
.597 .879 .992 r
.59152 .48665 .60399 .49221 .62879 .4847 .61654 .47899 Metetra
.59 .876 .993 r
.61654 .47899 .62879 .4847 .65383 .47748 .64179 .47154 Metetra
.583 .871 .994 r
.64179 .47154 .65383 .47748 .67912 .47058 .66729 .46432 Metetra
.576 .864 .996 r
.66729 .46432 .67912 .47058 .70468 .46408 .69306 .45742 Metetra
.567 .856 .997 r
.69306 .45742 .70468 .46408 .73053 .4581 .7191 .45093 Metetra
.555 .843 .998 r
.7191 .45093 .73053 .4581 .7567 .4528 .74546 .44503 Metetra
.539 .827 .999 r
.74546 .44503 .7567 .4528 .78323 .44843 .77216 .43996 Metetra
.514 .804 .998 r
.77216 .43996 .78323 .44843 .81018 .44536 .79927 .43605 Metetra
.477 .772 .996 r
.79927 .43605 .81018 .44536 .83764 .44414 .82687 .43385 Metetra
.416 .722 .988 r
.82687 .43385 .83764 .44414 .86578 .44575 .8551 .43429 Metetra
.305 .635 .964 r
.8551 .43429 .86578 .44575 .8949 .45212 .88425 .43923 Metetra
.028 .421 .863 r
.88425 .43923 .8949 .45212 .92587 .46942 .91516 .4546 Metetra
.838 .774 .79 r
.28911 .62556 .30393 .63757 .32815 .60803 .31346 .59763 Metetra
.798 .803 .856 r
.31346 .59763 .32815 .60803 .35178 .58826 .33721 .579 Metetra
.766 .825 .898 r
.33721 .579 .35178 .58826 .37524 .57271 .36082 .56435 Metetra
.738 .841 .928 r
.36082 .56435 .37524 .57271 .3987 .55965 .38442 .55202 Metetra
.712 .854 .95 r
.38442 .55202 .3987 .55965 .42223 .5482 .40811 .54116 Metetra
.688 .864 .965 r
.40811 .54116 .42223 .5482 .44588 .53787 .43193 .53131 Metetra
.667 .87 .976 r
.43193 .53131 .44588 .53787 .46968 .52833 .45591 .52214 Metetra
.649 .875 .982 r
.45591 .52214 .46968 .52833 .49365 .51935 .48007 .51343 Metetra
.634 .878 .987 r
.48007 .51343 .49365 .51935 .5178 .51078 .50443 .50505 Metetra
.622 .88 .989 r
.50443 .50505 .5178 .51078 .54216 .50251 .529 .49688 Metetra
.612 .881 .991 r
.529 .49688 .54216 .50251 .56673 .49448 .55378 .48887 Metetra
.604 .88 .991 r
.55378 .48887 .56673 .49448 .59152 .48665 .57878 .48096 Metetra
.599 .879 .992 r
.57878 .48096 .59152 .48665 .61654 .47899 .60401 .47316 Metetra
.594 .877 .993 r
.60401 .47316 .61654 .47899 .64179 .47154 .62948 .46547 Metetra
.59 .873 .994 r
.62948 .46547 .64179 .47154 .66729 .46432 .6552 .45793 Metetra
.585 .868 .995 r
.6552 .45793 .66729 .46432 .69306 .45742 .68118 .45061 Metetra
.579 .86 .996 r
.68118 .45061 .69306 .45742 .7191 .45093 .70743 .44361 Metetra
.57 .849 .997 r
.70743 .44361 .7191 .45093 .74546 .44503 .73398 .4371 Metetra
.557 .835 .997 r
.73398 .4371 .74546 .44503 .77216 .43996 .76086 .4313 Metetra
.536 .814 .997 r
.76086 .4313 .77216 .43996 .79927 .43605 .78813 .42654 Metetra
.503 .785 .996 r
.78813 .42654 .79927 .43605 .82687 .43385 .81587 .42335 Metetra
.449 .74 .99 r
.81587 .42335 .82687 .43385 .8551 .43429 .8442 .42261 Metetra
.348 .661 .972 r
.8442 .42261 .8551 .43429 .88425 .43923 .8734 .4261 Metetra
.087 .464 .888 r
.8734 .4261 .88425 .43923 .91516 .4546 .90425 .43951 Metetra
.831 .775 .799 r
.27406 .61336 .28911 .62556 .31346 .59763 .29851 .58705 Metetra
.788 .804 .866 r
.29851 .58705 .31346 .59763 .33721 .579 .32238 .56958 Metetra
.754 .825 .907 r
.32238 .56958 .33721 .579 .36082 .56435 .34611 .55584 Metetra
.724 .84 .936 r
.34611 .55584 .36082 .56435 .38442 .55202 .36986 .54424 Metetra
.698 .852 .956 r
.36986 .54424 .38442 .55202 .40811 .54116 .39371 .53399 Metetra
.675 .861 .97 r
.39371 .53399 .40811 .54116 .43193 .53131 .4177 .52461 Metetra
.655 .868 .979 r
.4177 .52461 .43193 .53131 .45591 .52214 .44186 .51582 Metetra
.639 .873 .985 r
.44186 .51582 .45591 .52214 .48007 .51343 .46621 .5074 Metetra
.626 .876 .988 r
.46621 .5074 .48007 .51343 .50443 .50505 .49077 .4992 Metetra
.616 .878 .99 r
.49077 .4992 .50443 .50505 .529 .49688 .51554 .49113 Metetra
.608 .88 .991 r
.51554 .49113 .529 .49688 .55378 .48887 .54053 .48313 Metetra
.603 .88 .992 r
.54053 .48313 .55378 .48887 .57878 .48096 .56576 .47516 Metetra
.6 .88 .992 r
.56576 .47516 .57878 .48096 .60401 .47316 .59121 .46719 Metetra
.598 .878 .992 r
.59121 .46719 .60401 .47316 .62948 .46547 .6169 .45926 Metetra
.596 .875 .993 r
.6169 .45926 .62948 .46547 .6552 .45793 .64284 .45139 Metetra
.594 .871 .993 r
.64284 .45139 .6552 .45793 .68118 .45061 .66903 .44364 Metetra
.59 .864 .994 r
.66903 .44364 .68118 .45061 .70743 .44361 .6955 .43613 Metetra
.584 .855 .995 r
.6955 .43613 .70743 .44361 .73398 .4371 .72225 .429 Metetra
.574 .842 .995 r
.72225 .429 .73398 .4371 .76086 .4313 .74932 .42246 Metetra
.557 .823 .995 r
.74932 .42246 .76086 .4313 .78813 .42654 .77676 .41684 Metetra
.529 .797 .994 r
.77676 .41684 .78813 .42654 .81587 .42335 .80464 .41263 Metetra
.481 .756 .991 r
.80464 .41263 .81587 .42335 .8442 .42261 .83308 .41068 Metetra
.389 .686 .978 r
.83308 .41068 .8442 .42261 .8734 .4261 .86234 .4127 Metetra
.147 .505 .91 r
.86234 .4127 .8734 .4261 .90425 .43951 .89314 .42414 Metetra
.823 .777 .809 r
.25875 .60095 .27406 .61336 .29851 .58705 .28329 .57628 Metetra
.776 .805 .876 r
.28329 .57628 .29851 .58705 .32238 .56958 .30727 .55997 Metetra
.74 .824 .916 r
.30727 .55997 .32238 .56958 .34611 .55584 .33112 .54716 Metetra
.71 .839 .944 r
.33112 .54716 .34611 .55584 .36986 .54424 .35501 .5363 Metetra
.683 .85 .963 r
.35501 .5363 .36986 .54424 .39371 .53399 .37901 .52666 Metetra
.661 .859 .975 r
.37901 .52666 .39371 .53399 .4177 .52461 .40317 .51778 Metetra
.642 .865 .983 r
.40317 .51778 .4177 .52461 .44186 .51582 .42751 .50936 Metetra
.628 .87 .988 r
.42751 .50936 .44186 .51582 .46621 .5074 .45205 .50122 Metetra
.617 .873 .99 r
.45205 .50122 .46621 .5074 .49077 .4992 .47681 .49322 Metetra
.609 .876 .991 r
.47681 .49322 .49077 .4992 .51554 .49113 .50179 .48525 Metetra
.604 .878 .992 r
.50179 .48525 .51554 .49113 .54053 .48313 .527 .47727 Metetra
.602 .88 .992 r
.527 .47727 .54053 .48313 .56576 .47516 .55244 .46922 Metetra
.601 .88 .992 r
.55244 .46922 .56576 .47516 .59121 .46719 .57812 .46109 Metetra
.602 .88 .992 r
.57812 .46109 .59121 .46719 .6169 .45926 .60404 .45291 Metetra
.602 .878 .992 r
.60404 .45291 .6169 .45926 .64284 .45139 .6302 .4447 Metetra
.603 .874 .992 r
.6302 .4447 .64284 .45139 .66903 .44364 .65662 .43652 Metetra
.602 .868 .993 r
.65662 .43652 .66903 .44364 .6955 .43613 .6833 .42848 Metetra
.598 .86 .993 r
.6833 .42848 .6955 .43613 .72225 .429 .71026 .42071 Metetra
.591 .848 .993 r
.71026 .42071 .72225 .429 .74932 .42246 .73752 .41342 Metetra
.577 .832 .993 r
.73752 .41342 .74932 .42246 .77676 .41684 .76514 .40692 Metetra
.553 .808 .993 r
.76514 .40692 .77676 .41684 .80464 .41263 .79317 .40168 Metetra
.511 .771 .99 r
.79317 .40168 .80464 .41263 .83308 .41068 .82173 .39852 Metetra
.429 .708 .981 r
.82173 .39852 .83308 .41068 .86234 .4127 .85106 .39905 Metetra
.206 .546 .929 r
.85106 .39905 .86234 .4127 .89314 .42414 .88182 .40847 Metetra
.813 .778 .82 r
.24318 .58833 .25875 .60095 .28329 .57628 .2678 .56532 Metetra
.763 .805 .886 r
.2678 .56532 .28329 .57628 .30727 .55997 .29187 .55019 Metetra
.725 .823 .926 r
.29187 .55019 .30727 .55997 .33112 .54716 .31584 .5383 Metetra
.694 .837 .952 r
.31584 .5383 .33112 .54716 .35501 .5363 .33986 .52821 Metetra
.668 .847 .969 r
.33986 .52821 .35501 .5363 .37901 .52666 .36401 .51918 Metetra
.646 .855 .98 r
.36401 .51918 .37901 .52666 .40317 .51778 .38833 .51079 Metetra
.629 .862 .986 r
.38833 .51079 .40317 .51778 .42751 .50936 .41284 .50277 Metetra
.617 .867 .99 r
.41284 .50277 .42751 .50936 .45205 .50122 .43758 .49492 Metetra
.608 .871 .992 r
.43758 .49492 .45205 .50122 .47681 .49322 .46253 .48711 Metetra
.603 .874 .992 r
.46253 .48711 .47681 .49322 .50179 .48525 .48772 .47924 Metetra
.601 .877 .992 r
.48772 .47924 .50179 .48525 .527 .47727 .51315 .47127 Metetra
.601 .879 .992 r
.51315 .47127 .527 .47727 .55244 .46922 .53882 .46314 Metetra
.602 .881 .992 r
.53882 .46314 .55244 .46922 .57812 .46109 .56473 .45486 Metetra
.605 .881 .991 r
.56473 .45486 .57812 .46109 .60404 .45291 .59088 .44642 Metetra
.608 .88 .991 r
.59088 .44642 .60404 .45291 .6302 .4447 .61727 .43786 Metetra
.611 .877 .991 r
.61727 .43786 .6302 .4447 .65662 .43652 .64392 .42924 Metetra
.612 .872 .991 r
.64392 .42924 .65662 .43652 .6833 .42848 .67082 .42066 Metetra
.611 .865 .991 r
.67082 .42066 .6833 .42848 .71026 .42071 .698 .41224 Metetra
.607 .854 .991 r
.698 .41224 .71026 .42071 .73752 .41342 .72547 .40419 Metetra
.596 .839 .99 r
.72547 .40419 .73752 .41342 .76514 .40692 .75327 .39679 Metetra
.577 .817 .99 r
.75327 .39679 .76514 .40692 .79317 .40168 .78146 .39051 Metetra
.54 .785 .988 r
.78146 .39051 .79317 .40168 .82173 .39852 .81015 .3861 Metetra
.467 .728 .983 r
.81015 .3861 .82173 .39852 .85106 .39905 .83955 .38512 Metetra
.264 .583 .945 r
.83955 .38512 .85106 .39905 .88182 .40847 .87029 .39251 Metetra
.803 .779 .831 r
.22734 .5755 .24318 .58833 .2678 .56532 .25202 .55416 Metetra
.749 .804 .897 r
.25202 .55416 .2678 .56532 .29187 .55019 .27618 .54022 Metetra
.709 .822 .935 r
.27618 .54022 .29187 .55019 .31584 .5383 .30026 .52928 Metetra
.677 .834 .959 r
.30026 .52928 .31584 .5383 .33986 .52821 .3244 .51995 Metetra
.651 .844 .974 r
.3244 .51995 .33986 .52821 .36401 .51918 .34869 .51155 Metetra
.63 .852 .984 r
.34869 .51155 .36401 .51918 .38833 .51079 .37317 .50366 Metetra
.615 .858 .989 r
.37317 .50366 .38833 .51079 .41284 .50277 .39786 .49603 Metetra
.605 .863 .992 r
.39786 .49603 .41284 .50277 .43758 .49492 .42278 .48847 Metetra
.599 .868 .993 r
.42278 .48847 .43758 .49492 .46253 .48711 .44794 .48086 Metetra
.596 .872 .993 r
.44794 .48086 .46253 .48711 .48772 .47924 .47334 .4731 Metetra
.597 .876 .993 r
.47334 .4731 .48772 .47924 .51315 .47127 .49899 .46513 Metetra
.599 .879 .992 r
.49899 .46513 .51315 .47127 .53882 .46314 .52489 .45693 Metetra
.604 .881 .991 r
.52489 .45693 .53882 .46314 .56473 .45486 .55103 .44847 Metetra
.609 .882 .991 r
.55103 .44847 .56473 .45486 .59088 .44642 .57741 .43977 Metetra
.614 .882 .99 r
.57741 .43977 .59088 .44642 .61727 .43786 .60405 .43086 Metetra
.619 .88 .99 r
.60405 .43086 .61727 .43786 .64392 .42924 .63093 .42179 Metetra
.623 .876 .989 r
.63093 .42179 .64392 .42924 .67082 .42066 .65806 .41265 Metetra
.624 .869 .988 r
.65806 .41265 .67082 .42066 .698 .41224 .68546 .40358 Metetra
.622 .86 .988 r
.68546 .40358 .698 .41224 .72547 .40419 .71314 .39475 Metetra
.615 .846 .987 r
.71314 .39475 .72547 .40419 .75327 .39679 .74114 .38644 Metetra
.599 .827 .987 r
.74114 .38644 .75327 .39679 .78146 .39051 .7695 .37909 Metetra
.567 .797 .986 r
.7695 .37909 .78146 .39051 .81015 .3861 .79832 .37342 Metetra
.503 .747 .983 r
.79832 .37342 .81015 .3861 .83955 .38512 .82781 .37091 Metetra
.32 .619 .956 r
.82781 .37091 .83955 .38512 .87029 .39251 .85853 .37625 Metetra
.791 .78 .843 r
.21123 .56244 .22734 .5755 .25202 .55416 .23596 .54279 Metetra
.732 .803 .908 r
.23596 .54279 .25202 .55416 .27618 .54022 .26019 .53006 Metetra
.691 .819 .944 r
.26019 .53006 .27618 .54022 .30026 .52928 .28436 .52007 Metetra
.658 .831 .966 r
.28436 .52007 .30026 .52928 .3244 .51995 .30862 .51152 Metetra
.633 .84 .98 r
.30862 .51152 .3244 .51995 .34869 .51155 .33305 .50375 Metetra
.614 .847 .988 r
.33305 .50375 .34869 .51155 .37317 .50366 .35769 .49638 Metetra
.601 .854 .992 r
.35769 .49638 .37317 .50366 .39786 .49603 .38255 .48915 Metetra
.593 .86 .994 r
.38255 .48915 .39786 .49603 .42278 .48847 .40766 .48188 Metetra
.59 .865 .994 r
.40766 .48188 .42278 .48847 .44794 .48086 .43302 .47447 Metetra
.59 .87 .994 r
.43302 .47447 .44794 .48086 .47334 .4731 .45863 .46681 Metetra
.593 .875 .993 r
.45863 .46681 .47334 .4731 .49899 .46513 .4845 .45886 Metetra
.598 .878 .992 r
.4845 .45886 .49899 .46513 .52489 .45693 .51063 .45057 Metetra
.605 .881 .991 r
.51063 .45057 .52489 .45693 .55103 .44847 .53701 .44194 Metetra
.613 .883 .99 r
.53701 .44194 .55103 .44847 .57741 .43977 .56364 .43297 Metetra
.62 .884 .989 r
.56364 .43297 .57741 .43977 .60405 .43086 .59051 .4237 Metetra
.627 .882 .988 r
.59051 .4237 .60405 .43086 .63093 .42179 .61764 .41417 Metetra
.633 .879 .987 r
.61764 .41417 .63093 .42179 .65806 .41265 .64501 .40447 Metetra
.637 .874 .986 r
.64501 .40447 .65806 .41265 .68546 .40358 .67264 .39471 Metetra
.637 .865 .984 r
.67264 .39471 .68546 .40358 .71314 .39475 .70054 .38509 Metetra
.632 .853 .983 r
.70054 .38509 .71314 .39475 .74114 .38644 .72874 .37586 Metetra
.62 .835 .983 r
.72874 .37586 .74114 .38644 .7695 .37909 .75728 .36742 Metetra
.593 .808 .982 r
.75728 .36742 .7695 .37909 .79832 .37342 .78625 .36047 Metetra
.537 .764 .981 r
.78625 .36047 .79832 .37342 .82781 .37091 .81583 .3564 Metetra
.374 .651 .965 r
.81583 .3564 .82781 .37091 .85853 .37625 .84655 .35967 Metetra
.777 .78 .855 r
.19484 .54916 .21123 .56244 .23596 .54279 .2196 .53121 Metetra
.714 .802 .919 r
.2196 .53121 .23596 .54279 .26019 .53006 .24389 .5197 Metetra
.67 .816 .953 r
.24389 .5197 .26019 .53006 .28436 .52007 .26814 .51068 Metetra
.638 .826 .973 r
.26814 .51068 .28436 .52007 .30862 .51152 .29252 .50292 Metetra
.613 .835 .985 r
.29252 .50292 .30862 .51152 .33305 .50375 .31708 .49579 Metetra
.596 .843 .991 r
.31708 .49579 .33305 .50375 .35769 .49638 .34186 .48893 Metetra
.586 .849 .994 r
.34186 .48893 .35769 .49638 .38255 .48915 .3669 .48211 Metetra
.58 .856 .995 r
.3669 .48211 .38255 .48915 .40766 .48188 .39219 .47515 Metetra
.58 .862 .995 r
.39219 .47515 .40766 .48188 .43302 .47447 .41775 .46793 Metetra
.583 .868 .995 r
.41775 .46793 .43302 .47447 .45863 .46681 .44358 .46038 Metetra
.589 .873 .994 r
.44358 .46038 .45863 .46681 .4845 .45886 .46968 .45243 Metetra
.597 .878 .992 r
.46968 .45243 .4845 .45886 .51063 .45057 .49604 .44406 Metetra
.606 .882 .991 r
.49604 .44406 .51063 .45057 .53701 .44194 .52266 .43525 Metetra
.616 .884 .99 r
.52266 .43525 .53701 .44194 .56364 .43297 .54953 .42601 Metetra
.626 .885 .988 r
.54953 .42601 .56364 .43297 .59051 .4237 .57666 .41637 Metetra
.635 .885 .986 r
.57666 .41637 .59051 .4237 .61764 .41417 .60403 .40637 Metetra
.643 .882 .985 r
.60403 .40637 .61764 .41417 .64501 .40447 .63165 .39609 Metetra
.649 .877 .983 r
.63165 .39609 .64501 .40447 .67264 .39471 .65952 .38565 Metetra
.651 .87 .981 r
.65952 .38565 .67264 .39471 .70054 .38509 .68765 .37521 Metetra
.649 .858 .979 r
.68765 .37521 .70054 .38509 .72874 .37586 .71606 .36503 Metetra
.639 .842 .978 r
.71606 .36503 .72874 .37586 .75728 .36742 .74479 .35549 Metetra
.618 .818 .977 r
.74479 .35549 .75728 .36742 .78625 .36047 .77392 .34725 Metetra
.57 .779 .977 r
.77392 .34725 .78625 .36047 .81583 .3564 .8036 .3416 Metetra
.426 .681 .97 r
.8036 .3416 .81583 .3564 .84655 .35967 .83434 .34277 Metetra
.761 .78 .868 r
.17817 .53565 .19484 .54916 .2196 .53121 .20293 .51942 Metetra
.693 .799 .93 r
.20293 .51942 .2196 .53121 .24389 .5197 .22726 .50914 Metetra
.648 .811 .962 r
.22726 .50914 .24389 .5197 .26814 .51068 .2516 .5011 Metetra
.615 .821 .979 r
.2516 .5011 .26814 .51068 .29252 .50292 .27607 .49413 Metetra
.592 .829 .989 r
.27607 .49413 .29252 .50292 .31708 .49579 .30076 .48766 Metetra
.578 .837 .994 r
.30076 .48766 .31708 .49579 .34186 .48893 .32569 .48133 Metetra
.57 .844 .996 r
.32569 .48133 .34186 .48893 .3669 .48211 .35089 .47491 Metetra
.568 .852 .997 r
.35089 .47491 .3669 .48211 .39219 .47515 .37637 .46825 Metetra
.57 .859 .996 r
.37637 .46825 .39219 .47515 .41775 .46793 .40213 .46124 Metetra
.576 .866 .995 r
.40213 .46124 .41775 .46793 .44358 .46038 .42817 .45379 Metetra
.585 .872 .994 r
.42817 .45379 .44358 .46038 .46968 .45243 .4545 .44585 Metetra
.596 .878 .993 r
.4545 .44585 .46968 .45243 .49604 .44406 .4811 .4374 Metetra
.607 .882 .991 r
.4811 .4374 .49604 .44406 .52266 .43525 .50796 .42841 Metetra
.62 .885 .989 r
.50796 .42841 .52266 .43525 .54953 .42601 .53509 .41889 Metetra
.632 .887 .987 r
.53509 .41889 .54953 .42601 .57666 .41637 .56247 .40886 Metetra
.643 .887 .985 r
.56247 .40886 .57666 .41637 .60403 .40637 .5901 .39838 Metetra
.653 .885 .982 r
.5901 .39838 .60403 .40637 .63165 .39609 .61797 .38751 Metetra
.66 .881 .98 r
.61797 .38751 .63165 .39609 .65952 .38565 .64609 .37637 Metetra
.665 .874 .977 r
.64609 .37637 .65952 .38565 .68765 .37521 .67445 .36511 Metetra
.665 .863 .975 r
.67445 .36511 .68765 .37521 .71606 .36503 .70309 .35397 Metetra
.658 .849 .973 r
.70309 .35397 .71606 .36503 .74479 .35549 .73202 .3433 Metetra
.641 .827 .972 r
.73202 .3433 .74479 .35549 .77392 .34725 .76131 .33374 Metetra
.6 .792 .973 r
.76131 .33374 .77392 .34725 .8036 .3416 .79112 .3265 Metetra
.474 .708 .971 r
.79112 .3265 .8036 .3416 .83434 .34277 .82188 .32553 Metetra
.743 .779 .882 r
.1612 .5219 .17817 .53565 .20293 .51942 .18595 .5074 Metetra
.669 .795 .942 r
.18595 .5074 .20293 .51942 .22726 .50914 .21031 .49836 Metetra
.623 .805 .97 r
.21031 .49836 .22726 .50914 .2516 .5011 .23471 .49131 Metetra
.591 .814 .985 r
.23471 .49131 .2516 .5011 .27607 .49413 .25928 .48516 Metetra
.57 .822 .993 r
.25928 .48516 .27607 .49413 .30076 .48766 .28408 .47934 Metetra
.558 .83 .997 r
.28408 .47934 .30076 .48766 .32569 .48133 .30916 .47355 Metetra
.553 .839 .998 r
.30916 .47355 .32569 .48133 .35089 .47491 .33452 .46755 Metetra
.554 .847 .998 r
.33452 .46755 .35089 .47491 .37637 .46825 .36018 .4612 Metetra
.56 .855 .997 r
.36018 .4612 .37637 .46825 .40213 .46124 .38614 .45439 Metetra
.569 .863 .996 r
.38614 .45439 .40213 .46124 .42817 .45379 .4124 .44705 Metetra
.581 .871 .995 r
.4124 .44705 .42817 .45379 .4545 .44585 .43895 .43912 Metetra
.594 .877 .993 r
.43895 .43912 .4545 .44585 .4811 .4374 .46579 .43057 Metetra
.609 .883 .991 r
.46579 .43057 .4811 .4374 .50796 .42841 .49291 .42139 Metetra
.623 .886 .988 r
.49291 .42139 .50796 .42841 .53509 .41889 .5203 .41159 Metetra
.638 .889 .986 r
.5203 .41159 .53509 .41889 .56247 .40886 .54794 .40117 Metetra
.651 .889 .983 r
.54794 .40117 .56247 .40886 .5901 .39838 .57583 .3902 Metetra
.662 .888 .98 r
.57583 .3902 .5901 .39838 .61797 .38751 .60397 .37873 Metetra
.672 .884 .977 r
.60397 .37873 .61797 .38751 .64609 .37637 .63234 .36687 Metetra
.678 .878 .973 r
.63234 .36687 .64609 .37637 .67445 .36511 .66096 .35477 Metetra
.68 .868 .97 r
.66096 .35477 .67445 .36511 .70309 .35397 .68982 .34265 Metetra
.676 .854 .967 r
.68982 .34265 .70309 .35397 .73202 .3433 .71896 .33084 Metetra
.662 .835 .966 r
.71896 .33084 .73202 .3433 .76131 .33374 .74844 .31993 Metetra
.628 .803 .967 r
.74844 .31993 .76131 .33374 .79112 .3265 .77838 .31107 Metetra
.52 .731 .97 r
.77838 .31107 .79112 .3265 .82188 .32553 .80918 .30795 Metetra
.722 .777 .896 r
.14392 .5079 .1612 .5219 .18595 .5074 .16865 .49516 Metetra
.643 .789 .952 r
.16865 .49516 .18595 .5074 .21031 .49836 .19302 .48738 Metetra
.595 .798 .977 r
.19302 .48738 .21031 .49836 .23471 .49131 .21747 .48133 Metetra
.564 .806 .99 r
.21747 .48133 .23471 .49131 .25928 .48516 .24213 .47599 Metetra
.546 .814 .996 r
.24213 .47599 .25928 .48516 .28408 .47934 .26704 .47085 Metetra
.537 .823 .998 r
.26704 .47085 .28408 .47934 .30916 .47355 .29225 .46559 Metetra
.536 .832 .999 r
.29225 .46559 .30916 .47355 .33452 .46755 .31777 .46002 Metetra
.54 .842 .999 r
.31777 .46002 .33452 .46755 .36018 .4612 .34361 .45398 Metetra
.549 .852 .998 r
.34361 .45398 .36018 .4612 .38614 .45439 .36977 .44738 Metetra
.562 .861 .997 r
.36977 .44738 .38614 .45439 .4124 .44705 .39625 .44015 Metetra
.577 .869 .995 r
.39625 .44015 .4124 .44705 .43895 .43912 .42303 .43222 Metetra
.593 .877 .993 r
.42303 .43222 .43895 .43912 .46579 .43057 .45012 .42358 Metetra
.61 .883 .991 r
.45012 .42358 .46579 .43057 .49291 .42139 .47749 .41421 Metetra
.627 .888 .988 r
.47749 .41421 .49291 .42139 .5203 .41159 .50514 .40411 Metetra
.643 .89 .985 r
.50514 .40411 .5203 .41159 .54794 .40117 .53305 .3933 Metetra
.658 .891 .981 r
.53305 .3933 .54794 .40117 .57583 .3902 .56122 .38182 Metetra
.671 .89 .977 r
.56122 .38182 .57583 .3902 .60397 .37873 .58962 .36973 Metetra
.682 .887 .973 r
.58962 .36973 .60397 .37873 .63234 .36687 .61826 .35714 Metetra
.691 .881 .969 r
.61826 .35714 .63234 .36687 .66096 .35477 .64714 .34418 Metetra
.695 .872 .965 r
.64714 .34418 .66096 .35477 .68982 .34265 .67624 .33106 Metetra
.693 .859 .962 r
.67624 .33106 .68982 .34265 .71896 .33084 .70561 .31809 Metetra
.682 .842 .959 r
.70561 .31809 .71896 .33084 .74844 .31993 .73528 .30582 Metetra
.654 .814 .96 r
.73528 .30582 .74844 .31993 .77838 .31107 .76536 .29532 Metetra
.562 .752 .966 r
.76536 .29532 .77838 .31107 .80918 .30795 .79622 .29002 Metetra
.696 .773 .911 r
.12634 .49365 .14392 .5079 .16865 .49516 .15101 .48267 Metetra
.612 .781 .962 r
.15101 .48267 .16865 .49516 .19302 .48738 .17539 .47617 Metetra
.564 .788 .983 r
.17539 .47617 .19302 .48738 .21747 .48133 .19987 .47114 Metetra
.535 .796 .993 r
.19987 .47114 .21747 .48133 .24213 .47599 .2246 .46663 Metetra
.52 .805 .998 r
.2246 .46663 .24213 .47599 .26704 .47085 .24961 .46216 Metetra
.515 .815 .999 r
.24961 .46216 .26704 .47085 .29225 .46559 .27495 .45746 Metetra
.517 .826 1 r
.27495 .45746 .29225 .46559 .31777 .46002 .30063 .45231 Metetra
.526 .837 .999 r
.30063 .45231 .31777 .46002 .34361 .45398 .32665 .44659 Metetra
.539 .848 .998 r
.32665 .44659 .34361 .45398 .36977 .44738 .35301 .4402 Metetra
.555 .858 .997 r
.35301 .4402 .36977 .44738 .39625 .44015 .3797 .43307 Metetra
.573 .868 .995 r
.3797 .43307 .39625 .44015 .42303 .43222 .40672 .42516 Metetra
.592 .876 .993 r
.40672 .42516 .42303 .43222 .45012 .42358 .43406 .41642 Metetra
.611 .883 .99 r
.43406 .41642 .45012 .42358 .47749 .41421 .46169 .40685 Metetra
.63 .889 .987 r
.46169 .40685 .47749 .41421 .50514 .40411 .48961 .39644 Metetra
.648 .892 .983 r
.48961 .39644 .50514 .40411 .53305 .3933 .5178 .38522 Metetra
.665 .893 .979 r
.5178 .38522 .53305 .3933 .56122 .38182 .54624 .37323 Metetra
.68 .893 .975 r
.54624 .37323 .56122 .38182 .58962 .36973 .57493 .36052 Metetra
.693 .89 .97 r
.57493 .36052 .58962 .36973 .61826 .35714 .60385 .34718 Metetra
.702 .884 .965 r
.60385 .34718 .61826 .35714 .64714 .34418 .63299 .33334 Metetra
.708 .876 .96 r
.63299 .33334 .64714 .34418 .67624 .33106 .66235 .3192 Metetra
.709 .864 .955 r
.66235 .3192 .67624 .33106 .70561 .31809 .69195 .30505 Metetra
.701 .847 .952 r
.69195 .30505 .70561 .31809 .73528 .30582 .72182 .29139 Metetra
.678 .823 .952 r
.72182 .29139 .73528 .30582 .76536 .29532 .75207 .27922 Metetra
.601 .77 .961 r
.75207 .27922 .76536 .29532 .79622 .29002 .783 .27172 Metetra
.667 .767 .925 r
.10844 .47914 .12634 .49365 .15101 .48267 .13303 .46995 Metetra
.578 .771 .971 r
.13303 .46995 .15101 .48267 .17539 .47617 .15739 .46473 Metetra
.53 .777 .988 r
.15739 .46473 .17539 .47617 .19987 .47114 .1819 .46073 Metetra
.504 .785 .995 r
.1819 .46073 .19987 .47114 .2246 .46663 .20669 .45706 Metetra
.492 .795 .999 r
.20669 .45706 .2246 .46663 .24961 .46216 .2318 .45328 Metetra
.491 .806 1 r
.2318 .45328 .24961 .46216 .27495 .45746 .25726 .44913 Metetra
.498 .818 1 r
.25726 .44913 .27495 .45746 .30063 .45231 .28309 .44442 Metetra
.511 .831 1 r
.28309 .44442 .30063 .45231 .32665 .44659 .30928 .43902 Metetra
.528 .844 .999 r
.30928 .43902 .32665 .44659 .35301 .4402 .33584 .43285 Metetra
.547 .855 .997 r
.33584 .43285 .35301 .4402 .3797 .43307 .36275 .42583 Metetra
.568 .866 .996 r
.36275 .42583 .3797 .43307 .40672 .42516 .39001 .41791 Metetra
.59 .876 .993 r
.39001 .41791 .40672 .42516 .43406 .41642 .41759 .40908 Metetra
.612 .884 .99 r
.41759 .40908 .43406 .41642 .46169 .40685 .44549 .3993 Metetra
.634 .89 .986 r
.44549 .3993 .46169 .40685 .48961 .39644 .47369 .38859 Metetra
.654 .894 .982 r
.47369 .38859 .48961 .39644 .5178 .38522 .50216 .37695 Metetra
.672 .895 .977 r
.50216 .37695 .5178 .38522 .54624 .37323 .53089 .36443 Metetra
.689 .895 .972 r
.53089 .36443 .54624 .37323 .57493 .36052 .55987 .35107 Metetra
.703 .892 .966 r
.55987 .35107 .57493 .36052 .60385 .34718 .58907 .33697 Metetra
.714 .887 .96 r
.58907 .33697 .60385 .34718 .63299 .33334 .61849 .32224 Metetra
.721 .879 .954 r
.61849 .32224 .63299 .33334 .66235 .3192 .64812 .30706 Metetra
.724 .868 .949 r
.64812 .30706 .66235 .3192 .69195 .30505 .67797 .29171 Metetra
.719 .853 .945 r
.67797 .29171 .69195 .30505 .72182 .29139 .70807 .27664 Metetra
.701 .83 .944 r
.70807 .27664 .72182 .29139 .75207 .27922 .73848 .26278 Metetra
.637 .785 .953 r
.73848 .26278 .75207 .27922 .783 .27172 .7695 .25305 Metetra
.632 .759 .939 r
.09021 .46436 .10844 .47914 .13303 .46995 .11469 .45698 Metetra
.539 .759 .978 r
.11469 .45698 .13303 .46995 .15739 .46473 .13902 .45306 Metetra
.493 .763 .991 r
.13902 .45306 .15739 .46473 .1819 .46073 .16354 .45009 Metetra
.47 .771 .996 r
.16354 .45009 .1819 .46073 .20669 .45706 .18838 .44728 Metetra
.463 .782 .998 r
.18838 .44728 .20669 .45706 .2318 .45328 .21357 .4442 Metetra
.467 .796 .999 r
.21357 .4442 .2318 .45328 .25726 .44913 .23915 .44061 Metetra
.478 .81 1 r
.23915 .44061 .25726 .44913 .28309 .44442 .26512 .43634 Metetra
.496 .825 .999 r
.26512 .43634 .28309 .44442 .30928 .43902 .29149 .43127 Metetra
.516 .839 .999 r
.29149 .43127 .30928 .43902 .33584 .43285 .31824 .42531 Metetra
.54 .853 .998 r
.31824 .42531 .33584 .43285 .36275 .42583 .34537 .4184 Metetra
.564 .865 .996 r
.34537 .4184 .36275 .42583 .39001 .41791 .37287 .41049 Metetra
.589 .875 .993 r
.37287 .41049 .39001 .41791 .41759 .40908 .40071 .40155 Metetra
.614 .884 .99 r
.40071 .40155 .41759 .40908 .44549 .3993 .42888 .39156 Metetra
.637 .891 .986 r
.42888 .39156 .44549 .3993 .47369 .38859 .45736 .38053 Metetra
.659 .895 .981 r
.45736 .38053 .47369 .38859 .50216 .37695 .48612 .36846 Metetra
.679 .897 .975 r
.48612 .36846 .50216 .37695 .53089 .36443 .51515 .3554 Metetra
.697 .897 .969 r
.51515 .3554 .53089 .36443 .55987 .35107 .54443 .34139 Metetra
.713 .894 .962 r
.54443 .34139 .55987 .35107 .58907 .33697 .57393 .32651 Metetra
.725 .889 .955 r
.57393 .32651 .58907 .33697 .61849 .32224 .60364 .31087 Metetra
.734 .882 .949 r
.60364 .31087 .61849 .32224 .64812 .30706 .63356 .29463 Metetra
.738 .871 .942 r
.63356 .29463 .64812 .30706 .67797 .29171 .66367 .27805 Metetra
.736 .857 .937 r
.66367 .27805 .67797 .29171 .70807 .27664 .69399 .26156 Metetra
.722 .837 .935 r
.69399 .26156 .70807 .27664 .73848 .26278 .7246 .24598 Metetra
.669 .798 .944 r
.7246 .24598 .73848 .26278 .7695 .25305 .75573 .23399 Metetra
.591 .747 .952 r
.07164 .44932 .09021 .46436 .11469 .45698 .096 .44375 Metetra
.495 .742 .983 r
.096 .44375 .11469 .45698 .13902 .45306 .12027 .44114 Metetra
.452 .746 .992 r
.12027 .44114 .13902 .45306 .16354 .45009 .14479 .43923 Metetra
.434 .756 .995 r
.14479 .43923 .16354 .45009 .18838 .44728 .16966 .43728 Metetra
.432 .769 .997 r
.16966 .43728 .18838 .44728 .21357 .4442 .19493 .43491 Metetra
.441 .784 .998 r
.19493 .43491 .21357 .4442 .23915 .44061 .22061 .43189 Metetra
.458 .801 .999 r
.22061 .43189 .23915 .44061 .26512 .43634 .24673 .42807 Metetra
.48 .818 .999 r
.24673 .42807 .26512 .43634 .29149 .43127 .27326 .42333 Metetra
.505 .834 .999 r
.27326 .42333 .29149 .43127 .31824 .42531 .30021 .41759 Metetra
.532 .85 .998 r
.30021 .41759 .31824 .42531 .34537 .4184 .32756 .41079 Metetra
.56 .863 .996 r
.32756 .41079 .34537 .4184 .37287 .41049 .35529 .40287 Metetra
.588 .875 .994 r
.35529 .40287 .37287 .41049 .40071 .40155 .3834 .39382 Metetra
.615 .884 .99 r
.3834 .39382 .40071 .40155 .42888 .39156 .41184 .38362 Metetra
.64 .892 .985 r
.41184 .38362 .42888 .39156 .45736 .38053 .44061 .37226 Metetra
.664 .896 .979 r
.44061 .37226 .45736 .38053 .48612 .36846 .46967 .35976 Metetra
.686 .899 .973 r
.46967 .35976 .48612 .36846 .51515 .3554 .49901 .34614 Metetra
.705 .899 .966 r
.49901 .34614 .51515 .3554 .54443 .34139 .5286 .33146 Metetra
.722 .896 .958 r
.5286 .33146 .54443 .34139 .57393 .32651 .55841 .31578 Metetra
.735 .891 .951 r
.55841 .31578 .57393 .32651 .60364 .31087 .58843 .29921 Metetra
.746 .884 .943 r
.58843 .29921 .60364 .31087 .63356 .29463 .61863 .28189 Metetra
.751 .874 .936 r
.61863 .28189 .63356 .29463 .66367 .27805 .64902 .26407 Metetra
.751 .861 .929 r
.64902 .26407 .66367 .27805 .69399 .26156 .6796 .24612 Metetra
.741 .842 .926 r
.6796 .24612 .69399 .26156 .7246 .24598 .71041 .2288 Metetra
.699 .809 .933 r
.71041 .2288 .7246 .24598 .75573 .23399 .74167 .21453 Metetra
.542 .731 .962 r
.05272 .43399 .07164 .44932 .096 .44375 .07693 .43025 Metetra
.445 .722 .984 r
.07693 .43025 .096 .44375 .12027 .44114 .10112 .42898 Metetra
.406 .726 .99 r
.10112 .42898 .12027 .44114 .14479 .43923 .12562 .42813 Metetra
.394 .738 .992 r
.12562 .42813 .14479 .43923 .16966 .43728 .15051 .42705 Metetra
.399 .754 .994 r
.15051 .42705 .16966 .43728 .19493 .43491 .17585 .4254 Metetra
.414 .772 .995 r
.17585 .4254 .19493 .43491 .22061 .43189 .20163 .42296 Metetra
.436 .792 .997 r
.20163 .42296 .22061 .43189 .24673 .42807 .22788 .41959 Metetra
.463 .811 .998 r
.22788 .41959 .24673 .42807 .27326 .42333 .25458 .41519 Metetra
.493 .83 .999 r
.25458 .41519 .27326 .42333 .30021 .41759 .28172 .40967 Metetra
.524 .847 .998 r
.28172 .40967 .30021 .41759 .32756 .41079 .30929 .40298 Metetra
.556 .862 .997 r
.30929 .40298 .32756 .41079 .35529 .40287 .33727 .39506 Metetra
.586 .875 .994 r
.33727 .39506 .35529 .40287 .3834 .39382 .36563 .3859 Metetra
.616 .885 .99 r
.36563 .3859 .3834 .39382 .41184 .38362 .39436 .37547 Metetra
.644 .893 .984 r
.39436 .37547 .41184 .38362 .44061 .37226 .42342 .36378 Metetra
.669 .898 .978 r
.42342 .36378 .44061 .37226 .46967 .35976 .45279 .35083 Metetra
.693 .9 .971 r
.45279 .35083 .46967 .35976 .49901 .34614 .48245 .33665 Metetra
.713 .9 .963 r
.48245 .33665 .49901 .34614 .5286 .33146 .51236 .32128 Metetra
.731 .898 .954 r
.51236 .32128 .5286 .33146 .55841 .31578 .54249 .30478 Metetra
.745 .893 .946 r
.54249 .30478 .55841 .31578 .58843 .29921 .57283 .28726 Metetra
.757 .886 .937 r
.57283 .28726 .58843 .29921 .61863 .28189 .60334 .26884 Metetra
.764 .877 .929 r
.60334 .26884 .61863 .28189 .64902 .26407 .63402 .24975 Metetra
.766 .864 .921 r
.63402 .24975 .64902 .26407 .6796 .24612 .66486 .23032 Metetra
.759 .847 .917 r
.66486 .23032 .6796 .24612 .71041 .2288 .69591 .21124 Metetra
.726 .818 .922 r
.69591 .21124 .71041 .2288 .74167 .21453 .72731 .19466 Metetra
.484 .709 .97 r
.03345 .41837 .05272 .43399 .07693 .43025 .05747 .41648 Metetra
.389 .697 .982 r
.05747 .41648 .07693 .43025 .10112 .42898 .08157 .41655 Metetra
.357 .703 .984 r
.08157 .41655 .10112 .42898 .12562 .42813 .10603 .41678 Metetra
.352 .717 .986 r
.10603 .41678 .12562 .42813 .15051 .42705 .13093 .41659 Metetra
.364 .737 .989 r
.13093 .41659 .15051 .42705 .17585 .4254 .15631 .41566 Metetra
.386 .758 .992 r
.15631 .41566 .17585 .4254 .20163 .42296 .18219 .41381 Metetra
.414 .781 .994 r
.18219 .41381 .20163 .42296 .22788 .41959 .20857 .41091 Metetra
.446 .803 .997 r
.20857 .41091 .22788 .41959 .25458 .41519 .23542 .40685 Metetra
.481 .824 .998 r
.23542 .40685 .25458 .41519 .28172 .40967 .26276 .40155 Metetra
.516 .844 .998 r
.26276 .40155 .28172 .40967 .30929 .40298 .29054 .39496 Metetra
.551 .86 .997 r
.29054 .39496 .30929 .40298 .33727 .39506 .31877 .38705 Metetra
.585 .874 .994 r
.31877 .38705 .33727 .39506 .36563 .3859 .3474 .37777 Metetra
.617 .885 .989 r
.3474 .37777 .36563 .3859 .39436 .37547 .37641 .36711 Metetra
.647 .893 .984 r
.37641 .36711 .39436 .37547 .42342 .36378 .40578 .35507 Metetra
.674 .899 .977 r
.40578 .35507 .42342 .36378 .45279 .35083 .43547 .34166 Metetra
.699 .902 .969 r
.43547 .34166 .45279 .35083 .48245 .33665 .46545 .3269 Metetra
.721 .902 .96 r
.46545 .3269 .48245 .33665 .51236 .32128 .49569 .31082 Metetra
.739 .9 .95 r
.49569 .31082 .51236 .32128 .54249 .30478 .52616 .2935 Metetra
.755 .895 .941 r
.52616 .2935 .54249 .30478 .57283 .28726 .55683 .275 Metetra
.767 .888 .931 r
.55683 .275 .57283 .28726 .60334 .26884 .58767 .25547 Metetra
.776 .879 .921 r
.58767 .25547 .60334 .26884 .63402 .24975 .61865 .23508 Metetra
.78 .866 .913 r
.61865 .23508 .63402 .24975 .66486 .23032 .64978 .21415 Metetra
.776 .85 .907 r
.64978 .21415 .66486 .23032 .69591 .21124 .68107 .19328 Metetra
.751 .825 .91 r
.68107 .19328 .69591 .21124 .72731 .19466 .71264 .17436 Metetra
.415 .68 .971 r
.01381 .40245 .03345 .41837 .05747 .41648 .03762 .40243 Metetra
.327 .666 .975 r
.03762 .40243 .05747 .41648 .08157 .41655 .06159 .40386 Metetra
.304 .675 .975 r
.06159 .40386 .08157 .41655 .10603 .41678 .08599 .40518 Metetra
.308 .694 .978 r
.08599 .40518 .10603 .41678 .13093 .41659 .11089 .40588 Metetra
.327 .718 .982 r
.11089 .40588 .13093 .41659 .15631 .41566 .13632 .40569 Metetra
.356 .744 .987 r
.13632 .40569 .15631 .41566 .18219 .41381 .16228 .40444 Metetra
.391 .77 .991 r
.16228 .40444 .18219 .41381 .20857 .41091 .18877 .402 Metetra
.429 .795 .995 r
.18877 .402 .20857 .41091 .23542 .40685 .21578 .39829 Metetra
.469 .819 .997 r
.21578 .39829 .23542 .40685 .26276 .40155 .2433 .39322 Metetra
.508 .84 .998 r
.2433 .39322 .26276 .40155 .29054 .39496 .27131 .38674 Metetra
.547 .858 .997 r
.27131 .38674 .29054 .39496 .31877 .38705 .29977 .37882 Metetra
.584 .874 .994 r
.29977 .37882 .31877 .38705 .3474 .37777 .32868 .36942 Metetra
.618 .886 .989 r
.32868 .36942 .3474 .37777 .37641 .36711 .35798 .35853 Metetra
.65 .894 .983 r
.35798 .35853 .37641 .36711 .40578 .35507 .38766 .34613 Metetra
.679 .9 .975 r
.38766 .34613 .40578 .35507 .43547 .34166 .41768 .33225 Metetra
.705 .903 .966 r
.41768 .33225 .43547 .34166 .46545 .3269 .448 .31689 Metetra
.728 .903 .957 r
.448 .31689 .46545 .3269 .49569 .31082 .47858 .3001 Metetra
.748 .901 .946 r
.47858 .3001 .49569 .31082 .52616 .2935 .5094 .28192 Metetra
.764 .896 .936 r
.5094 .28192 .52616 .2935 .55683 .275 .54042 .26243 Metetra
.777 .889 .925 r
.54042 .26243 .55683 .275 .58767 .25547 .57159 .24175 Metetra
.787 .88 .914 r
.57159 .24175 .58767 .25547 .61865 .23508 .60291 .22005 Metetra
.792 .868 .905 r
.60291 .22005 .61865 .23508 .64978 .21415 .63434 .19759 Metetra
.791 .853 .897 r
.63434 .19759 .64978 .21415 .68107 .19328 .66589 .17491 Metetra
.773 .831 .897 r
.66589 .17491 .68107 .19328 .71264 .17436 .69765 .15362 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.1515 .21036 m
.15612 .21503 L
s
[(0.2)] .14227 .20104 .98988 1 Mshowa
.27764 .16097 m
.28204 .16584 L
s
[(0.4)] .26884 .15124 .90478 1 Mshowa
.41014 .10909 m
.4143 .11416 L
s
[(0.6)] .40182 .09894 .81968 1 Mshowa
.5495 .05452 m
.55338 .05981 L
s
[(0.8)] .54173 .04395 .73459 1 Mshowa
.125 Mabswid
.06081 .24588 m
.06366 .24859 L
s
.09068 .23418 m
.09351 .23692 L
s
.12091 .22234 m
.12371 .22511 L
s
.18247 .19824 m
.18521 .20107 L
s
.21381 .18597 m
.21651 .18883 L
s
.24553 .17355 m
.2482 .17644 L
s
.31015 .14824 m
.31276 .15119 L
s
.34306 .13535 m
.34564 .13834 L
s
.37639 .1223 m
.37893 .12532 L
s
.44432 .09571 m
.44677 .09878 L
s
.47893 .08215 m
.48134 .08526 L
s
.51399 .06843 m
.51636 .07157 L
s
.58547 .04044 m
.58776 .04364 L
s
.62192 .02616 m
.62416 .0294 L
s
.65884 .01171 m
.66104 .01497 L
s
gsave
.29165 .07573 -75.8979 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooon?ooooo`;o0000/?oo
ool00?ooooooS?ooool3o`000003ooooool0003ooooo0:oooooo003ooooooh[ooooo0_l00004oooo
o`;o0000[oooool00?ooooooQoooool3o`0000Kooooo00?o0000ooooool00000[_ooool00?oooooo
QOooool2o`0000Wooooo00?o0000ooooool00000[_ooool00?ooooooP_ooool3o`0000_ooooo00Co
0000oooooooooooo0000[Oooool00?ooooooOoooool3o`0000kooooo00Go0000oooooooooooooooo
o`00002/ooooo`00oooooommooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`05o`000?oo
ooooooooooooool00000[?ooool00?ooooooN_ooool3o`0000Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo003oooooogSooooo0_l0000G
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool00?ooooooMOooool3o`00
01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00oooooomcooooo`;o
00007?ooool00ol0003oooooooooo`03ooooo`;o0000Z?ooool00?ooooooL?ooool3o`0001kooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`00002Xooooo`00oooooom^ooooo`;o00008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo003oooooof_ooooo1?l0000R
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0YOooool00?oooooo=oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0002Cooooo0_l00004ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Uooooo`00oooooolfooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`?o0000:?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Cooooo003oooooocKooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000001gooooo0ol0000[ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Xoooool00?oooooo=_ooool01?l0003oooooooooool0
0008ooooo`?o00007?ooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2Sooooo`00oooooolfooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000Hooooo`?o0000<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:;ooooo
003oooooocKooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Ko
oooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00?oooooo
=oooool2o`0000Wooooo0ol0000Dooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0:7ooooo003ooooooeOooooo0_l00002ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00oooooomDooooo`?o00001Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo0ol0002Qooooo`00oooooomBoooo
o`;o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo003oooooodoo
oooo0ol00010ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0W_ooool00?oooooo
COooool2o`0004?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Mooooo`00oooo
oom:ooooo`?o0000AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo003o
ooooodOooooo0ol00018ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0W?ooool0
0?ooooooAOooool2o`000003ooooool0003ooooo04Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2Kooooo`00oooooom2ooooo`?o00001?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Voooool00;Gooooo0_l000001?oooooo0000
o`000?ooool4o`00083ooooo0_l00008ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2Jooooo`00]_ooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0007cooooo0ol0001Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0VOooool00;Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001jooooo`;o
0000EOooool00ol0003oooooooooo`0@ooooo`;o0000V_ooool00;Oooooo00?o0000ooooooooool0
0_ooool3o`0007Sooooo0ol0001Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000
V_ooool00;Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001eooooo`;o0000
F_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09Oooooo002fooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo0000L_ooool4o`0005_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`2Gooooo`00]Oooool2o`000004ooooool0003o0000ooooo`Co0000
LOooool2o`0000Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Wooooo0ol00004ooooo`;o00001?ooool2o`0007kooooo003oooooobkooooo0ol0
001Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001moooo
o`00ooooool[ooooo`?o0000I?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo07_ooooo003oooooobWooooo0_l0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0Noooool00?oooooo9_ooool3o`0006[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`06ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0007gooooo003oooooobCooooo0_l0001]ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo0000OOooool00>gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol0000Uooooo`Co0000K_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
1Ol00003ooooo`;o00001?ooool2o`0007kooooo003/ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Rooooo`;o00001?ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo01Kooooo0_l0002Cooooo`00k?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000007oooool3o`0007Cooooo00?o0000ooooooooool05?ooool2o`00
0003ooooool0003ooooo09;ooooo003/ooooo`04o`000?ooooooooooo`0000Oooooo1?l0000Noooo
o`;o0000Moooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo093ooooo003/ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07?ooool3o`0007Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`2@ooooo`00k?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo01Wooooo0_l0001looooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0Soooool00>gooooo0_l0000:ooooo`;o00005_ooool3o`0007kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`2>ooooo`00ooooool?ooooo`Co0000P?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo08kooooo003oooooo`gooooo0_l00004ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2=ooooo`00ooooool:
ooooo`?o0000Q_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08cooooo003ooooo
o`Sooooo0_l00029ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0S?ooool00?oo
oooo1Oooool3o`0008_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2;ooooo`00
ooooool3ooooo`;o0000S_ooool00ol0003oooooooooo`0Looooo`?o0000S?ooool00?oooooo0ol0
002@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0R_ooool00?gooooo0_l00000
0ooooooo0000ooooo`2Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0ROooool0
0?[ooooo0ol00004ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`28ooooo`00n?ooool2o`0000Sooooo00?o0000ooooooooool0S_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo08Sooooo003eooooo`?o0000Voooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo08Oooooo003booooo`?o0000W_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo08Kooooo003`ooooo`;o0000XOooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo08Kooooo003]ooooo`?o0000Xoooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo08Gooooo003[ooooo`;o000000?oooooo`000?ooool0Xoooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo08Gooooo003Xooooo`?o00001?ooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo02?ooooo0_l00025ooooo`00i_ooool2o`000:_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooo`000025ooooo`00hoooool3o`000:gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`23ooooo`00hOooool2o`000;3ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`22ooooo`00g_ooool3o`000;;ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`21ooooo`00Yoooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0002Kooooo0_l0002eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
POooool00:Kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Rooooo`?o0000
0_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
P?ooool00:Kooooo00Co0000oooooooooooo00001oooool5o`00023ooooo0ol0002kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0Ooooool00:Kooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0000Oooooo`;o0000__ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo07oooooo002Vooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
00007?ooool3o`000<3ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1nooooo`00
Y_ooool01?l0003oooooooooool00009ooooo`;o00006_ooool2o`000<?ooooo00?o0000oooooooo
ool0:?ooool2o`0007oooooo002Wooooo`;o00002oooool00ol0003oooooooooo`0Eooooo`?o0000
aOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo000007oooooo003:ooooo`?o0000aooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07cooooo0037ooooo`?o00000oooool0
0ol0003oooooooooo`34ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Noooool0
0<Gooooo0_l0003<ooooo`;o0000;Oooool00ol0003oooooooooo`1kooooo`00`_ooool3o`000<go
oooo00?o0000olGDiOl00000;_ooool00ol0003oooooooooo`1jooooo`00`?ooool2o`000<kooooo
0_l00002olGDi@;o0000;_ooool00ol0003oooooooooo`1iooooo`00_Oooool3o`000<oooooo00?o
0000olGDiOo5e>D00_o5e>D00ol0003oaMCUo`00000]ooooo`03o`000?oooooooooo07Wooooo002j
ooooo`?o0000d?ooool2o`0000GoaMCU00Co0000olGDiOo5e>Go0000;Oooool00ol0003ooooooooo
o`1hooooo`00^?ooool2o`000003ooooool0003ooooo0<kooooo0_l00007olGDi@04o`000?o5e>Go
aMCUo`0002kooooo00?o0000ooooooooool0Moooool00;Gooooo0ol00004ooooo`03o`000?oooooo
oooo0<_ooooo00?o0000olGDiOo5e>D01oo5e>D01Ol0003oaMCUolGDiOo5e>Go000002gooooo0_l0
001hooooo`00/oooool2o`0000Sooooo00?o0000ooooooooool0b?ooool2o`0000[oaMCU00?o0000
olGDiOo5e>D00_o5e>D00ol0003oooooooooo`0Yooooo`03o`000?oooooo000007Sooooo002`oooo
o`?o0000e?ooool00ol0003oaMCUolGDi@0:olGDi@03o`000?o5e>GoaMCU00;oaMCU00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`1fooooo`00[_ooool2o`000=Gooooo0_l0000>olGDi@03
o`000?o5e>GoaMCU00;oaMCU00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`;o0000GOooool00:_ooooo0ol0003Fooooo`03o`00
0?o5e>GoaMCU00koaMCU00?o0000olGDiOo5e>D00oo5e>D00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0F_ooool00:Wooooo0ol0003Fooooo`;o00004Oo5e>D00ol0003o
aMCUolGDi@03olGDi@;o0000;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1Jooooo`00Y_ooool3o`0000?o
oooo00?o0000ooooooooool0d_ooool00ol0003ob][Uo`00000AolGDi@04o`000?o5e>GoaMCUolGD
i@;o000000?o`=?Xo`000?ooool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1Jooooo`00Y?ooool2o`00
0=[ooooo00Go0000ol[JiOo:f^Gob][Uo`00000@olGDi@04o`000?o5e>GoaMCUo`0000Co`=?X00?o
0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000?o00000ooo
ool01?l0003oooooooooool0001Looooo`00XOooool3o`000=[ooooo0_l00005ol[Ji@03o`000?o5
e>GoaMCU00goaMCU0ol00006ol3Cj003o`000?oooooooooo02[ooooo00?o0000ooooooooool01Ooo
ool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0001Loooo
o`00W_ooool3o`000=cooooo00?o0000ol[JiOo:f^D01_o:f^D00ol0003oaMCUolGDi@0;olGDi@;o
00002?o0dnP00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo
0000o`000003o`0000?ooooo0_l0001Mooooo`00W?ooool2o`000=kooooo00?o0000ol[JiOo:f^D0
2?o:f^D00ol0003oaMCUolGDi@09olGDi@03o`000?o0dnSo000000Wo`=?X00?o0000ooooooooool0
:_ooool2o`0007;ooooo001Uooooo`;o00001?ooool01?l0003oooooooooooooool5o`0002Gooooo
0ol0003Nooooo`;o00002oo:f^D00ol0003oaMCUolGDi@07olGDi@;o00000_o0dnP00ol0003o`=?X
ol3Cj008ol3Cj003o`000?oooooooooo02Oooooo0_l000000ooooooo0000ooooo`1aooooo`00I?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0002?ooooo0_l000000ooooooo
0000ooooo`3Mooooo`03o`000?o:f^Gob][U00cob][U00?o0000olGDiOo5e>D01?o5e>D2o`0000Co
`=?X00?o0000ol3Cj?o0dnP02?o0dnP00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06oo
oooo001Tooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08?ooool3o`0000Co
oooo00?o0000ooooooooool0f_ooool00ol0003ob][Uol[Ji@0>ol[Ji@03o`000?o5e>GoaMCU00;o
aMCU00?o0000ol3Cj?o0dnP01?o0dnP00ol0003o`=?Xol3Cj009ol3Cj003o`000?oooooooooo02_o
oooo00?o0000ooooooooool0K_ooool006Cooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`0Mooooo`;o0000h_ooool2o`0001;ob][U00Co0000olGDiOl0003o00001oo0dnP00ol0
003o`=?Xol3Cj009ol3Cj003o`000?oooooooooo02_ooooo00?o0000ooooooooool0K_ooool006Co
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001_ooooo0ol0003S
ooooo`03o`000?o:f^Gob][U01;ob][U0_l00009ol3Cj003o`000?o0dnSo`=?X00[o`=?X00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1]ooooo`00I?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000006Oooool2o`000>Gooooo00?o0000ol[JiOo:f^D04_o:
f^D00ol0003oa]WXo`000009ol3Cj003o`000?o0dnSo`=?X00[o`=?X0_l0000]ooooo`03o`000?oo
oooooooo06cooooo001Uooooo`;o00002Oooool3o`0001Oooooo0ol0003Uooooo`;o00004oo:f^D2
o`0000?oa]WX00?o0000ol3Cj?o0dnP01_o0dnP00ol0003o`=?Xol3Cj008ol3Cj0;o000000?o^M7/
o`000?ooool0;?ooool00ol0003oooooooooo`1/ooooo`00R?ooool3o`000>Kooooo00?o0000ol[N
iol000004_o:f^D00ol0003oa]WXolKIj004olKIj003o`000?o0dnSo`=?X00Go`=?X00?o0000ol3C
j?o0dnP01_o0dnP2o`0000Co^M7/00?o0000ooooooooool0:oooool00ol0003oooooooooo`1[oooo
o`00QOooool3o`0000?ooooo00?o0000ooooooooool0h_ooool01Ol0003ob]kWol[Nioo:g^Oo0000
00oob][U0_l00008olKIj003o`000?o0dnSo`=?X00Go`=?X00?o0000ol3Cj?o0dnP00oo0dnP2o`00
00Oo^M7/00?o0000ooooooooool0:_ooool2o`0006cooooo0022ooooo`?o0000jOooool2o`0000Go
b]kW00?o0000ol[JiOo:f^D02oo:f^D00ol0003oa]WXolKIj009olKIj003o`000?o0dnSo`=?X00Co
`=?X00Co0000ol3Cj?o0dnSo`=?X0_l00009okWAk003o`000?oooooooooo02Wooooo00?o0000oooo
ool00000K?ooool0083ooooo0_l0003[ooooo`03o`000?o:g^Oob]kW00Kob]kW00?o0000ol[JiOo:
f^D02Oo:f^D00ol0003oa]WXolKIj00;olKIj003o`000?o0dnSo`=?X00?o`=?X00Co0000ol3Cj?l0
003o00003?nidN`00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo0ol0000doooo
o`00OOooool3o`000>cooooo00?o0000ol[Nioo:g^L02?o:g^L00ol0003ob][Uol[Ji@06ol[Ji@;o
00003oo6fNP00ol0003o`=?Xol3Cj002ol3Cj0;o00003onidN`00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool007_ooooo0_l0003]ooooo`;o0000
3?o:g^L00ol0003ob][Uol[Ji@04ol[Ji@03o`000?o6fNSoa]WX013oa]WX00?o0000ol3Cj?l00000
0_l0000AokWAk003o`000?oooooooooo02[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0cooooo`00N?ooool3o`000>kooooo00?o0000ol[Nioo:g^L03Oo:g^L01?l0003ob][Uol[J
iOo:f^D2o`0001?oa]WX0_l00002okWAk003o`000?nidNco^M7/00oo^M7/00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03?ooooo001fooooo`;o00000ooo
ool00ol0003oooooooooo`3Zooooo`03o`000?o:g^Oob]kW00oob]kW00?o0000ol[JiOl000005?o6
fNP00ol0003o`]SZo`000002okWAk003o`000?nidNco^M7/013o^M7/00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0^ooooo`05o`000?oooooo0000ooooool00000<oooool007?ooooo0ol0
0006ooooo`03o`000?oooooooooo0>Oooooo0_l0000Bol[Ni`;o00004oo6fNP2o`0000?o`]SZ00?o
0000okWAk?l000004_nidN`2o`0002cooooo00?o0000ooooooooool0;_ooool01Ol0003oooooo`00
0?oooooo000003?ooooo001aooooo`;o0000l_ooool00ol0003ob]kWol[Ni`0Aol[Ni`04o`000?o7
gNWoamgYo`00013oa]WX0_l00006ol;HjP;o00004?nidN`2o`000003ok;?k_l0003ooooo02cooooo
00?o0000ooooooooool0;Oooool5o`0003?ooooo001^ooooo`?o0000loooool00ol0003ob]kWol[N
i`0@ol[Ni`;o00001?o7gNT00ol0003oa]WXolKIj00<olKIj003o`000?o2f>[o`]SZ00Oo`]SZ00?o
0000okWAk?nidN`02onidN`3o`0000Co//o^00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1Uooooo`00K?ooool2o`000?Cooooo0ol0000@ol[Ni`;o00001oo7gNT00ol0003oa]WXolKIj009
olKIj0;o00002_o2f>X2o`0000[o^M7/0_l00008ok;?kP03o`000?oooooooooo02Sooooo0ol0001V
ooooo`00JOooool3o`000?Gooooo00Go0000olWQjOo9hNWobN7Yo`00000>ol[Ni`03o`000?o7gNWo
amgY00SoamgY00?o0000olKIj?o6fNP01oo6fNP00ol0003o`]SZol;HjP0:ol;HjP;o00002?nidN`2
o`0000_o//o^00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`00I_ooool3o`00
00?ooooo00?o0000ooooooooool0l?ooool2o`0000GobN7Y00?o0000ol[Nioo:g^L02Oo:g^L2o`00
00coamgY00?o0000olKIj?o6fNP01?o6fNP2o`0000go`]SZ00?o0000ol;Hj_l000001?nidN`3o`00
00ko//o^00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Sooooo`00I?ooool2o`000?So
oooo00?o0000olWQjOo9hNT01_o9hNT00ol0003ob]kWol[Ni`07ol[Ni`03o`000?o7gNWoamgY00go
amgY00Co0000olKIj?o6fNSoa]WX0_l0000?ol;HjP05o`000?o2f>[o`]SZo`000?nidN`00_l0000A
ok;?kP03o`000?oooooooooo02[ooooo00?o0000ooooooooool0H_ooool0067ooooo0ol0003hoooo
o`;o00002_o9hNT00ol0003ob]kWol[Ni`04ol[Ni`;o00004Oo7gNT00ol0003oa]WXo`00000Aol;H
jP03o`000?o2f>[o`]SZ00;o00005?nbcnh00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
067ooooo001Oooooo`;o0000n_ooool00ol0003obN7YolWQj@0;olWQj@04o`000?o:g^Oob]kWol[N
i`;o00004oo7gNT2o`0001;o`]SZ0ol000000onmengo0000ok;?kP0Dok;?kP03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0HOooool005cooooo0ol0003kooooo`03o`000?o9hNWobN7Y00go
bN7Y00?o0000ol[Niol000005?o7gNT00ol0003oa=g[o`00000Bol;HjP;o00000onmend00ol0003o
//o^ok;?kP0Cok;?kP03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H?ooool005[ooooo
0_l0003looooo`;o00004?o9hNT2o`0001?oamgY0_l00003olCMj`03o`000?o2f>[o`]SZ00go`]SZ
0_l000000onmengo0000okgGk@03okgGk@03o`000?nbcnko//o^01;o//o^0_l0000[ooooo`03o`00
0?oooooooooo05oooooo001Gooooo`?o00000_ooool00ol0003oooooooooo`3hooooo`03o`000?o9
hNWobN7Y00oobN7Y00Co0000olKQjoo6hN_o00004?o7gNT2o`0000Koa=g[00?o0000ol;Hj_o2f>X0
2_o2f>X2o`0000?o_MO]00?o0000okgGkOnmend00onmend00ol0003o//o^ok;?kP0>ok;?kP?o0000
00?oZlcao`000?ooool0:_ooool00ol0003oooooooooo`1Oooooo`00EOooool2o`000?kooooo0_l0
000@olWQj@;o00001?o6hN/00ol0003oamgYolOMj@0<olOMj@03o`000?o4gN_oa=g[00Ooa=g[00?o
0000ol;Hj_o2f>X01oo2f>X2o`0000Go_MO]00?o0000okgGkOnmend01?nmend00ol0003o//o^ok;?
kP0:ok;?kP?o00001On[c?400ol0003oooooooooo`0Wooooo`?o0000H?ooool005;ooooo0ol0003o
ooooo`03o`000?o9hNWobN7Y00oobN7Y00?o0000olKQjoo6hN/01Oo6hN/00ol0003oamgYolOMj@09
olOMj@;o00002oo4gN/00ol0003o`]SZol;HjP04ol;HjP;o00001onmend00ol0003o_MO]okgGk@05
okgGk@03o`000?nbcnko//o^00Oo//o^0_l00009oj_<l@03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0GOooool0053ooooo0_l0003oooooo`7ooooo0ol0000?olWQj@;o00002Oo6hN/00ol0
003oamgYolOMj@07olOMj@03o`000?o4gN_oa=g[00coa=g[00?o0000ol;Hj_o2f>X00_o2f>X00ol0
003o_MO]okgGk@07okgGk@03o`000?nmengo_MO]00Ko_MO]00?o0000ok;?k_nbcnh00onbcnh3o`00
00_oZlca00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Mooooo`00COooool3o`000?oo
oooo0_ooool01Ol0003oa^?/olKSk?o6hnco000000gobN7Y00?o0000olKQjoo6hN/02_o6hN/00ol0
003oamgYolOMj@04olOMj@;o00004?o4gN/01?l0003o`]SZo`000?l0000:okgGk@03o`000?nmengo
_MO]00Oo_MO]00?o0000ok;?k_l000000_l0000?oj_<l@03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0G?ooool004[ooooo0ol0003oooooo`?ooooo0_l00005olKSk003o`000?o9hNWobN7Y
00WobN7Y00?o0000olKQjoo6hN/03?o6hN/01?l0003oamgYolOMjOo7gNT2o`0001;oa=g[0_l0000;
okgGk@;o00002Onmend2o`0001?oZlca00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1K
ooooo`00B?ooool2o`0000?ooooo00?o0000ooooooooool0o_ooool00ol0003oa^?/olKSk006olKS
k003o`000?o9hNWobN7Y00KobN7Y0_l0000@olKQj`03o`000?o7gNWo000001;oa=g[0_l00002ol3L
k@03o`000?nmengo_MO]00Go_MO]0ol000000onmengo0000okgGk@06okgGk@;o000000?o^=K_o`00
0?n[c?404on[c?400ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05_ooooo0015ooooo`?o
0000ooooool5ooooo`;o00002_o6hn`00ol0003obN7YolWQj@04olWQj@03o`000?o6hN_oa^7[013o
a^7[0ol0000AolCMj`03o`000?o0g>go`=c]00?o`=c]00Co0000okgGkOnmengo_MO]0ol00005okgG
k@03o`000?nmengo_MO]00;o_MO]0_l00004okSFk`03o`000?n[c?7oZlca017oZlca00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Jooooo`00@oooool2o`000?oooooo1oooool00ol0003o
a^?/olKSk00;olKSk004o`000?o9hNWobN7YolWQj@;o00004_o6hN/01Ol0003o`n3]ol?PkOo3h>go
000000koa=g[0_l00007ol3Lk@?o00002Onmend01?l0003o_MO]o`000?l00007okSFk`03o`000?n[
c?7oZlca017oZlca00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Iooooo`00@?ooool3
o`000?oooooo2?ooool00ol0003oa^?/olKSk00=olKSk003o`000?o9hNWo000001;oa^7[0_l00005
ol?Pk@03o`000?o4gN_oa=g[00Woa=g[0_l00006ol3Lk@?o000000?o`=c]o`000?nmend02Onmend2
o`0000[o^=K_00?o0000oj_<lOn[c?403on[c?43o`0002[ooooo00?o0000ooooooooool0FOooool0
03oooooo0_l0003oooooo`Sooooo0_l0000@olKSk0?o00004?o6hN/2o`0000So`n3]00?o0000olCM
joo4gN/01oo4gN/00ol0003o`=c]ol3Lk@03ol3Lk@?o00001Oo0g>d00ol0003o_MO]okgGk@05okgG
k@;o000000?o^=K_o`000?nhe^l02_nhe^l00ol0003oZlcaoj_<l@0;oj_<l@?o00000_nSb?<00ol0
003oooooooooo`0Wooooo`?o0000F_ooool003oooooo00?o0000ooooool00000ooooool6ooooo`03
o`000?o6hncoa^?/00ooa^?/00Go0000olCSk_o4hnkoa>?^o`00000>olKQj`03o`000?o3h>go`n3]
00Wo`n3]00?o0000olCMjoo4gN/01?o4gN/2o`0000?o`=c]0ol00009ol3Lk@03o`000?nmengo_MO]
00;o_MO]0_l00004okSFk`03o`000?nhe^oo^=K_00So^=K_00?o0000oj_<lOn[c?402?n[c?43o`00
00KoXlSc00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Gooooo`00?_ooool3o`000003
ooooool0003ooooo0?oooooo0_ooool2o`00013oa^?/0_l00005olCSkP03o`000?o6hN_oa^7[00Wo
a^7[0_l0000=ol?Pk@04o`000?o4gN_oa=g[olCMj`;o00000_o0g>d3o`0000go`=c]00Co0000okgG
kOl0003o00001onhe^l00ol0003o^=K_okSFk`08okSFk`03o`000?n[c?7oZlca00CoZlca0ol0000:
oj?8l`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool3o`0000Cooooo0_l00004
ooooo`;o00001?ooool2o`0003Sooooo000oooooo`05o`000?ooooooooooooooool00000ooooool1
ooooo`03o`000?o6hncoa^?/00koa^?/0_l00008olCSkP03o`000?o6hN_oa^7[00Ooa^7[00?o0000
ol?PkOo3h>d03_o3h>d00ol0003oa=g[o`000002ol3Lk@;o00004?o0g>d2o`0000Wo^=K_00?o0000
okSFkonhe^l02Onhe^l00ol0003oZlcaoj_<l@03o`0000koXlSc00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003Oooooo000nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0noooool3o`0000ooa^?/00?o0000olCSk_o4hnh0
2Oo4hnh00ol0003oa^7[olKQj`04olKQj`;o00004Oo3h>d5o`00013o`=c]0_l000000onlfnoo0000
okSFk`09okSFk`03o`000?nhe^oo^=K_00So^=K_0ol0000Boj?8l`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000gooooo`00?_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?Wooooo00Go0000ol?Ukoo3iNoo`nG_o`00000<
olKSk0;o00003Oo4hnh01?l0003oa^7[olKQjoo6hN/2o`0001;o`n3]0ol0000Bol3Lk@03o`000?nl
fnoo_=__00;o_=__00?o0000okSFkonhe^l02?nhe^l00ol0003o^=K_okSFk`05okSFk`;o000000?o
/mCao`000?nSb?<04_nSb?<00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000=oooool003kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3fooooo`;o00001Oo3iNl00ol0003oa^?/olKSk008olKSk003o`000?o4hnkoa>?^00ko
a>?^00?o0000olKQjol000004Oo3h>d3o`0000?o`=o_00?o0000ol3LkOo0g>d03Oo0g>d2o`0000Ko
_=__00?o0000okSFkonhe^l02?nhe^l01?l0003o^=K_okSFkonhe^l3o`0000Co/mCa00?o0000oj?8
lonSb?<04OnSb?<00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000=oooool003kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3cooooo`;o00002?o3iNl2o`0000Koa^?/0_l0000AolCSkP?o00003_o3h>d4o`0000Ko`=o_00?o
0000ol3LkOo0g>d02_o0g>d2o`0000Wo_=__00?o0000okSFkonhe^l01onhe^l01?l0003o^=K_o`00
0?l00008ok?Dl@03o`000?nSb??oXlSc017oXlSc00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`07ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000=oooool003kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3aooooo`03o`000?o3iNoo`nG_00[o`nG_00Co0000olKSk?o6hncoa^?/0_l0000A
olCSkP;o00000oo1h^l00ol0003o`n3]ol?Pk@08ol?Pk@?o000000?o`n3]o`000?o0gnl02?o0gnl0
0ol0003o`=c]ol3Lk@07ol3Lk@;o00003?nlfnl00ol0003o^=K_okSFk`06okSFk`;o00002once?40
0ol0003oXlScoj?8l`0?oj?8l`?o0000:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0003Sooooo000nooooo`;o00002Oooool00ol0
003oooooooooo`3^ooooo`;o00003_o3iNl00ol0003oa^?/o`00000BolCSkP03o`000?o1h^oo`N;_
00Co`N;_00?o0000ol?PkOo3h>d01?o3h>d3o`0000;o`n3]0_l0000;ol3Ok`03o`000?o0g>go`=c]
00Co`=c]0_l0000?okcKk`03o`000?nhe^oo^=K_00;o^=K_0ol00002ok?Dl@03o`000?nce?7o/mCa
00Wo/mCa00?o0000oj?8lonSb?<02_nSb?<4o`0000;oVLGf00?o0000ooooooooool09oooool2o`00
05Cooooo000mooooo`;o00002oooool00ol0003oooooooooo`3/ooooo`03o`000?o3iNoo`nG_00ko
`nG_0ol0000@olCSkP;o00002?o1h^l00ol0003o`n3]ol?Pk@03o`0000Co`n3]00?o0000ol3Okoo0
gnl03?o0gnl00ol0003o`=c]ol3Lk@02ol3Lk@03o`000?nlfnoo_=__013o_=__00Co0000okSFkol0
003o00001_nce?400ol0003o/mCaok?Dl@09ok?Dl@03o`000?nSb??oXlSc00GoXlSc1?l00007oiW5
mP03o`000?oooooooooo02Cooooo0_l000000ooooooo0000ooooo`1Cooooo`00?Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0>Wooooo0_l0000@ol?Uk`05o`000?o1iO3o`NG`ol7U
l?l000003Oo4hnh2o`0000[o`N;_0ol00005ol?Pk@;o00004?o0gnl01?l0003o`=c]o`000?l0000C
okcKk`;o00002?nce?400ol0003o/mCaok?Dl@0:ok?Dl@03o`000?nSb??oXlSc00Co00003?nIaOH0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo057ooooo000mooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0i_ooool2o`00013o`nG_0_l00005ol7Ul003o`000?o4hnkoa>?^
00Soa>?^0_l0000:ol7Rk`;o00000_o1h^l01?l0003o`n3]ol?PkOo3h>d2o`0001;o`=o_0ol0000B
okcKk`;o00000_nhf_400ol0003o/mCaok?Dl@06ok?Dl@03o`000?nce?7o/mCa00Wo/mCa0ol0000@
oiW5mP03o`000?oooooooooo02Sooooo00?o0000ooooooooool0D?ooool003gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3Tooooo`03o`000?o3iNoo`nG_00ko`nG_0_l00008ol7U
l0;o00001_o4hnh2o`0000Wo`N;_0ol00005ol7Rk`03o`000?o3h>go000001;o`=o_0_l00003okcN
l@03o`000?nlfnoo_=__00go_=__0_l00005okSJl@03o`000?nce?7o/mCa00Ko/mCa00?o0000ok?D
lOnce?401Once?43o`000003ojgBlol0003oVLGf017oVLGf00?o0000ooooooooool09oooool00ol0
003oooooooooo`1@ooooo`00?Oooool00ol0003oooooooooo`0>ooooo`;o0000h_ooool3o`0000oo
`nG_00?o0000ol7Ul?o1iO002_o1iO000ol0003oa>?^olCSkP02olCSkP03o`000?o1h^oo`N;_00Ko
`N;_0ol00008ol7Rk`?o00004?o0gnl2o`0000Ko_=ka00?o0000okcKkonlfnl02_nlfnl2o`0000So
^=[a00?o0000ok?DlOnce?401Once?400ol0003o/mCaok?Dl@02ok?Dl@?o00001On]d_<00ol0003o
VLGfoiW5mP0@oiW5mP03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Coooool003gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Mooooo`;o00000onoi_800ol0003o`nG_
ol?Uk`0:ol?Uk`;o00003_o1iO001?l0003oa>?^o`000?l00006ol7Rk`?o00002Oo1h^l2o`0000?o
_^;a00?o0000ol3Okoo0gnl02oo0gnl2o`0000Wo_=ka00?o0000okcKkonlfnl02?nlfnl00ol0003o
^=[aokSJl@09okSJl@03o`000?nce?7o/mCa00Go/mCa00Co0000ok?DlOl0003o00002On]d_<00ol0
003oVLGfoiW5mP0@oiW5mP03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool003go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Kooooo`03o`000?noi_;o_nKb00Co
_nKb00?o0000ol?Ukoo3iNl02?o3iNl00ol0003o`NG`ol7Ul00>ol7Ul0?o00001?o1h^l3o`0000_o
`N;_00?o0000okkRlOnnh_401?nnh_400ol0003o`=o_ol3Ok`09ol3Ok`03o`000?nlg_7o_=ka00[o
_=ka00?o0000okcKkonlfnl01Onlfnl2o`0000go^=[a00?o0000ok?DlOnce?400once?43o`0000co
[M;c00?o0000oiW5m_nIaOH03onIaOH00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04ko
oooo000looooo`?o00004oooool00ol0003oooooooooo`3Hooooo`;o00002?noi_82o`0000Ko`nG_
0_l0000?ol7Ul0;o00000onni?84o`0000co`N;_0_l00008okkRl@;o00001oo0gnl2o`0000ko_=ka
00?o0000okcKkonlfnl00_nlfnl2o`00013o^=[a00?o0000ok?DlOl000000_l00003ojgBl`03o`00
0?n]d_?o[M;c00[o[M;c00?o0000oiW5m_nIaOH03onIaOH00ol0003oooooooooo`0Wooooo`;o0000
C_ooool003cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3Eooooo`;o00003?no
i_801?l0003o`nG_ol?Ukoo3iNl2o`00013o`NG`00Co0000okkTl_nni?;o_^Cb1?l0000<ol7Rk`;o
00003?nnh_400ol0003o`=o_ol3Ok`02ol3Ok`;o00004Onlg_401?l0003o_=__o`000?l0000BokSJ
l@;o00001_n]d_<00ol0003o[M;cojgBl`0;ojgBl`03o`000?nIaOKoVLGf00_oVLGf1Ol0000Woooo
o`03o`000?oooooo000004kooooo000looooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0d_ooool2o`0000oo_nKb00?o0000ol?Ukol000004?o1iO02o`000004okkTl_l0003o0000o`00
00Co_^Cb00?o0000ol7Rkoo1h^l01oo1h^l2o`0000oo_^;a00Co0000ol3Okol0003o00004onlg_42
o`0001;o^=[a0_l000000oncf??o0000ojgBl`06ojgBl`03o`000?n]d_?o[M;c00_o[M;c00?o0000
oiW5m_nIaOH00_nIaOH8o`0000CoSl3g00?o0000ooooooooool09oooool00ol0003oooooooooo`1<
ooooo`00??ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<oooooo0_l0000AokoV
lP?o00003_o1iO02o`000003okkTl_l0003o000000So_^Cb00?o0000ol7Rkoo1h^l01?o1h^l2o`00
017o_^;a0_l0000CokcNl@;o00000_nig_800ol0003o^=[aokSJl@0=okSJl@;o00001?ncf?<00ol0
003o[M;cojgBl`05ojgBl`03o`000?n]d_?o[M;c00[o[M;c1Ol0000=oho0m`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0Boooool003cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3=ooooo`03o`000?noi_;o_nKb00oo_nKb0_l00003okgVl`;o00002oo1iO04o`0000_o
_^Cb00?o0000ol7Rkoo1h^l00_o1h^l00ol0003o_^;aokkRl@0?okkRl@;o00000_nkhO800ol0003o
_=kaokcNl@0>okcNl@;o00001Onig_800ol0003o^=[aokSJl@0:okSJl@;o00001oncf?<00ol0003o
[M;cojgBl`05ojgBl`03o`000?n]d_?o[M;c00Ko[M;c0ol000000onWd?Go0000oho0m`0@oho0m`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0B_ooool003cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`3:ooooo`;o00004?noi_82o`0000Oo_NKc0_l00007ol7Ul0?o0000
3onni?801?l0003o`N;_o`000?l0000AokkRl@03o`000?nkhO;o^n7b00?o^n7b00?o0000okcNlOnl
g_402onlg_42o`0000So^Mkb00?o0000okSJlOnhf_402?nhf_400ol0003o/mScok?Hl`08ok?Hl`03
o`000?n]d_?o[M;c00Co[M;c00?o0000ojgBlon]d_<00on]d_<3o`0000GoYm3e00?o0000oho0mon?
`?L03_n?`?L00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04[ooooo000kooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0aoooool3o`0000oo_nKb0_l0000;okgVl`04o`00
0?o1iO3o`NG`ol7Ul0?o00004_nni?83o`00013o_^;a0_l00007ok_QlP03o`000?nlg_7o_=ka00So
_=ka0_l0000;okWNlP03o`000?nhf_7o^=[a00Go^=[a0_l0000<ok?Hl`03o`000?n]d_?o[M;c00Co
[M;c00?o0000ojgBlon]d_<00_l00009ojO@m@03o`000?n?`?OoSl3g00koSl3g00?o0000oooooooo
ool09oooool00ol0003oooooooooo`19ooooo`00>oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0<Cooooo0_l00003ok[Wm0;o00003?noi_800ol0003o_NKcokgVl`0<okgVl`Co0000
4_nni?82o`0000?o_>Cc00?o0000okkRlOnnh_402onnh_42o`0000[o^n7b00?o0000okcNlOnlg_40
1Onlg_42o`0000ko^Mkb00?o0000okSJlOnhf_400_nhf_42o`0000oo/mSc00?o0000ojgBlon]d_<0
0on]d_<3o`0000_oYm3e00?o0000oho0mon?`?L03on?`?L00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo04Sooooo000kooooo`?o00007?ooool00ol0003oooooooooo`32ooooo`03o`000?nj
ioCo^^Od00Go^^Od0_l00008okoVlP;o00003?nmi_<3o`000004okgVlol0003o0000o`00013o_^Cb
0_l00006okcTl`03o`000?nnh_7o_^;a00So_^;a0_l0000=ok_QlP03o`000?nlg_7o_=ka00;o_=ka
0_l0000AokWNlP04o`000?nhf_7o0000o`0001;o/mSc00?o0000ojgBlol000000_l000000onWd?Go
0000ojO@m@0<ojO@m@03o`000?n?`?OoSl3g00koSl3g00?o0000ooooooooool09oooool00ol0003o
ooooooooo`18ooooo`00>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;oooooo
0_l0000:ok[Wm003o`000?noi_;o_nKb00?o_nKb0_l0000;okgVl`?o00000_nmi_<2o`0000?o^nGd
00?o0000okkTl_nni?802onni?82o`0000Wo_>Cc0_l00006okkRl@;o00004?nkhO801?l0003o_=ka
o`000?l0000CokWNlP?o00004oncf?<2o`0000GoYm3e00?o0000ojO@mOnWd?D02onWd?D00ol0003o
Sl3goho0m`0>oho0m`03o`000?oooooooooo02Kooooo0_l00019ooooo`00>oooool00ol0003ooooo
ooooo`0Nooooo`;o0000_Oooool2o`0000go^^Od0_l000000onoi_;o0000o`00000:okgVl`?o0000
1?nmi_<00ol0003o^nGdok_Um004ok_Um003o`000?nni?;o_^Cb00Wo_^Cb00?o0000okcTlonli?<0
2onli?<00ol0003o_^;aokkRl@02okkRl@03o`000?nkhO;o^n7b013o^n7b0ol0000BokWNlP;o0000
0onegO@00ol0003o/mScok?Hl`0=ok?Hl`?o00000_n^eoD00ol0003oYm3eojO@m@03ojO@m@03o`00
0?nWd?GoYm3e00[oYm3e00?o0000oho0mon?`?L02on?`?L5o`0002Kooooo00Co0000oooooooooooo
0000B?ooool003_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2hooooo`;o0000
4?njio@3o`0000So_NKc0ol00005okgVl`;o00002?nkiO@2o`0000Oo_^Cb0_l0000?okcTl`04o`00
0?nnh_7o0000o`00017o^n7b0_l00003okSQm003o`000?nig_;o^Mkb00go^Mkb0_l00006okGMm003
o`000?ncf??o/mSc00[o/mSc0_l00006ojkGm@03o`000?nWd?GoYm3e00?oYm3e00?o0000ojO@mOnW
d?D02_nWd?D00ol0003oSl3goho0m`02oho0m`So00001?n5^oP00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo04Kooooo000kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
]Oooool2o`00013o^^Od0_l00003okSVm@03o`000?nmi_?o_NKc00?o_NKc0_l00006okgVl`;o0000
3?nkiO@00ol0003o_^CbokkTlP02okkTlP;o00004Onli?<3o`00013o^n7b0_l00006okSQm003o`00
0?nig_;o^Mkb00Wo^Mkb0ol00009okGMm003o`000?ncf??o/mSc00Ko/mSc0ol00009ojkGm@03o`00
0?nWd?GoYm3e00;oYm3e00?o0000ojO@mOnWd?D02OnWd?D6o`0000goQK_h00?o0000ooooooooool0
9oooool00ol0003oooooooooo`15ooooo`00>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ok[Wm?njio@03onjio@00ol0003o^>KeokSVm@04okSVm@03o`000?nm
i_?o000000;o00001_nmi_<2o`0000oo^nGd00Co0000okkTl_l0003o00004Onli?<2o`0000?o^N?d
00?o0000ok_Ql_nkhO802_nkhO83o`0000Wo^>7d0_l00007okWNlP;o00003OnegO@00ol0003o/mSc
ok?Hl`03ok?Hl`;o00003On^eoD00ol0003oYm3eojO@m@02ojO@m@03o`000?nWd?GoYm3e00CoYm3e
1?l00002oj3=m`03o`000?n5^oSoQK_h00ooQK_h00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`15ooooo`00>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;3ooooo0_l0
000@ok[Wm0;o00001_nhi_D4o`0000Ko_NKc0_l0000Aok_Um0?o00004?nli?<2o`0000Ko^N?d0_l0
0008ok_QlP;o00003_nhhO@00ol0003o^MkbokWNlP02okWNlP;o00004?negO@00ol0003o/mSco`00
0002o`00013o[]Oe00?o0000ojO@mOnWd?D00_nWd?D00ol0003oYm3eojO@m@03o`0000OoX<gg00?o
0000ohFkn?n5^oP03on5^oP00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Cooooo000j
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0[Oooool3o`0000oo^^Od0_l00005
okSVm@?o00001?nhi_D00ol0003o_NKcokgVl`02okgVl`03o`000?nkiOCo^nGd00oo^nGd0_l00003
okSUm@03o`000?nli??o_>Cc00_o_>Cc0_l0000:okWSm0;o00001?nkhO82o`00017o^>7d00Co0000
okWNl_l0003o00004_negO@2o`0001Co[]Oe00?o0000ojO@mOnWd?D01?l0000;oj3=m`03o`000?n5
^oSoQK_h00ooQK_h00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`00>_ooool4
o`0002Gooooo00?o0000ooooooooool0Z_ooool2o`0000?o]>Og0_l0000;ok[Wm0;o00001?nhi_D3
o`0000So^>Ke00Co0000okgVlol0003o00004?nkiO@2o`0000Ko^>Ge00?o0000okcTlonli?<02Onl
i?<00ol0003o^N?dokWSm00<okWSm004o`000?nkhO;o0000o`0001?o^>7d0ol0000AokGMm0;o0000
0_nafoH00ol0003o[]OeojkGm@0AojkGm@?o00000_nPcOL00ol0003oX<ggoj3=m`0;oj3=m`03o`00
0?n5^oSoQK_h00koQK_h00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`00>Ooo
ool2o`0002Wooooo00?o0000ooooooooool0Yoooool2o`0000Oo]>Og0_l00007ok[Wm0;o00000onh
i_D3o`0000_o^>Ke0ol0000?ok_Um0;o00002OnhiOD2o`0000Oo_>Cc0_l0000?okWSm0?o00004_nh
hO@2o`0000?o]N3e00?o0000okGMm?negO@03?negO@2o`0000Go/M_f00?o0000ojkGmOn^eoD03On^
eoD3o`0000;oZMGg00Go0000oj3=monPcOOoX<ggo`00000=oj3=m`03o`000?n5^oSoQK_h00koQK_h
00?o0000ooooooooool09_ooool2o`0004?ooooo000jooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0Y?ooool2o`0000_o]>Og00?o0000ok[Wm?njio@00onjio@00ol0003o^>KeokSV
m@03o`0000co^>Ke0_l00003okKVmP;o00003?nkiO@00ol0003o^>GeokSUm@0;okSUm@03o`000?nl
i??o_>Cc00;o_>Cc0_l0000?okWSm0;o00000onfhoD00ol0003o^>7dokSQm00<okSQm0?o00001_ne
h?D00ol0003o]MgdokGMm008okGMm0?o00002?nafoH00ol0003o[]OeojkGm@0:ojkGm@;o00001_nY
eOL01Ol0003oX<ggoj3=monPcOOo000000goX<gg00?o0000ohFkn?n5^oP03_n5^oP00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooo000004?ooooo000Looooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00002?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0:7ooooo0_l0
000>okCWm`;o000000?o^^Odo`000?l000000ol0000=okSVm@;o00001onfi_H2o`0000So^nGd0_l0
000?okSUm@04o`000?nli??o0000o`0000oo^N?d0_l00006okKSm@03o`000?nhhOCo^>7d00Wo^>7d
0_l0000:okGPm@03o`000?negOCo]Mgd00Go]Mgd0_l0000<ok7KmP03o`000?n^eoGo[]Oe00Ko[]Oe
0ol00009ojWEm`05o`000?nPcOOoX<ggoj3=mol000003OnPcOL00ol0003oQK_hohFkn006ohFkn0Wo
00009oooool00ol0003oooooooooo`11ooooo`006oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Nooooo`;o00004Ond
ioL4o`0000ko^>Ke0_l0000;okKVmP03o`000?nkiOCo^nGd00?o^nGd0_l0000AokSUm@?o00003_ni
ho@2o`0000Wo]^?e00?o0000okSQm?nhhO@01_nhhO@2o`0000go]N3e00?o0000okGMm?negO@00_ne
gO@2o`0000oo/M_f00?o0000ojkGmOn^eoD00on^eoD2o`0000goZMGg00Co0000oj3=monPcOOo0000
3?nPcOL:o`0000SoNKGh00?o0000ooooooooool09_ooool00ol0003oooooooooo`10ooooo`005Ooo
ool5o`0000Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09_ooooo0_l0000AokCWm`Co000000?o/^Kho`000?l000003?nhi_D00ol0
003o]^KfokKVmP0<okKVmP;o000000?o^nGdo`000?l000004OnhiOD2o`0000?o]^Cf00?o0000okWS
m?niho@02_niho@00ol0003o]^?eokKSm@0:okKSm@03o`000?nhhOCo^>7d00;o^>7d0ol0000@okGP
m@04o`000?negOCo0000o`0001;o/M_f00?o0000ojkGmOl000000_l0000@ojWEm`04o`000?nPcOOo
X<ggo`0000KoX<gg1Ol00002oiW:n@03o`000?mi]OSoNKGh00koNKGh00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0oooooo`007oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0V?ooool2o`00013o]>Og1?l00006ok;Vn0;o
00002?nhi_D2o`00013o]^Kf0ol0000@okSUm@;o00001_nfi?H2o`0000So^N?d0_l0000>okKSm@04
o`000?nhhOCo0000o`0001?o]N3e0ol0000Cok7KmP?o00004onYeOL00ol0003oX<ggoj3=m`06o`00
00SoVL[i00?o0000ogVen?mi]OP03_mi]OP00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03oooooo000Kooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo09Gooooo0ol0000?okCWm`?o00002onbi_P00ol0003o^>KeokSVm@03okSVm@;o00004?nf
i_H2o`0000?o]>Kg00?o0000okSUmOnhiOD02_nhiOD3o`0000[o]^Cf0_l00004okWSm0;o00004?nf
hoD3o`0001;o]N3e0_l00003ok7Om`03o`000?nafoKo/M_f00go/M_f0ol00003ojgJm`03o`000?nY
eOOoZMGg013oZMGg1?l0000>oiW:n@03o`000?mi]OSoNKGh00goNKGh00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0nooooo`006oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`;o
0000<?ooool2o`0009?ooooo0_l00003ojgVn@;o00002_ndioL3o`0000oo/^Kh0_l000000onhi_Go
0000o`00000@okKVmP;o00001_ndi_L2o`0000So^>Ge0_l0000?okKTmP04o`000?nihoCo0000o`00
013o]^?e0_l00003ok?Rm`03o`000?neh?Go]N3e00go]N3e0_l00006ok7Om`03o`000?nafoKo/M_f
00[o/M_f0_l00007ojgJm`03o`000?nYeOOoZMGg00coZMGg0ol000001OnTdoSo0000oiW:nOnIb_Wo
000000koVL[i00?o0000ogVen?mi]OP03Omi]OP00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03gooooo000Kooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo08kooooo0_l00007ojgVn@?o00001?ndioL4o`00
01;o/^Kh0ol0000?okKVmP;o00002_ndi_L2o`0000Co^>Ge0_l0000AokKTmP?o00003onfhoD2o`00
00Ko/n;g00?o0000okGPmOneh?D02Oneh?D3o`0000Wo/Mog00?o0000ok7Km_nafoH01_nafoH3o`00
00[o[M[g00?o0000ojWEmonYeOL02?nYeOL3o`0000GoY=?h00Co0000oiW:nOnIb_Wo00003_nIb_T0
0ol0003oNKGhogVen00=ogVen003o`000?oooooooooo02Gooooo00?o0000ooooooooool0?Oooool0
03Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`?o00003?n]i_T5o`00
01?o/^Kh0_l00003ok7Vn003o`000?nfi_Ko]^Kf00[o]^Kf0_l0000>okCVm`04o`000?nhiOGo0000
o`00017o]^Cf0_l00003ok?Tm`03o`000?nfhoGo]^?e00Wo]^?e0ol00009ok?Rm`;o00001oneh?D2
o`0000go/Mog00?o0000ok7Km_nafoH00onafoH2o`0000ko[M[g00?o0000ojWEmonYeOL01?nYeOL3
o`0000WoY=?h00Co0000oiW:nOnIb_Wo00003_nIb_T00ol0003oNKGhogVen00<ogVen003o`000?oo
oooooooo02Cooooo0ol0000nooooo`00>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo08Oooooo0_l0000=ojgVn@Ko00004Onbi_P3o`0000Ko/NKh0_l00008okKVmP;o00004?ndi_L3
o`00013o]^Cf0_l00006ok?Tm`;o00001onfhoD2o`0000ko/n;g00?o0000okGPmOneh?D00_neh?D2
o`00013o/Mog00?o0000ok7Km_l000000_l0000AojgJm`03o`000?nYeOOoZMGg00?o00003OnTdoP0
0ol0003oVL[io`00000=oiW:n@_o00001_mi]OP00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03_ooooo000hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Q?ooool2o`00
00go[NKi0_l000000on]i_Wo0000o`000003ojcVnP;o00003Onbi_P2o`0000_o/NKh0_l00004okKV
mP;o00004?ndi_L2o`0000?o/^Gh00?o0000okKTm_nfi?H02_nfi?H3o`0000[o/nCg00?o0000okKS
mOnfhoD00_nfhoD2o`00017o/n;g00Co0000okGPmOl0003o00004_nagoL3o`0001?o[M[g0ol0000A
ojCCn003o`000?nIb_Wo000000OoVL[i1Ol00002oi77nP03o`000?m][_SoKJkh00KoKJkh2?l0000W
ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool3o`0000Cooooo0_l0000M
ooooo`00>?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo087ooooo0_l0000<ojgV
n@?o000000?o[NKio`000?l000001on/i_X2o`0000Wo/^Kh0_l0000?ok7Vn004o`000?nfi_Ko0000
o`00013o]>Kg0_l00006ok;Un0;o00002?nfi?H2o`0000ko/nCg00Co0000okKSmOl0003o00004onc
h_L3o`00013o/Mog0ol00003ojkNn003o`000?n]f_Oo[M[g00go[M[g0ol000000onXfOWo0000ojCC
n00BojCCn004o`000?nIb_Wo0000oiW:n@Go00002?nAaoX00ol0003oKJkhoff^n00<off^n003o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo01[ooooo000hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O_ooool3o`00
00[o[NKi0ol000001?n]i_Wo0000o`000?l0000;ojcVnP03o`000?nbi_So/^Kh00?o/^Kh0ol0000A
ok7Vn0?o00003ondi_L2o`0000[o/^Gh0_l00004okKTmP;o00004?nci?L3o`00017o/n;g0ol00003
ok3Qn003o`000?nagoOo/Mog00_o/Mog0_l00007ojkNn003o`000?n]f_Oo[M[g00[o[M[g0_l00005
ojSIn@03o`000?nTdoSoY=?h013oY=?h1?l0000>oi77nP03o`000?m][_SoKJkh00coKJkh00?o0000
ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01[ooooo000h
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0N_ooool3o`0000?oY^Ck0_l00005
ojgVn@?o00000_n]i_T2o`0000oo[>Kj0_l000000onbi_So0000o`00000Bok7Vn0;o00000on_i_T2
o`0000co]>Kg00?o0000ok;Un?nbiOP03?nbiOP01?l0003o]^Cfo`000?l0000@ok?Tm`;o00000ona
hoP00ol0003o/n;gok?Rm`0<ok?Rm`;o00001on`hOP2o`0000So/Mog0ol0000:ojkNn003o`000?n]
f_Oo[M[g00Ko[M[g0ol00008ojSIn@03o`000?nTdoSoY=?h00coY=?h0ol00002oikAnP;o00003onA
aoX00ol0003oKJkhoff^n00<off^n003o`000?oooooooooo02Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0Jooooo`00=oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo07Kooooo0ol00008ojKTn`Go00000on]i_T2o`0001;o[>Kj0ol0000Aok7Vn0;o00001on_
i_T2o`0000So]>Kg0_l0000?ok;Un0?o00003onci?L2o`0000Ko/N?h0_l00009ok?Rm`?o00002on`
hOP00ol0003o/Mogok7Om`03ok7Om`;o00003_n^g_P00ol0003o[M[gojgJm`03ojgJm`;o00003?nX
fOT00ol0003oY=?hojCCn008ojCCn0?o00001_nNdOX2o`0000ooTLOj00?o0000off^n?m][_P03?m]
[_P00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooooooool0000Looooo`00
=oooool3o`0003_ooooo00?o0000ooooooooool0Loooool2o`0000[oY^Ck0ol000001?nVi?_o0000
o`000?n]i_T2o`0001;o[>Kj0_l00003oj_UnP;o00003?nai_P3o`0000_o[nKi00?o0000okCVmond
i_L00ondi_L2o`0000oo/^Gh0_l00003ok3Un003o`000?nci?Oo/nCg00Wo/nCg0ol0000:ok7Sn0;o
00001Onch_L2o`0000oo/>7h00?o0000ok7Omol000000_l0000AojkNn003o`000?n]f_Oo000000;o
00003onXfOT00ol0003oY=?hojCCn004ojCCn0?o00002_nNdOX2o`0000ooTLOj00?o0000off^n?m]
[_P03?m][_P00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`07
o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0001cooooo000g
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Koooool3o`0000WoY^Ck0ol00005
ojKTn`?o00004On/i_X2o`0000OoZnGj0_l00008ok7Vn0;o00003on_i_T2o`000003okCVmol0003o
000000oo/^Gh0_l00006ok3Un0;o00001onci?L2o`0000oo/N?h00?o0000ok?Rmol000000_l0000A
ok3Qn0?o00004on^g_P3o`0001;oZ=Wi00?o0000ojCCn?nTdoP00ol0000>oikAnP03o`000?nAao[o
TLOj00koTLOj00?o0000off^n?m][_P02om][_P00ol0003oooooooooo`0Tooooo`?o00001oooool0
0ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?ooooo0_l0000Mooooo`00=oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo06_ooooo0ol00009ojKTn`?o00001_nVi?/2o`00
00?oYNCk0_l0000<ojcVnP?o00002on[iOX00ol0003o/NKhok7Vn003ok7Vn0;o00004_n_i_T3o`00
00go/^Gh0ol0000:ok3Un003o`000?nci?Oo/nCg00;o/nCg0_l0000Aok7Sn0?o00004?n`hOP3o`00
00?o[N3i00?o0000ojkNn?n^g_P03On^g_P3o`0000?oZ]ci00?o0000ojSInOnXfOT03_nXfOT4o`00
01;oW]7j00?o0000oi77n_nAaoX02_nAaoX9o`0000WoKJkh00?o0000ooooooooool08Oooool2o`00
00;ooooo00?o0000ooooooooool0=_ooool003Oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`1Xooooo`?o00002?nVi?/3o`0000OoY^Ck0_l00007ojGTn`;o00002?n/i_X2o`0000oo
ZnGj0_l000000onai_So0000o`00000AojoVn@?o00000on]iOT2o`0000Wo/^Gh0_l0000>ok3Un004
o`000?nci?Oo0000o`00017o/N?h0_l00003ojkSn@03o`000?n`hOSo/>7h00_o/>7h0_l00007ojgP
n@03o`000?n^g_So[]kh00[o[]kh0_l00007oj[Ln@03o`000?nXfOWoZ=Wi00WoZ=Wi1?l00004oj?G
nP03o`000?nNdO[oW]7j013oW]7j00?o0000oi77n_nAaoX00_nAaoX7o`0000CoRL?k00?o0000oenV
momOY_L00_mOY_L8o`0000;oKJkh00?o0000ooooooooool09Oooool00ol0003oooooooooo`0eoooo
o`00=oooool00ol0003oooooooooo`0oooooo`;o0000IOooool3o`0000?oW^;m0_l00004ojKTn`;o
00001onVi?/3o`0000_oYNCk00?o0000ojcVn_n/i_X00on/i_X2o`0001;oZnGj0ol0000@ojoVn@;o
00002?n]iOT2o`0000Go/^Gh0_l0000@ok3Un0?o00004?nahoP2o`0000Ko[^?i0_l00008ok3Qn0?o
00002_n]h?T00ol0003o[]khojkNn006ojkNn0?o00002_nZg?T00ol0003oZ=WiojSIn@05ojSIn@?o
00002OnSeoX00ol0003oW]7joikAnP0>oikAnPKo00003?n9`o/00ol0003oGjKgoenVm`09oenVm`Co
00009_ooool00ol0003oooooooooo`0eooooo`00=_ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo063ooooo0_l00008oikRo@Co00001onVi?/2o`0000ooYNCk0_l000000on/i_[o0000
o`00000Aoj_UnP?o00000onYiOX2o`0000_o[nKi0ol0000<ojgUn@;o000000?o/^Gho`000?l00000
4?n`iOP2o`0000?o[^Ci00?o0000ok7Sn?nahoP02_nahoP3o`0000[o[^?i00?o0000ok3Qn?n`hOP0
0on`hOP2o`0000ko[N3i00?o0000ojkNn?n^g_P00on^g_P2o`0000koZ]ci00?o0000ojSInOnXfOT0
1?l0000=oj?GnP03o`000?nNdO[oW]7j00WoW]7j1?l00002oiO>n`03o`000?n9`o_oRL?k00koRL?k
00?o0000oenVmomOY_L02omOY_L00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Cooooo
000fooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0G?ooool3o`0000SoW^;m0ol0
00000onNh_go0000o`000005ojKTn`;o00004_nUi?/3o`00013oZnGj0_l00008ojWUnP?o00001_n_
i_T2o`00013o[NGi0ol0000?ok3Un0;o00001_n^i?T2o`0000So/N?h0_l0000>ojkSn@03o`000?n`
hOSo000000;o00004On]h?T00ol0003o[]kho`000002o`00013oZ]ci0ol0000Boj?GnP03o`000?nN
dO[oW]7j00GoW]7j0ol00007oiO>n`03o`000?n9`o_oRL?k00koRL?k00?o0000oenVmomOY_L02omO
Y_L00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo000fooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0FOooool2o`0000SoW^;m0ol00006oikRo@;o000000?oY^Ck
o`000?l000004OnUi?/3o`0000?oY>Ck0_l0000;oj_UnP?o00003OnYiOX2o`000004ojoVnOl0003o
0000o`00013o[NGi0_l00003ojcUnP03o`000?n`iOSo/>Gh00[o/>Gh0_l0000:ojkTn@;o00001?na
hoP2o`00013o[^?i0ol0000CojgPn@?o00003onZg?T3o`0000?oY]_j00?o0000oj?Gn_nSeoX04?nS
eoX00ol0003oW]7joikAnP04o`0000_oUlkk00?o0000ohW3non9`o/03On9`o/00ol0003oGjKgoenV
m`0<oenVm`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<oooool003Kooooo0_l00016
ooooo`03o`000?oooooooooo05Gooooo0ol00007oikRo@?o00002_nNh_d3o`00013oYNCk0_l00008
ojCTn`?o00001_n[iOX2o`00017oZNGj0ol0000@ojgUn@;o00001_n/iOX2o`0000So/>Gh0_l0000>
ojkTn@04o`000?nahoSo0000o`00013o[^?i0_l00003ojcRnP03o`000?n]h?Wo[N3i00go[N3i0ol0
0003oj[OnP03o`000?nZg?WoZ]ci00[oZ]ci0_l00007ojKKnP03o`000?nSeo[oXmOj00koXmOj1?l0
000@oiO>n`03o`000?n9`o_oRL?k00goRL?k00?o0000oenVmomOY_L03?mOY_L00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03;ooooo000fooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0D_ooool3o`0000KoW^;m0ol0000:oikRo@?o00000onMh_d2o`0000_oYNCk0ol0000=
ojCTn`;o000000CoZnGjo`000?l0003o00004?nYiOX3o`0000?oZ>Gk00?o0000ojgUnOn]iOT02_n]
iOT3o`0000[o[>Gj0_l00004ok3Un0;o00004?n^i?T3o`0000oo[^?i0_l00006ojcRnP;o00002_n]
h?T3o`0000OoZ]oj0_l00008oj[Ln@;o00002_nVfoX00ol0003oXmOjoj?GnP09oj?GnPCo00000onN
eO/00ol0003oUlkkoiO>n`0>oiO>n`;o00003on9`o/00ol0003oGjKgoenVm`0;oenVm`03o`000?oo
oooooooo02?ooooo0ol0000cooooo`00=_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo04kooooo0ol00003oiGOoPKo00002_nNh_d3o`0000SoWN;m0ol00006ojGTn`;o00004OnTi?/3
o`00013oZNGj0_l00007ojSUn`;o00002?n]iOT2o`0000oo[>Gj00Co0000ok3Un?l0003o00003on^
i?T3o`0000?oZn?j00?o0000ojkSnOn^hoT02On^hoT3o`0000[o[>;j00?o0000ojgPnOn]h?T01?n]
h?T3o`0000coZ]oj00?o0000oj[LnOnZg?T00_nZg?T3o`0000goY]_j00?o0000oj?Gn_nSeoX01OnS
eoX3o`0000SoW]Gk00?o0000oiO>nonGc_/03_nGc_/2o`0000SoRL?k3?l00009oenVm`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0<Oooool003Gooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`1:ooooo`?o00001_nEgoh5o`0000SoW^;m0ol0000>oigRo@;o000000CoYNCk
o`000?l0003o00004?nTi?/3o`0000?oXnCl0_l0000;ojWUnP?o00002onXiO/2o`0000Co[NGi0_l0
000AojcUnP?o00003_n^i?T2o`0000OoZn?j0_l00007ojkSn@;o00003_n/h_X00ol0003o[N3iojgP
n@03o`00013oZ]oj00Co0000oj[LnOl0003o00004OnVfoX00ol0003oXmOjoj?GnP04o`0000coW]Gk
00?o0000oiO>nonGc_/03OnGc_/:o`0000OoP;ok00?o0000oe6Nm?mAW_@00_mAW_@8o`0000;oGjKg
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0`ooooo`00=Oooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo04Kooooo0ol00007oiGOoP;o00001OnEgoh3o`0000;oW^;m0ol0
000BoigRo@?o00004?nTi?/2o`0000SoXnCl0ol00006ojWUnP;o00004?nXiO/01?l0003o[NGio`00
0?l0000@ojcUnP?o00000onZi?X2o`0000Wo[^Ci0ol0000;oj_SnP03o`000?n^hoWo[^?i00;o[^?i
0_l0000@ojcRnP?o00004onZgoX3o`0001;oY]_j0ol0000AoikEn`03o`000?nGc__oUlkk00OoUlkk
1Ol000001?nAc?co0000oi7<o?l0000>oh2on`03o`000?mAW_CoDIkd00WoDIkd1?l0000Uooooo`03
o`000?oooooooooo033ooooo000eooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
@_ooool3o`0000OoUMon0ol00009oiGOoP?o00004_nMh_d3o`0000?oWN;m0_l0000;ojCTn`?o0000
3OnSi?`2o`000004ojWUn_l0003o0000o`0001;oZ>Gk0ol0000?ojcUnP;o00002?nZi?X00ol0003o
[^CiojkTn@04ojkTn@;o00003on[hoX01?l0003o[^?io`000?l0000?ojcRnP?o00000onXhOX00ol0
003oZ]ojoj[OnP0=oj[OnP?o00000onVg_/00ol0003oY]_jojKKnP0<ojKKnP?o00000_nQf_/00ol0
003oW]GkoikEn`0@oikEn`04o`000?nGc__oUlkkoiO>n`Go00001onAc?`00ol0003oTLclo`00000>
oh2on`03o`000?mAW_CoDIkd00_oDIkd00?o0000ooooooooool09?ooool00ol0003oooooooooo`0_
ooooo`00=Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03gooooo1?l00007oiGO
oP?o00002OnEgoh3o`0000?oUMon0_l0000=oigRo@?o00002?nMh_d3o`0000KoY>Ck0_l0000Aoj?T
o0?o00004OnXiO/3o`0000?oYnCk0_l0000:ojcUnP?o00002onZi?X2o`000004ojkTnOl0003o0000
o`00017oZn?j0ol0000>ojcRnP;o00001onXhOX2o`0000[oZ]oj0ol00007ojKNn`03o`000?nVfo[o
Y]_j00SoY]_j0ol00006oj7Jn`03o`000?nNeO_oW]Gk00koW]Gk1Ol0000=oi7<o003o`000?nAc?co
000000koP;ok00?o0000oe6Nm?mAW_@02omAW_@00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02kooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>Oooool3o`00
00CoS=_o0ol000001?nEgoko0000o`000?l00009oiGOoP?o00002?nEgoh3o`0000OoWN;m0ol0000>
oigRo@;o000000CoY>Cko`000?l0003o00004?nSi?`3o`0000?oXnCl00?o0000ojSUnonXiO/03?nX
iO/2o`0000SoYnCk0_l00006ojcUnP;o00003onZi?X3o`00013oZn?j0ol00003ojWSnP;o00002_n/
h_X2o`0000_oZ>7j00?o0000oj[On_nZgoX01?nZgoX3o`0000_oY]kk00?o0000ojKKn_nVfoX01?nV
foX3o`0000[oXM[k00?o0000oikEnonNeO/02OnNeO/4o`0000?oVM?l00?o0000oi7<o?nAc?`03OnA
c?`00ol0003oTLclo`00000>oh2on`03o`000?mAW_CoDIkd00_oDIkd00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0^ooooo`00=Oooool2o`0004oooooo00?o0000ooooooooool0=?ooool4
o`0000SoS=_o1?l00008oiGOoP?o00003_nEgoh2o`0000;oWN;m0ol0000BoigRo@?o00004?nSi?`2
o`0000OoXnCl0_l00009ojSUn`?o00003?nWi?/2o`000004ojcUn_l0003o0000o`0000koZ^Cj0ol0
0003ojSTn`;o00002on[hoX3o`0000SoZN?j0_l00005ojcRnP?o00003_nXhOX00ol0003oZ]ojoj[O
nP03o`0000ooY]kk00?o0000ojKKn_nVfoX00ol0000>oj7Jn`03o`000?nNeO_oW]Gk00GoW]Gk0ol0
0008oiWCo003o`000?nAc?coTLcl00coTLcl00Co0000oi7<o?nAc?co00003_n0_o/00ol0003oDIkd
oe6Nm00:oe6Nm003o`000?oooooooooo02Cooooo00?o0000ooooooooool0;Oooool003Cooooo0_l0
001Aooooo`03o`000?oooooooooo033ooooo0ol00009ohcKo`?o00001?n<fol3o`0000;oUMon0ol0
000BoiGOoP?o00004_nMh_d3o`0000?oWN;m0_l0000;oj?To0?o00002onSi?`2o`0000GoZ>Gk0_l0
000@ojOTn`?o00003_nZi?X2o`0000SoZ>Ck0_l00006oj_SnP?o00003OnYhoX2o`000003ojcRn_l0
003o0000017oZ>7j0ol0000BojKNn`?o00004_nQf_/00ol0003oW]GkoikEn`04o`0000coVM?l00?o
0000oi7<o?nAc?`03?nAc?`Eo`0000[oDIkd00?o0000ooooooooool08_ooool3o`0002kooooo000d
ooooo`03o`000?oooooooooo057ooooo0_l0000/ooooo`Co00002On<fol3o`0000SoS=_o1?l0000B
oiGOoP?o00000onFgoh3o`0000coWN;m0ol00008oigRo@?o00001_nSi?`2o`00013oXnCl00?o0000
ojSUnol000000_l0000?ojOTn`?o00000onUi?/2o`0000[oZ^Cj0_l0000<ojSTn`;o000000CoZn?j
o`000?l0003o00004OnYhoX3o`0000ooZ>7j0ol00003ojKPn`03o`000?nVg__oY]kk00coY]kk0ol0
0003oj?Mn`03o`000?nQf__oXM[k00koXM[k1?l0000AoiWCo003o`000?nAc?coTLcl00OoTLcl1_l0
00000on:b?co0000ogNjn`0=ogNjn`03o`000?m3UO7o@iGa00Co00001omAW_@00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02cooooo000dooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool09?ooool5o`0000CoP]Oo0ol00003ohcKo`?o00002?n<fol3o`0000CoSMco0ol0000<
oiGOoP?o00002OnFgoh2o`0000OoWN;m0ol0000>oigRo@;o000000CoXnClo`000?l0003o00004_nS
i?`3o`0000ooYnCk0_l00008ojGTn`;o00001OnZi?X3o`0000ooZ>Ck0ol0000@ojWSnP?o00000onW
h_/00ol0003oZ>7jojSQnP0:ojSQnP;o00001onVh?/2o`0000WoY]kk0ol00007oj?Mn`;o00002onQ
f_/3o`0000CoWMSl00?o0000oiWCo?nIdo`03onIdo`01?l0003oTLcloi7<o?nAc?`5o`0000KoR/Sl
00?o0000oh[8o?l000003_mg^_/00ol0003o@iGaod>El@03od>El@Co00000omAW_@00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02_ooooo000dooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool07_ooool5o`0000coP]Oo0ol00007ohcKo`Co00002_n=g?l2o`0000OoUMon0ol0
000>oiKOoP?o000000CoWN;mo`000?l0003o00004_nMh_d3o`00017oXnCl0ol00003oj;So0;o0000
2_nWi?/3o`0000coYNCk0_l000000onZi?[o0000o`00000?ojSTn`?o00000onVho/00ol0003oZN?j
ojWSnP0;ojWSnP;o00001onWh_/2o`0000SoZ>7j0_l0000;ojKPn`03o`000?nVg__oY]kk00?oY]kk
0ol0000<oj?Mn`03o`000?nQf__oXM[k00CoXM[k1?l00008oigHo003o`000?nIdocoVM?l00goVM?l
1Ol0000;oh[8o004o`000?n:b?coR/Slo`0000koMk[k00?o0000od>ElOm3UO401_m3UO45o`0002Ko
oooo00?o0000ooooooooool0:_ooool003Cooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Hooooo`Go00003on2eol2o`0000;oP]Oo0ol00002ohcKo`?o00004?n=g?l3o`000004oiGO
o_l0003o0000o`0001?oU]on0ol0000AoigRo@?o00000onMh_d2o`0000coXnCl0ol00008oj;So0;o
00001_nWi?/2o`00013oYNCk0ol0000>ojSTn`;o00001onVho/2o`0000SoZN?j0ol0000;ojORn`03
o`000?nXhO[oZ>7j00;oZ>7j0ol0000>ojKPn`03o`000?nVg__o000000;o00004?nSgO/00ol0003o
XM[koj7Jn`03o`0000goWMSl00?o0000oiWCo?nIdo`01onIdo`5o`0000CoTm7m00?o0000oh[8o?n:
b?`02_n:b?`01?l0003oR/Sloh[8o?l0000>ogNjn`03o`000?m3UO7o@iGa00Wo@iGa0_l0000Uoooo
o`03o`000?oooooooooo02[ooooo0002ooooo`Go000000Coooooo`000?l0003o0000:Oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo01;ooooo1Ol00004ogSAo`?o00002_n2eol3o`00
00GoP]Oo1?l0000DohgLo`Co00004_nFgoh3o`0000?oU]on0_l0000<oigRo@?o00002?nMh_d3o`00
00KoXnCl0ol0000=oj;So0;o000000CoYnCko`000?l0003o00003onUi?/3o`0000?oY>?l0_l00009
ojSTn`?o00002onVho/00ol0003oZN?jojWSnP03ojWSnP;o00003onWh_/01?l0003oZ>7jo`000?l0
000AojKPn`?o00004OnSgO/4o`00017oWMSl00Co0000oiWCo?nIdocoVM?l1Ol0000:oi?Ao@03o`00
0?n:b?coR/Sl00[oR/Sl00Co0000oh[8o?n:b?co00003_mg^_/00ol0003o@iGaod>El@09od>El@03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
3?ooool5o`0000coN=7o0_l00005oh;Go`?o00000on2eol5o`0000CoQ=So0_l0000>ohgLo`Co0000
1?n>g?l2o`0000goU]on0ol00008oiKOoP?o00001_nMh_d3o`0000koWN;m0_l000001?nSi?co0000
o`000?l0000Aoj;So0?o00003onUi?/2o`0000SoY>?l00?o0000ojSTnonXi?/01?nXi?/2o`0000oo
Y^?k00?o0000ojWSn_l000000_l0000AojORn`?o00003onVh?/3o`0000?oXmol00?o0000oj?MnonS
gO/02_nSgO/4o`0000CoWmcl00?o0000oigHo?nMf?`03OnMf?`5o`00013oTm7m00?o0000oh[8o?n:
b?`02On:b?`01Ol0003oR/Sloh[8o?n:b?co000000koMk[k00?o0000od>ElOm3UO402Om3UO400ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Sooooo0003ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool09oooool01?l0003oooooo`000?l0001Hooooo`03o`000?oooooooooo
00Kooooo1Ol0000CogSAo`Go000000?oP]Ooo`000?l000000ol0000;ohCHo`?o00002?n=g?l3o`00
00[oS]co0ol00007oiKOoP?o00003_nFgoh2o`000004oigRoOl0003o0000o`0001;oWN;m0ol0000@
oj;So0?o00000onQho`2o`0000[oYNCk0ol0000;ojCSo0;o000000CoZ>Cko`000?l0003o00004OnV
ho/3o`00013oYn;k0ol00003ojCQo0;o00002_nVh?/3o`0000OoXmol0_l00007oj?Mn`?o00002OnO
g?`00ol0003oWMSloigHo009oigHo0?o00001?nHe_d00ol0003oTm7moi?Ao@0?oi?Ao@03o`000?n:
b?coR/Sl00KoR/Sl6Ol00009od>El@03o`000?oooooooooo02?ooooo0_l0000Yooooo`001?ooool0
0ol0003oooooooooo`02ooooo`?o00009oooool2o`0005_ooooo2?l00005ofg;oP?o00003omhdOl7
o`0001?oQ=So0_l00002ohgLo`Co00004?n>g?l2o`0000;oU]on0ol0000BoiKOoP?o00004OnMh_d3
o`0000?oW>;m0_l0000;oj;So0?o00002?nQho`2o`0000KoYNCk0_l0000?ojCSo0?o00004?nVho/3
o`0000?oY>?l0_l0000;ojORn`?o00002?nThO`00ol0003oY^3kojKPn`04ojKPn`?o00003?nSgo`0
0ol0003oXmgkoj?Mn`04o`0000goWmcl00?o0000oigHo?nMf?`01?nMf?`4o`0000SoV=Km0_l0000>
oi?Ao@[o00001?n2aOd01Ol0003oP/Gmoh;5oOn2aOgo000000goKKGk00?o0000ocB;kOldRnd00ol0
0007od>El@03o`000?oooooooooo027ooooo00?o0000ooooool00000:Oooool000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Woooooa?o0000@?ooool;o`0000ooKL_n0_l0000:
ogSAo`Go00001?mkd_l2o`0001;oQ=So1?l0000DohkLo`Co00004_nFgoh3o`0000?oU]on0_l0000<
oigRo@?o00002?nLh_d2o`0000KoX^?l0ol0000=oj7So0;o000000CoYNCko`000?l0003o00003_nT
ho`3o`0000?oXn?l0_l0000;ojKSn`?o00002?nTho`00ol0003oYn;kojORn`05ojORn`?o00003?nT
hO`2o`000004ojKPnol0003o0000o`0000ooXmol0ol0000BoioLo003o`000?nMf?coWMSl00?o0000
3_nHe_d00ol0003oTm7moi?Ao@06oi?Ao@Go00000on=c_h00ol0003oP/Gmoh;5o@09oh;5o@05o`00
0?n2aOgoP/Gmoh;5oOl000003Om]]O/00ol0003o=8_]ocB;k@02ocB;k@?o00001?m3UO400ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00007?ooool2o`0000Sooooo00?o0000ooooool000002omZ[_P00ol0003o
Dj[ioe>Zn@02oe>ZnA[o00003?oooolJo`0000WoI<Gm0ol0000@ofg;oP?o00000_mhdOl5o`0000_o
Nm;o0_l0000=ohCHo`?o00001?n6f?l3o`0000koS]co0ol00004ohoLoP;o00003OnFgoh3o`0000So
U]on0_l00007oigRo@?o00003OnLh_d2o`000004oj;So?l0003o0000o`00017oXN?l0ol0000>ojCS
o0;o00002?nSho`2o`0000KoY^?k0ol0000<ojCSo0;o00000_nWh_/3o`00013oY>7l0ol0000>oj?O
o0?o00000onOg_`00ol0003oWmcloioLo00>oioLo0Co00004_nHe_d00ol0003oTm7moi?Ao@05o`00
00WoSLkn00?o0000oh;5oOn2aOd02?n2aOd00ol0003oP/Gmoh;5o@02oh;5o@03o`000?m]]O_oKKGk
00_oKKGk00?o0000ocB;kOldRnd01?ldRnd3o`0000;o@iGa00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Vooooo`002?ooool5o`0001_ooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0000;ofZ^n0;o00002OmCZ_T2o`0000_oCJci0_l00004odjanPco00002?mC]o/2
o`0000_oFkkl0_l0000?ofC5o@;o00003_m]boh7o`00013oNm;o0_l00007ohCHo`Co00002_n6f?l2
o`0000SoS]co1?l00009ohoLoP?o00001onFgoh3o`0000goU]on0_l00002oigRo@?o00004OnLh_d3
o`00013oXN?l0ol00003oj3So0;o00002_nTho`2o`0000coXn?l0_l000001?nVho_o0000o`000?l0
000@ojCSo0?o00004?nThO`3o`0000?oX^7l00?o0000oj?Oo?nSgo`02?nSgo`3o`0000OoWmkl0_l0
000;oioLo0?o00001?nKf_d00ol0003oV=KmoiSFo@0>oiSFo@Co00003on=c_h00ol0003oP/Gmoh;5
o@08oh;5o@03o`000?n2aOgoP/Gm00;oP/Gm00?o0000offenom]]O/02om]]O/00ol0003o=8_]ocB;
k@06ocB;k@Co00009Oooool00ol0003oooooooooo`0Uooooo`00:?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000003?mZ[_P00ol0003oDj[ioe>Zn@08oe>Zn@;o0000
2om=[?T00ol0003oC[7jodjanP08odjanP;o00003OmC]o/00ol0003oFkkloe^no00:oe^no0?o0000
3_mTaOd3o`0000CoKL_n1ol00002og;=o`;o000000CoL/goo`000?l0003o00004Omkd_l2o`0000;o
Q=So0ol0000@ohKHo`?o00000_n>g?l3o`00013oSmcn0_l00002oiKOoP?o00004OnFgoh3o`00017o
W>;m0ol00003oicRo@;o00002onQho`3o`0000SoX>?l0_l00005ojCSo0?o00003onSho`3o`0000oo
Y>?l0ol00003oj;Ro0;o00002onThO`3o`0000OoX^7l0_l00005oj?Oo0?o00003?nOg_`00ol0003o
WmcloioLo004oioLo0Co00002?nKf_d2o`0000WoV=Km1Ol00004oi?DoP03o`000?n=c_koSLkn00go
SLkn00?o0000oh;5oOn2aOd02?n2aOd00ol0003oP/Gmoh;5o@02oh;5o@03o`000?m]]O_oKKGk00_o
KKGk00?o0000ocB;kOldRnd02?ldRnd2o`0002Cooooo00?o0000ooooooooool09Oooool002Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`;o00002omZ[_P00ol0003o
Dj[ioe>Zn@09oe>Zn@03o`000?m=[?WoCJci00WoCJci0_l0000:odjanP;o00003?mC]o/2o`0000go
Fkkl0_l0000<ofC5o@Oo00001_mbcOl3o`0000KoL/go0_l0000>og_Bo`Go00005?n6f?l4o`0001?o
Smcn1?l0000AoiKOoP?o00000onGh?h2o`0000coW>;m0ol00008oicRo@;o00001_nQho`3o`0000go
X>?l0_l000000onThoco0000o`00000?oj?So0?o00000onQho`2o`0000[oY>?l0ol00008oj;Ro003
o`000?nThOcoY>7l00GoY>7l0ol0000<oj;Qo003o`000?nSgoco000000;o00004?nOg_`00ol0003o
WmcloioLo003o`0000koVm[m00Co0000oiSFoOnHe_goV=Km1Ol0000:oi?DoP03o`000?n=c_koSLkn
00goSLkn00?o0000oh;5oOn2aOd01_n2aOd@o`0000GoKKGk00?o0000ocB;kOldRnd02?ldRnd00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo000Xooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oJZkhofZ^n009ofZ^n0;o00002_mCZ_T2o`00
00_oCJci0_l0000:odjanP;o00003?mC]o/2o`0000goFkkl0_l00003ofC5o@Oo00001OmYaoh2o`00
00?oL/go0ol0000;og;=o`?o00001?mkd_l7o`0000GoO]Co0ol0000>ohKHo`?o00001?n8fOl2o`00
00koSmcn0ol00004oi3MoP;o00003?nFgoh3o`0000SoUn3n0ol00006oicRo@?o00003OnLh_d2o`00
0004oj7So?l0003o0000o`00017oX>?l0ol0000=oj?So0?o00002?nQho`00ol0003oY>?lojCSo004
ojCSo0?o00003?nRh_`2o`0000;oY>7l0ol0000?oj;Qo0?o00004OnOg_`4o`00013oVm[m1Ol0000@
oi?DoP03o`000?n=c_koSLkn00[oSLkn2ol00002og_1o@03o`000?mk`OgoNl7m00;oNl7m00?o0000
of>_n_mS[oX01_mS[oX8o`0000Wo=8_]00?o0000ooooooooool08oooool00ol0003oooooooooo`0S
ooooo`00:?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo00?o0000
ofZ^n?mZ[_P02_mZ[_P00ol0003oDj[ioe>Zn@09oe>Zn@;o00002om=[?T00ol0003oC[7jodjanP09
odjanP;o00003?mC]o/00ol0003oFkkloe^no005oe^no0[o00003_mYaoh3o`0000ooL/go1_l0000?
ogkDo`;o00002?n6f?l4o`0000WoR=Wo0ol00007ohoLoPCo00002On@gOh3o`0000KoU]on0ol0000>
oiOPoP;o000000CoW>;mo`000?l0003o00004OnLh_d3o`00013oX>?l0ol00003oioRo0?o00001onS
ho`3o`0000coXN?l0_l000001?nThoco0000o`000?l0000@oj;Ro0?o00003onRhO`3o`0000?oWn3m
0_l0000<oioNo0?o00001?nLgOd00ol0003oVm[moi_Jo@0:oi_Jo@?o00001?nGfOh00ol0003oTmCn
oi?DoP0?oi?DoP03o`000?n=c_koSLkn00;oSLkn1ol00004ohO<oP03o`000?mk`OgoNl7m00OoNl7m
00?o0000og_1oOmk`Od00_mk`Od00ol0003oHjojof>_nP0;of>_nP03o`000?lUPNSo000000;o0000
1oldRnd00ol0003oooooooooo`0Rooooo`;o00009?ooool002Wooooo0_l00007ooooo`;o00002?oo
ool00ol0003oJZkhofZ^n004ofZ^n43o00002OmR`_d3o`0000WoJLOn0ol00002ofW7oP;o00002Omb
cOl5o`0000CoM/oo0_l0000AogkDo`?o00000_n6f?l3o`00013oR=Wo0_l00002ohoLoP?o00004?n@
gOh2o`000004oiKOo_l0003o0000o`0001;oUn3n0ol0000@oicRo@?o00000onLh_d2o`0000_oX>?l
0ol00009oioRo0?o000000CoXn?lo`000?l0003o00004?nQho`3o`0000ooX^;l0ol00003oj3Qo0;o
00002_nRhO`3o`0000SoWn3m00?o0000oioNo?nOg_`01OnOg_`4o`0000SoW=gm0_l00006oi_Jo@Co
00002?nGfOh00ol0003oTmCnoi?DoP0=oi?DoPKo00003?n7c?h00ol0003oNl7mog_1o@07og_1o@03
o`000?mk`OgoNl7m00;oNl7m00?o0000of>_n_mS[oX02omS[oX01?l0003o9H7XobF1j?lUPNP3o`00
00Go=8_]00?o0000ooooooooool08?ooool00ol0003oooooo`00000Tooooo`00<_ooool00ol0003o
ooooooooo`08ooooo`Ko00002?mk]OP00ol0003oHk;kof>bn`0:of>bn`;o00002_mK/o/2o`0000_o
F[Ol0_l0000;oeflo@;o00003omR`_d2o`0000CoJLOn0ol00007ofW7oP;o00000_mbcOl5o`0000_o
M/oo0_l0000@ogkDo`Co00004on8fOl4o`0001?oT=gn1?l0000AoiOPoP?o00000onGh?h2o`0000_o
W>;m0ol00008oicRo@;o00001_nPho`3o`0000koWn;l0ol0000?oj7So0?o00000onPh_`2o`0000[o
X^;l0ol00008oj3Qo003o`000?nRhOcoX^7l00CoX^7l0ol0000<oioPo@;o00000_nOg_`3o`0000ko
W=gm00?o0000oi_JoOnKf_d00ol0000=oiOIoP03o`000?nCe?koTmCn00OoTmCn1Ol00003ohkBoP03
o`000?n7c?koQlcn00goQlcn00?o0000og_1oOmk`Od01_mk`Od00ol0003oNl7mog_1o@03og_1o@03
o`000?mS[o[oHjoj00_oHjoj00?o0000obF1j?lUPNP00olUPNP2o`0000?o=8_]00?o0000oooooooo
ool08oooool00ol0003oooooooooo`08ooooo`?o00000oooool3o`0000Cooooo0_l00004ooooo`;o
00001?ooool003;ooooo00?o0000ooooooooool02_ooool00ol0003oNkGhog^en00:og^en0;o0000
3?mS/_/00ol0003oFk?koe^cn`09oe^cn`;o00002omJ]o`2o`0000_oGKcm0_l0000?of;2o@Co0000
1_mYaoh8o`0001;oM/oo0_l00009ogkDo`Go00001?n1eOl2o`0000koR=Wo0ol00004oh[Jo`;o0000
3_n@gOh3o`0000CoTMgn0_l0000<oiOPoP?o00002?nGh?h2o`0000KoW>;m0ol0000=oicRo@;o0000
00CoX>?lo`000?l0003o00003_nOh_`3o`0000?oW^;m0_l0000:oj7So0?o00002?nPh_`00ol0003o
X^;loj;Ro004oj;Ro0?o00003?nPhO`2o`000004oj;Qo?l0003o0000o`00013oWn3m0ol0000@oicM
o@Co00004OnGfOh01?l0003oTmCnoi?Do_nCe?h5o`0000WoS];n00?o0000ohO<o_n7c?h03On7c?h0
0ol0003oNl7mog_1o@06og_1o@03o`000?mk`OgoNl7m00?oNl7m00?o0000of>_n_mS[oX02omS[oX0
0ol0003o9H7XobF1j004obF1j0?o000000?o=8_]o`000?ooool08oooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00Oooool003;ooooo00?o0000ooooooooool0
2oooool00ol0003oNkGhog^en00;og^en003o`000?mS/__oHk;k00[oHk;k0_l0000;oe^cn`03o`00
0?mJ]ocoF[Ol00[oF[Ol0_l0000;oeflo@;o00002omR`_d<o`0000SoKl[o0ol0000AogK?o`;o0000
0_mne?l5o`0000_oPMGo0ol00007ohSIo`Co00002On:f_l3o`0000OoT=gn1?l00009oi7MoP?o0000
1_nGh?h3o`0000goUn3n0_l000001?nLh_go0000o`000?l0000@oicRo@Co00003OnOh_`3o`0000So
W^;m00?o0000oj7So?nQho`01?nQho`3o`0000coX>;l0_l000001?nRh_co0000o`000?l0000?oj3Q
o0Co00003onOh?d3o`0000?oW=om00?o0000oicMoOnLgOd02_nLgOd3o`0000CoVMcn00?o0000oiOI
o_nGfOh03OnGfOh5o`0000ooS];n00?o0000ohO<o_n7c?h03On7c?h00ol0003oNl7mog_1o@05og_1
o@co00002?mS[oX00ol0003o9H7XobF1j007obF1j0?o00009?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo007ooooo000aooooo`03o`000?oooooooooo00gooooo00?o0000
og^en?mk]OP02omk]OP00ol0003oHk;kof>bn`0;of>bn`;o00002_mK/o/2o`0000coF[Ol0_l0000;
oeflo@;o00001?mR`_d7o`0000GoJLGn0_l0000>ofo:o`;o00003_mfcol5o`0001?oPMGo0_l00002
ohSIo`?o00004?n:f_l2o`0000;oT=gn0ol0000@oi7MoP;o000000CoUn3no`000?l0003o00004?nG
h?h4o`0000ooW>;m0ol00004oi_Ro@?o00001onOh_`3o`0000coW^;m0_l000001?nQhoco0000o`00
0?l0000@oj3Ro0?o00003_nPhO`3o`0000CoW^7m0_l0000:oioPo@?o00001onLgod2o`0000KoW=gm
1?l00008oiWLoP;o00002?nGfOh5o`0000CoT]On00?o0000ohkBo_n>d_h03_n>d_h00ol0003oQlcn
ohO<oP06ohO<oPko00000_mb_Od00ol0003oL[gmog:mo@03og:mo@04o`000?mIZOSoFJWhoeVYn0Oo
00000_mS[oX00ol0003o9H7XobF1j009obF1j003o`000?oooooooooo02;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`01ooooo`00<Oooool00ol0003oooooooooo`0>oooo
o`;o00003?mk]OP2o`0000goHk;k00?o0000oe^cnomK/o/02OmK/o/2o`0000KoF[Ol6_l0000;ofW5
oP;o00003_m_b_l3o`0000CoM/oo1ol00005og[Ao`;o00004On1eOl5o`0001;oR][o1?l0000Coi7M
oPCo00003onGh?h3o`0000CoUn3n0ol00008oicRo@Co00002_nKh_d3o`000004oioRo?l0003o0000
o`00013oW^;m0ol0000?oj3Ro0?o00000onNh_d3o`0000OoX>7l1?l00009oikQo@03o`000?nOh?go
Wn3m00CoWn3m0ol0000<oicOo@03o`000?nLgOgoW=gm00?o00003_nIg?h00ol0003oUmWnoiOIoP05
o`0000[oT]On00?o0000ohkBo_n>d_h03?n>d_h:o`0000SoP<Sn00?o0000og:moOmb_Od01Omb_Od0
0ol0003oL[gmog:mo@04og:mo@03o`000?mIZOSoFJWh00OoFJWh1Ol00009obF1j003o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool4o`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`00<Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?mk]OSoNkGh00_oNkGh00?o0000of>bnomS/_/01OmS/_/Io`0000SoI;cm
0_l0000:ofK1oP?o00004?mYaOh2o`0000coKl[o1ol0000>og[Ao`?o00002On1eOl5o`0000GoQ=Ko
0ol0000:oh[Jo`Go00001?n<f_l2o`0000koTMgn0ol00004oi;NoP?o00002?nGh?h4o`0000[oUn3n
0ol00002oicRo@?o00004?nKh_d3o`0000ooW^;m0ol00003oigRo@;o00002_nPh_`3o`0000WoW^;m
0_l00002oj3Qo0?o00003_nNhOd2o`000004oioPoOl0003o0000o`0000koW=om1?l0000@oiWLoPCo
00004?nBeoh00ol0003oS];nohkBoP06ohkBoPGo00001?n9d?l00ol0003oP<Snoh38oP0<oh38oP03
o`000?mb_OgoL[gm00GoL[gm00?o0000og:moOmb_Od01?mb_Od00ol0003oFJWhoeVYn009oeVYn004
o`000?lFM^?o0000o`0000So9H7X00?o0000ooooooooool08_ooool00ol0003oooooooooo`05oooo
o`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool0037ooooo00?o0000ooooooooool04Oooool00ol0003oNkGhog^en008
og^en0[o00002?ma^?/00ol0003oIkWmofNio@0:ofNio@03o`000?mT_?goI;cm00_oI;cm00?o0000
ofK1o_mV`Oh01?mV`Oh3o`0000?oI/7n0_l0000@ofW5oP;o00000om_b_l7o`0000GoMLgo0ol0000@
og[Ao`;o00000_n1eOl5o`0000goQ=Ko0ol00002oh[Jo`Go00002on<f_l3o`0000OoTMgn1?l0000:
oi;NoP?o00000_nGh?h3o`00013oUn3n0ol0000@oi_Ro@?o00000onKhOd2o`0000[oW^;m0ol00008
oigRo@;o00001_nPh_`2o`0000goW^;m0ol0000AoikQo@Co00003OnLgod3o`0000CoV]kn0_l0000;
oiWLoP?o00001?nEf_h00ol0003oT]Onoi;GoP0>oi;GoP03o`000?n>d_koS];n00Go00002_n9d?l0
0ol0003oP<Snoh38oP0<oh38oP03o`000?mb_OgoL[gm00GoL[gm00?o0000og:moOmb_Od01?mb_Od0
0ol0003oFJWhoeVYn009oeVYn003o`000?lFM^?o5WKS00?o00001_lUPNP00ol0003oooooooooo`0P
ooooo`?o00001oooool01?l0003oooooooooooooool5o`0000?ooooo0_l00004ooooo`;o00001?oo
ool0037ooooo00?o0000ooooooooool04_ooool01?l0003oNkGhog^en?mk]OP6o`0000GoR[_f00?o
0000og6hnoma^?/02oma^?/2o`0000_oIkWm0_l0000<ofBlo@;o000000CoI/7no`000?l0003o0000
2?mV`Oh2o`0000goJLGn1_l0000?ogG=o`;o00003OmjdOl5o`0001?oQ=Ko1?l0000CohcJo`;o0000
0_nAgOh3o`0000ooT]kn1?l0000@oiOPoP?o00000onHh?h2o`0000_oVn;m0ol00008oi_Qo@03o`00
0?nNh_goW^;m00CoW^;m0ol0000=oigRo@;o000000CoX>;lo`000?l0003o00003?nNh_d3o`0000?o
WN7m0_l0000<oikQo@?o00001?nLh?d3o`0000OoW=om0ol00009oi[NoP03o`000?nIg?koVMcn00Go
VMcn0ol00008oiGJoP;o00003OnBeoh4o`00013oRM3o00?o0000oh38o_n0b?h03?n0b?h00ol0003o
L[gmog:mo@05og:mo@03o`000?mb_OgoL[gm00CoL[gm00?o0000oeVYn?mIZOP02OmIZOP00ol0003o
5WKSoaIfh`02oaIfh`;o00001?lUPNP00ol0003oooooooooo`0Mooooo`Co000000?oooooo`000?oo
ool07_ooool0037ooooo0_l0000Dooooo`?o00003?n:^oH2o`0000goLKSk00?o0000ofNioOmW^Od0
2_mW^Od00ol0003oI;cmofBlo@09ofBlo@Co00003?mV`Oh2o`0000CoJLGn1ol00005og38o`;o0000
4?mecOl3o`0000?oN]7o1ol00005ogkCo`;o00003_n4e_l3o`0000CoQmSo0_l0000AohcJo`Co0000
3onBg_h3o`0000CoTmkn0_l0000;oiOPoP?o00002?nHh?h2o`0000KoVn;m0ol0000<oi_Qo@;o0000
00CoW^;mo`000?l0003o00004?nMh_d4o`0000_oW^;m0ol00008oigQo@03o`000?nNhOgoW^7m00Go
W^7m1?l0000:oicPo@;o00000_nLgod3o`0000goV]kn0_l00002oiWLoP?o00003OnEf_h00ol0003o
T]Onoi;GoP05oi;GoPGo00001?n>eOl00ol0003oRM3oohW@o`0>ohW@o`03o`000?n0b?koP<Sn00Go
P<Sn6_l00008oeVYn003o`000?lFM^?o5WKS00?o5WKS0_l00003obF1j003o`000?oooooooooo01Wo
oooo0ol00005ooooo`03o`000?oooooooooo01gooooo000`ooooo`03o`000?oooooooooo01Kooooo
00?o0000ohZkm_n:^oH03?n:^oH00ol0003oLKSkog6hn`0;og6hn`03o`000?mW^OgoIkWm00[oIkWm
0_l00006ofBlo@?o00001?mT_?d00ol0003oI/7nofK1oP05ofK1oP[o00003_m`b?l3o`0000goMLgo
1_l0000>ogkCo`?o00001on4e_l4o`0000WoQmSo0ol00009ohcJo`Go00001?n>fol3o`0000SoT]kn
1?l00009oi?NoP;o00001_nGh?h3o`0000goV>3n0_l000001?nKh_go0000o`000?l0000?oi_Qo@Co
00003onMh_d3o`0000CoW>;m0ol00006oikRo@;o00003?nMhOd2o`0000;oW^7m0ol0000?oicPo@?o
00004?nJg_h4o`00017oUM[n00?o0000oi;Go_nBeoh01?l0000:ohkEo`;o00003?n9d?l:o`0000Wo
N/Gn00?o0000ofZho?mZ^?`00omZ^?`00ol0003oJ[SlofZho005ofZho003o`000?m>X_KoCZ;f00Go
00001?mIZOP00ol0003o5WKSoaIfh`04oaIfh`Co00005oooool4o`0000Sooooo00?o0000oooooooo
ool07Oooool0033ooooo00?o0000ooooooooool05oooool00ol0003oR[_fohZkmP0<ohZkmP03o`00
0?ma^?_oLKSk00_oLKSk0_l0000<ofNio@03o`000?mT_?goI;cm00?o00000_mT_?d=o`0000SoK/Co
0ol0000@og38o`;o00001?mecOl7o`0000GoN/oo0_l0000@ogkCo`;o00000_n4e_l3o`00013oQmSo
0_l00002ohcJo`Go00003?n>fol3o`0000;oT]kn0ol0000?oi?NoP;o000000CoUn3no`000?l0003o
00004?nHh?h4o`0000koVn7m0ol00004oi_Qo@?o00002?nMh_d4o`0000[oW>;m0_l000001?nNh_go
0000o`000?l0000>oigQo@Co00003onLh?d3o`0000?oV]om00?o0000oi[No_nJg_h02_nJg_h3o`00
00CoUmgn00?o0000oiGJo_nEf_h03OnEf_h4o`00013oS]Go00?o0000ohW@oon9d?l00_n9d?l7o`00
00GoPlgo00?o0000og[5o_mjaOh03?mjaOh00ol0003oJ[SlofZho003ofZho003o`000?mZ^?coJ[Sl
00GoJ[Sl00?o0000odjRm_m>X_H01?m>X_H6o`0000So5WKS0_l0000Cooooo`?o00003?ooool00ol0
003oooooooooo`0Mooooo`00<?ooool00ol0003oooooooooo`0Hooooo`03o`000?n:^oKoR[_f00co
R[_f0_l0000=og6hn`03o`000?mW^OgoIkWm00CoIkWm3Ol00008ofo1oP;o00003_m^a?l2o`0000go
L<So1ol0000>og[?o`?o00003?mndol5o`0001?oQmSo1?l0000BohkKo`Co00004_nCg_h4o`0000oo
V>3n0ol00004oiSPoP?o00002?nKhOd3o`0000[oVn7m0ol00002oigRo@?o00003onLh_d3o`0000go
WN7m0ol00004oi_Qo@;o00002_nLh?d3o`0000OoV]om0_l00006oi[NoPCo00002?nGgOh2o`0000So
UM[n1Ol00004oi7Io`03o`000?n>eOooS]Go00coS]Go1_l0000=oh?=o`03o`000?mjaOkoN/Gn00co
N/Gn00?o0000ofZho?mZ^?`00_mZ^?`00ol0003oJ[SlofZho006ofZho003o`000?m>X_KoCZ;f00So
CZ;f0ol00008oaIfh`03o`000?oooooooooo00gooooo0ol0000@ooooo`03o`000?oooooooooo01co
oooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0000>ohZkmP03o`000?ma^?_oLKSk00GoLKSk
3?l00003og>no@;o00000omc__d2o`0000goKl7n0_l0000>ofk4o`?o00000om`b?l7o`0000GoMl_o
0_l0000Aog[?o`;o00000omndol7o`0000GoP]Co0_l0000>ohOHo`?o00001?n9fOl2o`0000goS]_o
0ol00004ohoLo`;o00003OnCg_h3o`0000CoU=kn0ol00008oiSPoPCo00002_nHh?h3o`0000;oVn7m
0ol0000?oi_Qo@?o00003onLh_d3o`0000?oVn7m0ol00007oigQo@?o00002OnKhOd00ol0003oW>3m
oicPo@04oicPo@?o00003?nJgod00ol0003oV]knoi[NoP03o`0000koUmgn00?o0000oiGJo_nEf_h0
1Ol0000:oi7Io`03o`000?n>eOooS]Go00KoS]Go1Ol00004ohWCo`03o`000?n3cOooPlgo00goPlgo
00?o0000og[5o_mjaOh03?mjaOh00ol0003oJ[SlofZho002ofZho003o`000?mZ^?coJ[Sl00KoJ[Sl
00?o0000odjRm_m>X_H02Om>X_H3o`0000Ko5WKS00?o0000ooooooooool02Oooool4o`0001?ooooo
00?o0000ooooooooool07?ooool0033ooooo00?o0000ooooooooool06oooool00ol0003oR[_fohZk
mP0:ohZkmPWo00002?mn_O/01?l0003oLkkmog>noOmc__d3o`0000OoLkkm0_l0000=ofo1oP;o0000
3?m^a?l6o`0000koMl_o0_l0000?og[?o`Go00003_n2e?l3o`0000OoQmSo1?l00009ohWIo`?o0000
1on>fol3o`0000WoSmco0ol00007oi?NoP?o00002_nDg_h3o`0000;oV>3n0ol0000@oiSPoP?o0000
3onKhOd3o`0000?oV^7m0_l0000:oicRo@?o00002OnKhOd2o`0000;oWN7m0ol0000=oi_Qo@;o0000
00CoW>3mo`000?l0003o00003_nJgod4o`00013oUmgn1?l0000@oi7Io`03o`000?n>eOooS]Go00Go
00002_n9dol00ol0003oPlgooh?=o`0=oh?=o`03o`000?mjaOkoN/Gn00GoN/Gn4?l00005ofZho003
o`000?m>X_KoCZ;f00WoCZ;f00Co0000o`M[g?l0003o00001OlFM^<00ol0003oooooooooo`05oooo
o`?o00005oooool00ol0003oooooooooo`0Looooo`00<?ooool00ol0003oooooooooo`0Looooo`03
o`000?n:^oKoR[_f00GoR[_f1?l00004oiNol`03o`000?mn_O_oO[gk00_oO[gk0ol0000<og>no@;o
00003Om_`Oh2o`0000?oK/Co1ol00005ogK8o`;o00003omgbol00ol0003oN/ooog[?o`07og[?o`Go
00001?modOl2o`00013oP]Co0_l00002ohOHo`?o00004?n9fOl2o`0000;oS]_o0ol0000?ohoLo`;o
00000_nCg_h3o`0000koU=kn1?l0000@oiSPoP?o00000onHh?d2o`0000[oVn7m0ol00008oi[Qo@03
o`000?nLh_goW>;m00CoW>;m0ol0000=oi_Qo@?o00004?nKhOd4o`0000goV]om0ol00004oiSNoP03
o`000?nGgOkoUmgn00[oUmgn0ol00004oiCLoP03o`000?nAfOooTMWo00coTMWo1?l0000@ohWCo`03
o`000?n3cOooPlgo00[oPlgo2_l00007og;1oP03o`000?mQ/o_oHK?k00?oHK?k00?o0000of6cnomQ
/o/02_l00008odjRmP03o`000?l7Jmco1f_L00;o00001?lFM^<01?l0003oooooooooooooool3o`00
01[ooooo00?o0000ooooooooool07?ooool0033ooooo00?o0000ooooooooool07Oooool00ol0003o
R[_fohZkmP04o`0000WoUkoc0_l00008ogjmn`?o00000_mn_O/00ol0003oLkkmog>no@0<og>no@;o
00001om_`Oh9o`0000koM/So0_l0000>ogO;o`;o00000_mjcol5o`0000_oOm7o0_l0000>oh;Do`Go
00004_n9fOl4o`0001;oSmco1?l0000>oiCNoP?o00001?nEgoh2o`0000_oV>3n0ol00008oiSPo@03
o`000?nKhOgoVn7m00CoVn7m0ol0000<oi[Qo@;o000000CoW>;mo`000?l0003o00003OnKhOd3o`00
00?oV^7m00?o0000oi_QoOnKhOd02_nKhOd3o`0000CoV^3m0_l00007oi[Oo@Co00002?nHg_h2o`00
00KoUmgn1?l00008oiCLoP;o00001onAfOl5o`0000CoS]Oo00?o0000ohWCoon9dol03_n9dol00ol0
003oPlgooh?=o`02oh?=o`Oo00001?mmbol00ol0003oL/7nog;1oP0;og;1oP03o`000?mQ/o_oHK?k
00;oHK?k00?o0000of6cnomQ/o/01_mQ/o/01?l0003o@Y_dod:Km?m2Vo@5o`0000CoCZ;f00Co0000
o`M[g?l7Jmco1f_L0_l00003oaIfh`?o00007Oooool00ol0003oooooooooo`0Looooo`00;oooool0
0ol0003oooooooooo`0Oooooo`;o00003onG_o<00ol0003oO[gkogjmn`02ogjmn`?o00001_mn_O/2
o`0000_oLkkm2_l00008ogS5oP;o00003omfb?l00ol0003oMl_oogO;o`0:ogO;o`Go00004_modOl0
0ol0003oP]Cooh;Do`06oh;Do`Go00001On6e_l3o`0000[oRMWo1Ol00004ohcJo`;o00003On?g?l3
o`0000CoTMcn0ol00008oiCNoP?o00002OnEgoh2o`0000KoV>3n0ol0000<oiSPo@;o000000CoVn7m
o`000?l0003o00003onJhOd4o`0000coVn7m0ol00007oi[Qo@;o00001_nKhOd4o`0000WoV^3m0_l0
0002oi[Oo@?o00003_nHg_h00ol0003oUmgnoiOMoP03o`0000koU=cn00?o0000oi7IoonAfOl01?l0
000:ohkGo`;o00003?n9dol7o`0000coOL_o00?o0000og;1o_mb`Oh02omb`Oh00ol0003oHK?kof6c
n`02of6cn`03o`000?mQ/o_oHK?k00KoHK?k00?o0000od:Km?m2Vo@01Om2Vo@6o`0000Co1f_L0_l0
00000olFM^?o0000ooooo`0Nooooo`03o`000?oooooooooo01cooooo000_ooooo`?o00008Oooool0
0ol0003oUkocoiNol`0=oiNol`Co00002omn_O/01?l0003oLkkmog>noOmc__d7o`0000GoO/?m0_l0
000=ogS5oP;o00003_mfb?l2o`0000?oMl_o1ol00005ogg>o`?o00004?modOl2o`0000;oP]Co1?l0
000=ohKFo`?o00000_n9fOl5o`0000_oS=[o0_l00007ohoLo`Co00002_nAg?h3o`0000;oU=kn0ol0
000>oiGOoP;o000000CoV>3no`000?l0003o00003onHh?d4o`0000koV^7m0ol00004oi[Qo@?o0000
1_nKhOd3o`0000coV^7m00?o0000oi_QoOnKhOd00ol0000=oi[Po@Co00004?nHg_h4o`00013oU=cn
1?l0000@ohkGo`03o`000?n9doooRM?o00;oRM?o1ol00005ohGAo`03o`000?mmboooOL_o00coOL_o
00?o0000og;1o_mb`Oh02omb`Oh00ol0003oHK?kof6cn`02of6cn`03o`000?mQ/o_oHK?k00KoHK?k
00?o0000od:Km?m2Vo@02Om2Vo@3o`0000Co1f_L0ol0000Nooooo`03o`000?oooooooooo01cooooo
000_ooooo`03o`000?oooooooooo02;ooooo00?o0000oiNolonG_o<02_nG_o<5o`0000[oO[gk1_l0
000>ogk3o@03o`000?mhaOkoN<Gn00coN<Gn00?o0000ogK8oomfb?l02_mfb?l6o`0000ooOLko0_l0
000=ogoAo`Go00004_n6e_l4o`0001;oS=[o0_l00002ohoLo`?o00003onAg?h4o`00017oUMon1?l0
000>oiSPo@?o00001?nIh?d3o`0000SoV^7m0ol0000:oi[Qo@;o000000CoVn7mo`000?l0003o0000
3_nJhOd4o`0000goV^3m0ol00004oiSOoP?o00002?nHg_h5o`0000CoUMkn0_l00009oiCLoPGo0000
1?nAfol00ol0003oS]OoohkGo`0<ohkGo`Ko00003On5dOl2o`0000goOL_o00?o0000og;1o_mb`Oh0
2omb`Oh00ol0003oHK?kof6cn`02of6cn`03o`000?mQ/o_oHK?k00KoHK?k00?o0000od:Km?m2Vo@0
2Om2Vo@01?l0003o063Fo`000?l00004o`M[g0;o00007_ooool00ol0003oooooooooo`0Kooooo`00
;oooool00ol0003oooooooooo`0Sooooo`03o`000?nG_o?oUkoc00KoUkoc0ol00005oiNol`04o`00
0?mn_O_oO[gkogjmn`Ko00001On9`_X2o`0000koO/?m0_l0000=ogS5oP;o00000omfb?l7o`0000Go
OL_o0_l0000@ogg>o`?o00000omodOl7o`0000GoQ=?o0_l0000=ohKFo`?o00001?n:eol2o`00013o
S=[o1?l0000?oi7LoP?o00001?nCgOh2o`0000coUMon0ol00004oiKOoP?o00002?nHh?d3o`0000[o
VN3m0ol00002oi[Qo@?o00003OnJhOd4o`0000goV^7m0ol00004oi[Qo@?o00001onJh?d3o`0000[o
V=on0_l00002oiSNoPCo00002onEg_h2o`0000;oU=cn1Ol0000:oi7Ko`;o00001on>eol5o`0000Co
R]Ko00?o0000ohGAoon5dOl03_n5dOl00ol0003oOL_oogg;o`05ogg;oago00001OmQ/o/00ol0003o
@Y_dod:Km009od:Km004o`000?l0H=Ko063Fo`0000Go1f_L00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`00;oooool00ol0003oooooooooo`0Tooooo`03o`000?nG_o?oUkoc00?o
Ukoc0_l00007oiNol`Go00003On9`_X00ol0003oO/?mogk3o@0=ogk3o@;o00002_mhaOh6o`0000ko
OL_o0_l0000?ogg>o`Go00003_n4dol3o`0000OoQ]Ko0ol00009oh[Go`?o00002?n<f_l5o`0000Co
Sm[o0ol00008oi7LoPCo00002OnCgOh2o`0000OoUMon0ol0000:oiKOoP?o00000_nHh?d3o`0000ko
VN3m1?l0000=oi[Qo@?o00001?nJhOd3o`0000OoV^7m0ol0000:oi[Qo@;o00000_nJh?d3o`0000go
V=on1?l0000?oiGNoPCo00004OnAfol00ol0003oS]OoohkGo`04o`0000[oR]Ko0_l0000<ohGAo`[o
00002?mgb?l00ol0003oJkgnof^moP0;of^moP04o`000?mH[_[oF:kjo`0000?oF:kj2Ol00009od:K
m003o`000?l0H=Ko063F00;o00000ol7Jm`00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo000_ooooo`03o`000?oooooooooo02Gooooo00?o0000oiNolol000000_l00006oiNol`?o
00001?nQ`_000ol0003oRL;johW2nP0<ohW2nP;o00003omn`od01?l0003oN<GnogS5o_mhaOh6o`00
00GoPLSn0_l0000?ogg;o`;o00002?mmc_l5o`0000CoPm3o0_l0000@ohCCo`;o00000_n6e_l3o`00
00ooR]Oo0_l00002ohcJo`Co00003?n?f_l3o`0000;oTMcn0ol0000?oi?MoP;o00000_nEgoh3o`00
00koU]on1?l0000>oiWPo@?o00001?nIhOd3o`0000OoV^7m0ol0000:oi[Qo@;o00000_nJhOd3o`00
00goV^7m1?l0000=oiSOoP?o00001?nGgoh00ol0003oUMknoiGNoP09oiGNoP?o00001?nCgOh00ol0
003oTM_ooi7Ko`0=oi7Ko`Co00004?n:e_l00ol0003oQM7oohGAo`02ohGAo`Oo00001On0col00ol0
003oMlSoogO8o`0;ogO8o`;o00003?m[_Oh01?l0003oF:kjoeR^n_l00008oeR^nP03o`000?lgTo7o
=i?a00Co00001_m2Vo@01?l0003o063Fo`1Pe_l0H=H2o`0000;o1f_L00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Kooooo`00;_ooool00ol0003oooooooooo`0Uooooo`?o00001_nG_o<3
o`0000SoXL;`00?o0000ohW2n_n9`_X03On9`_X2o`0000_oO/?m1_l0000=oh78oP;o00003ommbol2
o`0000;oOLko1?l0000;oh?@o`?o00003?n4dol5o`0001;oR]Oo1?l0000AohoJo`Co00004_nCgOh4
o`0000koU]on0ol00004oiOOoP?o00001onIh?d4o`0000[oVN7m0_l00002oi[Qo@?o00003OnJhOd4
o`0000goV^7m0ol00004oiWPo@?o00001onHgoh3o`0000SoUmon0_l00006oiGNoP?o00002?nCgOh2
o`0000SoTM_o1Ol00004ohkIo`;o00003?n:e_l7o`0000goP<oo00?o0000ogO8oomgb?l03?mgb?l0
0ol0003oJkgnof^moP0:of^moP04o`000?mH[_[oF:kjo`0000SoF:kj00?o0000ocNClOlgTo400olg
To43o`0000?o@Y_d00?o0000o`1Pe_l0H=H00ol0H=H2o`000003o`M[g?l0003ooooo01[ooooo00?o
0000ooooooooool06oooool002kooooo00?o0000ooooooooool08_ooool3o`0000?ooooo00?o0000
oiNolonG_o<00ol0000<oj72l0;o00003on9`_X01?l0003oO/?mogk3oOmn`od7o`0000GoQlKl0_l0
000>oh78oP;o00003?mmbol5o`0001;oPm3o0_l00003ohCCo`Oo00001On9e?l3o`0000[oR]Oo1Ol0
0004ohgHo`;o00003?n?f_l3o`0000CoTM_n0_l0000=oi?MoP?o00001?nEg_h3o`0000OoU]on1?l0
000:oiOOoP;o00000_nIh?d3o`0000koVN7m1?l0000=oi[Qo@?o00001?nIhOd3o`0000OoV^7m0ol0
000:oiWPo@;o00000_nHgoh3o`0000goUmon00?o0000oiGNo_nEg_h00ol0000=oi?MoP03o`000?nA
foooTM_o00Go00002on>fOl2o`0000?oR]Ko1ol00005ohKDo`03o`000?n0coooP<oo00goP<oo00?o
0000ogO8oomgb?l01Omgb?l?o`0000GoJkgn00?o0000oeR^n_l000002OmH[_X00ol0003o=i?aocNC
l@05ocNCl@Go00001_l0H=H3o`0001[ooooo00?o0000ooooooooool06oooool002kooooo00?o0000
ooooooooool07oooool3o`0000Oooooo0_l0000Aoj72l003o`000?n9`_[oRL;j00_oRL;j1Ol0000>
ohO6o0;o00003_n1b?h2o`0000?oOL_o1ol00005ohG>o`;o00004?n3d?l5o`0000ooRMCo0ol00002
oh[Go`Go00002on=f?l2o`0000OoSm[o0ol00009oi7KoP;o00001onCgOh4o`0000[oUMkn0_l00002
oiKOoP?o00003_nGgoh4o`0000koVN7m0ol00004oiWQo@?o00001onJhOd3o`0000[oVN7m0_l00002
oi[Qo@?o00003OnIh?d4o`0000ooUmon1?l0000?oi?MoPCo00004?n>fOl5o`0000goQ]Co00?o0000
oh3?oon0col02_n0col:o`0000SoLLGo00?o0000of>ioOmS^Od01?mS^Od;o`0000OoF:kj00?o0000
ocNClOlgTo402?lgTo43o`0000Ko063F0_l0000Iooooo`03o`000?oooooooooo01_ooooo000^oooo
o`;o00007Oooool3o`0000cooooo00?o0000oj72l?nQ`_003onQ`_000ol0003oRL;johW2nP05ohW2
nPGo00001?nCaOP00ol0003oQlKlohO6o00>ohO6o003o`000?n1b?koPLSn00[oPLSn1_l0000>ohG>
o`?o00002?n3d?l5o`0000CoRM;o0_l0000?ohWDo`Co00004_n=f?l2o`0000;oSm[o0ol0000>oi7K
oP;o00000_nCgOh3o`0000koUMkn1?l0000>oiOOoP?o00001?nHh?h3o`0000SoVN7m0ol0000:oiWQ
o@;o00000_nJhOd3o`0000goVN7m1?l0000=oiWPo@?o00001?nHh?h2o`0000SoUmon1Ol00004oiGN
oP;o00002?nCgOh5o`0000CoTMcn0_l00009ohkIo`Go00001?n:f?l00ol0003oQ]CoohKDo`0<ohKD
o`03o`000?n0coooP<oo00;oP<oo1ol00005og_<o`03o`000?maaOooLLGo00_oLLGo00?o0000of>i
oOmS^Od02_mS^Od01?l0003oCjSho`000?m?Z?P7o`000003oeR^n_l0003o=i?a00Wo=i?a00?o0000
o`1Ec_l000001_l0H=H2o`0001Wooooo00?o0000ooooooooool06_ooool002gooooo0_l0000Koooo
o`?o00004?ooool2o`00013oXL;`00?o0000ohW2n_n9`_X01?l0000:oi?5n0;o00003on7a_`2o`00
00?oPLSn1ol00005ohS;oP;o00004?n5c_l2o`0000;oPm3o1?l0000;ohWBo`;o00002?n9e?l5o`00
00CoSMKo0_l0000@ohgHo`Co00004OnAfoh4o`0000koUMkn0ol00004oiONoP?o00002?nGgoh3o`00
00[oV>3n0ol00002oiWQo@?o00003OnIhOd4o`0000goVN7m0ol00004oiWQo@;o00001onIh?d4o`00
00WoV>3n0_l00002oiOOoPCo00002onEg_h2o`0000;oTmgn1?l0000;oi7LoP;o00000_n>fOl5o`00
00[oR]So00?o0000ohKDoon6e?l02On6e?l7o`0000goNlco00?o0000og75oomaaOl02omaaOl00ol0
003oHkWmof>io@0:of>io@;o00002?m?Z?P5o`0000So=i?a00Co0000o`1Ec_l0003o00001_l0H=H0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo000^ooooo`03o`000?oooooooooo
01Kooooo0ol0000Eooooo`03o`000?nQ`_3oXL;`00goXL;`0ol0000@oi?5n003o`000?n7a_coQlKl
00coQlKl1Ol0000>ohS;oP;o00003_n5c_l4o`00017oRM;o0_l00002ohWDo`Co00002on=e_l3o`00
00SoSMSo1Ol00004oi7Jo`?o00002OnAfoh5o`0000CoU=cn0ol00008oiGNoP?o00002_nGg_h3o`00
00;oUmon0ol0000>oiSPoPCo00003OnIhOd3o`0000CoV^7m0ol00007oiWQo@?o00002OnIhOd2o`00
00;oVN3m0ol0000=oiSPoPCo00003onEg_h4o`0000ooTMcn1?l0000@oh[Ho`04o`000?n6e?ooQ]Co
ohKDo`Oo00001On2d_l2o`0000koNlco00?o0000og75oomaaOl02omaaOl00ol0003oHkWmof>io@0:
of>io@;o00002_m?Z?P00ol0003o:hc]o`000003o`0000Go=i?a00?o0000o`1Ec_l0ELh00_l00004
o`1PeP03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool002gooooo00?o0000oooo
ooooool05?ooool3o`0001Wooooo00?o0000oj72l?nQ`_002OnQ`_03o`0000?oZ/C/0_l0000?oi?5
n0;o00001on7a_`5o`0000CoT<Wk00?o0000ohS;o_n8boh03_n8boh00ol0003oQLkoohG>o`06ohG>
o`Go00001?n;d?h2o`0000ooRM;o1?l0000BohgFo`;o00000_n=f?l4o`0000coTM[o0ol00002oi7K
oPCo00003?nDg?h3o`0000;oUMkn0ol0000>oiONoPCo00003_nHh?h3o`0000CoVN3m0ol00007oiWQ
o@?o00002_nJhOd2o`0000;oVN7m0ol0000<oiWQo@Co00003OnHh?h3o`0000CoUn3n00?o0000oiGN
o_nEg_h02OnEg_h3o`0000CoTmkn0_l00008oi7LoPGo00001?n>fol2o`0000coR]So1_l0000>oh;B
o`;o00001omkc?lLo`0000GoHkWm0_l0000:odnXn003o`000?l[S>go:hc]00;o:hc]0ol00003ocNC
l@05o`000?l0ELko05G>o`1Ec_l000001?l0H=H00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01[ooooo000]ooooo`03o`000?oooooooooo01;ooooo0_l0000Mooooo`;o00001_nQ`_03o`00
00SoZ/C/00?o0000oi?5n?nCaOP03_nCaOP00ol0003oQlKlohO6o004o`0000[oT<Wk0_l0000?ohS;
oP;o00000_n5c_l4o`0000_oRm3n0_l00008ohWBo`Go00001?n>e?l2o`00013oSMKo1?l0000Aoi7J
o`Co00004OnDg?h4o`0000koUmkn0ol00004oiSOoP?o00001onHh?h4o`0000[oVN3m0_l00002oiWQ
o@?o00003OnJhOd4o`0000coVN7m0ol00004oiWQo@?o00001onHh?h3o`0000SoUn3n0_l00006oiGN
oP?o00002OnCg_h2o`0000;oTMcn1?l0000;ohkKo`;o00000on:f?l7o`0000GoQmOo0_l0000<oh;B
o`[o00002?meb_l00ol0003oJl7nof_1oP0;of_1oP03o`000?mL]OcoG;Gl00?oG;Gl2ol00007odnX
n003o`000?l[S>go:hc]00Co:hc]1Ol00003o`1EcP;o00000ol0H=H00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01[ooooo000]ooooo`03o`000?oooooooooo00oooooo0ol0000Qooooo`03
o`000?nQ`_3oXL;`00?o00003?nZa>`2o`0000goTlGh1?l0000@oi39n`03o`000?n8bokoR<_n00co
R<_n1?l0000Aoh_@oP;o00000_n9d_l4o`0000_oS]Co0_l0000;ohgFo`?o00001?nAf?h2o`0000co
TM[o0ol00004oiCKoP;o00003?nDg?h3o`0000CoUmgn0ol00008oiONoP?o00002_nHgoh2o`0000;o
V>3n0ol0000?oiWPo@?o00003OnJhOd3o`0000CoV^7m0_l00007oiWQo@?o00002_nIhOd2o`0000;o
V>3n0ol0000=oiOPoP03o`000?nEg_koUMkn00?o00003?nCg_h4o`0000ooS]_o1Ol0000>ohOGo`;o
00000on2d_l7o`0000GoOM3o00?o0000ogG:oomeb_l02omeb_l2o`0000coJl7n00?o0000oebeo?mL
]O`02OmL]O`01?l0003oAJ;fodFRm_m5X_H7o`000003odnXn?l0003o:hc]00So:hc]0ol00003o`1E
cP04o`000?l0H=Ko063Fo`0001Kooooo00?o0000ooooooooool06_ooool002gooooo00?o0000oooo
ooooool03?ooool3o`0002Gooooo0_l0000Aoj[4k0;o00001onCaOP4o`0000CoW<Of00?o0000oi39
non@bO/03_n@bO/2o`0000OoR<_n1Ol00004oi3>o@;o00003on;d?h4o`00017oS]Co00?o0000ohgF
oon=e_l01On=e_l3o`0000WoTMSn0_l00007oi7Jo`?o00002OnDfoh2o`0000OoU=cn0ol0000:oiOM
oP?o00000_nGg_h3o`0000goV=on1?l0000?oiWPo@?o00000onJh?d3o`0000OoV^7m0ol00009oi[Q
o@;o00000_nIhOd3o`0000goVN7m1?l0000?oiOPoPCo00003?nCg_h3o`0000CoTMgn0_l00008ohkK
o`Go00001?n<f_l2o`0000coQmOo1_l0000=ogg@o`03o`000?meb_ooML[o00coML[o00?o0000of_1
o_m[`Oh02_m[`Oh00ol0003oG;Gloebeo009oebeo003o`000?m5X_KoAJ;f00OoAJ;f1?l00008ob^<
k@03o`000?l0BLKo000000?o05G>0_l000000ol0H=Ko0000ooooo`0Dooooo`03o`000?oooooooooo
01[ooooo000]ooooo`03o`000?oooooooooo00Wooooo0ol0000Zooooo`03o`000?nZa>coZ/C/013o
Z/C/00?o0000oi?5n?nCaOP01?l00009oic7mP;o00004?n@bO/00ol0003oR<_nohS;oP04o`0000_o
T<km0ol00008oh_@oPCo00001?nAd_h2o`00013oS]Co0_l00002ohgFo`?o00003_nAf?h2o`0000;o
TM[o0ol0000>oiCKoP;o00000_nDg?h3o`0000koUmgn1?l0000=oiSOoP?o00001?nJgod2o`0000[o
VN3m0ol00009oi[Po@;o00000_nJhOd3o`0000goV^7m0ol0000=oiWQo@?o00001?nHhOd2o`0000So
Un3n1Ol00004oiKOoP;o00001onCg_h3o`0000WoTMgn0_l00002ohkKo`Co00002on<f_l2o`0000?o
QmOo1ol00005ohCEo`03o`000?mmd?ooOM3o00coOM3o00?o0000ogG:oomeb_l01Omeb_lIo`0000Oo
G;Gl00?o0000odFRm_m5X_H02Om5X_H4o`0000Ko:hc]00Co0000o`19a_l0003o00000ol0ELh2o`00
01Kooooo00?o0000ooooooooool06Oooool002gooooo00?o0000ooooooooool01_ooool3o`0002ko
oooo00?o0000oj[4k?nZa>`03onZa>`3o`0000ooW<Of00?o0000oi39non@bO/03?n@bO/4o`0001;o
T<km0_l00002oh_@oPCo00002_nAd_h2o`0000koS]Co1?l0000Aoi7HoPCo00004OnDfoh4o`0000ko
Umgn0ol00004oiWNoP?o00001onHgoh3o`0000WoV]om0_l00006oiWPo@;o00003OnJh?d3o`0000go
V^7m0ol00003oi[Qo@?o00001onIhOd3o`0000WoV>7m0_l00002oiOPoPCo00002onFgoh2o`0000;o
Tmkn0ol0000<oi7MoPCo00003on<f_l5o`0000goQ=Go00?o0000ogg@oommd?l02Ommd?l:o`0000Wo
L<Oo00?o0000ofBmoOmT_Od02OmT_Od01?l0003oDk3joe>`n_mC/?X7o`000003oebeo?l0003oAJ;f
00[oAJ;f00?o0000oan3jOlOPnT00_l00005ob^<k@04o`000?l0BLKo04W6o`0000Co05G>00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Iooooo`00;Oooool3o`0000?ooooo0ol0000boooo
o`03o`000?nZa>coZ/C/00coZ/C/0_l00003ok;5j@03o`000?nLaoKoW<Of00goW<Of0_l00007oi39
n`Go00001?nHc?X2o`00013oT<km1?l0000@oi7BoP03o`000?n>e?ooS]Co00KoS]Co1Ol00004oi?F
oP?o00002OnAf?h5o`0000CoU]Wn0_l0000<oiCKoP?o00001?nGg?h3o`0000SoUmgn0ol0000:oiWN
oP;o00000_nHgoh3o`0000koV]om0_l000001?nIh?go0000o`000?l0000<oi[Po@?o00000onKhOd3
o`0000OoV^7m0ol00009oi[Qo@;o00000_nIhOd3o`0000coV>7m1?l0000?oiKOoPGo00002OnAgOh5
o`0000CoT=gn0_l00008ohcJo`Go00001?n9fOl00ol0003oQ=GoohCEo`0<ohCEo`04o`000?mmd?oo
OM3oogg@o`Oo00001Omic_l00ol0003oL<Ooog37o`0<og37o`03o`000?mT_OgoI;gm00WoI;gm00?o
0000oe>`n_mC/?X01omC/?X6o`0000SoAJ;f00Co0000oan3jOlOPnWo7h?Y0ol00003ob^<k@03o`00
0?l0BLKo04W600;o00000ol0ELh00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo
000/ooooo`;o00000_ooool3o`0003Kooooo00?o0000oj[4k?nZa>`02OnZa>`2o`0000Ko//GY00?o
0000oic7m_nLaoH03_nLaoH00ol0003oT<Wkoi39n`04o`0000_oV<cj0_l0000;oi3>o@?o00001?nG
d?`00ol0003oTM;noi7BoP0>oi7BoP;o00000_n>e?l4o`0000coTmKn0ol00002oi7HoPCo00002onF
fOh2o`0000OoU=_n0ol0000:oiOLoP?o00000_nGgOh3o`0000koVMkn0ol0000Aoi[Oo@Co00002onJ
h?d3o`0000WoVn7m0_l00002oi[Qo@?o00003?nJhOd4o`0000coV>7m0ol00004oiSPo@;o00002?nF
goh5o`0000GoU=on0ol00002oi7MoPCo00002on@gOh2o`0000;oS=[o1?l0000:ohWIo`03o`000?n4
eOooQ=Go00WoQ=Go1_l0000=ogW>o`03o`000?m`aoooL<Oo00coL<Oo00?o0000ofBmoOmT_Od02OmT
_Od00ol0003oDk3joe>`nP08oe>`nP04o`000?mC/?[o0000oc^Lm0Go00001?m5X_H00ol0003o7h?Y
oan3j@03oan3j@;o000000?o:hc]o`000?l0BLH00ol0BLH01?l0003o05G>o`1Ec_l0000Dooooo`03
o`000?oooooooooo01Wooooo000/ooooo`Co0000>_ooool00ol0003oZ/C/oj[4k005oj[4k0?o0000
2OnbaNT2o`0000koW<Of0ol0000AoiS<nP03o`000?n@c_goT<km00GoT<km0ol00008oiO@o0;o0000
3_nAd_h4o`00017oTmKn1?l0000AoiKIoP;o00000_nDfoh3o`0000koUmcn1?l0000>oiWNoP?o0000
0onKg_d2o`0000coV]om0ol00004oi_Po@?o00001_nJh?d2o`0000goVn7m0ol0000<oi[Qo@?o0000
1?nKhOd2o`0000OoV>7m0ol00009oiSPo@;o00000_nFgoh4o`0000_oU=on1?l0000?oi3MoPCo0000
3on9fOl01?l0003oQ=GoohCEoon4eOl7o`0000GoP=Co0_l0000=ogW>o`03o`000?m`aoooL<Oo00Go
L<Oo3ol00004ofBmo@03o`000?mC/?[oDk3j00SoDk3j00?o0000oe>`n_l000001OlkW?@6o`0000Ko
7h?Y0ol00004o`19aP04o`000?l0ELko05G>o`0001?ooooo00?o0000ooooooooool06Oooool000oo
oooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000?Oooool00ol0003o
Z/C/oj[4k002oj[4k0;o00003_nbaNT00ol0003oW<Ofoic7mP08oic7mP?o00000onTbO<2o`00013o
V<cj0_l00002oi3>o@?o00003OnGd?`2o`0000OoTM;n1Ol00004oiODo@;o00003?nCe_h3o`0000Co
V=Om0_l0000?oiKIoPCo00003_nGg?h3o`0000CoV]cm0_l0000:oiWNoP;o00002?nKg_d2o`0000Oo
V]om0ol0000:oi_Po@;o000000CoV^3mo`000?l0003o00003?nKhOd3o`0000?oW>7m0_l00007oi[Q
o@?o00002OnKhOd2o`0000;oV>7m0ol0000=oiSPo@?o00003?nDgoh3o`0000CoTmkn0_l00008oi3M
oPGo00001?n>g?l2o`0000_oRMWo1_l0000>oh3Do`03o`000?mic_ooNLko00GoNLko3Ol00009of[4
oP03o`000?mM^_coGK[l00?oGK[l3Ol00002oe>`nP04o`000?mC/?[oDk3jo`0000Wo>icd0ol00007
oan3j@;o00000ol0BLH2o`000003o`1Ec_l0003ooooo017ooooo00?o0000ooooooooool06Oooool0
00kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo03_o
oooo00Co0000oj[4k?l0003o00004OnbaNT00ol0003oW<Ofoic7mP04oic7mP?o00002?nTbO<2o`00
00koV<cj1?l0000BoiO@o003o`000?nAd_koTM;n00Co00002onGe?d2o`0000OoTmKn0ol00009oiSG
o@;o00002?nFfOh5o`0000CoVM[m0ol00008oiOLoP?o00002OnJg?d2o`0000KoVMkn0_l0000<oi_N
o@;o00000_nJgod3o`0000goVn3m1?l0000;oi_Qo@?o00002?nLhOd2o`0000;oV^7m0ol0000=oi_Q
o@?o00003OnHh?d3o`0000?oV>3n0_l00007oiCOoP?o00002OnCg_h2o`0000;oT=gn1?l0000;ohkL
o`04o`000?n9fOooRMWoohWIo`Oo00001On6f?l2o`0000_oP=Co2_l00008ogC<o`;o00003OmZa?h0
0ol0003oGK[loefjo009oefjo003o`000?m;ZoWoBj_i00?oBj_i2Ol00008oc^Lm0Co00001OlOPnT2
o`0000Co04W600?o0000o`1Ec_l000004Oooool00ol0003oooooooooo`0Iooooo`004_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo0_l0000Cok;5j@03o`00
0?nLaoKoW<Of00?o00003OnTbO<00ol0003oV<cjoiS<nP06oiS<nPGo00001?nOc_P2o`00013oUm3l
0ol0000AoiODo@;o00000_nCe_h3o`0000koV=Om0_l00002oiKIoPCo00003?nIf_d3o`0000;oUmcn
0ol0000>oi[Lo@;o000000CoVMkno`000?l0003o00003_nKg_d4o`0000goVn3m0ol00004oigPo@?o
00001_nKhOd2o`0000coW>7m0ol0000=oi_Qo@?o00000onKhOd3o`0000OoV>3m0ol00008oiSPoP;o
00000_nDgoh3o`0000coTmkn1?l0000>ohkLo`Go00003_n6f?l2o`0000?oP=Co1_l00005oggBo`;o
00003Omdc?l2o`0000coJ/Cn00?o0000oefjo?mM^_`02OmM^_`00ol0003oBj_iod^[n@06od^[n@05
o`000?m;ZoWoBj_io`000?laU_401?l00005oc^Lm003o`000?lCNnCo4g_T00;o00001?lOPnT3o`00
00?o04W60_l0000Booooo`03o`000?oooooooooo01Sooooo000Booooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0??ooool00ol0003o//GYok;5j@0@ok;5j@?o00004OnT
bO<2o`0000;oV<cj1?l0000;oio>n0;o00002onGd?`3o`0000?oWM;j0_l0000@oiODo@?o00004_nH
eod3o`00017oVM[m1?l0000Aoi[Lo@Co00003OnKg_d3o`0000CoWMom0ol00007oi_Po@?o00002_nM
h?d2o`000004oi_QoOl0003o0000o`0000_oW>7m0ol00003oigQo@?o00001onKhOd3o`0000WoVn7m
0_l00002oiSPo@?o00003?nHh?h3o`0000coTmkn0ol00004oi;NoP;o00002?n>g?l4o`0000CoS=_o
0_l0000<ohKHo`Ko00003Ommd_l2o`0000OoM<co6ol00004oefjo003o`000?m;ZoWoBj_i00KoBj_i
00Co0000od^[nOm;ZoWo00001?laU_43o`0000?o>icd00Co0000oa=ki?lCNnCo4g_T0ol00002oan3
j@03o`000?l0?[go000000Co04W600?o0000ooooooooool03oooool00ol0003oooooooooo`0Hoooo
o`003_ooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000cooooo0_l0000mooooo`03o`000?nbaNWo//GY00go//GY0_l0
0003okS6i@03o`000?nTbO?oY<Wc00ooY<Wc0ol0000Aoio>n003o`000?nGd?coUm3l00GoUm3l0ol0
0008oigBnP;o00002onGe?d3o`0000?oW=Gl0_l0000=oiSGo@?o00000onMf?`2o`0000coVM[m0ol0
0004oigKo@;o00003?nJg?d3o`0000CoWMgm0ol00007oi_No@?o00002_nMgod2o`0000;oVn3m0ol0
000=oigPo@Go00002OnLhOd3o`0000WoWN7m0_l00002oi_Qo@?o00003?nKhOd4o`0000coV>3n0ol0
0003oiSPoP;o00001onCg_h3o`0000WoT]kn0_l00002ohkLo`Co00002_n<fol2o`0000?oQ]So1ol0
0005ohCGo`;o00002ommd_l:o`0001_ooooo2_l00003od^[n@05o`000?m;ZoWoBj_iod^[nOl00000
1_laU_45o`0000Go4g_T0_l000000olOPnWo0000o`0n_@02o`0000?o04W600?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Hooooo`003_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000>oooo
o`03o`000?oooooooooo03_ooooo0_l0000;ok;5j@;o00001_nha^D2o`0000coY<Wc0ol00003oj_;
l@03o`000?nOc_SoWlkh00ooWlkh0_l00002oiO@o0?o00003OnMd_X00ol0003oUmCmoiODo@05oiOD
o@?o00002?nLeO`3o`0000OoV=Om0ol00008oigHo0;o00001onIf_d3o`0000WoWM_m0_l00007oi[L
o@?o00002_nMgOd2o`0000;oVmkm0ol0000=oigOo@Co00003OnMh?d3o`0000GoWn7m0ol00003oicQ
o@?o00003?nMhOd4o`0000coVn7m0ol00004oi_Qo@;o00001onHh?h3o`0000SoV>3n0_l00002oi?N
oP?o00003?nBg_h4o`0000koS=_o1Ol0000>ohCGo`04o`000?mmd_ooOM;ooggBo`Oo0000;oooool7
o`000003od^[nOl0003o<IKa00So<IKa0ol00005oa=ki0?o00000_l0?[d2o`000003o`19a_l0003o
oooo00oooooo00?o0000ooooooooool06?ooool000kooooo1Ol00003ooooo`;o00001?ooool2o`00
00Cooooo0_l0000@ooooo`03o`000?oooooooooo03cooooo00?o0000ok;5jOnbaNT01OnbaNT3o`00
00[o^<KU00?o0000ojC9lonTbO<01onTbO<2o`0000OoZl_a0_l0000?oio>n0Co00004OnMd_X2o`00
00;oUmCm0ol0000>oicEo0;o00000_nHeod3o`0000goWMSl0_l00002oiWJo@?o00003_nMfod2o`00
00;oV]cm0ol0000=oigMo@Co00003OnMgod3o`0000CoX>3l0ol00007oigPo@?o00002onOhOd3o`00
00coWN7m0ol00004oikRo@;o00001onKhOd3o`0000WoVn7m0_l00002oiSPoP?o00002onHh?h5o`00
00WoT]kn1Ol00004oi7NoP;o00001on<fol5o`0000CoR][o0_l0000;ohCGo`Ko0000>oooool00ol0
003oooooo`000004o`0000Oo<IKa00Co0000o`Mbgol0003o00001_lCNn@2o`0000;o03jm00?o0000
o`19a_l000003oooool00ol0003oooooooooo`0Hooooo`00=Oooool00ol0003oooooooooo`0loooo
o`03o`000?nbaNWo//GY00;o//GY0_l0000>okS6i@;o00001OnTbO<2o`0000_oZl_a00?o0000oio>
n?nOc_P02OnOc_P3o`0000CoYLof00?o0000oigBn_nMd_X03_nMd_X4o`00017oW=Gl1?l0000AoigH
o0?o00004OnMfod4o`0000goWMgm0ol00004oj3No0?o00001onMgod3o`0000[oX>3l0_l00002oigP
o@?o00002onOhOd3o`0000?oX>7l0_l00007oigQo@?o00002OnNh_d2o`0000;oVn7m0ol0000<oi_Q
o@Go00002OnHh?h4o`0000GoUn3n0ol00002oi;NoPCo00002onAg_h00ol0003oS=_oohcKo`04o`00
00_oR][o00Co0000ohCGoon4eoooQ=Oo1ol00012ooooo`03o`000?oooooooooo00?ooooo0ol00005
oc6Fl@03o`000?l7L]oo1g;O00;o00001?lCNn@00ol0003o03Beo`000002o`0n_@?o00003_ooool0
0ol0003oooooooooo`0Hooooo`00=_ooool00ol0003oooooooooo`0looooo`04o`000?nbaNWo0000
o`0001;o^<KU00?o0000ojC9lol000000_l0000>oj_;l@;o00001_nOc_P3o`0000SoYLof0_l0000;
oigBnP?o00001?nSdoT2o`0000coW=Gl0ol00004oj;GnP;o00003?nMf?`3o`0000?oXM[k0_l0000<
oigKo@?o00001?nQg?`3o`0000OoWMgm0ol0000:oj3No0;o00000_nMgod3o`0000goX>3l1?l0000;
oioQo@?o00002?nPhO`2o`0000;oWN7m0ol0000=oikRo@?o00003?nKhOd3o`0000GoVn7m0ol00002
oiSPoPCo00002onGh?h3o`0000koTMkn1?l0000>oh[Jo`Go0000BOooool00ol0003oooooooooo`06
ooooo`Co00000_laU_401?l0003o1g;Oo`Mbgol7L]l3o`0000;o4g_T00?o0000o`0d]Ol000000ol0
?[d2o`0000gooooo00?o0000ooooooooool06?ooool003Oooooo0_l0000mooooo`;o00004onha^D3
o`0001;oZl_a00?o0000oio>n?nOc_P00ol0000=ojG?mP;o00001_nMd_X3o`0000WoXm?i0_l00007
oicEo0?o00002OnReoX2o`0000OoWMSl0ol00008oj7Jn`;o00001onMfod3o`0000[oXMcl0_l00002
oigMo@?o00003_nPg_`3o`0000goX>3l0ol00004oj;Po0?o00001_nOhOd2o`0000coX>7l0ol0000=
oikRo@?o00000onOh_d2o`0000OoVn7m0ol0000:oi_Qo@?o00003?nGh?h3o`0000?oUn3n0_l00008
oi7NoPCo00001?n@gOh2o`0000SoR][o1?l0001?ooooo`03o`000?oooooooooo00Wooooo1?l00005
o`Mbg`;o000000Co4g_To`000?l0=;Go00000ol0?[d2o`0000cooooo00?o0000ooooooooool06?oo
ool003Wooooo00?o0000ooooooooool0??ooool00ol0003o^<KUokS6i@0>okS6i@;o00000onnan40
0ol0003oZl_aoj_;l@0?oj_;l@?o00004_nUcoH00ol0003oWM;joigBnP03o`0000koXm?i0_l00002
oicEo0?o00003_nReoX2o`0000;oWMSl0ol0000=oj7Jn`;o00000_nMfod3o`0000koXMcl0ol0000>
oj3No0?o00000onSgo`3o`0000OoX>3l0ol0000:oj;Po0;o000000CoWn7mo`000?l0003o00002onP
hO`3o`0000?oX^;l0ol00007oikRo@?o00002?nOh_d2o`0000;oVn7m0ol0000:oi_Qo@?o00000onL
hOd2o`0000OoUn3n0ol00008oiOPoP;o00000_nAg_h4o`0000[oT=gn0_l00002oh[Jo`Co0000E?oo
ool00ol0003oooooooooo`0;ooooo`?o00001Ol7L]l3o`000003o`0d]Ol0003o000000?o03jm00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`00>_ooool00ol0003oooooooooo`0l
ooooo`03o`000?nha^Go^<KU00_o^<KU0_l00006okk7h@03o`000?n[bo7oZl_a00_oZl_a0ol00003
ok7<kP;o00004?nUcoH3o`0001;oXm?i0ol0000Aoj;GnPCo00004OnQf_/3o`0000koXMcl0ol00003
ojCMn`?o00002?nPg_`3o`0000WoXmol0_l00002oj3Po0?o00003OnRh?`4o`0000_oX>7l0_l00009
oj;Ro0;o00000_nNh_d3o`0000coWn;m1?l00009oi_Qo@?o00002?nLhOd2o`0000;oUn3n0ol0000<
oiOPoP?o00003_n@gOh4o`0005Sooooo00?o0000ooooooooool03_ooool2o`0000Go1g;O0_l00002
o`0d]@05o`000?l0?[go03jmo`0n_Ol000002oooool00ol0003oooooooooo`0Gooooo`00>oooool0
0ol0003oooooooooo`0looooo`;o00002Onha^D2o`0000Wo_/OQ0_l00008oj_;l@?o00002?nac>h2
o`0000_oYLof0ol00003oj_@l`03o`000?nSdoWoXm?i00coXm?i0ol00003ojSDm`;o00003?nReoX3
o`0000CoY]Si0_l0000<oj7Jn`?o00000onUf_X3o`0000SoXMcl0ol00009ojCMn`?o00000_nPg_`3
o`0000goXmol0ol0000=oj;Po0?o00001?nThO`3o`0000KoX>7l0_l0000;oj;Ro0Co00003?nOh_d3
o`0000CoX>;l0ol00003oi_Qo@?o00003?nLhOd3o`0000coUn3n0ol00003oiOPoP;o00001on@gOh5
o`0005gooooo00?o0000ooooooooool03oooool2o`0000Go1g;O0_l000001Ol0=;Go0000o`0n_Ol0
?[go000000_ooooo00?o0000ooooooooool05oooool003cooooo0_l0000nooooo`03o`000?nha^Go
^<KU00Go^<KU00?o0000okk7hOnnan402onnan400ol0003oZl_aoj_;l@03oj_;l@;o00003Onac>h0
0ol0003oYLofojG?mP05ojG?mP?o00001on[d?<2o`0000WoXm?i0ol00008ojSDm`;o00001onReoX3
o`0000WoY]Si0_l00007oj7Jn`?o00002OnUf_X3o`0000;oXMcl0ol0000>ojCMn`?o00003OnSgo`3
o`0000?oY]ok0ol00007oj;Po0?o00002_nThO`2o`000004oj3Qo?l0003o0000o`0000[oX^;l0ol0
0004oj?Ro0;o00001onOh_d3o`0000WoX>;l1?l0000<oicQo@?o00000onLh_d2o`0000OoUn3n0ol0
0008oiOPoP03o`000?n@gOkoT=gn00Co0000Hoooool00ol0003oooooooooo`0@ooooo`;o00000ol7
L]l01Ol0003o02V/o`000?l0=;Go000000;o03jm00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Gooooo`00?_ooool00ol0003oooooooooo`0looooo`03o`000?nha^Go^<KU00;o^<KU0_l0
000?okk7h@03o`000?n[bo7o000000;o00004?nac>h2o`0000;oYLof0ol0000<oj_@l`;o00001OnS
doT2o`0000goZ=Cg0_l00002oj;GnP?o00003_nVf?T2o`0000;oXM[k0ol0000>ojGJnP?o00003_nT
gO/3o`0000?oYmkj0_l00009oj?Oo0;o00002OnVgo/2o`0000;oX^3l0ol0000=ojCQo0Go00002?nR
h_`3o`0000WoXn;l0_l00002oioRo@?o00002OnPh_`3o`0000CoXN;l0_l00007oicQo@?o00002?nL
h_d2o`0000;oUn3n0ol0000:oiOPoPCo0000J?ooool00ol0003oooooooooo`0Aooooo`09o`000?l7
L]oo1g;Oo`Mbgol0003o02V/o`000?l0=;Go000000;o03jm00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Gooooo`00?oooool00ol0003oooooooooo`0looooo`04o`000?nha^Go0000o`00
017o_/OQ0ol0000Cok7<kP?o00004On[d?<00ol0003oXm?io`000002o`00013oZ=Cg0ol0000BojKH
n@?o00003_nUf_X3o`0000?oZM_i0_l00009ojCMn`?o00002?nWg_X00ol0003oXmoloj?Oo004oj?O
o0;o00003?nVgo/3o`0000goY>7l0ol00005ojKQn`?o00000_nRh_`3o`0000goXn;l1?l00008oj3R
o0?o00002OnQh_`2o`0000;oW>7m0ol0000;oicRo@Co00002OnGh?h4o`0006cooooo00?o0000oooo
ooooool04_ooool2o`0000;o1g;O00Co0000o`0Y[?l0003o03Be0ol00009ooooo`03o`000?oooooo
oooo01Oooooo0010ooooo`03o`000?oooooooooo03cooooo0_l0000Aokk7h@05o`000?o2amko`/ON
ol;7g_l000004?nac>h2o`0000?o]/g[00?o0000oj_@lon[d?<03_n[d?<3o`0000ooZ=Cg0ol00003
ojgEm@03o`000?nVf?WoY]Si00coY]Si0ol00003oj_Hn0;o00002OnUf_X3o`0000SoZM_i00?o0000
ojCMnonTgO/01?nTgO/2o`0000coYmkj0_l000001?nSgoco0000o`000?l0000;ojKOn`?o00000onX
h?X3o`0000OoY>7l0ol0000:ojKQn`?o00003OnSh_`3o`0000CoYN;k0ol00002oj3Ro0?o00003?nQ
h_`4o`0000WoW>;m1Ol00004oicRo@?o00000_nGh?h4o`00077ooooo00?o0000ooooooooool04ooo
ool3o`0000;o02V/00?o0000o`0d]Ol0=;D00_l00008ooooo`03o`000?oooooooooo01Oooooo0011
ooooo`;o0000?_ooool00ol0003o_/OQokk7h@0=okk7h@03o`000?o2amko`/ON00?o`/ON0_l0000<
ok7<kP;o00001_nfcN/00ol0003oZm3coj_@l`0:oj_@l`?o00000on`dO42o`0000_oZ=Cg0_l00007
ojgEm@;o00002OnVf?T3o`0000SoZmSh00?o0000ojGJn_nUf_X01?nUf_X2o`0000coZM_i0_l00000
1?nTgO_o0000o`000?l0000?ojONnP?o00002onVgo/2o`0000WoZ>3j0_l00002ojCQo0?o00002_nV
hO/3o`0000?oZ>;k0ol00007oj?Ro0?o00002OnUh_/3o`0000coXN;l0ol00004oj;So0?o00000_nL
h_d4o`0000_oW>;m0ol0001fooooo`03o`000?oooooooooo01Cooooo0_l00002o`0Y[004o`000?l0
=;Go03Beo`0000Wooooo00?o0000ooooooooool05_ooool004?ooooo00?o0000ooooooooool0??oo
ool00ol0003o_/OQokk7h@0:okk7h@;o00002?o2amh00ol0003o/Lc^ok7<kP06ok7<kP?o00002Onf
cN/2o`0000SoZm3c0_l00008ok3Al@?o00001_nXe?L2o`0000_o[MGe0_l00005ojKHn@;o00003?n[
f?P2o`000004ojGJn_l0003o0000o`0000ooZM_i0ol0000>ojONnP?o00000onZg_T3o`0000KoY]ok
0_l0000<ojSPnP?o00002onVhO/2o`0000WoZ>;k0_l00002oj?Ro0?o00002OnUh_/3o`0000?oY^?k
0_l00007oj7Ro0?o00002OnRho`3o`0000coW>;m0ol0001jooooo`03o`000?oooooooooo01Gooooo
0_l000001Ol0:Jco0000o`0d]Ol0=;Go000000Sooooo00?o0000ooooooooool05_ooool004Cooooo
00?o0000ooooooooool0??ooool00ol0003o_/OQokk7h@08okk7h@03o`000?o2amko`/ON00Wo`/ON
0_l00004ok7<kP;o00003_nfcN/00ol0003oZm3coj_@l`03oj_@l`;o00003On`dO42o`000004ojSD
mol0003o0000o`0000oo[MGe00?o0000ojKHnOl000000_l0000?oj_Hn0?o00003_nYfoT3o`0000?o
[=ch0ol00008ojONnP?o00002OnZg_T2o`000004ojKOnol0003o0000o`0000_oZ>3j0ol00003oj_Q
nP?o00001_nVhO/2o`0000coZ>;k0ol0000:ojGRn`;o00002?nVho/2o`0000;oXN;l0ol00009oj;S
o0?o00000onSho`2o`0000OoW>;m0ol0001mooooo`03o`000?oooooooooo01Oooooo00Ko0000o`0Y
[?l0003o0000o`0d]Ol00007ooooo`03o`000?oooooooooo01Kooooo0015ooooo`03o`000?oooooo
oooo03cooooo00?o0000okk7hOnnan401_nnan400ol0003o`/ONol;7gP0<ol;7gP04o`000?nac>ko
0000o`00017o]/g[00?o0000oj_@lol000000_l0000@ok3Al@?o00004On]eOD3o`0000koZmSh0ol0
0003ojkImP;o00002_nYfoT2o`0000Wo[=ch0ol00002ojONnP?o00003OnZg_T3o`0000_oZ>3j0_l0
0009oj_QnP;o000000CoY^7ko`000?l0003o00002onXh_/3o`0000?oZ^;j0_l00006ojGRn`;o0000
2onVho/3o`0000[oX^?l0_l00008oj?So0;o00000_nLh_d3o`00087ooooo00?o0000ooooooooool0
5oooool00ol0003o02V/o`0Y[002o`0000Oooooo00?o0000ooooooooool05_ooool004Kooooo0_l0
000mooooo`03o`000?nnan7o_/OQ00?o_/OQ0_l0000?ol;7gP?o00004_nfcN/3o`00013o/=7a0_l0
0003okGBk`03o`000?n]eOGo[MGe00_o[MGe0ol00003ok7Fl`;o00002_n[f?P2o`0000So[]Wf0_l0
0006ojWKn@;o00003On/g?P3o`0000goZ]ki0ol00003ojgOn0?o00001_nXh?X2o`0000coZn7j0ol0
000;ojSRn`;o00002?nZh_X2o`000004ojGRnol0003o0000o`0000[oY^?k0ol00003ojOSn`;o0000
1_nRho`2o`0000_oXn?l0ol00025ooooo`03o`000?oooooooooo01Oooooo00?o0000o`0Y[?l0:J`0
0_l00006ooooo`03o`000?oooooooooo01Kooooo0018ooooo`03o`000?oooooooooo03_ooooo00Go
0000okk7hOnnan7o_/OQo`00000@ol;7gP05o`000?o6am[oa/OJolK7f_l000003onfcN/2o`0000?o
^lgX00?o0000ok3AlOn`dO402on`dO42o`0000Ko]M;_0_l00009ojgEm@;o00002?nae_<2o`0000Ko
ZmSh0_l0000<ojkImP;o000000CoZM_io`000?l0003o00003?n/g?P3o`0000?o/=gg0_l00009oj[N
n@;o00002On]goP2o`000004ojSPn_l0003o0000o`0000_oZn7j0ol00003ojgQn@?o00001_nXh_/2
o`0000_oZ^;j0ol0000:ojKSn`;o00002?nWho/2o`000004oj;So?l0003o0000o`0000[oXn?l0ol0
0028ooooo`03o`000?oooooooooo01Sooooo00?o0000o`0Y[?l0:J`00_l00005ooooo`03o`000?oo
oooooooo01Kooooo0019ooooo`03o`000?oooooooooo03_ooooo00?o0000okk7hOl000004?o2amh0
0ol0003oa/OJolK7fP03olK7fP03o`000?nfcN_o]/g[00[o]/g[0_l00006ok_=j0;o00002?n`dO43
o`0000[o]M;_0_l00005ojgEm@;o00003?nae_<2o`000004oj_Hn?l0003o0000o`0000oo[]Wf0ol0
000;ojcLn0?o00002?n`gOL00ol0003oZ]kioj[Nn@04oj[Nn@;o00003?n]goP3o`0000_oZn7j0_l0
0009ojgQn@;o000000CoZ>;ko`000?l0003o00002_nZh_X3o`0000?o[>?j0_l00006ojKSn`;o0000
2onWho/4o`0000SoXn?l0ol0002<ooooo`03o`000?oooooooooo01Sooooo00?o0000o`0Y[?l0:J`0
0_l00004ooooo`03o`000?oooooooooo01Kooooo001:ooooo`03o`000?oooooooooo03_ooooo0_l0
000>ol;7gP;o00001oo6amX2o`0000Oo]/g[0ol0000:ok_=j0;o00001?n`dO42o`0000oo]M;_00?o
0000ojgEmOl000000_l0000?ok7Fl`?o00003_n^fOH3o`0000?o/][d0ol00006ojcLn0;o00003?n`
gOL2o`000004oj[NnOl0003o0000o`0000_o[Moh0ol00003ok3Om`?o00001_n[hOX2o`0000co[N7i
0ol0000:oj[RnP;o00002?n/hoX2o`000004ojKSnol0003o0000o`0000[oYn?k0ol00004ojWSnP?o
00000_nSho`3o`00093ooooo00?o0000ooooooooool06?ooool01?l0003o02V/o`0Y[?l00005oooo
o`03o`000?oooooooooo01Gooooo001;ooooo`03o`000?oooooooooo03cooooo00?o0000ol;7g_o2
amh02_o2amh00ol0003oa/OJolK7fP09olK7fP03o`000?nfcN_o]/g[00;o]/g[0_l0000?ok_=j004
o`000?n`dO7o0000o`00017o]M;_0ol0000>ok7Fl`?o00000onee_42o`0000[o[]Wf0_l00009ok;J
m0;o000000Co[=cho`000?l0003o00003on`gOL3o`0000_o[Moh0_l00009ok3Om`;o000000CoZn7j
o`000?l0003o00002on]hOT3o`0000?o[n;h0_l00006oj[RnP;o00002on/hoX4o`0000SoYn?k0ol0
0009ojWSnP?o0000U?ooool00ol0003oooooooooo`0Hooooo`;o000000?o02V/o`000?ooool00ooo
ool00ol0003oooooooooo`0Eooooo`00C?ooool2o`0003gooooo00?o0000ol;7g_o2amh02?o2amh0
0ol0003oa/OJolK7fP0;olK7fP04o`000?nfcN_o0000o`00017o^lgX0ol0000@okGBk`;o00000oni
d^d2o`0000[o/MKc0_l00008okGFl@;o00001_n^fOH2o`0000co/][d0ol0000>ok3Mm`?o00000onc
gOD3o`0000Ko[Moh0_l0000<ok3Om`?o00002on]hOT2o`0000So[n;h0_l000001?nZh_[o0000o`00
0?l0000:ojcSnP?o00001?n^hoT3o`0000;oYn?k0ol00009ojWSnP?o0000Uoooool00ol0003ooooo
ooooo`0Jooooo`03o`000?l0:Jco000000?ooooo00?o0000ooooooooool05Oooool004kooooo00?o
0000ooooooooool0>oooool00ol0003o`/ONol;7gP06ol;7gP03o`000?o6am[oa/OJ00coa/OJ0ol0
000@ok_=j0;o00000onocND00ol0003o]M;_okGBk`0;okGBk`;o00001onid^d2o`0000Ko/MKc0_l0
000<okGFl@;o000000Co[]Wfo`000?l0003o00003?nbf_@2o`0000?o]][c0_l0000:ok3Mm`;o0000
2OncgOD2o`000004ojgOn?l0003o0000o`0000_o/=og0ol00003ok?PmP?o00001_n]hOT2o`0000_o
[n;h1?l00008ojcSnP?o00002On^hoT3o`0000[oZN?j0_l0002Kooooo`03o`000?oooooooooo01[o
oooo0_l00003ooooo`03o`000?oooooooooo01Gooooo001?ooooo`03o`000?oooooooooo03_ooooo
00?o0000ol;7g_o2amh00oo2amh2o`0000koa/OJ00Go0000ol[7eoo:amOob/OGo`00000>ok_=j003
o`000?nocNGo_lgU00Co_lgU0_l00008okGBk`?o00002onid^d2o`000004ok7Flol0003o0000o`00
00oo]MKa0ol0000<ok;Jm0;o00001onff_<2o`0000Ko/=gg0_l0000<ok?Mm@?o00002on`goL2o`00
00Wo/n3f0_l000001?n]hOWo0000o`000?l0000:ojoRn0?o00001?nah_L3o`0000;o[>?j0ol0000:
ojkSn@;o00000on_hoP2o`0000KoZN?j0_l0002Nooooo`03o`000?oooooooooo01[ooooo0_l00002
ooooo`03o`000?oooooooooo01Gooooo001@ooooo`03o`000?oooooooooo03_ooooo00Go0000ol;7
g_o2amko`/ONo`00000?olK7fP03o`000?o:amOob/OG00?ob/OG0_l0000:ok_=j0;o00002OnocND2
o`0000Co]M;_0_l0000?okWBk@?o00003onee_42o`0000?o^MO_0_l00008ok;Jm0;o00002onff_<2
o`000004ok3Mmol0003o0000o`0000co/mge0_l00003okKMm0?o00001_n`goL2o`0000co/n3f0ol0
000:ojoRn0;o00002Onah_L3o`0000[o[^?i0ol00007ojoSn0;o000000CoZN?jo`000?l0003o0000
XOooool00ol0003oooooooooo`0Jooooo`;o000000?oooooo`000?ooool05_ooool0057ooooo0_l0
000looooo`03o`000?o2amko000000ooa/OJ00?o0000ol[7eoo:amL01_o:amL00ol0003o^lgXok_=
j005ok_=j0;o00003OnocND01?l0003o]M;_o`000?l0000?okWBk@;o00000onmd^X00ol0003o]MKa
okGFl@0:okGFl@;o00001onienl00ol0003o/][dok;Jm003ok;Jm0;o00003_nff_<3o`0000co/mge
0_l00008okKMm0;o000000Co/=ogo`000?l0003o00002onch?H3o`0000?o]N3e0_l00006ojoRn0;o
00002Onah_L2o`0000?o]>;f0ol00005ojkSn@;o00002on_hoP2o`000:Cooooo00?o0000oooooooo
ool06oooool3o`0001Oooooo001Cooooo`03o`000?oooooooooo03[ooooo0_l0000>olK7fP03o`00
0?o:amOob/OG00Sob/OG0_l00004ok_=j003o`000?nocNGo_lgU00go_lgU0ol0000>okWBk@;o0000
1_nmd^X2o`0000Oo]MKa0ol0000:okWGk`;o000000?o/][do`000?l000003_nff_<2o`0000?o^M[a
0_l00008ok?Mm@;o00002onfgO@3o`0000_o/n3f0_l00008okGPm@;o000000Co[n;ho`000?l0003o
00002Onah_L2o`0000So]>;f0_l000000on^hoWo0000o`00000;ojoSn0;o0000Yoooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooo000001Kooooo001Dooooo`03o`000?oooooooooo03_ooooo
00?o0000olK7f_o6amX02Oo6amX2o`0000gob/OG00Co0000ok_=j?l0003o00003onocND01Ol0003o
`lkRol?>h_o3c^;o000000_o^M;]0_l0000:okgBjP03o`000?nee_7o]MKa00;o]MKa0_l0000>okWG
k`?o00003Onff_<2o`0000Oo^M[a00?o0000ok?MmOncgOD00oncgOD2o`0000_o]]gd0_l00003okWN
l`?o00001_nch?H2o`0000_o]N3e0ol0000:ok7Rm`03o`000?ndh_Ko]>;f00Wo]>;f0ol00009ojoS
n0?o0000Z_ooool00ol0003oooooooooo`0Kooooo`;o00005_ooool005Gooooo00?o0000oooooooo
ool0>oooool2o`0000Soa/OJ00?o0000ol[7eoo:amL03Oo:amL3o`0000ko_lgU0_l00005ol?>hP;o
00002?nid^d00ol0003o_M;ZokgBjP0;okgBjP04o`000?nee_7o0000o`0000ko^MO_0_l00003okcG
k@;o00002?nff_<3o`0000[o^M[a0_l000000oncgOGo0000o`00000;okKMm0;o00002?nig_<2o`00
0004ok?Pm_l0003o0000o`0000_o]N3e0_l00003okSPm0?o00001Onah_L2o`0000[o]>;f0_l00003
okKRmP;o00001On_hoP2o`000:gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`00E_ooool2o`0003gooooo00?o0000olK7f_o6amX01?o6amX00ol0003ob/OGol[7e`0=ol[7
e`05o`000?o=amCocLODolg7e?l000003?nocND00ol0003o`lkRol?>hP07ol?>hP;o00001?nid^d2
o`0000ko_M;Z0ol0000=okWGk`;o00001onlend00ol0003o]][cokKJl`03okKJl`;o00003_nif_43
o`0000[o]]gd0_l0000;okWNl`?o00002oneh?D2o`0000So^>3d0_l000000onah_Oo0000o`00000:
okCRmP;o00001onfh_H2o`000003ojoSn?l0003o00000;3ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Dooooo`00F?ooool00ol0003oooooooooo`0kooooo`;o00000oo6amX00ol0
003ob/OGol[7e`0=ol[7e`03o`000?o=amCocLOD00?ocLOD00?o0000oko=iOnocND01onocND2o`00
00co`lkR00Co0000okWBkOl0003o00003_nmd^X2o`0000?o`M?X0_l00009okWGk`;o00002_nlend2
o`000003okKJlol0003o000000ko^M[a0_l00003okcKk`?o00001OnfgO@2o`0000_o^Mkc0_l00003
ok_Nl@03o`000?neh?Go]N3e00Ko]N3e0_l0000;okSPm0?o00002Ondh_H2o`0000[o]^;f0_l0002c
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000oooo
ooooool0??ooool00ol0003oa/OJo`00000?ol[7e`03o`000?o=amCocLOD00GocLOD0_l00006oko=
i@03o`000?o3c^;o`lkR00co`lkR0ol0000>okgBjP03o`000?o1dnSo`M?X00Go`M?X0_l00005okWG
k`;o00003Onlend3o`0000go^M[a0_l00008okcKk`;o000000?o]]gdo`000?l000003?nig_<00ol0
003o^mkaok_Nl@04ok_Nl@;o00001?neh?D2o`0000_o^>3d0_l00003ok[Ql`;o00001Ondh_H2o`00
00Wo]^;f0ol0002fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool005[o
oooo00?o0000ooooooooool0??ooool2o`0000kob/OG00?o0000olg7e?o=am@02?o=am@01?l0003o
_lgUoko=iOnocND2o`0000ko`lkR00Go0000olK>h?o6c^3oa/kPo`00000;okgBjP;o00002_o1dnP2
o`000003okWGkol0003o000000go_=O]0_l00003okoGj`;o00002Onif_42o`0000_o_=__0ol0000;
okWNl`;o00002Onkg_401?l0003o]N3eo`000?l0000;okSPm0;o00001onjhO<2o`000003okCRm_l0
003o000000Wo]^;f0_l0002iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?oo
ool005_ooooo0_l0000nooooo`03o`000?o:amOob/OG00Wob/OG0_l0000<olg7e003o`000?nocNGo
000000oo`lkR00?o0000olK>h?o6c^000oo6c^02o`0000Oo_M;Z0_l0000=ol7Cj0?o00003Onlend0
0ol0003o_mO[okoGj`05okoGj`;o00001Onif_42o`0000_o_=__0_l00003okoKkP;o00001onig_<2
o`0000_o^mka0ol0000:okSPm0;o00002_njhO<4o`0000Oo]^;f0_l0002looooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool04oooool005gooooo00?o0000ooooooooool0??ooool00ol0
003ob/OGol[7e`07ol[7e`03o`000?o=amCocLOD00cocLOD0ol0000=ol?>hP;o00002?o6c^02o`00
00Co_M;Z00?o0000ol7Cj?o1dnP03?o1dnP01Ol0003oa=?UolCCiOo4dnGo000000[o_=O]0_l0000:
okoGj`;o000000?o^M[ao`000?l000003?nlfnl00ol0003o_m_^okoKkP05okoKkP03o`000?nig_?o
^Mkc00?o^Mkc00?o0000ok_NlOnkg_402Onkg_42o`0000?o_]k`0ol00005okSPm0;o00002_njhO<2
o`0000Co_>7b0ol000001?nfh_Ko0000o`000?l0002oooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool04oooool005kooooo00?o0000ooooooooool0??ooool00ol0003ob/OGol[7e`05
ol[7e`03o`000?o=amCocLOD00cocLOD00Go0000om37dOo@am7od<OAo`00000;ol?>hP03o`000?o6
c^3oa/kP00[oa/kP00Co0000okgBj_l0003o00003Oo1dnP2o`0000Goa=?U0_l00006okcGk@;o0000
3Onoen/3o`0000_o_=__0_l00009okoKkP;o000000?o^Mkco`000?l000002_nkg_42o`0000So_]k`
0_l000000onhh?Co0000o`00000:ok[Ql`;o00002?nlhO82o`000<?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Cooooo`00Goooool00ol0003oooooooooo`0looooo`03o`000?o:
amOob/OG00?ob/OG00?o0000olg7e?o=am@03?o=am@00ol0003od<OAom37d@03om37d@03o`000?o3
c^;o`lkR00Oo`lkR00?o0000olK>h?o6c^002oo6c^03o`0000go`M?X00?o0000olCCiOo4dnD01oo4
dnD00ol0003o_=O]okcGk@02okcGk@03o`000?noen_o_mO[00_o_mO[0_l00003ol;Gj@;o00001onl
fnl2o`0000co_m_^0ol00009ok_Nl@;o00002onng_03o`0000Wo^^7c0_l00008okcQlP;o0000aOoo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo001Pooooo`03o`000?oooooo
oooo03cooooo00Go0000ol[7eoo:amOob/OGo`00000>olg7e003o`000?o@am7od<OA00God<OA0_l0
0005ol?>hP;o00003Oo6c^001Ol0003obLgMolW=gOo9cMgo000000[o`M?X0_l0000;olCCi@04o`00
0?nlengo0000o`0000go_mO[00?o0000ol;GjOo2enT01Oo2enT00ol0003o_=__okcKk`03okcKk`03
o`000?nofnko_m_^00[o_m_^0_l00003ol7Kk0;o00001Onkg_42o`0000_o_]k`0_l00003ol3NkP;o
00001OnjhO<2o`0000Wo_>7b00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01?ooooo001Qooooo`;o0000?Oooool00ol0003ob/OGo`00000>olg7e003o`00
0?o@am7od<OA00Sod<OA00Go0000ol?>h_o3c^;o`lkRo`00000>olK>h003o`000?o9cMgobLgM00?o
bLgM0_l00007ol7Cj003o`000?o4dnGoa=?U00_oa=?U0ol0000<okoGj`;o00002Oo2enT2o`000003
okcKkol0003o000000_o_m_^0_l00007ol7Kk0;o000000?o^mkao`000?l000002onng_02o`0000Oo
`=k^0_l000000onjhO?o0000o`000009okcQlP;o0000b_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01?ooooo001Sooooo`03o`000?oooooooooo03_ooooo0_l0000=olg7e003o`00
0?o@am7od<OA00[od<OA00?o0000ol?>h_l000003Oo6c^02o`0000SobLgM0_l00003ol7Cj0;o0000
3Oo4dnD01?l0003oam;SolOBhoo7d^<2o`0000So_mO[0_l0000<ol;Gj@?o00002_nofnh2o`0000[o
`M_/0ol0000:okkNl0;o00002_o0g^h3o`0000So_>7b0_l0003<ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool04oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003ocLOD
olg7e009olg7e003o`000?o@am7od<OA00_od<OA0ol0000<olK>h003o`000?o9cMgobLgM00[obLgM
00?o0000ol7Cj?l000003Oo4dnD2o`0000Koam;S0_l00005okoGj`03o`000?o2enWo`]OY00[o`]OY
0_l00003olGGi`?o00001Onofnh2o`0000_o`M_/00Co0000olCKj_o4fn[oa=_Z0ol00005okkNl0;o
00002_o0g^h2o`0000?o`]k]0_l00005okcQlP03o`000?oooooooooo0<gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Booooo`00IOooool00ol0003oooooooooo`0looooo`03o`00
0?o=amCocLOD00OocLOD00?o0000om37dOo@am402oo@am401Ol0003od/K?om;6cooBa/oo000000[o
a/kP00?o0000olW=gOo9cMd02oo9cMd3o`0000coa=?U00?o0000olOBhoo7d^<02?o7d^<2o`000003
okoGjol0003o000000co`]OY00?o0000olGGioo5enL01_o5enL2o`000003okoKk_l0003o000000_o
`M_/0_l00007olCKjP;o000000?o_]k`o`000?l000002_o0g^h2o`0000Oo`]k]0_l000000onlhO;o
0000o`00003Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool006Kooooo
0_l0000mooooo`03o`000?o=amCocLOD00GocLOD00?o0000om37dOo@am402oo@am400ol0003od/K?
om;6c`03om;6c`;o00001_o6c^02o`0000gobLgM00Go0000olc=foo<cM_oc<gKo`000009olCCi@;o
00003?o7d^<3o`0000_o`]OY0_l0000:olGGi`?o00002_o1fn`2o`0000[oa=_Z0ol00009ol3NkP;o
00002_o2g^d2o`000=Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`00
J?ooool00ol0003oooooooooo`0kooooo`03o`000?o=amCocLOD00?ocLOD00?o0000om37dOo@am40
2oo@am400ol0003od/K?om;6c`06om;6c`;o00000oo6c^000ol0003obLgMolW=g@0<olW=g@03o`00
0?o<cM_oc<gK00?oc<gK0_l00006olCCi@03o`000?o7d^?oam;S00_oam;S00Co0000olWBhOo9d^7o
bM;Q0_l00007ol;Gj@;o00002oo5enL01?l0003oamOUolOGiOo7enD2o`0000Oo`M_/00?o0000olCK
j_o4fnX02Oo4fnX01?l0003oa]_YolKKjOo6fnT2o`0000Go`=k^0_l0000;ol;Nk@03o`000?oooooo
oooo0=Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`00JOooool00ol0
003oooooooooo`0kooooo`05o`000?o=amCocLODolg7e?l000003Oo@am400ol0003od/K?om;6c`09
om;6c`03o`000?o6c^3o000000gobLgM0_l00008olc=f`04o`000?o4dnGoa=?UolCCi@;o00003?o7
d^<2o`0000KobM;Q00?o0000ol;GjOo2enT00oo2enT00ol0003oaMOWolGGi`09olGGi`;o00001_o7
enD00ol0003o`M_/ol7Kk002ol7Kk0;o00002_o4fnX2o`0000Koa]_Y0_l000000oo0g^ko0000o`00
000;ol;Nk@;o0000f?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo001Z
ooooo`03o`000?oooooooooo03_ooooo00?o0000olg7e?l000003Oo@am400ol0003od/K?om;6c`0;
om;6c`;o00003?o9cMd00ol0003oc<gKolc=f`09olc=f`03o`000?o4dnGo000000goam;S00?o0000
olWBhOo9d^401oo9d^42o`000003ol;GjOl0003o000000_oaMOW00?o0000olOGiOo7enD01oo7enD2
o`000003ol7Kk?l0003oa=_Z00[oa=_Z00?o0000olKKjOo6fnT01oo6fnT3o`0000[o`]k]0_l0003K
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool006_ooooo0_l0000loooo
o`;o00003?o@am400ol0003od/K?om;6c`0<om;6c`03o`000?oDa/co000000[obLgM00?o0000olc=
foo<cM/02_o<cM/3o`0000_oam;S0_l0000;olWBh@?o00002_o5enL2o`0000_oamOU0ol00009olCK
jP;o00002Oo6fnT01?l0003ob=_WolSKioo8fnL2o`0000Oo`]k]00?o0000ooooooooool0g?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo001]ooooo`03o`000?oooooooooo
03_ooooo00?o0000om37dOo@am402?o@am400ol0003od/K?om;6c`0<om;6c`05o`000?oDa/coe<K<
omC6c?l000002?o9cMd00ol0003oc<gKolc=f`0:olc=f`04o`000?o>cMSoc/gHolk=f0;o00002?o7
d^<00ol0003obM;QolWBh@0:olWBh@04o`000?o<d]ooc=;OolcBg`;o00001oo5enL00ol0003oamOU
olOGi@0:olOGi@05o`000?o:en?ob]OSol[Ghol000001oo4fnX00ol0003oa]_YolKKj@08olKKj@03
o`000?o8fnOob=_W00Cob=_W00?o0000ol;NkOo2g^d00_o2g^d2o`000=oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Booooo`00K_ooool00ol0003oooooooooo`0kooooo`03o`00
0?o@am7od<OA00Kod<OA00?o0000om;6cooBa/l03?oBa/l00ol0003oe<K<omC6c003omC6c003o`00
0?o9cMgobLgM00?obLgM0_l0000<olc=f`03o`000?o>cMSoc/gH00Coc/gH0_l00004olOBh`;o0000
3?o9d^400ol0003oc=;OolcBg`04olcBg`03o`000?o5enOoaMOW00;oaMOW0_l0000;olOGi@;o0000
1Oo:en<2o`0000?oa=_Z0_l00009olKKj@;o00002?o8fnL2o`000003ol;NkOl0003ooooo0>7ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`00Koooool00ol0003ooooooooo
o`0kooooo`;o00001Oo@am400ol0003od/K?om;6c`0<om;6c`03o`000?oDa/coe<K<00Goe<K<00Go
0000olW=gOo9cMgobLgMo`00000=olc=f`03o`000?o>cMSoc/gH00Ooc/gH0_l000000oo7d^?o0000
olWBh@0;olWBh@;o00002?o<d]l2o`000003olGGiol0003oamOU00_oamOU00?o0000ol[Ghoo:en<0
1oo:en<00ol0003oa=_Zo`00000:olKKj@03o`000?o8fnOob=_W00Wob=_W0_l0003Tooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04Oooool0073ooooo0_l0000mooooo`05o`000?o@
am7od<OAom37dOl000003_oBa/l00ol0003oe<K<omC6c007omC6c003o`000?o9cMgo000000goc<gK
00?o0000olk=f?o>cMP02Oo>cMP3o`0000_obM;Q00?o0000olcBgoo<d]l02Oo<d]l3o`0000[oamOU
0_l0000:ol[Gh`?o00002?o6fnT2o`0000[ob=_W0_l0003Wooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04Oooool007;ooooo00?o0000ooooooooool0>oooool00ol0003od<OAo`00
000>om;6c`03o`000?oDa/coe<K<00Woe<K<0_l0000;olc=f`;o00002oo>cMP01Ol0003od<gFom3=
e_o@cMKo000000WobM;Q00?o0000olcBgoo<d]l02Oo<d]l01?l0003oc];MolkBgOo>d]d2o`0000Oo
amOU00?o0000ol[Ghoo:en<02Oo:en<01?l0003oc=OQolcGhOo<en43o`0000Coa]_Y00?o0000olSK
ioo8fnL02Oo8fnL00ol0003oooooooooo`3Wooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04Oooool007?ooooo00?o0000ooooooooool0>oooool2o`0000god/K?00?o0000omC6c?oD
a/`02_oDa/`00ol0003oe/K:o`000009olc=f`03o`000?o>cMSoc/gH00[oc/gH00?o0000om3=e_o@
cMH00oo@cMH2o`0000GobM;Q0_l0000;olcBg`03o`000?o>d]goc];M00Coc];M00?o0000olOGiOo7
enD00_o7enD2o`0000_ob]OS00?o0000olcGhOo<en401Oo<en42o`000003olKKjOl0003ob=_W00Wo
b=_W0_l0003[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool007Cooooo
00?o0000ooooooooool0??ooool00ol0003od/K?om;6c`09om;6c`03o`000?oDa/coe<K<00[oe<K<
00Co0000omK6b_oFa/[oe/K:0_l00006olc=f`03o`000?o>cMSoc/gH00[oc/gH00?o0000om3=e_o@
cMH01_o@cMH01Ol0003obM;QolWBhOo9d^7o000000coc=;O00?o0000olkBgOo>d]d01_o>d]d2o`00
0003olOGiOl0003ob]OS00[ob]OS0_l00009olcGh@?o00002?o8fnL2o`000>kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Aooooo`00MOooool00ol0003oooooooooo`0looooo`03
o`000?oBa/ood/K?00Ood/K?00?o0000omC6c?oDa/`02_oDa/`00ol0003oe/K:omK6bP04omK6bP;o
00000oo<cM/00ol0003oc/gHolk=f00:olk=f003o`000?o@cMKod<gF00Sod<gF00?o0000olWBhOl0
00003?o<d]l00ol0003oc];MolkBg@08olkBg@?o00002_o:en<00ol0003oc=OQolcGh@08olcGh@04
o`000?o>e]ooc]KOolkFg`;o00001Oo8fnL00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04Oooool007Kooooo0_l0000mooooo`03o`000?oBa/ood/K?00Go
d/K?00?o0000omC6c?oDa/`02_oDa/`00ol0003oe/K:omK6bP07omK6bP03o`000?o<cM_o000000co
c/gH00?o0000om3=e_o@cMH02Oo@cMH3o`0000[oc=;O0_l0000:olkBg@04o`000?o@dM_od=7Kom3A
f`;o00001_o:en<2o`0000[oc=OQ00?o0000olkFgoo>e]l01?o>e]l2o`000003olSKiol0003o0000
0?;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`00N?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oBa/ood/K?00?od/K?00?o0000omC6c?oDa/`02_oDa/`00ol0003o
e/K:omK6bP09omK6bP;o00002oo>cMP00ol0003od<gFom3=eP09om3=eP05o`000?oBc=Cod/cDom;<
e?l000002?o<d]l00ol0003oc];MolkBg@09olkBg@03o`000?o@dM_od=7K00Cod=7K00?o0000ol[G
hoo:en<00_o:en<00ol0003oc=OQolcGh@08olcGh@;o00002?o>e]l2o`000?Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0@ooooo`00NOooool00ol0003oooooooooo`0kooooo`05
o`000?oBa/ood/K?om;6col000003?oDa/`00ol0003oe/K:omK6bP0:omK6bP03o`000?oHaLOo0000
00Woc/gH00?o0000om3=e_o@cMH02Oo@cMH00ol0003od/cDom;<e003om;<e0;o00001Oo<d]l00ol0
003oc];MolkBg@09olkBg@03o`000?o@dM_od=7K00Kod=7K0_l000000oo:en?o0000olcGh@09olcG
h@03o`000?o>e]ooc]KO00Ooc]KO00?o0000ooooooooool0m_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo013ooooo001jooooo`03o`000?oooooooooo03_ooooo00?o0000om;6col0
00003?oDa/`00ol0003oe/K:omK6bP0:omK6bP04o`000?oHaLOof<G7omS5a`;o00001_o>cMP00ol0
003od<gFom3=eP09om3=eP03o`000?oBc=Cod/cD00Kod/cD00Go0000olcBgoo<d]ooc=;Oo`00000;
olkBg@03o`000?o@dM_od=7K00Sod=7K0ol00009olcGh@03o`000?o>e]ooc]KO00Ooc]KO00?o0000
ooooooooool0moooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo001koooo
o`;o0000??ooool2o`0000coe<K<00?o0000omK6b_oFa/X02OoFa/X00ol0003of<G7omS5a`04omS5
a`;o00000oo>cMP00ol0003od<gFom3=eP09om3=eP03o`000?oBc=Cod/cD00Sod/cD00?o0000olcB
gol000002_o>d]d2o`0000[od=7K00Go0000om7AfOoAdMWodM7Io`000006olcGh@;o00002Oo>e]l0
0ol0003oooooooooo`3iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool0
07gooooo00?o0000ooooooooool0>oooool00ol0003oe<K<omC6c008omC6c003o`000?oFa/[oe/K:
00Woe/K:00?o0000omS5aooHaLL01ooHaLL00ol0003oc/gHo`00000;om3=eP03o`000?oBc=Cod/cD
00Wod/cD0ol00009olkBg@03o`000?o@dM_od=7K00Wod=7K00?o0000om7AfOoAdMT00ooAdMT2o`00
00?oc=OQ00?o0000olkFgoo>e]l02?o>e]l00ol0003oooooooooo`3kooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool007kooooo00?o0000ooooooooool0>oooool00ol0003o
e<K<omC6c006omC6c003o`000?oFa/[oe/K:00Woe/K:00?o0000omS5aooHaLL02OoHaLL2o`0000[o
d<gF00?o0000om;<e?oBc=@02OoBc=@01?l0003oe<cBomC<d_oDc=82o`0000Koc];M00?o0000om3A
foo@dM/02Oo@dM/00ol0003odM7Iom7Af@06om7Af@03o`000?o<en7o000000[oc]KO00?o0000oooo
ooooool0oOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo001oooooo`03
o`000?oooooooooo03_ooooo0_l00005omC6c003o`000?oFa/[oe/K:00[oe/K:00?o0000omS5aooH
aLL02OoHaLL00ol0003ofLG5o`000008om3=eP03o`000?oBc=Cod/cD00Wod/cD00?o0000omC<d_oD
c=801?oDc=800ol0003oc];MolkBg@02olkBg@03o`000?o@dM_od=7K00Wod=7K00?o0000om7AfOoA
dMT02?oAdMT2o`0000Woc]KO00?o0000ooooooooool0o_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00oooooo0020ooooo`;o0000?Oooool01Ol0003oe<K<omC6c?oDa/co000000co
e/K:00?o0000omS5aooHaLL02OoHaLL01?l0003ofLG5omW5aOoIaLD2o`0000God<gF00?o0000om;<
e?oBc=@02OoBc=@00ol0003oe<cBomC<dP06omC<dP;o000000?oc];Mo`000?o@dM/02Oo@dM/2o`00
00[odM7I00?o0000om?AeooCdML00_l00006olkFg`03o`000?oooooooooo0?oooooo0Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0022ooooo`03o`000?oooooooooo03_o
oooo00?o0000omC6c?l000003?oFa/X00ol0003of<G7omS5a`09omS5a`03o`000?oIaLGofLG500Co
fLG500Go0000om3=e_o@cMKod<gFo`00000;om;<e003o`000?oDc=;oe<cB00Woe<cB0_l00009om3A
f`03o`000?oAdMWodM7I00WodM7I00?o0000om?AeooCdML00ooCdML00ol0003oc]KOolkFg`02olkF
g`03o`000?oooooooooo0?oooooo0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00oooooo0023ooooo`03o`000?oooooooooo03_ooooo0_l0000;omK6bP03o`000?oHaLOof<G700Wo
f<G700?o0000omW5aOoIaLD01_oIaLD00ol0003od<gFo`00000;om;<e003o`000?oDc=;oe<cB00Wo
e<cB00?o0000omK;d?oFbm000_l00006om3Af`03o`000?oAdMWodM7I00WodM7I00?o0000om?AeooC
dML01OoCdML2o`000003olkFgol0003ooooo0?oooooo1Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00oooooo0024ooooo`03o`000?oooooooooo03cooooo00?o0000omK6b_oFa/X0
1ooFa/X00ol0003of<G7omS5a`09omS5a`03o`000?oIaLGofLG500SofLG50_l0000:om;<e003o`00
0?oDc=;oe<cB00Woe<cB00?o0000omK;d?oFbm000ooFbm000ol0003od=7Kom3Af`02om3Af`03o`00
0?oAdMWodM7I00WodM7I00?o0000om?AeooCdML01ooCdML2o`000?oooooo2?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00oooooo0025ooooo`;o0000?Oooool00ol0003oe/K:omK6
bP06omK6bP03o`000?oHaLOof<G700Wof<G700?o0000omW5aOoIaLD02?oIaLD00ol0003oflC3o`00
0008om;<e003o`000?oDc=;oe<cB00Woe<cB00?o0000omK;d?oFbm001OoFbm02o`000003om3Afol0
003odM7I00[odM7I00?o0000om?AeooCdML01ooCdML00ol0003oooooooooo`3oooooo`Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00Qoooool00ol0003oooooooooo`0k
ooooo`;o00001OoFa/X00ol0003of<G7omS5a`09omS5a`03o`000?oIaLGofLG500SofLG500Co0000
om_4`ooKa<?oflC30_l00005om;<e003o`000?oDc=;oe<cB00Woe<cB00?o0000omK;d?oFbm002?oF
bm02o`0000[odM7I00?o0000om?AeooCdML01ooCdML00ol0003oooooooooo`3oooooo`_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`00R?ooool00ol0003oooooooooo`0l
ooooo`05o`000?oFa/[oe/K:omK6b_l000002ooHaLL00ol0003ofLG5omW5a@08omW5a@03o`000?oK
a<?oflC300CoflC300Go0000om;<e?oBc=Cod/cDo`00000;omC<dP03o`000?oFbm3oe/_@00Woe/_@
00?o0000omO;c_l000002?oAdMT00ol0003odm7Gom?Ae`07om?Ae`03o`000?oooooooooo0?oooooo
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo0029ooooo`03o`000?oo
oooooooo03cooooo00?o0000omK6b_l000002ooHaLL00ol0003ofLG5omW5a@08omW5a@03o`000?oK
a<?oflC300KoflC300?o0000om;<e?l000002ooDc=800ol0003oe/_@omK;d009omK;d004o`000?oG
blkoel_>omO;cP;o00001OoAdMT00ol0003odm7Gom?Ae`07om?Ae`03o`000?oooooooooo0?oooooo
3_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo002:ooooo`03o`000?oo
oooooooo03cooooo0_l0000:omS5a`03o`000?oIaLGofLG500WofLG500?o0000om_4`ooKa<<01ooK
a<<2o`0000[oe<cB00?o0000omK;d?oFbm002OoFbm000ol0003oel_>omO;cP04omO;cP05o`000?oA
dMWodM7Iom7AfOl000002OoCdML00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`00Roooool2o`0003kooooo00?o0000omS5aooHaLL01_oH
aLL00ol0003ofLG5omW5a@09omW5a@03o`000?oKa<?oflC300SoflC300?o0000omc4`_l000002?oD
c=800ol0003oe/_@omK;d009omK;d003o`000?oGblkoel_>00Koel_>00?o0000om7AfOl000002OoC
dML00ol0003oooooooooo`3ooooooa;ooooo00Go0000ooooooooooooooooo`00000@ooooo`00SOoo
ool00ol0003oooooooooo`0looooo`03o`000?oHaLOof<G700Gof<G700?o0000omW5aOoIaLD02?oI
aLD00ol0003oflC3om_4``08om_4``04o`000?oLa<;og<C2omc4`P;o00001OoDc=800ol0003oe/_@
omK;d009omK;d003o`000?oGblkoel_>00Soel_>0_l00008om?Ae`03o`000?oooooooooo0?oooooo
4oooool01Ol0003ooooooooooooooooo0000013ooooo002>ooooo`03o`000?oooooooooo03cooooo
00?o0000omS5aooHaLL00ooHaLL00ol0003ofLG5omW5a@08omW5a@03o`000?oKa<?oflC300SoflC3
00?o0000omc4`_oLa<801?oLa<801Ol0003oe<cBomC<d_oDc=;o000000_oe/_@00?o0000omO;c_oG
blh02OoGblh00ol0003ofL_<o`000006om?Ae`03o`000?oooooooooo0?oooooo5Oooool01?l0003o
ooooooooool0000@ooooo`00Soooool00ol0003oooooooooo`0looooo`05o`000?oHaLOof<G7omS5
aol000002_oIaLD00ol0003oflC3om_4``09om_4``03o`000?oLa<;og<C200Gog<C200?o0000omC<
d_l000002ooFbm000ol0003oel_>omO;cP09omO;cP04o`000?oIblcofL_<omW;c0;o00000ooCdML0
0ol0003oooooooooo`3ooooooaOooooo00?o0000ooooool000004?ooool0093ooooo0_l0000moooo
o`03o`000?oHaLOo000000_ofLG500?o0000om_4`ooKa<<02?oKa<<00ol0003og<C2omc4`P07omc4
`P;o00002_oFbm000ol0003oel_>omO;cP09omO;cP03o`000?oIblcofL_<00CofL_<00?o0000om?A
eol00000oooooolJooooo`04o`000?ooooooooooo`0000oooooo002Booooo`03o`000?oooooooooo
03_ooooo0_l0000:omW5a@03o`000?oKa<?oflC300SoflC300?o0000omc4`_oLa<802?oLa<800ol0
003ogL?0o`000008omK;d003o`000?oGblkoel_>00Woel_>00?o0000omW;c?oIbl`01_oIbl`00ol0
003oooooooooo`3ooooooa[ooooo00?o0000ooooool000003oooool009?ooooo00?o0000oooooooo
ool0??ooool00ol0003ofLG5omW5a@06omW5a@03o`000?oKa<?oflC300WoflC300?o0000omc4`_oL
a<801ooLa<801?l0003ogL?0omg3`?oM`l02o`0000Goe/_@00?o0000omO;c_oGblh02OoGblh00ol0
003ofL_<omW;c007omW;c003o`000?oooooooooo0?oooooo6oooool2o`0000oooooo002Dooooo`03
o`000?oooooooooo03cooooo00?o0000omW5aOoIaLD01?oIaLD00ol0003oflC3om_4``09om_4``03
o`000?oLa<;og<C200Oog<C200?o0000omg3`?oM`l001?oM`l001Ol0003oe/_@omK;d?oFbm3o0000
00_oel_>00?o0000omW;c?oIbl`01ooIbl`00ol0003oooooooooo`3ooooooa_ooooo0ol0000?oooo
o`00UOooool2o`0003gooooo00?o0000omW5aOoIaLD00ooIaLD00ol0003oflC3om_4``08om_4``03
o`000?oLa<;og<C200Sog<C200?o0000omg3`?oM`l001OoM`l000ol0003oe/_@o`00000;omO;cP03
o`000?oIblcofL_<00OofL_<00?o0000ooooooooool0oooooolHooooo`Co00004_ooool009Oooooo
00?o0000ooooooooool0>oooool01Ol0003ofLG5omW5aOoIaLGo000000_oflC300?o0000omc4`_oL
a<801ooLa<800ol0003ogL?0omg3`007omg3`0;o00002_oGblh00ol0003ofL_<omW;c007omW;c003
o`000?oooooooooo0?oooooo5_ooool3o`0001Kooooo002Hooooo`03o`000?oooooooooo03_ooooo
00?o0000omW5aOl000002ooKa<<00ol0003og<C2omc4`P08omc4`P03o`000?oM`l3ogL?000OogL?0
00?o0000omk3__l000002?oGblh00ol0003ofL_<omW;c007omW;c003o`000?oooooooooo0?oooooo
4oooool4o`0001Wooooo002Iooooo`03o`000?oooooooooo03_ooooo0_l0000:om_4``03o`000?oL
a<;og<C200Sog<C200?o0000omg3`?oM`l001ooM`l001?l0003og/>nomk3__oN`kh2o`0000Goel_>
00?o0000omW;c?oIbl`02?oIbl`00ol0003oooooooooo`3oooooo`oooooo1?l0000Mooooo`00V_oo
ool2o`0003gooooo00?o0000om_4`ooKa<<01ooKa<<00ol0003og<C2omc4`P07omc4`P03o`000?oM
`l3ogL?000OogL?000?o0000omk3__oN`kh01?oN`kh01Ol0003oel_>omO;c_oGblko000000[ofL_<
00?o0000ooooooooool0ooooool<ooooo`Co00008Oooool009cooooo00?o0000ooooooooool0>ooo
ool00ol0003oflC3om_4``05om_4``03o`000?oLa<;og<C200Sog<C200?o0000omg3`?oM`l001ooM
`l000ol0003og/>nomk3_P05omk3_P03o`000?oGblko000000[ofL_<00?o0000ooooooooool0oooo
ool9ooooo`Co00009Oooool009gooooo00?o0000ooooooooool0>oooool2o`0000CoflC300?o0000
omc4`_oLa<802?oLa<800ol0003ogL?0omg3`007omg3`003o`000?oN`kkog/>n00Oog/>n0_l00009
omW;c003o`000?oooooooooo0?oooooo1oooool3o`0002Wooooo002Nooooo`03o`000?oooooooooo
03cooooo00Go0000om_4`ooKa<?oflC3o`000009omc4`P03o`000?oM`l3ogL?000SogL?000?o0000
omk3__oN`kh01ooN`kh00ol0003ogl>lo`000008omW;c003o`000?oooooooooo0?oooooo0oooool4
o`0002cooooo002Oooooo`03o`000?oooooooooo03cooooo00?o0000om_4`ol000002_oLa<800ol0
003ogL?0omg3`007omg3`003o`000?oN`kkog/>n00Oog/>n00Co0000omo3_?oO`kcogl>l0_l00005
omW;c003o`000?oooooooooo0?oooooo1?l0000`ooooo`00X?ooool2o`0003gooooo0_l00009omc4
`P03o`000?oM`l3ogL?000OogL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_004omo3
_005o`000?oIblcofL_<omW;c?l00000o_ooool4o`0003Cooooo002Rooooo`03o`000?oooooooooo
03cooooo00?o0000omc4`_oLa<801OoLa<800ol0003ogL?0omg3`008omg3`003o`000?oN`kkog/>n
00Oog/>n00?o0000omo3_?oO`k`01OoO`k`00ol0003ofL_<o`00003kooooo`Co0000>?ooool00:?o
oooo00?o0000ooooooooool0??ooool00ol0003og<C2omc4`P04omc4`P03o`000?oM`l3ogL?000Oo
gL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_007omo3_003o`000?oooooooooo0?Oo
oooo0ol0000looooo`00Y?ooool00ol0003oooooooooo`0looooo`03o`000?oLa<;og<C200;og<C2
00?o0000omg3`?oM`l002?oM`l000ol0003og/>nomk3_P07omk3_P03o`000?oO`kcogl>l00Oogl>l
00?o0000ooooooooool0loooool4o`0003oooooo002Uooooo`;o0000?Oooool01Ol0003og<C2omc4
`_oLa<;o000000WogL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_007omo3_003o`00
0?oooooooooo0?3ooooo1?l00013ooooo`00Yoooool00ol0003oooooooooo`0kooooo`03o`000?oL
a<;o000000WogL?000?o0000omk3__oN`kh01ooN`kh00ol0003ogl>lomo3_008omo3_003o`000?oo
oooooooo0>cooooo1?l00017ooooo`00Z?ooool00ol0003oooooooooo`0kooooo`;o00002OoM`l00
0ol0003og/>nomk3_P07omk3_P03o`000?oO`kcogl>l00Oogl>l00?o0000ooooooooool0jOooool4
o`0004_ooooo002Yooooo`03o`000?oooooooooo03cooooo00?o0000omg3`?oM`l001OoM`l000ol0
003og/>nomk3_P07omk3_P03o`000?oO`kcogl>l00Oogl>l00?o0000ooooooooool0ioooool3o`00
04oooooo002Zooooo`;o0000?Oooool00ol0003ogL?0omg3`004omg3`003o`000?oN`kkog/>n00Oo
g/>n00?o0000omo3_?oO`k`01ooO`k`00ol0003oooooooooo`3Sooooo`Co0000D_ooool00:cooooo
00?o0000ooooooooool0>oooool00ol0003ogL?0omg3`002omg3`003o`000?oN`kkog/>n00Oog/>n
00?o0000omo3_?oO`k`01ooO`k`00ol0003oooooooooo`3Pooooo`Co0000E_ooool00:gooooo00?o
0000ooooooooool0>oooool01?l0003ogL?0omg3`?l00009omk3_P03o`000?oO`kcogl>l00Sogl>l
00?o0000ooooooooool0g?ooool4o`0005[ooooo002^ooooo`03o`000?oooooooooo03_ooooo00?o
0000omg3`?l000002OoN`kh00ol0003ogl>lomo3_007omo3_003o`000?oooooooooo0=Wooooo1?l0
001Nooooo`00[oooool2o`0003cooooo0_l00008omk3_P03o`000?oO`kcogl>l00Sogl>l00?o0000
ooooooooool0e_ooool3o`0006;ooooo002aooooo`03o`000?oooooooooo03_ooooo00?o0000omk3
__oN`kh01OoN`kh00ol0003ogl>lomo3_007omo3_003o`000?oooooooooo0=?ooooo1?l0001Uoooo
o`00/_ooool00ol0003oooooooooo`0kooooo`;o00001?oN`kh00ol0003ogl>lomo3_007omo3_003
o`000?oooooooooo0=3ooooo1?l0001Yooooo`00/oooool00ol0003oooooooooo`0looooo`04o`00
0?oN`kkog/>no`0000[ogl>l00?o0000ooooooooool0c?ooool4o`0006gooooo002dooooo`03o`00
0?oooooooooo03cooooo00?o0000omk3__l000002OoO`k`00ol0003oooooooooo`39ooooo`Co0000
LOooool00;Gooooo0_l0000mooooo`;o00002OoO`k`00ol0003oooooooooo`36ooooo`?o0000MOoo
ool00;Oooooo00?o0000ooooooooool0??ooool00ol0003ogl>lomo3_005omo3_003o`000?oooooo
oooo0<?ooooo1?l0001hooooo`00^?ooool00ol0003oooooooooo`0looooo`03o`000?oO`kcogl>l
00Cogl>l00?o0000ooooooooool0_oooool4o`0007cooooo002iooooo`03o`000?oooooooooo03co
oooo00?o0000omo3_?oO`k`00_oO`k`00ol0003oooooooooo`2looooo`Co0000P?ooool00;[ooooo
0_l0000mooooo`04o`000?oO`kcogl>lo`000;cooooo0ol00024ooooo`00_?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oO`kco00000;Sooooo1?l00027ooooo`00_Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;?ooooo1?l0002;ooooo`00__ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo0:oooooo1?l0002?ooooo`00_oooool2o`0003[ooooo00?o0000oooo
ooooool0Zoooool4o`0009?ooooo0031ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Z?ooool3o`0009Oooooo0032ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
Y?ooool4o`0009[ooooo0033ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0X?oo
ool4o`0009kooooo0034ooooo`;o0000=Oooool00ol0003oooooooooo`2Looooo`Co0000X_ooool0
0<Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Hooooo`Co0000Y_ooool00<Oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Eooooo`?o0000Z_ooool00<Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Booooo`Co0000[Oooool00<Wooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2>ooooo`Co0000/Oooool00<[ooooo0_l0000^
ooooo`03o`000?oooooooooo08[ooooo1?l0002eooooo`00c?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo08Kooooo1?l0002iooooo`00cOooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo08?ooooo0ol0002mooooo`00c_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo07oooooo1?l00030ooooo`00coooool2o`0002Wooooo00?o0000ooooooooool0Nooo
ool4o`000<Cooooo003Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4
o`000<Sooooo003Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00
0<cooooo003Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool3o`000=3o
oooo003Dooooo`;o00009?ooool00ol0003oooooooooo`1/ooooo`Co0000doooool00=Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000eoooool00=Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000foooool00=Sooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000goooool00=Wooooo0_l0000Oooooo`03
o`000?oooooooooo05gooooo1?l0003Rooooo`00foooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05Wooooo1?l0003Vooooo`00g?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Gooooo1?l0003Zooooo`00gOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo057ooooo1?l0003^ooooo`00g_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04kooooo0ol0003booooo`00goooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`000?Go
oooo003Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`000?Wooooo
003Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`000?gooooo003S
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`000?oooooo0_ooool0
0>Cooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo0ol0003oooooo`Kooooo003Vooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`000?oooooo2Oooool00>Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000ooooool=ooooo`00j?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo1?l0003ooooooa7ooooo003Y
ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`Co0000oooooolEooooo`00joooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0003ooooooaWooooo003/ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`000?oooooo7?ooool00>gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000oooooolPooooo`00k_oo
ool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000?oooooo9?ooool00?3ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000oooooolXooooo`00lOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0003oooooobcooooo003booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000?oooooo;oooool00??ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000oooooolcooooo`00m?oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000?oooooo=oooool00?Kooooo00Co0000
oooooooooooo00002?ooool4o`000?oooooo>oooool00?Oooooo00?o0000ooooool000001Oooool3
o`000?oooooo?oooool00?Sooooo0_l000000ooooooo0000o`000002o`000?oooooo@_ooool00?Wo
oooo0_l0003oooooodKooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.081516, 0.0209008, \
0.00184551, 0.00184551}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s FindRoot function can be used to map out the miscibility gap. Note that \
the common tangent in this symmetric free energy model will have zero slope. \
FindRoot needs an initial guess and I start from 990 K and work downward \
along one branch of the curve."
}], "Text"],

Cell["\<\
First, initialize an array for storing pairs of values (T, XB) that \
will form the coexistence curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoexCurvePts = {}\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell["\<\
Here's the general procedure for calculating and extracting the \
value of a point on the coexistence curve:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(T = 990\), "\[IndentingNewLine]", 
    \(XBCoex = 
      FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 0, {XB, 
          0.6}]\), "\[IndentingNewLine]", 
    \(XBCoex[\([1, 2]\)]\)}], "Input"],

Cell[BoxData[
    \(990\)], "Output"],

Cell[BoxData[
    \({XB \[Rule] 0.5862555349875236`}\)], "Output"],

Cell[BoxData[
    \(0.5862555349875236`\)], "Output"]
}, Open  ]],

Cell["Now calculate a whole lot of points:", "Text"],

Cell[BoxData[{
    \(\(CoexCurvePts = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]XBCoex = 
        FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 0, {XB, 
            XBCoex[\([1, 2]\)]}]; \[IndentingNewLine]CoexCurvePts = 
        Append[CoexCurvePts, {XBCoex[\([1, 2]\)], T}], {T, 990, 
        300, \(-10\)}]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BSide = 
      ListPlot[CoexCurvePts, 
        AxesLabel \[Rule] {"\<Atom Fraction,XB\>", "\<Temperature,K\>"}]\)], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.3299 2.30907 -0.2412 0.000853049 [
[.05555 .00222 -9 -9 ]
[.05555 .00222 9 0 ]
[.28645 .00222 -9 -9 ]
[.28645 .00222 9 0 ]
[.51736 .00222 -9 -9 ]
[.51736 .00222 9 0 ]
[.74827 .00222 -9 -9 ]
[.74827 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.96668 .10002 -18 -4.5 ]
[.96668 .10002 0 4.5 ]
[.96668 .18532 -18 -4.5 ]
[.96668 .18532 0 4.5 ]
[.96668 .27063 -18 -4.5 ]
[.96668 .27063 0 4.5 ]
[.96668 .35593 -18 -4.5 ]
[.96668 .35593 0 4.5 ]
[.96668 .44124 -18 -4.5 ]
[.96668 .44124 0 4.5 ]
[.96668 .52654 -18 -4.5 ]
[.96668 .52654 0 4.5 ]
[.96668 .61185 -24 -4.5 ]
[.96668 .61185 0 4.5 ]
[.97918 .64303 -41 0 ]
[.97918 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05555 .01472 m
.05555 .02097 L
s
[(0.6)] .05555 .00222 0 1 Mshowa
.28645 .01472 m
.28645 .02097 L
s
[(0.7)] .28645 .00222 0 1 Mshowa
.51736 .01472 m
.51736 .02097 L
s
[(0.8)] .51736 .00222 0 1 Mshowa
.74827 .01472 m
.74827 .02097 L
s
[(0.9)] .74827 .00222 0 1 Mshowa
.125 Mabswid
.10173 .01472 m
.10173 .01847 L
s
.14791 .01472 m
.14791 .01847 L
s
.19409 .01472 m
.19409 .01847 L
s
.24027 .01472 m
.24027 .01847 L
s
.33264 .01472 m
.33264 .01847 L
s
.37882 .01472 m
.37882 .01847 L
s
.425 .01472 m
.425 .01847 L
s
.47118 .01472 m
.47118 .01847 L
s
.56354 .01472 m
.56354 .01847 L
s
.60972 .01472 m
.60972 .01847 L
s
.65591 .01472 m
.65591 .01847 L
s
.70209 .01472 m
.70209 .01847 L
s
.79445 .01472 m
.79445 .01847 L
s
.84063 .01472 m
.84063 .01847 L
s
.88681 .01472 m
.88681 .01847 L
s
.93299 .01472 m
.93299 .01847 L
s
.00937 .01472 m
.00937 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97918 .10002 m
.98543 .10002 L
s
[(400)] .96668 .10002 1 0 Mshowa
.97918 .18532 m
.98543 .18532 L
s
[(500)] .96668 .18532 1 0 Mshowa
.97918 .27063 m
.98543 .27063 L
s
[(600)] .96668 .27063 1 0 Mshowa
.97918 .35593 m
.98543 .35593 L
s
[(700)] .96668 .35593 1 0 Mshowa
.97918 .44124 m
.98543 .44124 L
s
[(800)] .96668 .44124 1 0 Mshowa
.97918 .52654 m
.98543 .52654 L
s
[(900)] .96668 .52654 1 0 Mshowa
.97918 .61185 m
.98543 .61185 L
s
[(1000)] .96668 .61185 1 0 Mshowa
.125 Mabswid
.97918 .03178 m
.98293 .03178 L
s
.97918 .04884 m
.98293 .04884 L
s
.97918 .0659 m
.98293 .0659 L
s
.97918 .08296 m
.98293 .08296 L
s
.97918 .11708 m
.98293 .11708 L
s
.97918 .13414 m
.98293 .13414 L
s
.97918 .1512 m
.98293 .1512 L
s
.97918 .16826 m
.98293 .16826 L
s
.97918 .20239 m
.98293 .20239 L
s
.97918 .21945 m
.98293 .21945 L
s
.97918 .23651 m
.98293 .23651 L
s
.97918 .25357 m
.98293 .25357 L
s
.97918 .28769 m
.98293 .28769 L
s
.97918 .30475 m
.98293 .30475 L
s
.97918 .32181 m
.98293 .32181 L
s
.97918 .33887 m
.98293 .33887 L
s
.97918 .373 m
.98293 .373 L
s
.97918 .39006 m
.98293 .39006 L
s
.97918 .40712 m
.98293 .40712 L
s
.97918 .42418 m
.98293 .42418 L
s
.97918 .4583 m
.98293 .4583 L
s
.97918 .47536 m
.98293 .47536 L
s
.97918 .49242 m
.98293 .49242 L
s
.97918 .50948 m
.98293 .50948 L
s
.97918 .54361 m
.98293 .54361 L
s
.97918 .56067 m
.98293 .56067 L
s
.97918 .57773 m
.98293 .57773 L
s
.97918 .59479 m
.98293 .59479 L
s
.25 Mabswid
.97918 0 m
.97918 .61803 L
s
gsave
.97918 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.10517 .59479 Mdot
.16682 .58626 Mdot
.21814 .57773 Mdot
.26277 .5692 Mdot
.30259 .56067 Mdot
.33872 .55214 Mdot
.37189 .54361 Mdot
.40262 .53507 Mdot
.43127 .52654 Mdot
.45812 .51801 Mdot
.48341 .50948 Mdot
.50729 .50095 Mdot
.52993 .49242 Mdot
.55142 .48389 Mdot
.57188 .47536 Mdot
.59138 .46683 Mdot
.61 .4583 Mdot
.6278 .44977 Mdot
.64484 .44124 Mdot
.66115 .43271 Mdot
.67679 .42418 Mdot
.69179 .41565 Mdot
.70618 .40712 Mdot
.72 .39859 Mdot
.73327 .39006 Mdot
.74602 .38153 Mdot
.75826 .373 Mdot
.77003 .36447 Mdot
.78133 .35593 Mdot
.79219 .3474 Mdot
.80261 .33887 Mdot
.81263 .33034 Mdot
.82224 .32181 Mdot
.83147 .31328 Mdot
.84032 .30475 Mdot
.84881 .29622 Mdot
.85694 .28769 Mdot
.86473 .27916 Mdot
.87219 .27063 Mdot
.87932 .2621 Mdot
.88613 .25357 Mdot
.89263 .24504 Mdot
.89883 .23651 Mdot
.90474 .22798 Mdot
.91036 .21945 Mdot
.9157 .21092 Mdot
.92077 .20239 Mdot
.92557 .19386 Mdot
.93011 .18532 Mdot
.9344 .17679 Mdot
.93844 .16826 Mdot
.94224 .15973 Mdot
.9458 .1512 Mdot
.94913 .14267 Mdot
.95224 .13414 Mdot
.95513 .12561 Mdot
.95782 .11708 Mdot
.9603 .10855 Mdot
.96258 .10002 Mdot
.96467 .09149 Mdot
.96658 .08296 Mdot
.96831 .07443 Mdot
.96988 .0659 Mdot
.97128 .05737 Mdot
.97254 .04884 Mdot
.97364 .04031 Mdot
.97462 .03178 Mdot
.97546 .02325 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{402.875, 248.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000n2000`400?l00000o`00003ooooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`002Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003Kooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0003Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0002`ooooo`002?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000003Cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`2]
ooooo`002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000=?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000003Cooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`2/ooooo`002?ooool01?l0003oooooooooool00007ooooo`Co0000=Oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo0000
2?ooool3o`0003Gooooo00Co0000oooooooooooo00002?ooool4o`000:kooooo0008ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool0000;oooo
o`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000003Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000:ko
oooo0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0=Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool00000=?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool00000[_ooool000Wooooo0_l0000:ooooo`;o0000=_ooool2o`0000So
oooo1Ol0000eooooo`;o00002Oooool3o`0003Kooooo0_l00009ooooo`?o0000[oooool00?oooooo
8Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo013ooooo003oooooob7ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0?ooooo`00oooooolQooooo`03o`000?oooooo
oooo00cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool3o`0000;ooooo00Go
0000ooooool0003oooooo`000007ooooo`?o00000oooool3o`0000Cooooo1?l00002ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool4o`0000Gooooo003oooooob7ooooo
00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`07o`000?oooooo0000ooooool0003oooooo`000008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00004ooooo`00ool0000Xo`0000Sooooo
1Ol00002ooooo`03o`000?oooooooooo00;ooooo00_o0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000oo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`0;o`000?oooooooooooooo
ool0003oooooo`000?oooooo0000ooooool000002?ooool3o`0000?ooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`?o00001Oooool0013ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000;ooooo1?l00003
ooooo`?o00000_ooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000_ooool4o`0000;ooooo0ol00004
ooooo`?o00000_ooool4o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`00oooooolOooooo`?o00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00001?ooool00?oooooo7oooool3o`0000oooooo0_l0
0004ooooo`03o`000?oooooooooo01Cooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool2o`000004ooooool0003o0000ooooo`Co00001Oooool00?oooooo7ooo
ool4o`00073ooooo003ooooooaoooooo0ol0001aooooo`00oooooolQooooo`03o`000?oooooooooo
06oooooo003ooooooaoooooo0ol0001aooooo`00oooooolOooooo`?o0000LOooool00?oooooo7_oo
ool2o`000003ooooool0003o0000073ooooo003ooooooakooooo0_l000000ooooooo0000ooooo`1`
ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003ooooooakooooo0_l000000ooooooo
0000ooooo`1`ooooo`00oooooolNooooo`;o000000?oooooo`000?ooool0L?ooool00?oooooo7Ooo
ool2o`0000;ooooo0_l0001`ooooo`00oooooolMooooo`;o00000_ooool00ol0003oooooooooo`1_
ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003ooooooagooooo0_l00002ooooo`03
o`000?oooooooooo06oooooo003ooooooagooooo0_l00002ooooo`03o`000?oooooooooo06oooooo
003ooooooacooooo0_l00003ooooo`;o0000L?ooool00?oooooo7?ooool2o`0000?ooooo00?o0000
ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00ooooool=ooooo`?o
00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo06oo
oooo003oooooo`kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo0ol00003ooooo`03o`000?oooooooooo06oooooo003oooooo`_ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_l00004ooooo`?o0000Koooool00?oo
oooo2oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_l00004ooooo`03o`000?oooooooooo06oooooo003oooooo`cooooo00?o0000oooo
ool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0Koooool00?oooooo3Oooool2o`0000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool0Koooool00?oooooo3_ooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool4o`0000Cooooo00?o0000ooooooooool0Koooool0
0?oooooo6_ooool2o`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo6_ooool2o`0000Go
oooo0_l0001`ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003ooooooaWooooo0_l0
0006ooooo`03o`000?oooooooooo06oooooo003ooooooaWooooo0_l00006ooooo`03o`000?oooooo
oooo06oooooo003ooooooaSooooo0_l00007ooooo`03o`000?oooooooooo06oooooo003ooooooaSo
oooo0_l00007ooooo`;o0000L?ooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00oooo
oolGooooo`;o00002?ooool00ol0003oooooooooo`1_ooooo`00oooooolGooooo`;o00002?ooool0
0ol0003oooooooooo`1_ooooo`00oooooolFooooo`;o00002Oooool00ol0003oooooooooo`1_oooo
o`00oooooolFooooo`;o00002Oooool2o`00073ooooo003oooooob7ooooo00?o0000ooooooooool0
Koooool00?oooooo5Oooool2o`0000[ooooo00?o0000ooooooooool0Koooool00?oooooo5Oooool2
o`0000[ooooo00?o0000ooooooooool0Koooool00?oooooo5?ooool2o`0000_ooooo00?o0000oooo
ooooool0Koooool00?oooooo5?ooool2o`0000_ooooo0_l0001`ooooo`00oooooolQooooo`03o`00
0?oooooooooo06oooooo003oooooo`cooooo0ol00004ooooo`;o00001?ooool2o`0000Kooooo00?o
0000ooooooooool0Koooool00?oooooo2oooool01Ol0003ooooooooooooooooo000000;ooooo1?l0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo3ooo
ool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool000000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06oooooo003oooooo`oooooo00?o0000ooooooooool00_l0
00001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooooooool00oooool3o`0006oooooo
003oooooo`_ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`1_ooooo`00ooooool;ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1_ooooo`00ooooool;ooooo`Oo000000?oooooo`000?l000001?ooool2o`0000Kooooo
00?o0000ooooooooool0Koooool00?oooooo3oooool2o`00013ooooo00?o0000ooooooooool0Kooo
ool00?oooooo3oooool2o`00013ooooo0_l0001`ooooo`00oooooolQooooo`03o`000?oooooooooo
06oooooo003oooooo`gooooo0_l0000Booooo`03o`000?oooooooooo06oooooo003oooooo`gooooo
0_l0000Booooo`03o`000?oooooooooo06oooooo003oooooo`cooooo0_l0000Cooooo`03o`000?oo
oooooooo06oooooo003oooooo`cooooo0_l0000Cooooo`;o0000L?ooool00?oooooo8Oooool00ol0
003oooooooooo`1_ooooo`00ooooool:ooooo`;o00005Oooool00ol0003oooooooooo`1_ooooo`00
ooooool:ooooo`;o00005Oooool00ol0003oooooooooo`1_ooooo`00ooooool8ooooo`;o00005ooo
ool00ol0003oooooooooo`1_ooooo`00ooooool8ooooo`;o00005oooool2o`00073ooooo003ooooo
ob7ooooo00?o0000ooooooooool0Koooool00?oooooo1oooool2o`0001Sooooo00?o0000oooooooo
ool0Koooool00?oooooo1oooool2o`0001Sooooo00?o0000ooooooooool0Koooool00?oooooo1Ooo
ool2o`0001[ooooo00?o0000ooooooooool0Koooool00?oooooo1Oooool2o`0001[ooooo0_l0001`
ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003oooooo`?ooooo0_l00007ooooo`?o
00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo003oooooo`?ooooo
0_l00006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo0Oooool2o`00
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00ooooool1ooooo`;o00002?oo
ool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`?o
0000Koooool00?oooooo2oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00oOooool2o`0000co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0Koooool00?gooooo0_l0000=ooooo`;o00001?ooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo003kooooo`;o00008oooool00ol0003o
ooooooooo`1_ooooo`00noooool2o`0002?ooooo0_l0001`ooooo`00oooooolQooooo`03o`000?oo
oooooooo06oooooo003iooooo`;o00009Oooool00ol0003oooooooooo`1_ooooo`00nOooool2o`00
02Gooooo00?o0000ooooooooool0Koooool00?Kooooo0_l0000Xooooo`03o`000?oooooooooo06oo
oooo003fooooo`;o0000:?ooool2o`00073ooooo003oooooob7ooooo00?o0000ooooooooool0Kooo
ool00?Cooooo0_l0000Zooooo`03o`000?oooooooooo06oooooo003dooooo`;o0000:_ooool00ol0
003oooooooooo`1_ooooo`00lOooool2o`0002gooooo00?o0000ooooooooool0Koooool00?7ooooo
0_l0000]ooooo`;o0000L?ooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00k_ooool2
o`00033ooooo00?o0000ooooooooool0Koooool00>kooooo0_l0000`ooooo`03o`000?oooooooooo
06oooooo003[ooooo`;o0000<oooool00ol0003oooooooooo`1_ooooo`00joooool2o`0003?ooooo
0_l0001`ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo003Xooooo`;o00008_ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0Koooool0
0>Sooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo003Uooooo`;o00009_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06oooooo003Uooooo`;o00009_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`?o
0000Koooool00?oooooo3oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1_ooooo`00h_ooool2o`0002Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00h_ooool2o`0002Kooooo1Ol00003
ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0Koooool00=kooooo0_l00010oooo
o`03o`000?oooooooooo06oooooo003Nooooo`;o0000@?ooool2o`00073ooooo003oooooob7ooooo
00?o0000ooooooooool0Koooool00=[ooooo0_l00014ooooo`03o`000?oooooooooo06oooooo003J
ooooo`;o0000A?ooool00ol0003oooooooooo`1_ooooo`00oooooolQooooo`03o`000?oooooooooo
06oooooo003Gooooo`;o0000Aoooool2o`00073ooooo003Gooooo`;o0000Aoooool00ol0003ooooo
ooooo`1_ooooo`00doooool2o`0004_ooooo00?o0000ooooooooool0Koooool00=?ooooo0_l0001;
ooooo`03o`000?oooooooooo06oooooo003oooooob7ooooo00?o0000ooooooooool0Koooool00<oo
oooo0_l0001?ooooo`;o0000L?ooool00<oooooo0_l0001?ooooo`03o`000?oooooooooo06oooooo
003;ooooo`;o0000Doooool00ol0003oooooooooo`1_ooooo`00boooool2o`0005?ooooo00?o0000
ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00a_ooool2o`0005So
oooo0_l0001`ooooo`00a_ooool2o`0005Sooooo00?o0000ooooooooool0Koooool00<;ooooo0_l0
0017ooooo`?o00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo0032
ooooo`;o0000A_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo003oooooo`_ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00_Oooool2o`0004cooooo0ol00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool3o`0006oooooo002m
ooooo`;o0000Boooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo002hooooo`;o0000
D?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo002hooooo`;o0000DOooool3o`00
00Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`1_ooooo`00oooooolQooooo`03
o`000?oooooooooo06oooooo002booooo`;o0000K?ooool2o`00073ooooo002booooo`;o0000K?oo
ool00ol0003oooooooooo`1_ooooo`00[Oooool2o`00077ooooo00?o0000ooooooooool0Koooool0
0:gooooo0_l0001aooooo`03o`000?oooooooooo06oooooo003oooooob7ooooo00?o0000oooooooo
ool0Koooool00:Oooooo0_l0001gooooo`;o0000L?ooool00:Oooooo0_l0001gooooo`03o`000?oo
oooooooo06oooooo002Qooooo`;o0000OOooool00ol0003oooooooooo`1_ooooo`00XOooool2o`00
07gooooo00?o0000ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00
Voooool2o`0008?ooooo0_l0001`ooooo`00Voooool2o`0008?ooooo00?o0000ooooooooool0Kooo
ool009Cooooo0_l0002:ooooo`03o`000?oooooooooo06oooooo002Dooooo`;o0000R_ooool00ol0
003oooooooooo`1_ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo002=ooooo`;o0000
TOooool2o`00073ooooo002=ooooo`;o0000TOooool00ol0003oooooooooo`1_ooooo`00Q_ooool2
o`0009Sooooo00?o0000ooooooooool0Koooool008Kooooo0_l00023ooooo`;o00001Oooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo003oooooo`kooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1_ooooo`00O_ooool2o`0008kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo0ol0001_ooooo`00O_ooool2
o`0008_ooooo1?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`1_ooooo`00MOooool2o`0009?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`1_ooooo`00MOooool2o`0009?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`1_ooooo`00ooooool<ooooo`?o00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo06oooooo001/ooooo`;o0000/_ooool2o`00073ooooo001/ooooo`;o0000/_ooool00ol0003o
ooooooooo`1_ooooo`00Hoooool2o`000;_ooooo00?o0000ooooooooool0Koooool006?ooooo0_l0
002kooooo`03o`000?oooooooooo06oooooo003oooooob7ooooo00?o0000ooooooooool0Koooool0
05Sooooo0_l00036ooooo`;o0000L?ooool005Sooooo0_l00036ooooo`03o`000?oooooooooo06oo
oooo001<ooooo`;o0000d_ooool00ol0003oooooooooo`1_ooooo`00C?ooool2o`000=;ooooo00?o
0000ooooooooool0Koooool00?oooooo8Oooool00ol0003oooooooooo`1_ooooo`00?oooool2o`00
0=oooooo0_l0001`ooooo`00?oooool2o`000=oooooo00?o0000ooooooooool0Koooool0033ooooo
0_l0003^ooooo`03o`000?oooooooooo06oooooo000`ooooo`;o0000k_ooool00ol0003ooooooooo
o`1_ooooo`00oooooolQooooo`03o`000?oooooooooo06oooooo000Nooooo`;o0000ooooool1oooo
o`;o0000L?ooool001kooooo0_l0003oooooo`7ooooo00?o0000ooooooooool0Koooool000Kooooo
0_l0003ooooooaWooooo00?o0000ooooooooool0Koooool000Kooooo0_l0003mooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`1_ooooo`00ooooool7
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Koooool00?oooooo
1oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00005ooooo`?o0000Koooool00?oooooo1oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06oooooo003oooooo`Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1_ooooo`00ooooool6ooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo0000Moooool00?oooooo1oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l0001hooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00oooo
oonCooooo`00oooooonCooooo`00oooooonCooooo`00ooooool<ooooo`?o0000;oooool00ol0003o
ooooooooo`1Booooo`00ooooool=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
DOooool00?[ooooo0ol00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo
0ol00003ooooo`?o00000_ooool3o`0000Cooooo1?l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o00001?ooool3o`0000Gooooo00?o0000ooooooooool00ol000000ooooooo0000
o`00001;ooooo`00noooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooool0003o
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0003o
ooooooooool0001<ooooo`00noooool01?l0003oooooooooooooool5o`000006ooooool0003ooooo
o`000?oooooo00000_ooool01Ol0003oooooooooool0003ooooo00Go00000_ooool00ol0003ooooo
ooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool5o`0000Sooooo00?o0000ooooool00000COooool00?_ooooo
00Go0000ooooooooooooooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000?ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0004kooooo003ioooo
o`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo0_l000001?oooooo0000oooooooo
ool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1?l0
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
2Oooool00ol0003oooooo`00001=ooooo`00nOooool01Ol0003oooooo`000?oooooo000002Kooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool0001<ooooo`00nOooool5o`0002Kooooo
00?o0000ooooooooool06_ooool3o`000003ooooool0003o000004_ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003o
oooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo003ooooooi?ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 401.875}, {247.938, 0}} -> {0.575944, 173.276, \
0.00147111, 3.98205}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Now do the same for the A-rich compositions, adding the points to \
CoexCurvePts. Note I'm adding the point at the top of the miscibility gap as \
well. Also, I could have made use of the fact that the coexistence curve is \
symmetric about XB = 0.5, but I calculated the points instead.\
\>", "Text"],

Cell[BoxData[{
    \(\(CoexCurvePts = 
        Prepend[CoexCurvePts, {0.5, 1000}];\)\), "\[IndentingNewLine]", 
    \(\(XBCoex[\([1, 2]\)] = 0.4;\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]XBCoex = 
        FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 0, {XB, 
            XBCoex[\([1, 2]\)]}]; \[IndentingNewLine]CoexCurvePts = 
        Prepend[CoexCurvePts, {XBCoex[\([1, 2]\)], T}], {T, 990, 
        300, \(-10\)}]\)}], "Input"],

Cell["Here is the calculated equilibrium diagram", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoexPlot = 
      ListPlot[CoexCurvePts, PlotJoined \[Rule] True, \ 
        AxesLabel \[Rule] {"\<Atom Fraction,XB\>", "\<Temperature,K\>"}, 
        PlotStyle \[Rule] {Thickness[0.005]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.953614 -0.237544 0.000840863 [
[.21453 .00222 -9 -9 ]
[.21453 .00222 9 0 ]
[.40526 .00222 -9 -9 ]
[.40526 .00222 9 0 ]
[.59598 .00222 -9 -9 ]
[.59598 .00222 9 0 ]
[.7867 .00222 -9 -9 ]
[.7867 .00222 9 0 ]
[.97742 .00222 -3 -9 ]
[.97742 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -41 0 ]
[.02381 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21453 .01472 m
.21453 .02097 L
s
[(0.2)] .21453 .00222 0 1 Mshowa
.40526 .01472 m
.40526 .02097 L
s
[(0.4)] .40526 .00222 0 1 Mshowa
.59598 .01472 m
.59598 .02097 L
s
[(0.6)] .59598 .00222 0 1 Mshowa
.7867 .01472 m
.7867 .02097 L
s
[(0.8)] .7867 .00222 0 1 Mshowa
.97742 .01472 m
.97742 .02097 L
s
[(1)] .97742 .00222 0 1 Mshowa
.125 Mabswid
.07149 .01472 m
.07149 .01847 L
s
.11917 .01472 m
.11917 .01847 L
s
.16685 .01472 m
.16685 .01847 L
s
.26221 .01472 m
.26221 .01847 L
s
.30989 .01472 m
.30989 .01847 L
s
.35757 .01472 m
.35757 .01847 L
s
.45294 .01472 m
.45294 .01847 L
s
.50062 .01472 m
.50062 .01847 L
s
.5483 .01472 m
.5483 .01847 L
s
.64366 .01472 m
.64366 .01847 L
s
.69134 .01472 m
.69134 .01847 L
s
.73902 .01472 m
.73902 .01847 L
s
.83438 .01472 m
.83438 .01847 L
s
.88206 .01472 m
.88206 .01847 L
s
.92974 .01472 m
.92974 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0988 m
.03006 .0988 L
s
[(400)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(500)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(600)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(700)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(800)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(900)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.005 w
.02504 .01472 m
.02534 .02312 L
.02569 .03153 L
.02609 .03994 L
.02655 .04835 L
.02707 .05676 L
.02765 .06517 L
.0283 .07358 L
.02901 .08198 L
.0298 .09039 L
.03066 .0988 L
.03161 .10721 L
.03263 .11562 L
.03374 .12403 L
.03493 .13244 L
.03622 .14084 L
.03759 .14925 L
.03907 .15766 L
.04063 .16607 L
.0423 .17448 L
.04407 .18289 L
.04595 .1913 L
.04793 .1997 L
.05002 .20811 L
.05223 .21652 L
.05455 .22493 L
.05699 .23334 L
.05955 .24175 L
.06224 .25016 L
.06505 .25857 L
.06799 .26697 L
.07107 .27538 L
.07429 .28379 L
.07765 .2922 L
.08115 .30061 L
.08481 .30902 L
.08862 .31743 L
.09259 .32583 L
.09673 .33424 L
.10103 .34265 L
.10552 .35106 L
.11019 .35947 L
.11504 .36788 L
.1201 .37629 L
.12536 .38469 L
.13084 .3931 L
.13655 .40151 L
.1425 .40992 L
.14869 .41833 L
.15515 .42674 L
Mistroke
.16189 .43515 L
.16892 .44356 L
.17627 .45196 L
.18396 .46037 L
.19202 .46878 L
.20047 .47719 L
.20934 .4856 L
.21869 .49401 L
.22855 .50242 L
.239 .51082 L
.25009 .51923 L
.26192 .52764 L
.27461 .53605 L
.28831 .54446 L
.30323 .55287 L
.31968 .56128 L
.33811 .56968 L
.3593 .57809 L
.38476 .5865 L
.41836 .59491 L
.50062 .60332 L
.58287 .59491 L
.61647 .5865 L
.64193 .57809 L
.66313 .56968 L
.68156 .56128 L
.698 .55287 L
.71292 .54446 L
.72662 .53605 L
.73931 .52764 L
.75115 .51923 L
.76224 .51082 L
.77268 .50242 L
.78254 .49401 L
.79189 .4856 L
.80077 .47719 L
.80922 .46878 L
.81727 .46037 L
.82496 .45196 L
.83231 .44356 L
.83935 .43515 L
.84608 .42674 L
.85254 .41833 L
.85874 .40992 L
.86468 .40151 L
.87039 .3931 L
.87587 .38469 L
.88113 .37629 L
.88619 .36788 L
.89105 .35947 L
Mistroke
.89572 .35106 L
.9002 .34265 L
.90451 .33424 L
.90864 .32583 L
.91261 .31743 L
.91642 .30902 L
.92008 .30061 L
.92358 .2922 L
.92694 .28379 L
.93016 .27538 L
.93324 .26697 L
.93618 .25857 L
.939 .25016 L
.94168 .24175 L
.94424 .23334 L
.94668 .22493 L
.949 .21652 L
.95121 .20811 L
.9533 .1997 L
.95529 .1913 L
.95716 .18289 L
.95893 .17448 L
.9606 .16607 L
.96217 .15766 L
.96364 .14925 L
.96502 .14084 L
.9663 .13244 L
.96749 .12403 L
.9686 .11562 L
.96963 .10721 L
.97057 .0988 L
.97143 .09039 L
.97222 .08198 L
.97294 .07358 L
.97358 .06517 L
.97416 .05676 L
.97468 .04835 L
.97514 .03994 L
.97554 .03153 L
.97589 .02312 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool007Cooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000A?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0004?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00015ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000B_ooool3o`0007Wooooo
001cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000@oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000004[ooooo00?o0000ooooooooool0N?ooool007?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00012oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo07So
oooo001cooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0@_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0004?ooooo00Co0000oooooooooooo00001ooo
ool4o`0004Cooooo00Co0000oooooooooooo00002?ooool3o`0004_ooooo00?o0000ooooooooool0
N?ooool007?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004?o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000013ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool00000B_ooool00ol0003oooooooooo`1hooooo`00Loooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000@oooool01?l0003oooooooooool00009oooo
o`;o0000@oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo04Cooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004Wooooo0_l0001jooooo`00M?oo
ool2o`0000Wooooo0ol00015ooooo`;o00002oooool00ol0003oooooooooo`12ooooo`;o00002_oo
ool2o`0004Gooooo0_l00009ooooo`?o0000Boooool00ol0003oooooooooo`1hooooo`00:Oooool0
0ol0003oooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooo
oaKooooo000Yooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`03o`000?oooooooooo017o
oooo000Yooooo`03o`000?oooooooooo0?ooooooooooool3ooooo`03o`000?oooooooooo013ooooo
000Yooooo`03o`000?oooooooooo0?oooooo/Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo0ol00003ooooo`?o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000oooo
o`Co00001_ooool002Wooooo00?o0000ooooooooool0oooooonaooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo000Noooooooo0000]?l0000;ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool002Sooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo0ol0000Foooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool02ol0003ooooooooooooooooo
0000ooooool0003oooooo`000?oooooo000000Sooooo0ol00003ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool3o`0000Kooooo000Xooooo`;o00004ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0@ooooo`?o00005_ooool00ol0003oooooo`000002ooooo`Co00000ooo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001?ooool3o`0000;ooooo1?l00002ooooo`?o00001?oo
ool3o`0000;ooooo1?l0000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1Oooool002Sooooo0_l0001Aooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04kooooo0ol0000Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0000Dooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`00
:?ooool2o`000?ooooooVoooool2o`0001Oooooo0_l00004ooooo`03o`000?oooooooooo01Cooooo
1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool2o`000004oooo
ool0003o0000ooooo`Co00001_ooool002Sooooo0_l0003ooooooi_ooooo0_l0001jooooo`00:?oo
ool2o`000?ooooooVoooool2o`0007[ooooo000Xooooo`?o0000oooooonJooooo`;o0000N_ooool0
02Sooooo0_l0003ooooooi_ooooo0_l0001jooooo`00:?ooool2o`000?ooooooVoooool2o`0007[o
oooo000Xooooo`;o0000oooooonKooooo`;o0000N_ooool002Sooooo0_l0003ooooooi_ooooo0_l0
001jooooo`00:?ooool2o`000?ooooooVoooool2o`0007[ooooo000Xooooo`;o0000oooooonKoooo
o`;o0000N_ooool002Sooooo0ol0003ooooooi[ooooo0_l0001jooooo`00:Oooool2o`000?oooooo
V_ooool2o`0007[ooooo000Yooooo`;o0000oooooonJooooo`;o0000N_ooool002Wooooo0_l0003o
oooooiWooooo0ol0001jooooo`00:Oooool2o`000?ooooooVOooool2o`0007_ooooo000Yooooo`;o
0000oooooonIooooo`;o0000Noooool002Wooooo0_l0003ooooooiWooooo0_l0001kooooo`00:Ooo
ool2o`000?ooooooVOooool2o`0007_ooooo000Yooooo`;o0000oooooonIooooo`;o0000Noooool0
02Wooooo0_l0003ooooooiWooooo0_l0001kooooo`00:Oooool2o`000?ooooooVOooool2o`0007_o
oooo000Yooooo`;o0000oooooonIooooo`;o0000Noooool002Wooooo0_l0003ooooooiWooooo0_l0
001kooooo`00:Oooool2o`000?ooooooVOooool2o`0007_ooooo000Yooooo`?o0000oooooonHoooo
o`;o0000Noooool002Wooooo0ol0003ooooooiSooooo0_l0001kooooo`00:Oooool3o`000?oooooo
V?ooool2o`0007_ooooo000Yooooo`?o0000oooooonHooooo`;o0000Noooool002Wooooo0ol0003o
oooooiOooooo0ol0001kooooo`00:Oooool3o`000?ooooooUoooool2o`0007cooooo000Cooooo`?o
00000oooool2o`0000Cooooo0_l00008ooooo`?o0000oooooonGooooo`;o0000O?ooool001Cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool3o`000?ooooooUoooool2o`0007cooooo000Aooooo`Go00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo0ol0003ooooooiOooooo0_l0001l
ooooo`004Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool3o`000?ooooooUoooool2o`0007cooooo000Booooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`?o
0000oooooonGooooo`;o0000O?ooool001?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool4o`000?ooooooUOooool3o`0007cooooo000Dooooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00002?ooool01?l0003oooooo`000?l0003ooooo
oiGooooo0_l0001mooooo`00:Oooool01?l0003oooooo`000?l0003ooooooiGooooo0_l0001moooo
o`00:Oooool01?l0003oooooo`000?l0003ooooooiGooooo0_l0001mooooo`00:Oooool01?l0003o
ooooo`000?l0003ooooooiGooooo0_l0001mooooo`00:Oooool4o`000?ooooooUOooool2o`0007go
oooo000Yooooo`04o`000?oooooo0000o`000?ooooooUOooool2o`0007gooooo000Yooooo`03o`00
0?oooooo000000;o0000oooooonCooooo`?o0000OOooool002Wooooo00?o0000ooooooooool00_l0
003ooooooi?ooooo0_l0001nooooo`00:Oooool00ol0003oooooooooo`02o`000?ooooooToooool2
o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000oooooonCooooo`;o0000O_ooool002Wo
oooo00?o0000ooooooooool00_l0003ooooooi?ooooo0_l0001nooooo`00:Oooool2o`000003oooo
ool0003o00000?ooooooToooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000oooo
oonCooooo`;o0000O_ooool002Wooooo00?o0000ooooooooool00_l0003ooooooi?ooooo0_l0001n
ooooo`00:Oooool00ol0003oooooooooo`03o`000?ooooooTOooool3o`0007kooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000oooooonAooooo`;o0000Ooooool002Wooooo00Co0000oooooooo
oooooooo0_l0003ooooooi7ooooo0_l0001oooooo`00:Oooool01?l0003oooooooooooooool2o`00
0?ooooooTOooool2o`0007oooooo000Yooooo`;o00000_ooool2o`000?ooooooTOooool2o`0007oo
oooo000Yooooo`04o`000?ooooooooooooooo`;o0000oooooonAooooo`;o0000Ooooool002Wooooo
00Co0000oooooooooooooooo0_l0003ooooooi7ooooo0_l0001oooooo`00:Oooool01?l0003ooooo
ooooooooool3o`000?ooooooSoooool3o`0007oooooo000Yooooo`03o`000?oooooooooo00;ooooo
0_l0003oooooohoooooo0_l00020ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000oooo
oon?ooooo`;o0000P?ooool002Wooooo00?o0000ooooooooool00_ooool2o`000?ooooooSoooool2
o`00083ooooo000Yooooo`03o`000?oooooooooo00;ooooo0ol0003oooooohgooooo0ol00020oooo
o`00:Oooool2o`0000Cooooo0_l0003oooooohgooooo0_l00021ooooo`00:Oooool00ol0003ooooo
ooooo`03ooooo`;o0000oooooon=ooooo`;o0000POooool002Wooooo00?o0000ooooooooool00ooo
ool3o`000?ooooooS?ooool2o`00087ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0003o
ooooohcooooo0_l00021ooooo`004_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`;o0000oooooon<ooooo`;o0000POooool0017ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`04ooooo`;o0000oooooon<ooooo`;o0000POooool001Gooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`000?ooooooRoooool3o`00087ooooo000Eooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`?o
00001?ooool2o`000?ooooooRoooool2o`0008;ooooo000Aooooo`Co00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool2o`00
0?ooooooRoooool2o`0008;ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Cooooo0_l0003o
oooooh_ooooo0_l00022ooooo`004Oooool5o`0000?ooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`?o0000oooooon9ooooo`?o0000P_ooool002Wooooo00?o0000oooooooo
ool01Oooool2o`000?ooooooROooool2o`0008?ooooo000Yooooo`03o`000?oooooooooo00Gooooo
0_l0003oooooohWooooo0_l00023ooooo`00:Oooool00ol0003oooooooooo`05ooooo`?o0000oooo
oon7ooooo`?o0000Poooool002Wooooo0_l00007ooooo`;o0000oooooon7ooooo`;o0000Q?ooool0
02Wooooo00?o0000ooooooooool01_ooool2o`000?ooooooQoooool2o`0008Cooooo000Yooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooohOooooo0_l00024ooooo`00:Oooool00ol0003ooooo
ooooo`06ooooo`?o0000oooooon5ooooo`?o0000Q?ooool002Wooooo00?o0000ooooooooool01ooo
ool2o`000?ooooooQOooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0003o
ooooohGooooo0_l00025ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o0000oooooon5oooo
o`;o0000QOooool002Wooooo00?o0000ooooooooool01oooool3o`000?ooooooPoooool3o`0008Go
oooo000Yooooo`;o00002Oooool2o`000?ooooooPoooool2o`0008Kooooo000Yooooo`03o`000?oo
oooooooo00Sooooo0_l0003ooooooh?ooooo0_l00026ooooo`00:Oooool00ol0003oooooooooo`08
ooooo`?o0000oooooon1ooooo`?o0000Q_ooool002Wooooo00?o0000ooooooooool02Oooool2o`00
0?ooooooPOooool2o`0008Oooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0003ooooooh7o
oooo0_l00027ooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000oooooon1ooooo`;o0000
Qoooool002Wooooo00?o0000ooooooooool02Oooool3o`000?ooooooOoooool3o`0008Oooooo000Y
ooooo`;o00002oooool2o`000?ooooooOoooool2o`0008Sooooo000Yooooo`03o`000?oooooooooo
00[ooooo0_l0003oooooogoooooo0_l00028ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`?o
0000oooooommooooo`?o0000R?ooool002Wooooo00?o0000ooooooooool02oooool2o`000?oooooo
OOooool2o`0008Wooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0003ooooooggooooo0_l0
0029ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000oooooommooooo`;o0000ROooool0
02Wooooo00?o0000ooooooooool02oooool3o`000?ooooooNoooool3o`0008Wooooo000Yooooo`;o
00003Oooool2o`000?ooooooNoooool2o`0008[ooooo000Yooooo`03o`000?oooooooooo00cooooo
0_l0003oooooog_ooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000oooo
oomkooooo`;o0000R_ooool002Wooooo00?o0000ooooooooool03?ooool3o`000?ooooooNOooool3
o`0008[ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0003oooooogWooooo0_l0002;oooo
o`004_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`;o
0000oooooomiooooo`;o0000Roooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0=
ooooo`?o0000oooooomgooooo`?o0000Roooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3o`0000kooooo
0ol0003oooooogKooooo0_l0002<ooooo`004Oooool4o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00oooooo0_l0003oooooogKo
oooo0_l0002<ooooo`004Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0?ooooo`;o0000oooooomeoooo
o`?o0000S?ooool001;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool03oooool3o`000?ooooooM?ooool2
o`0008gooooo000Cooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
013ooooo0_l0003oooooog?ooooo0ol0002=ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o
0000oooooomcooooo`;o0000S_ooool002Wooooo00?o0000ooooooooool04?ooool2o`000?oooooo
Loooool2o`0008kooooo000Yooooo`03o`000?oooooooooo013ooooo0ol0003oooooog7ooooo0ol0
002>ooooo`00:Oooool2o`0001;ooooo0_l0003oooooog7ooooo0_l0002?ooooo`00:Oooool00ol0
003oooooooooo`0Aooooo`;o0000oooooomaooooo`;o0000Soooool002Wooooo00?o0000oooooooo
ool04Oooool3o`000?ooooooKoooool3o`0008oooooo000Yooooo`03o`000?oooooooooo01;ooooo
0ol0003oooooofgooooo0ol0002@ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o0000oooo
oom]ooooo`;o0000TOooool002Wooooo00?o0000ooooooooool04oooool2o`000?ooooooKOooool2
o`00097ooooo000Yooooo`03o`000?oooooooooo01?ooooo0ol0003oooooof_ooooo0ol0002Aoooo
o`00:Oooool2o`0001Gooooo0_l0003oooooof_ooooo0_l0002Booooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`;o0000oooooom[ooooo`;o0000T_ooool002Wooooo00?o0000ooooooooool05?oo
ool3o`000?ooooooJOooool3o`0009;ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0003o
ooooofWooooo0_l0002Cooooo`00:Oooool00ol0003oooooooooo`0Eooooo`?o0000oooooomWoooo
o`?o0000Toooool002Wooooo00?o0000ooooooooool05_ooool2o`000?ooooooIoooool2o`0009Co
oooo000Yooooo`03o`000?oooooooooo01Kooooo0ol0003oooooofGooooo0ol0002Dooooo`00:Ooo
ool2o`0001Sooooo0ol0003oooooofCooooo0_l0002Eooooo`00:Oooool00ol0003oooooooooo`0H
ooooo`;o0000oooooomTooooo`;o0000UOooool002Wooooo00?o0000ooooooooool06?ooool2o`00
0?ooooooHoooool3o`0009Gooooo000Yooooo`03o`000?oooooooooo01Sooooo0ol0003oooooof;o
oooo0_l0002Fooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000oooooomQooooo`?o0000
U_ooool002Wooooo00?o0000ooooooooool06Oooool2o`000?ooooooHOooool2o`0009Oooooo000Y
ooooo`03o`000?oooooooooo01Wooooo0ol0003ooooooeoooooo0ol0002Gooooo`00:Oooool00ol0
003oooooooooo`0Jooooo`;o0000oooooomOooooo`;o0000V?ooool002Wooooo0_l0000Kooooo`?o
0000oooooomMooooo`?o0000V?ooool002Wooooo00?o0000ooooooooool06oooool2o`000?oooooo
GOooool2o`0009Wooooo000Yooooo`03o`000?oooooooooo01_ooooo0ol0003ooooooe_ooooo0ol0
002Iooooo`00:Oooool00ol0003oooooooooo`0Looooo`?o0000oooooomIooooo`?o0000V_ooool0
01?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
01gooooo0_l0003ooooooeWooooo0_l0002Kooooo`004oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0M
ooooo`?o0000oooooomGooooo`?o0000Voooool001Cooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Nooooo`;o0000oooooomGooooo`;o0000W?ooool001Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool3o`0001kooooo
0ol0003ooooooeGooooo0ol0002Looooo`005Oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`;o
0000oooooomEooooo`;o0000WOooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0O
ooooo`?o0000oooooomCooooo`?o0000WOooool0017ooooo1Ol00003ooooo`;o00001?ooool2o`00
00Sooooo00?o0000ooooooooool08?ooool3o`000?ooooooDOooool3o`0009kooooo000Yooooo`03
o`000?oooooooooo027ooooo0_l0003ooooooe7ooooo0_l0002Oooooo`00:Oooool00ol0003ooooo
ooooo`0Qooooo`?o0000oooooom?ooooo`?o0000Woooool002Wooooo00?o0000ooooooooool08_oo
ool2o`000?ooooooCoooool2o`000:3ooooo000Yooooo`;o00008oooool3o`000?ooooooCOooool3
o`000:3ooooo000Yooooo`03o`000?oooooooooo02?ooooo0_l0003oooooodgooooo0_l0002Qoooo
o`00:Oooool00ol0003oooooooooo`0Sooooo`?o0000oooooom;ooooo`?o0000XOooool002Wooooo
00?o0000ooooooooool09?ooool2o`000?ooooooBoooool2o`000:;ooooo000Yooooo`03o`000?oo
oooooooo02Cooooo0ol0003oooooodWooooo0ol0002Rooooo`00:Oooool00ol0003oooooooooo`0U
ooooo`?o0000oooooom8ooooo`;o0000Xoooool002Wooooo00?o0000ooooooooool09_ooool3o`00
0?ooooooA_ooool3o`000:?ooooo000Yooooo`;o0000:?ooool3o`000?ooooooA?ooool3o`000:Co
oooo000Yooooo`03o`000?oooooooooo02Sooooo0_l0003oooooodCooooo0_l0002Uooooo`00:Ooo
ool00ol0003oooooooooo`0Xooooo`?o0000oooooom2ooooo`?o0000YOooool002Wooooo00?o0000
ooooooooool0:Oooool2o`000?oooooo@Oooool3o`000:Kooooo000Yooooo`03o`000?oooooooooo
02Wooooo0ol0003oooooocoooooo0ol0002Wooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o
0000ooooooloooooo`;o0000Z?ooool002Wooooo00?o0000ooooooooool0:_ooool3o`000?oooooo
?Oooool3o`000:Sooooo000Yooooo`03o`000?oooooooooo02_ooooo0_l0003oooooocgooooo0_l0
002Yooooo`00:Oooool2o`0002cooooo0ol0003ooooooc_ooooo0ol0002Yooooo`00:Oooool00ol0
003oooooooooo`0/ooooo`?o0000ooooooliooooo`?o0000Z_ooool002Wooooo00?o0000oooooooo
ool0;Oooool3o`000?oooooo=oooool3o`000:_ooooo000Yooooo`03o`000?oooooooooo02kooooo
0ol0003oooooocGooooo0ol0002/ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o0000oooo
ooleooooo`;o0000[Oooool002Wooooo00?o0000ooooooooool0;oooool3o`000?oooooo<oooool3
o`000:gooooo000Yooooo`03o`000?oooooooooo033ooooo0ol0003ooooooc;ooooo0_l0002^oooo
o`00:Oooool2o`0003;ooooo0ol0003ooooooc3ooooo0ol0002^ooooo`00:Oooool00ol0003ooooo
ooooo`0booooo`;o0000ooooool`ooooo`;o0000[oooool002Wooooo00?o0000ooooooooool0<_oo
ool3o`000?oooooo;_ooool3o`000:oooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l0003o
ooooobgooooo0ol0002`ooooo`00:Oooool00ol0003oooooooooo`0cooooo`?o0000ooooool[oooo
o`?o0000/Oooool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000oooooooo
ool0=?ooool3o`000?oooooo:Oooool3o`000;;ooooo000Aooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0=Oooool3o`000?oooooo9oooool3o`000;?ooooo000Aooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo
0ol0000fooooo`?o0000oooooolUooooo`?o0000]?ooool001;ooooo0ol00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0gooooo`;o
0000oooooolUooooo`;o0000]Oooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0g
ooooo`?o0000oooooolSooooo`?o0000]Oooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0hooooo`?o0000oooooolQooooo`?o0000]_ooool001;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Sooooo00?o0000ooooooooool0>Oooool3o`000?oooooo7oooool3o`000;Oooooo000Y
ooooo`03o`000?oooooooooo03[ooooo0ol0003ooooooakooooo0_l0002hooooo`00:Oooool00ol0
003oooooooooo`0kooooo`?o0000oooooolLooooo`?o0000^?ooool002Wooooo00?o0000oooooooo
ool0??ooool3o`000?oooooo6_ooool3o`000;Wooooo000Yooooo`;o0000?_ooool3o`000?oooooo
5oooool4o`000;[ooooo000Yooooo`03o`000?oooooooooo03kooooo0ol0003ooooooaGooooo1?l0
002kooooo`00:Oooool00ol0003oooooooooo`0oooooo`?o0000oooooolCooooo`?o0000_Oooool0
02Wooooo00?o0000ooooooooool0@?ooool3o`000?oooooo4Oooool3o`000;kooooo000Yooooo`03
o`000?oooooooooo047ooooo0_l0003ooooooa7ooooo0_l0002oooooo`00:Oooool00ol0003ooooo
ooooo`11ooooo`?o0000ooooool?ooooo`?o0000_oooool002Wooooo00?o0000ooooooooool0@_oo
ool3o`000?oooooo3Oooool3o`000<3ooooo000Yooooo`;o0000A?ooool3o`000?oooooo2oooool3
o`000<7ooooo000Yooooo`03o`000?oooooooooo04Cooooo0ol0003oooooo`Wooooo0ol00032oooo
o`00:Oooool00ol0003oooooooooo`15ooooo`?o0000ooooool7ooooo`?o0000`oooool002Wooooo
00?o0000ooooooooool0A_ooool3o`000?oooooo1Oooool3o`000<Cooooo000Yooooo`03o`000?oo
oooooooo04Oooooo1?l0003oooooo`7ooooo1?l00035ooooo`00:Oooool00ol0003oooooooooo`18
ooooo`Co0000o_ooool4o`000<Kooooo000Yooooo`03o`000?oooooooooo04[ooooo0ol0003loooo
o`?o0000b?ooool002Wooooo0_l0001<ooooo`?o0000n_ooool3o`000<Wooooo000Yooooo`03o`00
0?oooooooooo04cooooo0ol0003hooooo`?o0000b_ooool002Wooooo00?o0000ooooooooool0COoo
ool3o`000?Kooooo0ol0003;ooooo`00:Oooool00ol0003oooooooooo`1>ooooo`?o0000m?ooool3
o`000<cooooo000Yooooo`03o`000?oooooooooo04oooooo1?l0003`ooooo`Co0000cOooool002Wo
oooo00?o0000ooooooooool0D?ooool4o`000>kooooo1?l0003>ooooo`00:Oooool00ol0003ooooo
ooooo`1Booooo`?o0000k?ooool3o`000=3ooooo000Yooooo`;o0000E?ooool4o`000>Wooooo0ol0
003Aooooo`00:Oooool00ol0003oooooooooo`1Dooooo`Co0000ioooool3o`000=;ooooo000Yoooo
o`03o`000?oooooooooo05Kooooo0ol0003Uooooo`?o0000doooool002Wooooo00?o0000oooooooo
ool0Eoooool3o`000>?ooooo0ol0003Dooooo`00:Oooool00ol0003oooooooooo`1Hooooo`Co0000
goooool4o`000=Gooooo000Booooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`03o`000?oo
oooooooo05Wooooo1?l0003Mooooo`Co0000e_ooool001Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Kooooo`?o0000foooool3o`000=Sooooo000Eooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05co
oooo0ol0003Iooooo`?o0000fOooool001;ooooo1?l00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool3o`0005gooooo1?l0003Eooooo`Co0000f_ooool0017o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`1Nooooo`Go0000dOooool5o`000=_ooooo000A
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0H?ooool4o`000<oooooo1?l0003Mooooo`00
4_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`1Rooooo`Co0000
boooool4o`000=oooooo000Yooooo`03o`000?oooooooooo06?ooooo1?l00039ooooo`Co0000h?oo
ool002Wooooo00?o0000ooooooooool0IOooool3o`000<Kooooo1?l0003Rooooo`00:Oooool00ol0
003oooooooooo`1Vooooo`?o0000a?ooool4o`000>?ooooo000Yooooo`;o0000J?ooool4o`000<3o
oooo1?l0003Uooooo`00:Oooool00ol0003oooooooooo`1Xooooo`Co0000__ooool4o`000>Kooooo
000Yooooo`03o`000?oooooooooo06[ooooo1?l0002jooooo`Co0000j?ooool002Wooooo00?o0000
ooooooooool0Joooool4o`000;Sooooo1?l0003Yooooo`00:Oooool00ol0003oooooooooo`1]oooo
o`Co0000]?ooool4o`000>_ooooo000Yooooo`03o`000?oooooooooo06kooooo1_l0002_ooooo`Go
0000k?ooool002Wooooo00?o0000ooooooooool0L?ooool6o`000:_ooooo1Ol0003^ooooo`00:Ooo
ool2o`0007Cooooo1Ol0002Wooooo`Go0000l?ooool002Wooooo00?o0000ooooooooool0MOooool5
o`000:?ooooo1Ol0003booooo`00:Oooool00ol0003oooooooooo`1gooooo`Co0000XOooool4o`00
0?Cooooo000Yooooo`03o`000?oooooooooo07Wooooo1?l0002Mooooo`Co0000m_ooool002Wooooo
00?o0000ooooooooool0N_ooool5o`0009Wooooo1Ol0003gooooo`00:Oooool00ol0003ooooooooo
o`1looooo`Go0000UOooool5o`000?Wooooo000Yooooo`03o`000?oooooooooo07kooooo1Ol0002A
ooooo`Go0000noooool002Wooooo00?o0000ooooooooool0P?ooool5o`0008gooooo1Ol0003moooo
o`00:Oooool2o`0008?ooooo1_l00027ooooo`Ko0000ooooool002Wooooo00?o0000ooooooooool0
Q?ooool7o`00087ooooo1ol0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo08Oooooo1ol0
001kooooo`Oo0000ooooool5ooooo`00:Oooool00ol0003oooooooooo`2:ooooo`Ko0000M_ooool7
o`000?oooooo2?ooool002Wooooo00?o0000ooooooooool0SOooool6o`00073ooooo1ol0003ooooo
o`_ooooo000Yooooo`03o`000?oooooooooo08oooooo1ol0001Zooooo`Oo0000ooooool>ooooo`00
:Oooool00ol0003oooooooooo`2Booooo`Oo0000I?ooool7o`000?oooooo4Oooool002Wooooo0_l0
002Fooooo`Oo0000G_ooool7o`000?oooooo5?ooool002Wooooo00?o0000ooooooooool0V?ooool7
o`0005Sooooo1ol0003ooooooaOooooo000Yooooo`03o`000?oooooooooo09_ooooo2?l0001@oooo
o`So0000oooooolJooooo`00:Oooool00ol0003oooooooooo`2Nooooo`So0000B_ooool8o`000?oo
oooo7Oooool002Wooooo00?o0000ooooooooool0X_ooool<o`0003[ooooo3?l0003oooooob7ooooo
000<ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003ooooooooo
o`2UoooooaGo00008_oooolEo`000?oooooo9?ooool000gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`2]oooooaWo00002_oooolIo`000?oooooo;?ooool000gooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001oooool3o`000;Wooooo9?l0003oooooocSooooo000=oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0aOooool<o`000?oooooo
A?ooool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3ooooo
oooooooo5_ooool000cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oooooooooo
oolFooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00008
ooooo`03o`000?oooooooooo0?oooooooooooolFooooo`00:Oooool00ol0003oooooooooo`3ooooo
oooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooooaKooooo000Yooooo`03o`00
0?oooooooooo0?oooooooooooolFooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool001Cooooo0ol0000_ooooo`03o`000?oooooo
oooo0?oooooon?ooool001Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3ooooo
ooOooooo0003ooooo`?o00000oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002oooo
o`?o00000oooool3o`0000;ooooo0ol00004ooooo`Co00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo00?o000000?oooooo`00
0?l00000oooooooaooooo`001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ool0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
1?l0003oooooooooool0003ooooooo;ooooo0004ooooo`04o`000?ooooooooooooooo`Go000000Ko
ooooo`000?oooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool01Ol00002oooo
o`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00002?ooool00ol0003oooooo`00003o
oooooo?ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo
0_l0003oooooooCooooo0002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo
0_l000001?oooooo0000ooooooooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002ooooo`?o00002Oooool00ol0003oooooo`00003ooooooo?ooooo0002ooooo`05
o`000?oooooo0000ooooool000009_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`000?ooooool_ooool000;ooooo1Ol0000Vooooo`03o`000?oooooooooo01[ooooo0ol000000ooo
oooo0000o`00003ooooooo7ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;o
oooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooo
oooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_oo
ool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0992175, 183.273, \
0.00241982, 2.7443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The same basic process can be used to calculate and plot the \
spinodals. I collect the two branches of the curve in separate arrays.\
\>", \
"Text"],

Cell[BoxData[{
    \(\(SpinodalCurvePtsR = {};\)\), "\[IndentingNewLine]", 
    \(\(SpinodalCurvePtsL = {};\)\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]XBSpin = 
        Flatten[Solve[\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, T] == 
              0, {XB}]]; \[IndentingNewLine]SpinodalCurvePtsR = 
        Append[SpinodalCurvePtsR, {XBSpin[\([2, 2]\)], 
            T}]; \[IndentingNewLine]SpinodalCurvePtsL = 
        Append[SpinodalCurvePtsL, {XBSpin[\([1, 2]\)], T}], {T, 990, 
        300, \(-10\)}]\)}], "Input"],

Cell["\<\
Now add in the point at the top of the spinodal curve, join the two \
branches of the curve into a single ordered list, and plot the results.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SpinodalCurvePts = 
        Prepend[SpinodalCurvePtsR, {0.5, 1000}];\)\), "\[IndentingNewLine]", 
    \(\(SpinodalCurvePts = 
        Join[Reverse[SpinodalCurvePtsL], 
          SpinodalCurvePts];\)\), "\[IndentingNewLine]", 
    \(SpinodalPlot = 
      ListPlot[SpinodalCurvePts, 
        AxesLabel \[Rule] {"\<Atom Fraction,XB\>", "\<Temperature,K\>"}, 
        PlotJoined \[Rule] True]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.03708 -0.237544 0.000840863 [
[.23123 .00222 -9 -9 ]
[.23123 .00222 9 0 ]
[.43864 .00222 -9 -9 ]
[.43864 .00222 9 0 ]
[.64606 .00222 -9 -9 ]
[.64606 .00222 9 0 ]
[.85347 .00222 -9 -9 ]
[.85347 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -41 0 ]
[.02381 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23123 .01472 m
.23123 .02097 L
s
[(0.2)] .23123 .00222 0 1 Mshowa
.43864 .01472 m
.43864 .02097 L
s
[(0.4)] .43864 .00222 0 1 Mshowa
.64606 .01472 m
.64606 .02097 L
s
[(0.6)] .64606 .00222 0 1 Mshowa
.85347 .01472 m
.85347 .02097 L
s
[(0.8)] .85347 .00222 0 1 Mshowa
.125 Mabswid
.07566 .01472 m
.07566 .01847 L
s
.12752 .01472 m
.12752 .01847 L
s
.17937 .01472 m
.17937 .01847 L
s
.28308 .01472 m
.28308 .01847 L
s
.33493 .01472 m
.33493 .01847 L
s
.38679 .01472 m
.38679 .01847 L
s
.4905 .01472 m
.4905 .01847 L
s
.54235 .01472 m
.54235 .01847 L
s
.5942 .01472 m
.5942 .01847 L
s
.69791 .01472 m
.69791 .01847 L
s
.74976 .01472 m
.74976 .01847 L
s
.80162 .01472 m
.80162 .01847 L
s
.90533 .01472 m
.90533 .01847 L
s
.95718 .01472 m
.95718 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0988 m
.03006 .0988 L
s
[(400)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(500)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(600)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(700)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(800)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(900)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.10851 .01472 m
.11162 .02312 L
.11475 .03153 L
.11791 .03994 L
.12109 .04835 L
.12429 .05676 L
.12752 .06517 L
.13077 .07358 L
.13405 .08198 L
.13736 .09039 L
.14069 .0988 L
.14405 .10721 L
.14744 .11562 L
.15086 .12403 L
.15431 .13244 L
.15779 .14084 L
.1613 .14925 L
.16485 .15766 L
.16842 .16607 L
.17204 .17448 L
.17569 .18289 L
.17937 .1913 L
.18309 .1997 L
.18686 .20811 L
.19066 .21652 L
.1945 .22493 L
.19839 .23334 L
.20232 .24175 L
.2063 .25016 L
.21032 .25857 L
.2144 .26697 L
.21852 .27538 L
.2227 .28379 L
.22693 .2922 L
.23123 .30061 L
.23558 .30902 L
.23999 .31743 L
.24447 .32583 L
.24902 .33424 L
.25364 .34265 L
.25833 .35106 L
.26311 .35947 L
.26796 .36788 L
.27291 .37629 L
.27794 .38469 L
.28308 .3931 L
.28832 .40151 L
.29367 .40992 L
.29913 .41833 L
.30472 .42674 L
Mistroke
.31045 .43515 L
.31632 .44356 L
.32235 .45196 L
.32855 .46037 L
.33493 .46878 L
.34152 .47719 L
.34833 .4856 L
.35539 .49401 L
.36272 .50242 L
.37037 .51082 L
.37837 .51923 L
.38679 .52764 L
.39568 .53605 L
.40516 .54446 L
.41533 .55287 L
.4264 .56128 L
.43864 .56968 L
.45254 .57809 L
.46902 .5865 L
.4905 .59491 L
.54235 .60332 L
.5942 .59491 L
.61568 .5865 L
.63216 .57809 L
.64606 .56968 L
.6583 .56128 L
.66936 .55287 L
.67954 .54446 L
.68901 .53605 L
.69791 .52764 L
.70633 .51923 L
.71433 .51082 L
.72198 .50242 L
.72931 .49401 L
.73637 .4856 L
.74318 .47719 L
.74976 .46878 L
.75615 .46037 L
.76235 .45196 L
.76838 .44356 L
.77425 .43515 L
.77997 .42674 L
.78557 .41833 L
.79103 .40992 L
.79638 .40151 L
.80162 .3931 L
.80675 .38469 L
.81179 .37629 L
.81673 .36788 L
.82159 .35947 L
Mistroke
.82636 .35106 L
.83106 .34265 L
.83568 .33424 L
.84023 .32583 L
.84471 .31743 L
.84912 .30902 L
.85347 .30061 L
.85776 .2922 L
.862 .28379 L
.86618 .27538 L
.8703 .26697 L
.87438 .25857 L
.8784 .25016 L
.88238 .24175 L
.88631 .23334 L
.8902 .22493 L
.89404 .21652 L
.89784 .20811 L
.9016 .1997 L
.90533 .1913 L
.90901 .18289 L
.91266 .17448 L
.91627 .16607 L
.91985 .15766 L
.9234 .14925 L
.92691 .14084 L
.93039 .13244 L
.93384 .12403 L
.93726 .11562 L
.94065 .10721 L
.94401 .0988 L
.94734 .09039 L
.95065 .08198 L
.95393 .07358 L
.95718 .06517 L
.96041 .05676 L
.96361 .04835 L
.96679 .03994 L
.96995 .03153 L
.97308 .02312 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool007_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000Boooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0004_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol0001<ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000ZOooool007[ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool0001:ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool00000B_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
0000Z?ooool007[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1:ooooo`04
o`000?ooooooooooo`0000Oooooo1Ol0001:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00001:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00002Xooooo`00N_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo04Wo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0001;ooooo`04o`000?oooooo
ooooo`0000Oooooo1?l0001;ooooo`04o`000?ooooooooooo`0000Sooooo0ol0002Yooooo`00N_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000B_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000004_ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`1<ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00002Xooooo`00N_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
0000B_ooool01?l0003oooooooooool00009ooooo`;o0000Boooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo00000:Sooooo001kooooo`;o00002Oooool3o`0004cooooo0_l0000;ooooo`03o`000?oo
oooooooo04[ooooo0_l0000:ooooo`;o0000C?ooool2o`0000Wooooo0ol0002Yooooo`00:Oooool0
0ol0003oooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooo
oaKooooo000Yooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`03o`000?oooooooooo017o
oooo000Yooooo`03o`000?oooooooooo0?ooooooooooool3ooooo`03o`000?oooooooooo013ooooo
000Yooooo`03o`000?oooooooooo0?oooooo/Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo0ol00003ooooo`?o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000oooo
o`Co00001_ooool002Wooooo00?o0000ooooooooool0oooooonaooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo000Noooooooo0000]?l0000;ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool002Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02oooo
o`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool3o`0000?o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`?o0000
1_ooool002Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooool000000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?ooool02?ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co00002_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo000Yooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool06oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000Gooooo000Yooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
oooooomcooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`03o`000?oooooooooo01Cooooo
1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool2o`000004oooo
ool0003o0000ooooo`Co00001_ooool002Wooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`3oooooog?ooooo00?o0000ooooooooool0NOooool002Wooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`3oooooog7ooooo00?o0000ooooooooool0N_ooool002Wooooo0_l0000U
ooooo`03o`000?oooooooooo0?ooooooLOooool00ol0003oooooooooo`1jooooo`00:Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo0?ooooooLOooool00ol0003oooooooooo`1joooo
o`00:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?ooooooL?ooool00ol0003o
ooooooooo`1kooooo`00:Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo
Koooool00ol0003oooooooooo`1kooooo`00:Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo0?ooooooK_ooool00ol0003oooooooooo`1looooo`00:Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo0?ooooooK_ooool00ol0003oooooooooo`1looooo`00:Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo0?ooooooKOooool00ol0003oooooooooo`1loooo
o`00:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?ooooooK?ooool00ol0003o
ooooooooo`1mooooo`00:Oooool2o`0002Sooooo00?o0000ooooooooool0oooooom[ooooo`03o`00
0?oooooooooo07gooooo000Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0oooo
oom[ooooo`03o`000?oooooooooo07gooooo000Yooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0oooooomYooooo`03o`000?oooooooooo07kooooo000Yooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0oooooomXooooo`03o`000?oooooooooo07oooooo000Yooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0oooooomXooooo`03o`000?oooooooooo07oo
oooo000Yooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0oooooomXooooo`03o`00
0?oooooooooo07oooooo000Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0oooo
oomVooooo`03o`000?oooooooooo083ooooo000Yooooo`;o0000:_ooool00ol0003oooooooooo`3o
ooooofKooooo00?o0000ooooooooool0P?ooool002Wooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3oooooofKooooo00?o0000ooooooooool0P?ooool002Wooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`3oooooofGooooo00?o0000ooooooooool0P?ooool002Wooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3oooooofCooooo00?o0000ooooooooool0
POooool002Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3oooooof?ooooo00?o
0000ooooooooool0POooool002Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3o
ooooof?ooooo00?o0000ooooooooool0POooool002Wooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`3oooooof7ooooo00?o0000ooooooooool0P_ooool002Wooooo0_l0000]ooooo`03
o`000?oooooooooo0?ooooooH?ooool00ol0003oooooooooo`23ooooo`00:Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo0?ooooooH?ooool00ol0003oooooooooo`23ooooo`00:Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?ooooooGoooool00ol0003ooooooooo
o`23ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?ooooooG_ooool0
0ol0003oooooooooo`24ooooo`00:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0?ooooooGOooool00ol0003oooooooooo`24ooooo`004oooool3o`0000?ooooo0_l00004ooooo`;o
00002?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0?ooooooGOooool00ol0003o
ooooooooo`24ooooo`005?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0oooooomLooooo`03o`000?oooooooooo08Gooooo000Aooooo`Go00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`3ooooooe_ooooo00?o0000ooooooooool0QOooool0017ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo
0ol0000_ooooo`03o`000?oooooooooo0?ooooooF_ooool00ol0003oooooooooo`26ooooo`004_oo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0?ooooooF_ooool00ol0003o
ooooooooo`26ooooo`004oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0oooooomHoooo
o`03o`000?oooooooooo08Oooooo000Dooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o
00002?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?ooooooEoooool00ol0003o
ooooooooo`27ooooo`00:Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo
Eoooool00ol0003oooooooooo`27ooooo`00:Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo0?ooooooE_ooool00ol0003oooooooooo`28ooooo`00:Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo0?ooooooEOooool00ol0003oooooooooo`28ooooo`00:Oooool2o`00
03?ooooo00?o0000ooooooooool0oooooomDooooo`03o`000?oooooooooo08Wooooo000Yooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooomDooooo`03o`000?oooooooooo08Wo
oooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0oooooomBooooo`03o`00
0?oooooooooo08[ooooo000Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0oooo
oomAooooo`03o`000?oooooooooo08[ooooo000Yooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0oooooomAooooo`03o`000?oooooooooo08[ooooo000Yooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0oooooom@ooooo`03o`000?oooooooooo08_ooooo000Yooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0oooooom?ooooo`03o`000?oooooooooo08_o
oooo000Yooooo`;o0000=_ooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0
S?ooool002Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool0S?ooool002Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3o
ooooodgooooo00?o0000ooooooooool0S?ooool002Wooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`3oooooodcooooo00?o0000ooooooooool0SOooool002Wooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool0SOooool002Wooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool0
SOooool002Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3oooooodWooooo00?o
0000ooooooooool0S_ooool002Wooooo0_l0000iooooo`03o`000?oooooooooo0?ooooooB?ooool0
0ol0003oooooooooo`2?ooooo`00:Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
0?ooooooB?ooool00ol0003oooooooooo`2?ooooo`00:Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0?ooooooAoooool00ol0003oooooooooo`2?ooooo`00:Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo0?ooooooA_ooool00ol0003oooooooooo`2@ooooo`00:Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0?ooooooAOooool00ol0003ooooooooo
o`2@ooooo`00:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0?ooooooAOooool0
0ol0003oooooooooo`2@ooooo`00:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
0?ooooooA?ooool00ol0003oooooooooo`2Aooooo`00:Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0?oooooo@oooool00ol0003oooooooooo`2Aooooo`00:Oooool2o`0003cooooo
00?o0000ooooooooool0oooooom2ooooo`03o`000?oooooooooo09;ooooo000Yooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0oooooom2ooooo`03o`000?oooooooooo09;ooooo000Y
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0oooooom0ooooo`03o`000?oooooo
oooo09?ooooo000Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0oooooolooooo
o`03o`000?oooooooooo09?ooooo000Booooo`?o00001?ooool2o`0000Cooooo0_l00008ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0ooooooloooooo`03o`000?oooooooooo09?o
oooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`3o
ooooockooooo00?o0000ooooooooool0U?ooool001Gooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3oooooocgooooo00?o0000ooooooooool0U?ooool001Gooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo
0ol0000nooooo`03o`000?oooooooooo0?oooooo??ooool00ol0003oooooooooo`2Eooooo`004Ooo
ool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0oooooollooooo`03o`000?oooooooooo09Go
oooo000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0oooooolkoooo
o`03o`000?oooooooooo09Gooooo000Aooooo`Go00000oooool2o`0000Cooooo0_l00008ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0ooooooljooooo`03o`000?oooooooooo09Ko
oooo000Yooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0ooooooliooooo`03o`00
0?oooooooooo09Kooooo000Yooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0oooo
ooliooooo`03o`000?oooooooooo09Kooooo000Yooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0oooooolgooooo`03o`000?oooooooooo09Oooooo000Yooooo`;o0000@oooool00ol0
003oooooooooo`3oooooocGooooo00?o0000ooooooooool0V?ooool002Wooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool0V?ooool002Wooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool0
VOooool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3ooooooc?ooooo00?o
0000ooooooooool0VOooool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3o
oooooc;ooooo00?o0000ooooooooool0V_ooool002Wooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`3ooooooc;ooooo00?o0000ooooooooool0V_ooool002Wooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`3ooooooc7ooooo00?o0000ooooooooool0V_ooool002Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
Voooool002Wooooo0_l00016ooooo`03o`000?oooooooooo0?oooooo;oooool00ol0003ooooooooo
o`2Kooooo`00:Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0?oooooo;oooool0
0ol0003oooooooooo`2Kooooo`00:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
0?oooooo;Oooool00ol0003oooooooooo`2Looooo`00:Oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`2Mooooo`00:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`2Mooooo`00:Ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003ooooooooo
o`2Nooooo`00:Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0?oooooo:_ooool0
0ol0003oooooooooo`2Nooooo`00:Oooool2o`0004Wooooo00?o0000ooooooooool0oooooolXoooo
o`03o`000?oooooooooo09oooooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0oooooolXooooo`03o`000?oooooooooo09oooooo000Yooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo0:3ooooo000Yooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo0:3ooooo000Y
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooo
oooo0:3ooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0oooooolSoooo
o`03o`000?oooooooooo0:7ooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0oooooolSooooo`03o`000?oooooooooo0:7ooooo000Yooooo`;o0000COooool00ol0003ooooo
ooooo`3oooooob7ooooo00?o0000ooooooooool0X_ooool002Wooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool0X_ooool002Wooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool0Xoooool0
02Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3ooooooaoooooo00?o0000oooo
ooooool0Xoooool002Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3ooooooako
oooo00?o0000ooooooooool0Y?ooool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0
Y?ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
0?oooooo7?ooool00ol0003oooooooooo`2Uooooo`004Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`?o0000Cooo
ool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0Y_ooool0017ooooo1?l00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`2Vooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003o
ooooooooo`2Vooooo`004_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
0?oooooo6?ooool00ol0003oooooooooo`2Wooooo`004oooool2o`0000Cooooo0_l00004ooooo`;o
00002?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003o
ooooooooo`2Wooooo`00:Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0?oooooo
5oooool00ol0003oooooooooo`2Wooooo`00:Oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo0?oooooo5Oooool00ol0003oooooooooo`2Xooooo`00:Oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`2Xooooo`00:Oooool2o`00
05Cooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo0:Wooooo000Yooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo0:Wo
oooo000Yooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0oooooolAooooo`03o`00
0?oooooooooo0:[ooooo000Yooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0oooo
ool?ooooo`03o`000?oooooooooo0:_ooooo000Yooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0ooooool?ooooo`03o`000?oooooooooo0:_ooooo000Yooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo0:cooooo000Yooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooooooo0:co
oooo000Yooooo`;o0000Eoooool00ol0003oooooooooo`3oooooo`cooooo00?o0000ooooooooool0
[Oooool002Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3oooooo`cooooo00?o
0000ooooooooool0[Oooool002Wooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3o
ooooo`[ooooo00?o0000ooooooooool0[_ooool002Wooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0[_ooool002Wooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0[oooool002Wooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0
[oooool002Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`3oooooo`Kooooo00?o
0000ooooooooool0/?ooool002Wooooo0_l0001Kooooo`03o`000?oooooooooo0?oooooo1?ooool0
0ol0003oooooooooo`2aooooo`00:Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
0?oooooo1?ooool00ol0003oooooooooo`2aooooo`00:Oooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`2booooo`00:Oooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`2booooo`00:Ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo0?oooooo00?o0000ooooooooool0/ooo
ool002Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`3oooooo`03o`000?oooooo
oooo0;?ooooo000Yooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0oOooool00ol0
003oooooooooo`2dooooo`00:Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0?go
oooo00?o0000ooooooooool0]?ooool002Wooooo0_l0001Oooooo`03o`000?oooooooooo0?_ooooo
00?o0000ooooooooool0]Oooool002Wooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`3kooooo`03o`000?oooooooooo0;Gooooo000Yooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0nOooool00ol0003oooooooooo`2fooooo`00:Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool0]oooool001?ooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0moooool00ol0003oooooooooo`2gooooo`004oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool0^?ooool001Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool0^?ooool0
01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01Oooool3o`0006;ooooo00?o0000ooooooooool0loooool00ol0003ooooooooo
o`2iooooo`005Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0??ooooo
00?o0000ooooooooool0^Oooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo0?7ooooo00?o0000ooooooooool0^_ooool0017ooooo1Ol00003ooooo`;o
00001?ooool2o`0000Sooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`3_ooooo`03
o`000?oooooooooo0;_ooooo000Yooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
koooool00ol0003oooooooooo`2kooooo`00:Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool0_?ooool002Wooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`3]ooooo`03o`000?oooooooooo0;cooooo000Yooooo`;o0000Ioooool00ol0
003oooooooooo`3[ooooo`03o`000?oooooooooo0;gooooo000Yooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0joooool00ol0003oooooooooo`2mooooo`00:Oooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool0__ooool002Wooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo0;kooooo000Y
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`2o
ooooo`00:Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo0>Kooooo00?o0000oooo
ooooool0_oooool002Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`3Tooooo`03
o`000?oooooooooo0<3ooooo000Yooooo`;o0000K?ooool00ol0003oooooooooo`3Rooooo`03o`00
0?oooooooooo0<7ooooo000Yooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0h_oo
ool00ol0003oooooooooo`31ooooo`00:Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo0>3ooooo00?o0000ooooooooool0`_ooool002Wooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`3Pooooo`03o`000?oooooooooo0<;ooooo000Yooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0g_ooool00ol0003oooooooooo`33ooooo`00:Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0`oooool002Wooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`3Looooo`03o`000?oooooooooo0<Cooooo000Y
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`35
ooooo`00:Oooool2o`00073ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`36oooo
o`00:Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0=Wooooo00?o0000oooooooo
ool0a_ooool002Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`3Gooooo`03o`00
0?oooooooooo0<Oooooo000Yooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0eOoo
ool00ol0003oooooooooo`38ooooo`00:Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo0=Gooooo00?o0000ooooooooool0b?ooool002Wooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`3Cooooo`03o`000?oooooooooo0<Wooooo000Yooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool0d_ooool00ol0003oooooooooo`39ooooo`00:Oooool2o`0007Gooooo
00?o0000ooooooooool0d?ooool00ol0003oooooooooo`3:ooooo`00:Oooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0b_ooool002Wooooo00?o0000
ooooooooool0MOooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo0<_ooooo000Yoooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0cOooool00ol0003oooooooooo`3<oooo
o`00:Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool0cOooool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo0<gooooo000Aooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo
0<kooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Oooooo0ol0001iooooo`03o`000?oooooooooo0<Kooooo00?o
0000ooooooooool0coooool001;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo0<Kooooo
00?o0000ooooooooool0coooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo0<Cooooo00?o0000ooooooooool0d?ooool0017ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0dOoo
ool001;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`31ooooo`03o`000?oooooooooo0=;ooooo000Yooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`3Booooo`00:Oooool00ol0003o
ooooooooo`1looooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0doooool002Wooooo
00?o0000ooooooooool0OOooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo0=?ooooo
000Yooooo`;o0000Ooooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo0=Cooooo000Y
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`3E
ooooo`00:Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0;Sooooo00?o0000oooo
ooooool0e_ooool002Wooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo0=Oooooo000Yooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
]_ooool00ol0003oooooooooo`3Gooooo`00:Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo0;Cooooo00?o0000ooooooooool0f?ooool002Wooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`2cooooo`03o`000?oooooooooo0=Wooooo000Yooooo`;o0000Q?ooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo0=[ooooo000Yooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`3Jooooo`00:Oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0foooool002Wooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo0=cooooo000Y
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`3M
ooooo`00:Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo0:Wooooo00?o0000oooo
ooooool0g_ooool002Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo0=oooooo000Yooooo`;o0000R_ooool00ol0003oooooooooo`2Uooooo`03o`00
0?oooooooooo0>3ooooo000Yooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0YOoo
ool00ol0003oooooooooo`3Pooooo`00:Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo
oooo0:?ooooo00?o0000ooooooooool0hOooool002Wooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo0>;ooooo000Yooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`3Sooooo`00:Oooool00ol0003ooooo
ooooo`2=ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0i?ooool002Wooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo0>Gooooo000Y
ooooo`;o0000T?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo0>Kooooo000Yoooo
o`03o`000?oooooooooo093ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`3Voooo
o`00:Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo09Kooooo00?o0000oooooooo
ool0ioooool002Wooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`2Dooooo`03o`00
0?oooooooooo0>Sooooo000Yooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`3Yooooo`004_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool0
0ol0003oooooooooo`2Cooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0j_ooool0
01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo08oooooo00?o
0000ooooooooool0joooool001Gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0UOooool00ol0003ooooo
ooooo`2=ooooo`03o`000?oooooooooo0>cooooo000Booooo`Co00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Oooooo0ol0002Fooooo`;o0000S?ooool00ol0003o
ooooooooo`3]ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool0R?ooool00ol0003oooooooooo`3^ooooo`004Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo09Wooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`3_ooooo`004_oo
ool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool0l?ooool002Wooooo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo0?7ooooo000Yooooo`03o`000?oooooooooo
09cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`3booooo`00:Oooool00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0loooool002Wooooo
0_l0002Oooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0m?ooool002Wooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?Gooooo000Y
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`3f
ooooo`00:Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool0moooool002Wooooo00?o0000ooooooooool0X_ooool2o`0007Cooooo0_l0003jooooo`00
:Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo06oooooo0_l0003looooo`00:Ooo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0o?oo
ool002Wooooo0_l0002Wooooo`;o0000Joooool2o`000?oooooo000Yooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`3oooooo`00:Oooool00ol0003o
ooooooooo`2Yooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0ooooool1ooooo`00
:Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
ooooool2ooooo`00:Oooool00ol0003oooooooooo`2[ooooo`;o0000HOooool2o`000?oooooo1Ooo
ool002Wooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0?oooooo1Oooool002Wooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo0?oooooo1_ooool002Wooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo0?oooooo1oooool002Wooooo0_l0002aooooo`;o0000
Eoooool2o`000?oooooo2_ooool002Wooooo00?o0000ooooooooool0/_ooool2o`0005?ooooo0_l0
003oooooo`cooooo000Yooooo`03o`000?oooooooooo0;Cooooo0_l0001?ooooo`;o0000ooooool>
ooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Boooool2o`000?oooooo4?ooool002Wo
oooo00?o0000ooooooooool0^?ooool2o`0004Oooooo0_l0003ooooooa;ooooo000Yooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3ooooooa;ooooo
000Yooooo`03o`000?oooooooooo0;_ooooo0_l00011ooooo`;o0000oooooolEooooo`00:Oooool2
o`000;kooooo0_l0000mooooo`;o0000oooooolGooooo`00:Oooool00ol0003oooooooooo`2ooooo
o`?o0000>?ooool2o`000?oooooo6Oooool002Wooooo00?o0000ooooooooool0`_ooool2o`0003?o
oooo0ol0003ooooooa_ooooo000Yooooo`03o`000?oooooooooo0<Cooooo0ol0000^ooooo`;o0000
oooooolNooooo`00:Oooool00ol0003oooooooooo`37ooooo`Go00009?ooool5o`000?oooooo8?oo
ool000cooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooo
oooo0<cooooo1ol0000Eooooo`So0000oooooolUooooo`003Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo0=?ooooo1ol00007ooooo`Oo0000ooooool]ooooo`003Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00007ooooo`?o0000f_ooool7o`000?oooooo=?ooool000go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3ooooooooooooo5_oo
ool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3ooooooooo
oooo5_ooool000cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oooooooooooolF
ooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00008oooo
o`03o`000?oooooooooo0?oooooooooooolFooooo`00:Oooool00ol0003oooooooooo`3ooooooooo
oooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooooaKooooo000Yooooo`03o`000?oo
oooooooo0?oooooooooooolFooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool001Cooooo0ol0000_ooooo`03o`000?oooooooooo
0?oooooon?ooool001Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3oooooooOo
oooo0003ooooo`?o00000oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o
00000oooool3o`0000;ooooo0ol00004ooooo`Co00000oooool2o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l0
0000oooooooaooooo`001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooool0
003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool0003ooooooo;ooooo0004ooooo`04o`000?ooooooooooooooo`Go000000Kooooo
o`000?oooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`Go00002?ooool00ol0003oooooo`00003ooooo
oo?ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0
003oooooooCooooo0002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo0_l0
00001?oooooo0000ooooooooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002ooooo`?o00002Oooool00ol0003oooooo`00003ooooooo?ooooo0002ooooo`05o`00
0?oooooo0000ooooool000009_ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`00
0?ooooool_ooool000;ooooo1Ol0000Vooooo`03o`000?oooooooooo01[ooooo0ol000000ooooooo
0000o`00003ooooooo7ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0912323, 183.273, \
0.00222507, 2.7443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here is a combined equilibrium showing the coexistence curve and \
the spinodal superposed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[CoexPlot, SpinodalPlot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.953614 -0.237544 0.000840863 [
[.21453 .00222 -9 -9 ]
[.21453 .00222 9 0 ]
[.40526 .00222 -9 -9 ]
[.40526 .00222 9 0 ]
[.59598 .00222 -9 -9 ]
[.59598 .00222 9 0 ]
[.7867 .00222 -9 -9 ]
[.7867 .00222 9 0 ]
[.97742 .00222 -3 -9 ]
[.97742 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.01131 .0988 -18 -4.5 ]
[.01131 .0988 0 4.5 ]
[.01131 .18289 -18 -4.5 ]
[.01131 .18289 0 4.5 ]
[.01131 .26697 -18 -4.5 ]
[.01131 .26697 0 4.5 ]
[.01131 .35106 -18 -4.5 ]
[.01131 .35106 0 4.5 ]
[.01131 .43515 -18 -4.5 ]
[.01131 .43515 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -41 0 ]
[.02381 .64303 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21453 .01472 m
.21453 .02097 L
s
[(0.2)] .21453 .00222 0 1 Mshowa
.40526 .01472 m
.40526 .02097 L
s
[(0.4)] .40526 .00222 0 1 Mshowa
.59598 .01472 m
.59598 .02097 L
s
[(0.6)] .59598 .00222 0 1 Mshowa
.7867 .01472 m
.7867 .02097 L
s
[(0.8)] .7867 .00222 0 1 Mshowa
.97742 .01472 m
.97742 .02097 L
s
[(1)] .97742 .00222 0 1 Mshowa
.125 Mabswid
.07149 .01472 m
.07149 .01847 L
s
.11917 .01472 m
.11917 .01847 L
s
.16685 .01472 m
.16685 .01847 L
s
.26221 .01472 m
.26221 .01847 L
s
.30989 .01472 m
.30989 .01847 L
s
.35757 .01472 m
.35757 .01847 L
s
.45294 .01472 m
.45294 .01847 L
s
.50062 .01472 m
.50062 .01847 L
s
.5483 .01472 m
.5483 .01847 L
s
.64366 .01472 m
.64366 .01847 L
s
.69134 .01472 m
.69134 .01847 L
s
.73902 .01472 m
.73902 .01847 L
s
.83438 .01472 m
.83438 .01847 L
s
.88206 .01472 m
.88206 .01847 L
s
.92974 .01472 m
.92974 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0988 m
.03006 .0988 L
s
[(400)] .01131 .0988 1 0 Mshowa
.02381 .18289 m
.03006 .18289 L
s
[(500)] .01131 .18289 1 0 Mshowa
.02381 .26697 m
.03006 .26697 L
s
[(600)] .01131 .26697 1 0 Mshowa
.02381 .35106 m
.03006 .35106 L
s
[(700)] .01131 .35106 1 0 Mshowa
.02381 .43515 m
.03006 .43515 L
s
[(800)] .01131 .43515 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(900)] .01131 .51923 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04835 m
.02756 .04835 L
s
.02381 .06517 m
.02756 .06517 L
s
.02381 .08198 m
.02756 .08198 L
s
.02381 .11562 m
.02756 .11562 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .14925 m
.02756 .14925 L
s
.02381 .16607 m
.02756 .16607 L
s
.02381 .1997 m
.02756 .1997 L
s
.02381 .21652 m
.02756 .21652 L
s
.02381 .23334 m
.02756 .23334 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .28379 m
.02756 .28379 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .31743 m
.02756 .31743 L
s
.02381 .33424 m
.02756 .33424 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38469 m
.02756 .38469 L
s
.02381 .40151 m
.02756 .40151 L
s
.02381 .41833 m
.02756 .41833 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46878 m
.02756 .46878 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50242 m
.02756 .50242 L
s
.02381 .53605 m
.02756 .53605 L
s
.02381 .55287 m
.02756 .55287 L
s
.02381 .56968 m
.02756 .56968 L
s
.02381 .5865 m
.02756 .5865 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.005 w
.02504 .01472 m
.02534 .02312 L
.02569 .03153 L
.02609 .03994 L
.02655 .04835 L
.02707 .05676 L
.02765 .06517 L
.0283 .07358 L
.02901 .08198 L
.0298 .09039 L
.03066 .0988 L
.03161 .10721 L
.03263 .11562 L
.03374 .12403 L
.03493 .13244 L
.03622 .14084 L
.03759 .14925 L
.03907 .15766 L
.04063 .16607 L
.0423 .17448 L
.04407 .18289 L
.04595 .1913 L
.04793 .1997 L
.05002 .20811 L
.05223 .21652 L
.05455 .22493 L
.05699 .23334 L
.05955 .24175 L
.06224 .25016 L
.06505 .25857 L
.06799 .26697 L
.07107 .27538 L
.07429 .28379 L
.07765 .2922 L
.08115 .30061 L
.08481 .30902 L
.08862 .31743 L
.09259 .32583 L
.09673 .33424 L
.10103 .34265 L
.10552 .35106 L
.11019 .35947 L
.11504 .36788 L
.1201 .37629 L
.12536 .38469 L
.13084 .3931 L
.13655 .40151 L
.1425 .40992 L
.14869 .41833 L
.15515 .42674 L
Mistroke
.16189 .43515 L
.16892 .44356 L
.17627 .45196 L
.18396 .46037 L
.19202 .46878 L
.20047 .47719 L
.20934 .4856 L
.21869 .49401 L
.22855 .50242 L
.239 .51082 L
.25009 .51923 L
.26192 .52764 L
.27461 .53605 L
.28831 .54446 L
.30323 .55287 L
.31968 .56128 L
.33811 .56968 L
.3593 .57809 L
.38476 .5865 L
.41836 .59491 L
.50062 .60332 L
.58287 .59491 L
.61647 .5865 L
.64193 .57809 L
.66313 .56968 L
.68156 .56128 L
.698 .55287 L
.71292 .54446 L
.72662 .53605 L
.73931 .52764 L
.75115 .51923 L
.76224 .51082 L
.77268 .50242 L
.78254 .49401 L
.79189 .4856 L
.80077 .47719 L
.80922 .46878 L
.81727 .46037 L
.82496 .45196 L
.83231 .44356 L
.83935 .43515 L
.84608 .42674 L
.85254 .41833 L
.85874 .40992 L
.86468 .40151 L
.87039 .3931 L
.87587 .38469 L
.88113 .37629 L
.88619 .36788 L
.89105 .35947 L
Mistroke
.89572 .35106 L
.9002 .34265 L
.90451 .33424 L
.90864 .32583 L
.91261 .31743 L
.91642 .30902 L
.92008 .30061 L
.92358 .2922 L
.92694 .28379 L
.93016 .27538 L
.93324 .26697 L
.93618 .25857 L
.939 .25016 L
.94168 .24175 L
.94424 .23334 L
.94668 .22493 L
.949 .21652 L
.95121 .20811 L
.9533 .1997 L
.95529 .1913 L
.95716 .18289 L
.95893 .17448 L
.9606 .16607 L
.96217 .15766 L
.96364 .14925 L
.96502 .14084 L
.9663 .13244 L
.96749 .12403 L
.9686 .11562 L
.96963 .10721 L
.97057 .0988 L
.97143 .09039 L
.97222 .08198 L
.97294 .07358 L
.97358 .06517 L
.97416 .05676 L
.97468 .04835 L
.97514 .03994 L
.97554 .03153 L
.97589 .02312 L
.97619 .01472 L
Mfstroke
.5 Mabswid
.10169 .01472 m
.10455 .02312 L
.10743 .03153 L
.11033 .03994 L
.11326 .04835 L
.1162 .05676 L
.11917 .06517 L
.12216 .07358 L
.12518 .08198 L
.12822 .09039 L
.13128 .0988 L
.13437 .10721 L
.13749 .11562 L
.14064 .12403 L
.14381 .13244 L
.14701 .14084 L
.15024 .14925 L
.1535 .15766 L
.15679 .16607 L
.16011 .17448 L
.16346 .18289 L
.16685 .1913 L
.17027 .1997 L
.17373 .20811 L
.17723 .21652 L
.18076 .22493 L
.18434 .23334 L
.18795 .24175 L
.19161 .25016 L
.19531 .25857 L
.19906 .26697 L
.20285 .27538 L
.20669 .28379 L
.21059 .2922 L
.21453 .30061 L
.21853 .30902 L
.22259 .31743 L
.22671 .32583 L
.23089 .33424 L
.23514 .34265 L
.23946 .35106 L
.24385 .35947 L
.24831 .36788 L
.25286 .37629 L
.25749 .38469 L
.26221 .3931 L
.26703 .40151 L
.27195 .40992 L
.27697 .41833 L
.28212 .42674 L
Mistroke
.28738 .43515 L
.29278 .44356 L
.29832 .45196 L
.30402 .46037 L
.30989 .46878 L
.31595 .47719 L
.32221 .4856 L
.3287 .49401 L
.33545 .50242 L
.34248 .51082 L
.34984 .51923 L
.35757 .52764 L
.36576 .53605 L
.37447 .54446 L
.38382 .55287 L
.394 .56128 L
.40526 .56968 L
.41803 .57809 L
.43319 .5865 L
.45294 .59491 L
.50062 .60332 L
.5483 .59491 L
.56805 .5865 L
.5832 .57809 L
.59598 .56968 L
.60723 .56128 L
.61741 .55287 L
.62677 .54446 L
.63548 .53605 L
.64366 .52764 L
.6514 .51923 L
.65876 .51082 L
.66579 .50242 L
.67253 .49401 L
.67902 .4856 L
.68528 .47719 L
.69134 .46878 L
.69721 .46037 L
.70291 .45196 L
.70845 .44356 L
.71385 .43515 L
.71912 .42674 L
.72426 .41833 L
.72929 .40992 L
.7342 .40151 L
.73902 .3931 L
.74374 .38469 L
.74837 .37629 L
.75292 .36788 L
.75738 .35947 L
Mistroke
.76177 .35106 L
.76609 .34265 L
.77034 .33424 L
.77452 .32583 L
.77864 .31743 L
.7827 .30902 L
.7867 .30061 L
.79065 .2922 L
.79454 .28379 L
.79838 .27538 L
.80218 .26697 L
.80592 .25857 L
.80962 .25016 L
.81328 .24175 L
.81689 .23334 L
.82047 .22493 L
.824 .21652 L
.8275 .20811 L
.83096 .1997 L
.83438 .1913 L
.83777 .18289 L
.84112 .17448 L
.84445 .16607 L
.84774 .15766 L
.851 .14925 L
.85423 .14084 L
.85743 .13244 L
.8606 .12403 L
.86374 .11562 L
.86686 .10721 L
.86995 .0988 L
.87301 .09039 L
.87605 .08198 L
.87907 .07358 L
.88206 .06517 L
.88503 .05676 L
.88798 .04835 L
.8909 .03994 L
.8938 .03153 L
.89668 .02312 L
.89954 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool007Cooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000A?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0004?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00015ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000B_ooool3o`0007Wooooo
001cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000@oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000004[ooooo00?o0000ooooooooool0N?ooool007?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00012oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000013ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo07So
oooo001cooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0@_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0004?ooooo00Co0000oooooooooooo00001ooo
ool4o`0004Cooooo00Co0000oooooooooooo00002?ooool3o`0004_ooooo00?o0000ooooooooool0
N?ooool007?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004?o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000013ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool00000B_ooool00ol0003oooooooooo`1hooooo`00Loooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000@oooool01?l0003oooooooooool00009oooo
o`;o0000@oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo04Cooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004Wooooo0_l0001jooooo`00M?oo
ool2o`0000Wooooo0ol00015ooooo`;o00002oooool00ol0003oooooooooo`12ooooo`;o00002_oo
ool2o`0004Gooooo0_l00009ooooo`?o0000Boooool00ol0003oooooooooo`1hooooo`00:Oooool0
0ol0003oooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooo
oaKooooo000Yooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`03o`000?oooooooooo017o
oooo000Yooooo`03o`000?oooooooooo0?ooooooooooool3ooooo`03o`000?oooooooooo013ooooo
000Yooooo`03o`000?oooooooooo0?oooooo/Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo0ol00003ooooo`?o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000oooool00ol0003oooooooooo`02o`000004ooooool0003o0000oooo
o`Co00001_ooool002Wooooo00?o0000ooooooooool0oooooonaooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo000Noooooooo0000]?l0000;ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool002Sooooo0_l0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0@ooooo`?o00005_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003o
ooooo`000008ooooo`?o00000oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo0ol00006ooooo`00:?ooool2o`0001?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo0ol0000Fooooo`03o`000?oo
oooo000000;ooooo1?l00003ooooo`?o00000_ooool2o`000003ooooool0003ooooo00Sooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000_oo
ool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`0000[ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`00:?ooool2o`00027ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01kooooo0ol0000Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0000Dooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`00
:?ooool2o`00027ooooo00?o0000ooooooooool0oooooomFooooo`03o`000?oooooooooo01kooooo
0_l0000Gooooo`;o00001?ooool00ol0003oooooooooo`0Dooooo`Go00005?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Ko
oooo000Xooooo`;o00008Oooool00ol0003oooooooooo`3ooooooeKooooo00?o0000ooooooooool0
7_ooool2o`0007[ooooo000Xooooo`;o00008_ooool00ol0003oooooooooo`3ooooooeCooooo00?o
0000ooooooooool07oooool2o`0007[ooooo000Xooooo`?o00008_ooool00ol0003oooooooooo`3o
oooooe?ooooo00?o0000ooooooooool07oooool2o`0007[ooooo000Xooooo`;o00008oooool00ol0
003oooooooooo`3ooooooe?ooooo00?o0000ooooooooool07oooool2o`0007[ooooo000Xooooo`;o
00008oooool00ol0003oooooooooo`3ooooooe;ooooo00?o0000ooooooooool08?ooool2o`0007[o
oooo000Xooooo`;o00009?ooool00ol0003oooooooooo`3ooooooe7ooooo00?o0000ooooooooool0
8?ooool2o`0007[ooooo000Xooooo`;o00009?ooool00ol0003oooooooooo`3ooooooe3ooooo00?o
0000ooooooooool08Oooool2o`0007[ooooo000Xooooo`;o00009?ooool00ol0003oooooooooo`3o
oooooe3ooooo00?o0000ooooooooool08Oooool2o`0007[ooooo000Xooooo`;o00009?ooool00ol0
003oooooooooo`3ooooooe3ooooo00?o0000ooooooooool08Oooool2o`0007[ooooo000Xooooo`?o
00009?ooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool08_ooool2o`0007[o
oooo000Yooooo`;o00009?ooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0
8_ooool2o`0007[ooooo000Yooooo`;o00009?ooool00ol0003oooooooooo`3oooooodkooooo00?o
0000ooooooooool08_ooool2o`0007[ooooo000Yooooo`;o00009Oooool00ol0003oooooooooo`3o
ooooodcooooo00?o0000ooooooooool08_ooool3o`0007[ooooo000Yooooo`;o00009_ooool00ol0
003oooooooooo`3ooooood_ooooo00?o0000ooooooooool08_ooool2o`0007_ooooo000Yooooo`;o
00009_ooool00ol0003oooooooooo`3ooooood_ooooo00?o0000ooooooooool08_ooool2o`0007_o
oooo000Yooooo`;o00009_ooool00ol0003oooooooooo`3ooooood[ooooo00?o0000ooooooooool0
8oooool2o`0007_ooooo000Yooooo`;o00009oooool00ol0003oooooooooo`3oooooodWooooo00?o
0000ooooooooool08oooool2o`0007_ooooo000Yooooo`;o00009oooool00ol0003oooooooooo`3o
ooooodSooooo00?o0000ooooooooool09?ooool2o`0007_ooooo000Yooooo`;o00009oooool00ol0
003oooooooooo`3oooooodSooooo00?o0000ooooooooool09?ooool2o`0007_ooooo000Yooooo`;o
00009oooool00ol0003oooooooooo`3oooooodSooooo00?o0000ooooooooool09?ooool2o`0007_o
oooo000Yooooo`;o0000:?ooool00ol0003oooooooooo`3oooooodKooooo00?o0000ooooooooool0
9Oooool2o`0007_ooooo000Yooooo`;o0000:?ooool00ol0003oooooooooo`3oooooodKooooo00?o
0000ooooooooool09Oooool2o`0007_ooooo000Yooooo`;o0000:?ooool00ol0003oooooooooo`3o
ooooodKooooo00?o0000ooooooooool09Oooool2o`0007_ooooo000Yooooo`?o0000:?ooool00ol0
003oooooooooo`3oooooodCooooo00?o0000ooooooooool09_ooool2o`0007_ooooo000Yooooo`?o
0000:?ooool00ol0003oooooooooo`3oooooodCooooo00?o0000ooooooooool09_ooool2o`0007_o
oooo000Yooooo`?o0000:?ooool00ol0003oooooooooo`3oooooodCooooo00?o0000ooooooooool0
9_ooool2o`0007_ooooo000Yooooo`?o0000:Oooool00ol0003oooooooooo`3ooooood?ooooo00?o
0000ooooooooool09_ooool2o`0007_ooooo000Yooooo`?o0000:Oooool00ol0003oooooooooo`3o
oooood;ooooo00?o0000ooooooooool09_ooool3o`0007_ooooo000Yooooo`?o0000:_ooool00ol0
003oooooooooo`3ooooood7ooooo00?o0000ooooooooool09_ooool2o`0007cooooo000Cooooo`?o
00000oooool2o`0000Cooooo0_l00008ooooo`?o0000:_ooool00ol0003oooooooooo`3ooooood7o
oooo00?o0000ooooooooool09_ooool2o`0007cooooo000Dooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo0ol0000Zoooo
o`03o`000?oooooooooo0?oooooo@?ooool00ol0003oooooooooo`0Wooooo`;o0000O?ooool0017o
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3
o`0002_ooooo00?o0000ooooooooool0ooooooloooooo`03o`000?oooooooooo02Oooooo0_l0001l
ooooo`004Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool3o`0002_ooooo00?o0000ooooooooool0oooooolnooooo`03o`00
0?oooooooooo02Sooooo0_l0001looooo`004_ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3o`0002_ooooo00?o0000oooooooo
ool0oooooolnooooo`03o`000?oooooooooo02Sooooo0_l0001looooo`004oooool2o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`Co0000:oooool00ol0
003oooooooooo`3ooooooccooooo00?o0000ooooooooool0:?ooool3o`0007cooooo000Dooooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00002?ooool01?l0003oooooo`000?l0000[oooo
o`03o`000?oooooooooo0?oooooo??ooool00ol0003oooooooooo`0Xooooo`;o0000OOooool002Wo
oooo00Co0000ooooool0003o0000:oooool00ol0003oooooooooo`3ooooooccooooo00?o0000oooo
ooooool0:?ooool2o`0007gooooo000Yooooo`04o`000?oooooo0000o`0002cooooo00?o0000oooo
ooooool0ooooooljooooo`03o`000?oooooooooo02Wooooo0_l0001mooooo`00:Oooool01?l0003o
ooooo`000?l0000/ooooo`03o`000?oooooooooo0?oooooo>_ooool00ol0003oooooooooo`0Yoooo
o`;o0000OOooool002Wooooo1?l0000]ooooo`03o`000?oooooooooo0?oooooo>?ooool00ol0003o
ooooooooo`0Zooooo`;o0000OOooool002Wooooo00Co0000ooooool0003o0000;Oooool00ol0003o
ooooooooo`3oooooocSooooo00?o0000ooooooooool0:_ooool2o`0007gooooo000Yooooo`03o`00
0?oooooo000000;o0000;Oooool00ol0003oooooooooo`3oooooocKooooo00?o0000ooooooooool0
:_ooool3o`0007gooooo000Yooooo`03o`000?oooooooooo00;o0000;Oooool00ol0003ooooooooo
o`3oooooocKooooo00?o0000ooooooooool0:_ooool2o`0007kooooo000Yooooo`03o`000?oooooo
oooo00;o0000;Oooool00ol0003oooooooooo`3oooooocKooooo00?o0000ooooooooool0:_ooool2
o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000;_ooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool0:_ooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00;o
0000;_ooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool0:oooool2o`0007ko
oooo000Yooooo`;o000000?oooooo`000?l00000;oooool00ol0003oooooooooo`3ooooooc?ooooo
00?o0000ooooooooool0:oooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00;o0000;ooo
ool00ol0003oooooooooo`3ooooooc?ooooo00?o0000ooooooooool0:oooool2o`0007kooooo000Y
ooooo`03o`000?oooooooooo00;o0000;oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000
ooooooooool0;?ooool2o`0007kooooo000Yooooo`03o`000?oooooooooo00?o0000;oooool00ol0
003oooooooooo`3ooooooc7ooooo00?o0000ooooooooool0:oooool3o`0007kooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000;oooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooo
ooooool0;?ooool2o`0007oooooo000Yooooo`04o`000?ooooooooooooooo`;o0000;oooool00ol0
003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0;?ooool2o`0007oooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000<?ooool00ol0003oooooooooo`3oooooobkooooo00?o0000oooo
ooooool0;Oooool2o`0007oooooo000Yooooo`;o00000_ooool2o`00033ooooo00?o0000oooooooo
ool0ooooool^ooooo`03o`000?oooooooooo02gooooo0_l0001oooooo`00:Oooool01?l0003ooooo
ooooooooool2o`00033ooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo02go
oooo0_l0001oooooo`00:Oooool01?l0003oooooooooooooool2o`00037ooooo00?o0000oooooooo
ool0ooooool]ooooo`03o`000?oooooooooo02gooooo0_l0001oooooo`00:Oooool01?l0003ooooo
ooooooooool3o`00033ooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo02go
oooo0ol0001oooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000<Oooool00ol0003ooooo
ooooo`3oooooob_ooooo00?o0000ooooooooool0;Oooool2o`00083ooooo000Yooooo`03o`000?oo
oooooooo00;ooooo0_l0000aooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003ooooooooo
o`0]ooooo`;o0000P?ooool002Wooooo00?o0000ooooooooool00_ooool2o`00037ooooo00?o0000
ooooooooool0oooooolZooooo`03o`000?oooooooooo02kooooo0_l00020ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`?o0000<Oooool00ol0003oooooooooo`3oooooobWooooo00?o0000oooo
ooooool0;Oooool3o`00083ooooo000Yooooo`;o00001?ooool2o`00037ooooo00?o0000oooooooo
ool0oooooolXooooo`03o`000?oooooooooo02kooooo0_l00021ooooo`00:Oooool00ol0003ooooo
ooooo`03ooooo`;o0000<Oooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool0
;_ooool2o`00087ooooo000Yooooo`03o`000?oooooooooo00?ooooo0ol0000aooooo`03o`000?oo
oooooooo0?oooooo9_ooool00ol0003oooooooooo`0_ooooo`;o0000POooool002Wooooo00?o0000
ooooooooool01?ooool2o`0003;ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooo
oooo02oooooo0_l00021ooooo`004_ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`;o0000<_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000oooo
ooooool0;oooool2o`00087ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?oo
ool2o`0003;ooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo033ooooo0_l0
0021ooooo`005Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o0000<oooool00ol0003ooooo
ooooo`3oooooob?ooooo00?o0000ooooooooool0;oooool3o`00087ooooo000Eooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`?o
00001?ooool2o`0003?ooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo033o
oooo0_l00022ooooo`004Oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Cooooo0_l0000cooooo`03o`000?oooooooooo
0?oooooo8_ooool00ol0003oooooooooo`0`ooooo`;o0000P_ooool0017ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01?ooool2o`0003?ooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooo
oooo033ooooo0_l00022ooooo`004Oooool5o`0000?ooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`04ooooo`?o0000<oooool00ol0003oooooooooo`3oooooob3ooooo00?o0000oooo
ooooool0<?ooool3o`0008;ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000cooooo`03
o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0`ooooo`;o0000Poooool002Wooooo
00?o0000ooooooooool01Oooool2o`0003?ooooo00?o0000ooooooooool0oooooolPooooo`03o`00
0?oooooooooo033ooooo0_l00023ooooo`00:Oooool00ol0003oooooooooo`05ooooo`?o0000<ooo
ool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0<?ooool3o`0008?ooooo000Y
ooooo`;o00001oooool2o`0003Cooooo00?o0000ooooooooool0oooooolLooooo`03o`000?oooooo
oooo037ooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o0000=?ooool00ol0
003oooooooooo`3ooooooacooooo00?o0000ooooooooool0<Oooool2o`0008Cooooo000Yooooo`03
o`000?oooooooooo00Kooooo0_l0000dooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0003o
ooooooooo`0aooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool01_ooool3o`0003Cooooo
00?o0000ooooooooool0oooooolJooooo`03o`000?oooooooooo037ooooo0ol00024ooooo`00:Ooo
ool00ol0003oooooooooo`07ooooo`;o0000=?ooool00ol0003oooooooooo`3ooooooa[ooooo00?o
0000ooooooooool0<Oooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000d
ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0aooooo`;o0000QOooool0
02Wooooo00?o0000ooooooooool01oooool2o`0003Gooooo00?o0000ooooooooool0oooooolHoooo
o`03o`000?oooooooooo03;ooooo0_l00025ooooo`00:Oooool00ol0003oooooooooo`07ooooo`?o
0000=?ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0<Oooool3o`0008Go
oooo000Yooooo`;o00002Oooool2o`0003Gooooo00?o0000ooooooooool0oooooolFooooo`03o`00
0?oooooooooo03;ooooo0_l00026ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o0000=Ooo
ool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool0<_ooool2o`0008Kooooo000Y
ooooo`03o`000?oooooooooo00Sooooo0ol0000eooooo`03o`000?oooooooooo0?oooooo5?ooool0
0ol0003oooooooooo`0booooo`?o0000Q_ooool002Wooooo00?o0000ooooooooool02Oooool2o`00
03Kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo0_l00027oooo
o`00:Oooool00ol0003oooooooooo`09ooooo`;o0000=_ooool00ol0003oooooooooo`3ooooooa?o
oooo00?o0000ooooooooool0<_ooool2o`0008Oooooo000Yooooo`03o`000?oooooooooo00Wooooo
0_l0000fooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003oooooooooo`0cooooo`;o0000
Qoooool002Wooooo00?o0000ooooooooool02Oooool3o`0003Kooooo00?o0000ooooooooool0oooo
oolAooooo`03o`000?oooooooooo03;ooooo0ol00027ooooo`00:Oooool2o`0000_ooooo0_l0000f
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0cooooo`;o0000R?ooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0003Kooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo03?ooooo0_l00028ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`?o
0000=_ooool00ol0003oooooooooo`3oooooo`kooooo00?o0000ooooooooool0<oooool3o`0008So
oooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0000gooooo`03o`000?oooooooooo0?oooooo
3Oooool00ol0003oooooooooo`0cooooo`;o0000ROooool002Wooooo00?o0000ooooooooool02ooo
ool2o`0003Oooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooooooo03?ooooo0_l0
0029ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000=oooool00ol0003oooooooooo`3o
ooooo`cooooo00?o0000ooooooooool0=?ooool2o`0008Wooooo000Yooooo`03o`000?oooooooooo
00_ooooo0ol0000gooooo`03o`000?oooooooooo0?oooooo2oooool00ol0003oooooooooo`0coooo
o`?o0000ROooool002Wooooo0_l0000=ooooo`;o0000=oooool00ol0003oooooooooo`3oooooo`[o
oooo00?o0000ooooooooool0=?ooool2o`0008[ooooo000Yooooo`03o`000?oooooooooo00cooooo
0_l0000gooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0dooooo`;o0000
R_ooool002Wooooo00?o0000ooooooooool03?ooool2o`0003Sooooo00?o0000ooooooooool0oooo
ool8ooooo`03o`000?oooooooooo03Gooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`0<
ooooo`?o0000=oooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0=?ooool3
o`0008[ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000hooooo`03o`000?oooooooooo
0?oooooo1_ooool00ol0003oooooooooo`0eooooo`;o0000Roooool001;ooooo0ol00004ooooo`;o
00001?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool2o`0003Sooooo00?o0000oooooooo
ool0ooooool6ooooo`03o`000?oooooooooo03Gooooo0_l0002;ooooo`004Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00gooooo0ol0000hooooo`03o`000?oooooooooo0?oooooo1?ooool0
0ol0003oooooooooo`0eooooo`?o0000Roooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool3o`0000kooooo
0ol0000gooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0eooooo`;o0000
S?ooool0017ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0?ooooo`;o0000=oooool00ol0003oooooooooo`3oooooo`Co
oooo00?o0000ooooooooool0=Oooool2o`0008cooooo000Aooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00oooooo0_l0000hooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`0eoooo
o`?o0000S?ooool001;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool03oooool3o`0003Oooooo00?o0000
ooooooooool0ooooool2ooooo`03o`000?oooooooooo03Gooooo0_l0002=ooooo`004oooool2o`00
00Cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`;o0000>?ooool00ol0
003oooooooooo`3oooooo`03o`000?oooooooooo03Gooooo0ol0002=ooooo`00:Oooool00ol0003o
ooooooooo`0@ooooo`;o0000>?ooool00ol0003oooooooooo`3oooooo`03o`000?oooooooooo03Go
oooo0_l0002>ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o0000>Oooool00ol0003ooooo
ooooo`3nooooo`03o`000?oooooooooo03Gooooo0_l0002>ooooo`00:Oooool00ol0003ooooooooo
o`0@ooooo`?o0000>?ooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo03Gooooo0ol0
002>ooooo`00:Oooool2o`0001;ooooo0_l0000iooooo`03o`000?oooooooooo0?cooooo00?o0000
ooooooooool0=Oooool2o`0008oooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0000ioooo
o`03o`000?oooooooooo0?cooooo00?o0000ooooooooool0=Oooool2o`0008oooooo000Yooooo`03
o`000?oooooooooo017ooooo0ol0000iooooo`03o`000?oooooooooo0?[ooooo00?o0000oooooooo
ool0=Oooool3o`0008oooooo000Yooooo`03o`000?oooooooooo01;ooooo0ol0000hooooo`03o`00
0?oooooooooo0?Wooooo00?o0000ooooooooool0=Oooool3o`00093ooooo000Yooooo`03o`000?oo
oooooooo01?ooooo0_l0000hooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool0=Ooo
ool2o`00097ooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000iooooo`03o`000?oooooo
oooo0?Oooooo00?o0000ooooooooool0=_ooool2o`00097ooooo000Yooooo`03o`000?oooooooooo
01?ooooo0ol0000hooooo`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool0=Oooool3o`00
097ooooo000Yooooo`;o00005Oooool2o`0003Wooooo00?o0000ooooooooool0mOooool00ol0003o
ooooooooo`0fooooo`;o0000T_ooool002Wooooo00?o0000ooooooooool05?ooool2o`0003Wooooo
00?o0000ooooooooool0mOooool00ol0003oooooooooo`0fooooo`;o0000T_ooool002Wooooo00?o
0000ooooooooool05?ooool3o`0003Wooooo00?o0000ooooooooool0loooool00ol0003ooooooooo
o`0fooooo`?o0000T_ooool002Wooooo00?o0000ooooooooool05Oooool2o`0003Wooooo00?o0000
ooooooooool0loooool00ol0003oooooooooo`0fooooo`;o0000Toooool002Wooooo00?o0000oooo
ooooool05Oooool3o`0003Wooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`0foooo
o`?o0000Toooool002Wooooo00?o0000ooooooooool05_ooool2o`0003Wooooo00?o0000oooooooo
ool0lOooool00ol0003oooooooooo`0fooooo`;o0000U?ooool002Wooooo00?o0000ooooooooool0
5_ooool3o`0003Wooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`0fooooo`?o0000
U?ooool002Wooooo0_l0000Hooooo`?o0000>Oooool00ol0003oooooooooo`3^ooooo`03o`000?oo
oooooooo03Kooooo0_l0002Eooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o0000>Oooool0
0ol0003oooooooooo`3^ooooo`03o`000?oooooooooo03Kooooo0_l0002Eooooo`00:Oooool00ol0
003oooooooooo`0Hooooo`;o0000>Oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
03Kooooo0ol0002Eooooo`00:Oooool00ol0003oooooooooo`0Hooooo`?o0000>Oooool00ol0003o
ooooooooo`3/ooooo`03o`000?oooooooooo03Kooooo0_l0002Fooooo`00:Oooool00ol0003ooooo
ooooo`0Iooooo`;o0000>Oooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo03Kooooo
0ol0002Fooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000>Oooool00ol0003ooooooooo
o`3[ooooo`03o`000?oooooooooo03Kooooo0_l0002Gooooo`00:Oooool00ol0003oooooooooo`0I
ooooo`?o0000>Oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo03Kooooo0ol0002G
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000>Oooool00ol0003oooooooooo`3Yoooo
o`03o`000?oooooooooo03Kooooo0_l0002Hooooo`00:Oooool2o`0001_ooooo0ol0000iooooo`03
o`000?oooooooooo0>Oooooo00?o0000ooooooooool0=_ooool3o`0009Sooooo000Yooooo`03o`00
0?oooooooooo01_ooooo0_l0000iooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0
=_ooool2o`0009Wooooo000Yooooo`03o`000?oooooooooo01_ooooo0ol0000iooooo`03o`000?oo
oooooooo0>Gooooo00?o0000ooooooooool0=_ooool3o`0009Wooooo000Yooooo`03o`000?oooooo
oooo01cooooo0ol0000iooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool0=_ooool3
o`0009[ooooo000Cooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00002?ooool00ol0
003oooooooooo`0Mooooo`;o0000>Oooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo
03Kooooo0_l0002Kooooo`004oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Mooooo`?o0000>Oooool0
0ol0003oooooooooo`3Qooooo`03o`000?oooooooooo03Kooooo0ol0002Kooooo`005?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01kooooo0_l0000iooooo`03o`000?oooooooooo0>7ooooo00?o
0000ooooooooool0=_ooool2o`0009cooooo000Dooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo0ol0000Nooooo`?o0000
>Oooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo03Kooooo0ol0002Looooo`005Ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Oooooo`;o0000>Oooool00ol0003oooooooooo`3Oooooo`03
o`000?oooooooooo03Kooooo0_l0002Mooooo`004Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo01oooooo0ol0000iooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool0=_ooool3
o`0009gooooo000Aooooo`Go00000oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
023ooooo0ol0000iooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool0=_ooool3o`00
09kooooo000Yooooo`03o`000?oooooooooo027ooooo0_l0000iooooo`03o`000?oooooooooo0=_o
oooo00?o0000ooooooooool0=_ooool2o`0009oooooo000Yooooo`03o`000?oooooooooo027ooooo
0ol0000iooooo`03o`000?oooooooooo0=Wooooo00?o0000ooooooooool0=_ooool3o`0009oooooo
000Yooooo`03o`000?oooooooooo02;ooooo0_l0000iooooo`03o`000?oooooooooo0=Wooooo00?o
0000ooooooooool0=_ooool2o`000:3ooooo000Yooooo`;o00008oooool3o`0003Wooooo00?o0000
ooooooooool0eoooool00ol0003oooooooooo`0fooooo`?o0000X?ooool002Wooooo00?o0000oooo
ooooool08oooool2o`0003Wooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`0foooo
o`;o0000XOooool002Wooooo00?o0000ooooooooool08oooool3o`0003Wooooo00?o0000oooooooo
ool0eOooool00ol0003oooooooooo`0fooooo`?o0000XOooool002Wooooo00?o0000ooooooooool0
9?ooool2o`0003Wooooo00?o0000ooooooooool0eOooool00ol0003oooooooooo`0fooooo`;o0000
X_ooool002Wooooo00?o0000ooooooooool09?ooool3o`0003Wooooo00?o0000ooooooooool0dooo
ool00ol0003oooooooooo`0fooooo`?o0000X_ooool002Wooooo00?o0000ooooooooool09Oooool3
o`0003Sooooo00?o0000ooooooooool0doooool00ol0003oooooooooo`0fooooo`;o0000Xoooool0
02Wooooo00?o0000ooooooooool09_ooool3o`0003Sooooo00?o0000ooooooooool0dOooool00ol0
003oooooooooo`0fooooo`?o0000Xoooool002Wooooo0_l0000Xooooo`?o0000>?ooool00ol0003o
ooooooooo`3?ooooo`03o`000?oooooooooo03Kooooo0ol0002Tooooo`00:Oooool00ol0003ooooo
ooooo`0Xooooo`;o0000>?ooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo03Kooooo
0_l0002Uooooo`00:Oooool00ol0003oooooooooo`0Xooooo`?o0000>?ooool00ol0003ooooooooo
o`3=ooooo`03o`000?oooooooooo03Kooooo0ol0002Uooooo`00:Oooool00ol0003oooooooooo`0Y
ooooo`;o0000>?ooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo03Gooooo0ol0002V
ooooo`00:Oooool00ol0003oooooooooo`0Yooooo`?o0000>?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo03Gooooo0ol0002Wooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o
0000>?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo03Gooooo0_l0002Xooooo`00
:Oooool00ol0003oooooooooo`0Zooooo`?o0000>?ooool00ol0003oooooooooo`39ooooo`03o`00
0?oooooooooo03Gooooo0ol0002Xooooo`00:Oooool00ol0003oooooooooo`0[ooooo`;o0000>?oo
ool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo03Gooooo0_l0002Yooooo`00:Oooool2
o`0002cooooo0ol0000hooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0=Oooool3
o`000:Wooooo000Yooooo`03o`000?oooooooooo02cooooo0ol0000gooooo`03o`000?oooooooooo
0<Oooooo00?o0000ooooooooool0=?ooool3o`000:[ooooo000Yooooo`03o`000?oooooooooo02go
oooo0ol0000gooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0=?ooool3o`000:_o
oooo000Yooooo`03o`000?oooooooooo02kooooo0ol0000gooooo`03o`000?oooooooooo0<?ooooo
00?o0000ooooooooool0=?ooool3o`000:cooooo000Yooooo`03o`000?oooooooooo02oooooo0_l0
000gooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0=?ooool2o`000:gooooo000Y
ooooo`03o`000?oooooooooo02oooooo0ol0000gooooo`03o`000?oooooooooo0<7ooooo00?o0000
ooooooooool0=?ooool3o`000:gooooo000Yooooo`03o`000?oooooooooo033ooooo0ol0000foooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0=?ooool2o`000:kooooo000Yooooo`;o
0000<_ooool3o`0003Kooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0dooooo`?o
0000[_ooool002Wooooo00?o0000ooooooooool0<_ooool2o`0003Kooooo00?o0000ooooooooool0
_oooool00ol0003oooooooooo`0dooooo`;o0000[oooool002Wooooo00?o0000ooooooooool0<_oo
ool3o`0003Kooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0dooooo`?o0000[ooo
ool002Wooooo00?o0000ooooooooool0<oooool2o`0003Kooooo00?o0000ooooooooool0_Oooool0
0ol0003oooooooooo`0cooooo`?o0000/?ooool002Wooooo00?o0000ooooooooool0<oooool3o`00
03Kooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`?o0000/Oooool001;o
oooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0=?ooool3o`0003Ko
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0booooo`?o0000/_ooool0017ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0eooooo`?o0000=_ooool00ol0003oooooooooo`2h
ooooo`03o`000?oooooooooo03;ooooo0ol0002cooooo`004Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`?o0000
=_ooool3o`0003Kooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0booooo`?o0000
]?ooool001;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0gooooo`;o0000=_ooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo03;ooooo0_l0002eooooo`004Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo03Oooooo0ol0000fooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0<_ooool3
o`000;Gooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0>?ooool3o`0003Gooooo
00?o0000ooooooooool0/oooool00ol0003oooooooooo`0booooo`?o0000]_ooool001;ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0>Oooool3o`0003Gooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`0booooo`?o0000]oooool002Wooooo00?o0000
ooooooooool0>_ooool3o`0003Cooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0b
ooooo`;o0000^?ooool002Wooooo00?o0000ooooooooool0>oooool3o`0003Cooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`0booooo`?o0000^?ooool002Wooooo00?o0000oooooooo
ool0??ooool3o`0003?ooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0aooooo`?o
0000^Oooool002Wooooo0_l0000nooooo`?o0000<oooool00ol0003oooooooooo`2]ooooo`03o`00
0?oooooooooo033ooooo1?l0002jooooo`00:Oooool00ol0003oooooooooo`0nooooo`?o0000<ooo
ool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo033ooooo1?l0002kooooo`00:Oooool0
0ol0003oooooooooo`0oooooo`?o0000<oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo033ooooo0ol0002mooooo`00:Oooool00ol0003oooooooooo`10ooooo`?o0000<oooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo033ooooo0ol0002nooooo`00:Oooool00ol0003o
ooooooooo`11ooooo`;o0000<oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo033o
oooo0_l0002oooooo`00:Oooool00ol0003oooooooooo`11ooooo`?o0000<oooool00ol0003ooooo
ooooo`2Uooooo`03o`000?oooooooooo033ooooo0ol0002oooooo`00:Oooool00ol0003ooooooooo
o`12ooooo`?o0000<_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo02oooooo0ol0
0030ooooo`00:Oooool2o`0004Cooooo0ol0000booooo`03o`000?oooooooooo0:?ooooo00?o0000
ooooooooool0;oooool3o`000<7ooooo000Yooooo`03o`000?oooooooooo04Cooooo0ol0000aoooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0;_ooool3o`000<;ooooo000Yooooo`03
o`000?oooooooooo04Gooooo0ol0000aooooo`03o`000?oooooooooo0:7ooooo00?o0000oooooooo
ool0;_ooool3o`000<?ooooo000Yooooo`03o`000?oooooooooo04Kooooo0ol0000aooooo`03o`00
0?oooooooooo09oooooo00?o0000ooooooooool0;_ooool3o`000<Cooooo000Yooooo`03o`000?oo
oooooooo04Oooooo1?l0000`ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0;Ooo
ool4o`000<Gooooo000Yooooo`03o`000?oooooooooo04Sooooo1?l0000`ooooo`03o`000?oooooo
oooo09_ooooo00?o0000ooooooooool0;Oooool4o`000<Kooooo000Yooooo`03o`000?oooooooooo
04[ooooo0ol0000`ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0;Oooool3o`00
0<Sooooo000Yooooo`;o0000C?ooool3o`00033ooooo00?o0000ooooooooool0Uoooool00ol0003o
ooooooooo`0]ooooo`?o0000bOooool002Wooooo00?o0000ooooooooool0C?ooool3o`0002oooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0/ooooo`?o0000b_ooool002Wooooo00?o
0000ooooooooool0COooool3o`0002oooooo00?o0000ooooooooool0UOooool00ol0003ooooooooo
o`0/ooooo`?o0000boooool002Wooooo00?o0000ooooooooool0C_ooool3o`0002oooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`0[ooooo`?o0000c?ooool002Wooooo00?o0000oooo
ooooool0Coooool4o`0002kooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Zoooo
o`Co0000cOooool002Wooooo00?o0000ooooooooool0D?ooool4o`0002kooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`0Zooooo`Co0000c_ooool002Wooooo00?o0000ooooooooool0
D_ooool3o`0002kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Zooooo`?o0000
d?ooool002Wooooo0_l0001Dooooo`Co0000;Oooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo02[ooooo0ol0003Aooooo`00:Oooool00ol0003oooooooooo`1Dooooo`Co0000;?ooool0
0ol0003oooooooooo`2<ooooo`03o`000?oooooooooo02Wooooo0ol0003Booooo`00:Oooool00ol0
003oooooooooo`1Fooooo`?o0000;?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
02Wooooo0ol0003Cooooo`00:Oooool00ol0003oooooooooo`1Gooooo`?o0000;?ooool00ol0003o
ooooooooo`28ooooo`03o`000?oooooooooo02Wooooo0ol0003Dooooo`00:Oooool00ol0003ooooo
ooooo`1Hooooo`Co0000:oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02Sooooo
1?l0003Eooooo`004_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool00ol0003ooooooooo
o`1Iooooo`Co0000:_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02Sooooo1?l0
003Fooooo`005?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo0ol0000Zooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0:?ooool3o`000=Sooooo000Eooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo05cooooo0ol0000Zooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool0:?ooool3o`000=Wooooo000Booooo`Co00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Oooooo0ol0001Mooooo`Co0000:Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo02Oooooo1?l0003Jooooo`004Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo05kooooo1Ol0000Xooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09_oo
ool5o`000=_ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0H?ooool4o`0002So
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Vooooo`Co0000gOooool001;ooooo
0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0H_ooool4o`0002Oooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Uooooo`Co0000goooool002Wooooo00?o
0000ooooooooool0Hoooool4o`0002Oooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`0Tooooo`Co0000h?ooool002Wooooo00?o0000ooooooooool0IOooool3o`0002Oooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0Sooooo`Co0000h_ooool002Wooooo00?o0000oooo
ooooool0I_ooool3o`0002Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Soooo
o`Co0000hoooool002Wooooo0_l0001Xooooo`Co00009_ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo02;ooooo1?l0003Uooooo`00:Oooool00ol0003oooooooooo`1Xooooo`Co0000
9Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02;ooooo1?l0003Vooooo`00:Ooo
ool00ol0003oooooooooo`1Zooooo`Co00009?ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo027ooooo1?l0003Xooooo`00:Oooool00ol0003oooooooooo`1[ooooo`Co00009?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo027ooooo1?l0003Yooooo`00:Oooool00ol0
003oooooooooo`1]ooooo`Co00008oooool2o`0006_ooooo0_l0000Rooooo`Co0000joooool002Wo
oooo00?o0000ooooooooool0K_ooool6o`0002;ooooo0_l0001Xooooo`03o`000?oooooooooo023o
oooo1Ol0003/ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`Ko00008_ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo01oooooo1Ol0003^ooooo`00:Oooool2o`0007Cooooo1Ol0
000Qooooo`03o`000?oooooooooo067ooooo0_l0000Pooooo`Go0000l?ooool002Wooooo00?o0000
ooooooooool0MOooool5o`00023ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0N
ooooo`Go0000l_ooool002Wooooo00?o0000ooooooooool0Moooool4o`00023ooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`0Nooooo`Co0000m?ooool002Wooooo00?o0000oooooooo
ool0NOooool4o`0001oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Mooooo`Co
0000m_ooool002Wooooo00?o0000ooooooooool0N_ooool5o`0001kooooo0_l0001Iooooo`;o0000
7_ooool5o`000?Oooooo000Yooooo`03o`000?oooooooooo07cooooo1Ol0000Nooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool07?ooool5o`000?Wooooo000Yooooo`03o`000?oooooo
oooo07kooooo1Ol0000Mooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool06oooool5
o`000?_ooooo000Yooooo`03o`000?oooooooooo083ooooo1Ol0000Looooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool06_ooool5o`000?gooooo000Yooooo`;o0000Poooool6o`0001[o
oooo0_l0001?ooooo`;o00006_ooool6o`000?oooooo000Yooooo`03o`000?oooooooooo08Cooooo
1ol0000Iooooo`;o0000Boooool2o`0001Wooooo1ol0003oooooo`;ooooo000Yooooo`03o`000?oo
oooooooo08Oooooo1ol0000Hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_oo
ool7o`000?oooooo1Oooool002Wooooo00?o0000ooooooooool0R_ooool6o`0001Oooooo0_l00015
ooooo`;o00005_ooool7o`000?oooooo2?ooool002Wooooo00?o0000ooooooooool0SOooool6o`00
01Kooooo0_l00011ooooo`;o00005Oooool7o`000?oooooo2oooool002Wooooo00?o0000oooooooo
ool0Soooool7o`0001Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`Oo
0000ooooool>ooooo`00:Oooool00ol0003oooooooooo`2Booooo`Oo00004oooool2o`0003_ooooo
0_l0000Booooo`Oo0000oooooolAooooo`00:Oooool2o`0009Kooooo1ol0000Booooo`;o0000=ooo
ool2o`00017ooooo1ol0003ooooooaCooooo000Yooooo`03o`000?oooooooooo09Sooooo1ol0000A
ooooo`;o0000<oooool2o`00013ooooo1ol0003ooooooaOooooo000Yooooo`03o`000?oooooooooo
09_ooooo2?l0000?ooooo`;o0000;oooool2o`0000kooooo2?l0003ooooooa[ooooo000Yooooo`03
o`000?oooooooooo09kooooo2?l0000>ooooo`;o0000:oooool2o`0000gooooo2?l0003ooooooago
oooo000Yooooo`03o`000?oooooooooo0:;ooooo3?l00008ooooo`Go00008_ooool4o`0000Oooooo
3?l0003oooooob7ooooo000<ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00002?oo
ool00ol0003oooooooooo`2UoooooaGo000000?oooooo`000?l000001Ol0000Doooooa_o0000oooo
oolTooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0:go
oooo7?l00006oooooa[o0000ooooool/ooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007
ooooo`?o0000^OoooolTo`000?oooooo>?ooool000gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`35ooooo`co0000oooooom4ooooo`003Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo0?oooooooooooolFooooo`003?ooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool0oooooooooooooaKooooo000=ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0oooooooo
oooooaKooooo000Yooooo`03o`000?oooooooooo0?oooooooooooolFooooo`00:Oooool00ol0003o
ooooooooo`3ooooooooooooo5_ooool002Wooooo00?o0000ooooooooool0oooooooooooooaKooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`005?ooool3o`0002oooooo00?o0000ooooooooool0ooooooohooooo`005Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo0?oooooomoooool000?ooooo0ol00003ooooo`?o
00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`?o00000_ooool3o`00
00Cooooo1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001?ooool3o`00
00Gooooo00?o0000ooooooooool00ol000000ooooooo0000o`00003ooooooo7ooooo0004ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003oooooo`000?oooooo000000;ooooo00Ko0000
oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`000?ooooool_oo
ool000Cooooo00Co0000oooooooooooooooo1Ol000001_oooooo0000ooooool0003oooooo`0000;o
oooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo00?o0000ooooooooool00oooool3o`00
00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo1Ol00008ooooo`03o`000?oooooo00000?ooooooloooool000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooom?ooool000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`?o00000_ooool2o`000004ooooool0003oooooooooo`Co
00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0ol00009oooo
o`03o`000?oooooo00000?ooooooloooool000;ooooo00Go0000ooooool0003oooooo`00000Voooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000ooooooobooooo`000_ooool5o`00
02Kooooo00?o0000ooooooooool06_ooool3o`000003ooooool0003o00000?oooooolOooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;o
oooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooo
oooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_oo
ool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.0992175, 183.273, \
0.00241982, 2.7443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diffuse Interfaces in the Bragg-Williams approximation", "Subsection"],

Cell["\<\
The gradient-energy coefficient Kc is related to W and \
\[CapitalDelta]U and the lattice constant a of the crystal. Assuming a \
reasonable value for the lattice constant I calculate Kc for the system \
as\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 0.29\[Times]10\^\(-9\);\)\), "\[IndentingNewLine]", 
    \(\(VMolar\  = \ a\^3\/2\ N0;\)\), "\[IndentingNewLine]", 
    \(\(VAtomic\  = \ a\^3\/2;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]U50 = \[CapitalDelta]U[0.5, 
          0];\)\), "\[IndentingNewLine]", 
    \(Kc = \(2\/3\) \[CapitalDelta]U50 \(\(\ \)\(\((\@3/2  \
a)\)\^2\)\)\/VMolar\)}], "Input"],

Cell[BoxData[
    \(4.760863103448276`*^-11\)], "Output"]
}, Open  ]],

Cell["\<\
We will look at the energy of the interface between equilibrium \
phases at T = 900 K. We need the expression for the free energy density \
\[CapitalDelta]fhom(XB) as illustrated in KoM Fig. 18.1. First calculate the \
free energy density of the equilibrium phases. Note again that \
\[CapitalDelta]F is symmetric about XB = 0.5 and the common tangent has zero \
slope.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(T = 900;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha]Root = 
        FindRoot[\[PartialD]\_XB\ \[CapitalDelta]F[XB, 0, T] \[Equal] 
            0, {XB,  .2}];\)\), "\[IndentingNewLine]", 
    \(XBEq\[Alpha] = \[Alpha]Root[\([1, 2]\)]\), "\[IndentingNewLine]", 
    \(\(XBEq\[Beta] = 1 - XBEq\[Alpha];\)\), "\[IndentingNewLine]", 
    \(\[CapitalDelta]FEq[T_] = \[CapitalDelta]F[XBEq\[Alpha], 0, 
        T]\)}], "Input"],

Cell[BoxData[
    \(0.2372852436709955`\)], "Output"],

Cell[BoxData[
    \(\(-2181.308904178689`\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now calculating \[CapitalDelta]fhom(XB) on a per unit volume basis (units \
are thus Joule/",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\^3\)\()\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]fHom[XB_, 
        T_] := \(\[CapitalDelta]F[XB, 0, T] - \[CapitalDelta]FEq[T]\)\/VMolar\
\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\[CapitalDelta]fHom[XB, T], {XB, XBEq\[Alpha], XBEq\[Beta]}, 
      AxesLabel \[Rule] {"\<Atom Fraction,XB\>", \
"\<\[CapitalDelta]fHom\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.406288 1.81258 0.0147151 3.53997e-08 [
[.31874 .00222 -9 -9 ]
[.31874 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.68126 .00222 -9 -9 ]
[.68126 .00222 9 0 ]
[.86252 .00222 -9 -9 ]
[.86252 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 100.125 6 ]
[.12498 .10321 -40.5 -6.25 ]
[.12498 .10321 0 6.25 ]
[.12498 .19171 -28.5 -6.25 ]
[.12498 .19171 0 6.25 ]
[.12498 .28021 -40.5 -6.25 ]
[.12498 .28021 0 6.25 ]
[.12498 .36871 -28.5 -6.25 ]
[.12498 .36871 0 6.25 ]
[.12498 .45721 -46.5 -6.25 ]
[.12498 .45721 0 6.25 ]
[.12498 .54571 -40.5 -6.25 ]
[.12498 .54571 0 6.25 ]
[.13748 .64303 -17.0625 0 ]
[.13748 .64303 17.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.31874 .01472 m
.31874 .02097 L
s
[(0.4)] .31874 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.5)] .5 .00222 0 1 Mshowa
.68126 .01472 m
.68126 .02097 L
s
[(0.6)] .68126 .00222 0 1 Mshowa
.86252 .01472 m
.86252 .02097 L
s
[(0.7)] .86252 .00222 0 1 Mshowa
.125 Mabswid
.17374 .01472 m
.17374 .01847 L
s
.20999 .01472 m
.20999 .01847 L
s
.24624 .01472 m
.24624 .01847 L
s
.28249 .01472 m
.28249 .01847 L
s
.35499 .01472 m
.35499 .01847 L
s
.39125 .01472 m
.39125 .01847 L
s
.4275 .01472 m
.4275 .01847 L
s
.46375 .01472 m
.46375 .01847 L
s
.53625 .01472 m
.53625 .01847 L
s
.5725 .01472 m
.5725 .01847 L
s
.60875 .01472 m
.60875 .01847 L
s
.64501 .01472 m
.64501 .01847 L
s
.71751 .01472 m
.71751 .01847 L
s
.75376 .01472 m
.75376 .01847 L
s
.79001 .01472 m
.79001 .01847 L
s
.82626 .01472 m
.82626 .01847 L
s
.10123 .01472 m
.10123 .01847 L
s
.06498 .01472 m
.06498 .01847 L
s
.02873 .01472 m
.02873 .01847 L
s
.89877 .01472 m
.89877 .01847 L
s
.93502 .01472 m
.93502 .01847 L
s
.97127 .01472 m
.97127 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Atom) show
93.125 13.000 moveto
(Fraction) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(XB) show
159.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13748 .10321 m
.14373 .10321 L
s
gsave
.12498 .10321 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.13748 .19171 m
.14373 .19171 L
s
gsave
.12498 .19171 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.13748 .28021 m
.14373 .28021 L
s
gsave
.12498 .28021 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.13748 .36871 m
.14373 .36871 L
s
gsave
.12498 .36871 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.13748 .45721 m
.14373 .45721 L
s
gsave
.12498 .45721 -46.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.25) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.13748 .54571 m
.14373 .54571 L
s
gsave
.12498 .54571 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.125 Mabswid
.13748 .03241 m
.14123 .03241 L
s
.13748 .05011 m
.14123 .05011 L
s
.13748 .06781 m
.14123 .06781 L
s
.13748 .08551 m
.14123 .08551 L
s
.13748 .12091 m
.14123 .12091 L
s
.13748 .13861 m
.14123 .13861 L
s
.13748 .15631 m
.14123 .15631 L
s
.13748 .17401 m
.14123 .17401 L
s
.13748 .20941 m
.14123 .20941 L
s
.13748 .22711 m
.14123 .22711 L
s
.13748 .24481 m
.14123 .24481 L
s
.13748 .26251 m
.14123 .26251 L
s
.13748 .29791 m
.14123 .29791 L
s
.13748 .31561 m
.14123 .31561 L
s
.13748 .33331 m
.14123 .33331 L
s
.13748 .35101 m
.14123 .35101 L
s
.13748 .38641 m
.14123 .38641 L
s
.13748 .40411 m
.14123 .40411 L
s
.13748 .42181 m
.14123 .42181 L
s
.13748 .43951 m
.14123 .43951 L
s
.13748 .47491 m
.14123 .47491 L
s
.13748 .49261 m
.14123 .49261 L
s
.13748 .51031 m
.14123 .51031 L
s
.13748 .52801 m
.14123 .52801 L
s
.13748 .56341 m
.14123 .56341 L
s
.13748 .58111 m
.14123 .58111 L
s
.13748 .59881 m
.14123 .59881 L
s
.13748 .61651 m
.14123 .61651 L
s
.25 Mabswid
.13748 0 m
.13748 .61803 L
s
gsave
.13748 .64303 -78.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(fHom) show
93.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01473 L
.02605 .01477 L
.02729 .01486 L
.02846 .01497 L
.03053 .01524 L
.03279 .01565 L
.03527 .01623 L
.0379 .01698 L
.04262 .0187 L
.05205 .02348 L
.06244 .03065 L
.0842 .05139 L
.10458 .07673 L
.14335 .13657 L
.18458 .21062 L
.22428 .28588 L
.26248 .3572 L
.30312 .42783 L
.34225 .48748 L
.38383 .53911 L
.4047 .55974 L
.4239 .57536 L
.44265 .58737 L
.45221 .59222 L
.46245 .59646 L
.46773 .59825 L
.47272 .59969 L
.47759 .60087 L
.48209 .60176 L
.48635 .60241 L
.48852 .60268 L
.49087 .60291 L
.49321 .6031 L
.49426 .60316 L
.49541 .60322 L
.49669 .60327 L
.49738 .60329 L
.49803 .6033 L
.49919 .60332 L
.50042 .60332 L
.50166 .60331 L
.50236 .60329 L
.50301 .60328 L
.50433 .60323 L
.50575 .60316 L
.50832 .60298 L
.51067 .60276 L
.51339 .60244 L
.51636 .60201 L
Mistroke
.52177 .60101 L
.53223 .59826 L
.54192 .59477 L
.56248 .5844 L
.5811 .57161 L
.62122 .53355 L
.65983 .48456 L
.70088 .42122 L
.74042 .35191 L
.77844 .28069 L
.81892 .20409 L
.85788 .13449 L
.87773 .10243 L
.89929 .07153 L
.91865 .04827 L
.92925 .03771 L
.93919 .0294 L
.94838 .02322 L
.95679 .01895 L
.96134 .01723 L
.96613 .01588 L
.96862 .01538 L
.97094 .01504 L
.97227 .0149 L
.97348 .0148 L
.97415 .01476 L
.97488 .01474 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo002<ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000AOoo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0004Kooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00016ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0:Wooooo002;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0@ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000A?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000A?ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo0:Wooooo002;ooooo`04o`000?ooooooooooo`0000Oooooo1Ol0
0014ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0@_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool00000A?ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo0:Sooooo002;ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000AOooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo04;ooooo
00Co0000oooooooooooo00001oooool4o`0004Gooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`2Xooooo`00Roooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
04Gooooo00Co0000oooooooooooo00001oooool4o`0004Gooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
Yoooool008_ooooo00Co0000oooooooooooo00002Oooool2o`0004Gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool0AOooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000ZOoo
ool008cooooo0_l0000;ooooo`03o`000?oooooooooo04Cooooo0_l00008ooooo`Go0000AOooool2
o`0000[ooooo0_l00016ooooo`;o00002?ooool5o`000:Wooooo000oooooo`03o`000?oooooooooo
0?ooooooooooool003oooooo00?o0000ooooooooool0ooooooooooooo`00?oooool00ol0003ooooo
ooooo`3ooooooooooooo000oooooo`03o`000?oooooooooo0?oooooojoooool00ol0003ooooooooo
o`0Aooooo`00?oooool00ol0003oooooooooo`3ooooooncooooo00?o0000ooooooooool04?ooool0
03oooooo00?o0000ooooooooool0oooooonKooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000?ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000001oooool3o`0000?ooooo0ol0
0004ooooo`Co00000_ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol0
00000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003ooooo
1?l00006ooooo`00?oooool00ol0003oooooooooo`3ooooooi_ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01ol0003oooooo`000?oooooo
0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
1Oooool00?oo0000dOl0000<ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`0;o`000?oo
ooooooooooooool0003oooooo`000?oooooo0000ooooool000002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001Oooool000gooooo00?o0000ooooooooool00ol0000;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo
0_l00003ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000002?oo
ool3o`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`?o00001_ooool000gooooo00?o0000ooooooooool00oooool2o`0000Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01_ooool2o`0000Gooooo00?o0000ooooooooool06Oooool00ol0003oooooo`000002oooo
o`Co00000oooool3o`0000;ooooo0_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool3o`0000;ooooo1?l00002oooo
o`?o00001?ooool3o`0000;ooooo1?l0000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool001Gooooo0ol0000Wooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool09_ooool2o`0002Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool06oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000Gooooo000Hooooo`;o00009Oooool00ol0003oooooooooo`3o
ooooogGooooo0_l0000Uooooo`;o00001?ooool00ol0003oooooooooo`0Dooooo`Go00005?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000Kooooo000Jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0oooooomd
ooooo`03o`000?oooooooooo08Sooooo000Kooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0oooooomcooooo`03o`000?oooooooooo08Wooooo000Looooo`;o00008Oooool00ol0003o
ooooooooo`3oooooog7ooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`0Nooooo`?o0000
oooooom`ooooo`03o`000?oooooooooo08cooooo000Oooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0oooooom_ooooo`03o`000?oooooooooo08gooooo000Pooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0oooooom^ooooo`03o`000?oooooooooo08kooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0oooooom/ooooo`;o0000TOooool002;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3oooooof_ooooo00?o0000oooooooo
ool0TOooool002?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooof[ooooo
00?o0000ooooooooool0T_ooool002Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`3oooooofWooooo00?o0000ooooooooool0Toooool002Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`3oooooofSooooo00?o0000ooooooooool0U?ooool002Kooooo00?o0000oooo
ooooool05_ooool3o`000?ooooooJ?ooool00ol0003oooooooooo`2Dooooo`009oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0?ooooooIoooool00ol0003oooooooooo`2Eooooo`00
9oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?ooooooI_ooool00ol0003ooooo
ooooo`2Fooooo`00:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?ooooooIOoo
ool00ol0003oooooooooo`2Gooooo`00:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0?ooooooI?ooool00ol0003oooooooooo`2Hooooo`00:_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo0?ooooooHoooool00ol0003oooooooooo`2Iooooo`00:_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0?ooooooHoooool00ol0003oooooooooo`2Iooooo`00
:oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0?ooooooH_ooool00ol0003ooooo
ooooo`2Jooooo`00;?ooool00ol0003oooooooooo`0@ooooo`?o0000oooooomQooooo`03o`000?oo
oooooooo09_ooooo000]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooomP
ooooo`03o`000?oooooooooo09cooooo000]ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0oooooomOooooo`03o`000?oooooooooo09gooooo000^ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0oooooomOooooo`03o`000?oooooooooo09gooooo000_ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0oooooomNooooo`03o`000?oooooooooo09kooooo
000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooooomMooooo`03o`000?oo
oooooooo09oooooo000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooooomM
ooooo`03o`000?oooooooooo09oooooo000aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0oooooomLooooo`03o`000?oooooooooo0:3ooooo000booooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0oooooomKooooo`03o`000?oooooooooo0:7ooooo000booooo`03o`00
0?oooooooooo00[ooooo0ol0003ooooooe_ooooo00?o0000ooooooooool0XOooool003?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`3ooooooe[ooooo00?o0000ooooooooool0X_oo
ool003Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooooeWooooo00?o0000
ooooooooool0Xoooool003Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooo
oeWooooo00?o0000ooooooooool0Xoooool003Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3ooooooeSooooo00?o0000ooooooooool0Y?ooool0017ooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo0ol00003ooooo`05o`000?ooooooooooooooool000001oooool3o`0000?o
oooo0ol00006ooooo`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`2Uooooo`00
4_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool0YOooool001?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool0oooooomFoooo
o`03o`000?oooooooooo0:Kooooo000Dooooo`03o`000?oooooooooo00[ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0
0005ooooo`Co0000oooooomDooooo`03o`000?oooooooooo0:Oooooo000Aooooo`05o`000?oooooo
ooooooooool000001oooool4o`0000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`3ooooooeGo
oooo00?o0000ooooooooool0Yoooool0017ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo013ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo0ol0003ooooo
oeKooooo00?o0000ooooooooool0Z?ooool001;ooooo0ol00008ooooo`Go00003oooool00ol0003o
ooooooooo`03ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`000?ooooooEOooool00ol0
003oooooooooo`2Yooooo`00>_ooool00ol0003oooooo`000003o`000?ooooooEOooool00ol0003o
ooooooooo`2Yooooo`00>oooool2o`0000;ooooo00?o0000ooooooooool0oooooomBooooo`03o`00
0?oooooooooo0:[ooooo000looooo`Co0000oooooomCooooo`03o`000?oooooooooo0:_ooooo000l
ooooo`04o`000?ooooooooooo`000?ooooooDoooool00ol0003oooooooooo`2[ooooo`00?Oooool0
0ol0003oooooo`000002o`000?ooooooD?ooool00ol0003oooooooooo`2/ooooo`00?_ooool2o`00
0?ooooooD_ooool00ol0003oooooooooo`2/ooooo`00?_ooool2o`000?ooooooDOooool00ol0003o
ooooooooo`2]ooooo`00?oooool00ol0003oooooooooo`3oooooodkooooo00?o0000ooooooooool0
[_ooool003oooooo0_l0003oooooodoooooo00?o0000ooooooooool0[_ooool003oooooo0_l0003o
ooooodkooooo00?o0000ooooooooool0[oooool003oooooo00?o0000ooooool00000oooooom<oooo
o`03o`000?oooooooooo0;3ooooo000oooooo`04o`000?ooooooooooo`000?ooooooBoooool00ol0
003oooooooooo`2`ooooo`00?oooool4o`000?ooooooB_ooool00ol0003oooooooooo`2aooooo`00
?oooool01Ol0003ooooooooooooooooo00000?ooooooBOooool00ol0003oooooooooo`2aooooo`00
?oooool01Ol0003ooooooooooooooooo00000?ooooooB?ooool00ol0003oooooooooo`2booooo`00
?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool00ol0003ooooo
ooooo`2booooo`00?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooA?oo
ool00ol0003oooooooooo`2cooooo`00?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo@_ooool00ol0003oooooooooo`2dooooo`00?oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo@Oooool00ol0003oooooooooo`2dooooo`00?oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool00ol0003oooooooooo`2eooooo`00
?oooool3o`0000Gooooo00?o0000ooooooooool0ooooooloooooo`03o`000?oooooooooo0;Gooooo
000oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolnooooo`03o`000?oo
oooooooo0;Kooooo000oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolm
ooooo`03o`000?oooooooooo0;Kooooo000oooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooollooooo`03o`000?oooooooooo0;Oooooo000oooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolkooooo`03o`000?oooooooooo0;Oooooo000oooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ooooooljooooo`03o`000?oooooooooo0;Sooooo
000oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooooliooooo`03o`000?oo
oooooooo0;Sooooo000oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolh
ooooo`03o`000?oooooooooo0;Wooooo000oooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0oooooolfooooo`03o`000?oooooooooo0;[ooooo000oooooo`?o00002_ooool00ol0003o
ooooooooo`3oooooocGooooo00?o0000ooooooooool0^_ooool003oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool0^oooool003oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`3ooooooc?ooooo00?o0000ooooooooool0^ooo
ool003oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooooc;ooooo00?o0000
ooooooooool0_?ooool003oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3ooooo
oc7ooooo00?o0000ooooooooool0_?ooool001kooooo0ol00003ooooo`05o`000?oooooooooooooo
ool000001oooool3o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0ooooool`ooooo`03o`000?oooooooooo0;gooooo000Mooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo;oooool0
0ol0003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo0;kooooo000Qoooo
o`07o`000?ooooooooooooooool0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001Oooool4o`0000gooooo00?o0000ooooooooool0ooooool]ooooo`03o`00
0?oooooooooo0;kooooo000Mooooo`Co00000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo0;oooooo000Mooooo`03o`00
0?oooooooooo013ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo0ol0000Aooooo`03
o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`30ooooo`007Oooool5o`0000oooooo
00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000ooooool0003o00004Oooool00ol0003o
ooooooooo`3oooooob[ooooo00?o0000ooooooooool0`?ooool003cooooo1?l0000Booooo`03o`00
0?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`31ooooo`00??ooool01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`31ooooo`00?Ooo
ool3o`0001?ooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo0<;ooooo000o
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooo
oooo0<;ooooo000oooooo`?o00004_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000oooo
ooooool0`oooool003oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3oooooob?o
oooo00?o0000ooooooooool0`oooool003oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`3oooooob;ooooo00?o0000ooooooooool0a?ooool003oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool0a?ooool003oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool0aOooool0
03oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooakooooo00?o0000oooo
ooooool0a_ooool003oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooako
oooo00?o0000ooooooooool0a_ooool003oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`3ooooooacooooo00?o0000ooooooooool0aoooool003oooooo0ol0000Fooooo`03o`000?oo
oooooooo0?oooooo7?ooool00ol0003oooooooooo`37ooooo`00?oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`38ooooo`00?oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`38oooo
o`00?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003o
ooooooooo`39ooooo`00?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo
6?ooool00ol0003oooooooooo`39ooooo`00?oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo0?oooooo5_ooool00ol0003oooooooooo`3:ooooo`00?oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`3:ooooo`00?oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo0?oooooo5?ooool00ol0003oooooooooo`3;oooo
o`00?oooool3o`0001[ooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo0<co
oooo000oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0oooooolBooooo`03o`00
0?oooooooooo0<cooooo000oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0oooo
oolAooooo`03o`000?oooooooooo0<gooooo000oooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0ooooool@ooooo`03o`000?oooooooooo0<gooooo000oooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo0<kooooo000oooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo0<ko
oooo000oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0ooooool<ooooo`03o`00
0?oooooooooo0<oooooo000oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooo
ool<ooooo`03o`000?oooooooooo0<oooooo000oooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0ooooool:ooooo`03o`000?oooooooooo0=3ooooo000oooooo`?o00007oooool00ol0
003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0d?ooool003oooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0dOooool003oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0
dOooool003oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3oooooo`Kooooo00?o
0000ooooooooool0d_ooool003oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3o
ooooo`Gooooo00?o0000ooooooooool0doooool001?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000Oooooo0ol00004
ooooo`;o00001_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0?oooooo1?ooool0
0ol0003oooooooooo`3Cooooo`004oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0?oooooo0ooo
ool00ol0003oooooooooo`3Dooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3oooooo`;ooooo00?o
0000ooooooooool0e?ooool001Cooooo00?o0000ooooooooool02_ooool01ol0003ooooooooooooo
oooo0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo1?l0000Rooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`3Eooooo`00
5Oooool00ol0003oooooooooo`05ooooo`Co00000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`3Eooooo`004Oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool04?ooool2o`0000Cooooo00Co0000oooo
oooooooo00000oooool3o`0002Kooooo00?o0000ooooooooool0o_ooool00ol0003oooooooooo`3F
ooooo`004Oooool5o`0000Oooooo1Ol0000?ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`04o`000?oooooo0000o`0002Oooooo00?o0000ooooooooool0oOooool00ol0003oooooooooo`3F
ooooo`00??ooool4o`0002Oooooo00?o0000ooooooooool0o?ooool00ol0003oooooooooo`3Goooo
o`00??ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo0?_ooooo00?o0000oooo
ooooool0eoooool003gooooo0ol0000Xooooo`03o`000?oooooooooo0?[ooooo00?o0000oooooooo
ool0f?ooool003oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3iooooo`03o`00
0?oooooooooo0=Sooooo000oooooo`?o00009oooool00ol0003oooooooooo`3hooooo`03o`000?oo
oooooooo0=Wooooo000oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0moooool0
0ol0003oooooooooo`3Iooooo`00?oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0?Gooooo00?o0000ooooooooool0f_ooool003oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3eooooo`03o`000?oooooooooo0=[ooooo000oooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0loooool00ol0003oooooooooo`3Kooooo`00?oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool0foooool003oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`3aooooo`03o`000?oooooooooo0=cooooo000ooooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`3Loooo
o`00?oooool3o`0002cooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`3Mooooo`00
?oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool0
g_ooool003oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3]ooooo`03o`000?oo
oooooooo0=kooooo000oooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0k?ooool0
0ol0003oooooooooo`3Oooooo`00?oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0>_ooooo00?o0000ooooooooool0goooool003oooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`3Yooooo`03o`000?oooooooooo0>3ooooo000oooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0jOooool00ol0003oooooooooo`3Pooooo`00?oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0hOooool003oooooo0ol0000`
ooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0hOooool003oooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo0>;ooooo000oooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`3Rooooo`00
?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool0
hoooool003oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`3Sooooo`03o`000?oo
oooooooo0>?ooooo000oooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0hOooool0
0ol0003oooooooooo`3Tooooo`00?oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
0>7ooooo00?o0000ooooooooool0i?ooool003oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`3Oooooo`03o`000?oooooooooo0>Gooooo000oooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0g_ooool00ol0003oooooooooo`3Uooooo`00?oooool3o`0003Gooooo00?o
0000ooooooooool0gOooool00ol0003oooooooooo`3Vooooo`00?oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo0=cooooo00?o0000ooooooooool0i_ooool003oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo0>Oooooo000oooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`3Wooooo`00
?oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0=Wooooo00?o0000ooooooooool0
j?ooool001kooooo0ol00003ooooo`05o`000?ooooooooooooooool000001oooool3o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0eoooool00ol0003ooooo
ooooo`3Yooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0eoooool00ol0003oooooooooo`3Yooooo`007oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0eOooool00ol0003ooooo
ooooo`3Zooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`Co0000>Oooool00ol0003ooooo
ooooo`3Dooooo`03o`000?oooooooooo0>[ooooo000Oooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0=?ooooo00?o0000oooooooo
ool0joooool001kooooo0_l0000@ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooo000003gooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`3/ooooo`00
7oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooo000003gooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`3/ooooo`00?Ooo
ool00ol0003oooooo`00000nooooo`03o`000?oooooooooo0<oooooo00?o0000ooooooooool0kOoo
ool003kooooo0_l0000oooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool0kOooool0
03cooooo1?l0000oooooo`03o`000?oooooooooo0<gooooo00?o0000ooooooooool0k_ooool003oo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo0>oo
oooo000oooooo`?o0000?_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo0>oooooo
000oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0bOooool00ol0003ooooooooo
o`3`ooooo`00?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Sooooo00?o0000
ooooooooool0l?ooool003oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`37oooo
o`03o`000?oooooooooo0?7ooooo000oooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0aOooool00ol0003oooooooooo`3booooo`00?oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo0<Gooooo00?o0000ooooooooool0l_ooool003oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo0??ooooo000oooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`3cooooo`00?oooool3o`00
04?ooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`3dooooo`00?oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0mOooool003oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo0?Gooooo
000oooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0_Oooool00ol0003ooooooooo
o`3fooooo`00?oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0;cooooo00?o0000
ooooooooool0m_ooool003oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2koooo
o`03o`000?oooooooooo0?Oooooo000oooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0^Oooool00ol0003oooooooooo`3hooooo`00?oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo0;Wooooo00?o0000ooooooooool0n?ooool003oooooo0ol00018ooooo`03o`000?oo
oooooooo0;Oooooo00?o0000ooooooooool0nOooool003oooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`2fooooo`03o`000?oooooooooo0?Wooooo000oooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`3jooooo`00?oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0noooool003oooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo0?_ooooo
000oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0/Oooool00ol0003ooooooooo
o`3looooo`00?oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0;3ooooo00?o0000
ooooooooool0o?ooool003oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2_oooo
o`03o`000?oooooooooo0?gooooo000oooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0[Oooool00ol0003oooooooooo`3nooooo`00?oooool3o`0004kooooo00?o0000ooooooooool0
[?ooool00ol0003oooooooooo`3nooooo`00?oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo0:_ooooo00?o0000ooooooooool0ooooool003oooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`2Yooooo`03o`000?oooooooooo0?oooooo0Oooool003oooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo0?oooooo0Oooool003oo
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo0?oo
oooo0_ooool000cooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000?o
oooo00Go0000ooooooooooooooooo`000007ooooo`?o00001?ooool2o`0000Kooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo0?oooooo0oooool000go
oooo00?o0000ooooooooool02?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0YOooool00ol0003o
ooooooooo`3oooooo`?ooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool0Xoooool00ol0003oooooooooo`3oooooo`Cooooo000=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo0000ooooool000002Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo1?l0001Booooo`03o`000?oooooo
oooo0:;ooooo00?o0000ooooooooool0ooooool4ooooo`003Oooool00ol0003oooooooooo`07oooo
o`06o`000?ooooooooooooooool0003ooooo1?l00003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo0?oooooo1Oooool000cooooo
0_l00009ooooo`07o`000?ooooooooooooooool0003oooooo`00000Booooo`;o00001?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooo000005Kooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`3oooooo`Kooooo000=ooooo`03o`000?oooooooooo00Sooooo0ol00002oooo
o`Go00003oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooo`00001Goooo
o`03o`000?oooooooooo09kooooo00?o0000ooooooooool0ooooool6ooooo`00?Oooool00ol0003o
ooooo`00001Gooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0ooooool7ooooo`00
?_ooool2o`0005Sooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`3oooooo`Sooooo
000looooo`Co0000FOooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo0?oooooo2?oo
ool003oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2Iooooo`03o`000?oooooo
oooo0?oooooo2Oooool003oooooo0ol0001Hooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool0ooooool:ooooo`00?oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool0ooooool:ooooo`00?oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo09Gooooo00?o0000ooooooooool0ooooool;ooooo`00?oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0ooooool;ooooo`00?oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0ooooool<
ooooo`00?oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool0ooooool=ooooo`00?oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool0ooooool=ooooo`00?oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo08oooooo00?o0000ooooooooool0ooooool>ooooo`00?oooool3o`0005gooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`3oooooo`oooooo000oooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`3ooooooa3ooooo000ooooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooo
oa7ooooo000oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`3ooooooa;ooooo000oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`3ooooooa;ooooo000oooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`3ooooooa?ooooo000oooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`3ooooooaCooooo000ooooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`3ooooo
oaGooooo000oooooo`?o0000I?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo0?oo
oooo5_ooool003oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo0?oooooo5_ooool003oooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`1mooooo`03o`000?oooooooooo0?oooooo5oooool003oooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo0?oooooo6?ooool003oooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo0?oooooo6Oooool003oo
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0?oo
oooo6_ooool003oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo0?oooooo6oooool003oooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo0?oooooo6oooool003oooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo0?oooooo7?ooool003oooooo0ol0001[oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0oooooolMooooo`00?oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0oooooolNooooo`00
?oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
oooooolOooooo`00?oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool0oooooolPooooo`00?oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0oooooolQooooo`004_ooool3o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o00001?ooool2
o`0000Kooooo00?o0000ooooooooool0Koooool2o`0006Wooooo00?o0000ooooooooool0oooooolR
ooooo`004oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0oooo
oolSooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0?oooooo9?oo
ool001?ooooo00?o0000ooooooooool02oooool01ol0003ooooooooooooooooo0000ooooool00000
2Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo1?l0001booooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0oooooolUooooo`004oooool00ol0003ooooo
ooooo`07ooooo`Co00000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`3oooooobKooooo000Booooo`;o00002Oooool00ol0003o
ooooooooo`0@ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo0000
07Oooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`3oooooobOooooo000Cooooo`03
o`000?oooooooooo00Oooooo1Ol0000?ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooo000007Sooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`3oooooobSo
oooo000mooooo`03o`000?oooooo000007Wooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`3oooooobWooooo000nooooo`;o0000N_ooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo0?oooooo:_ooool003cooooo1?l0001kooooo`;o0000E_ooool00ol0003oooooooooo`3o
ooooob_ooooo000oooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`3oooooobcooooo000oooooo`?o0000O?ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo0?oooooo;Oooool003oooooo00?o0000ooooooooool0OOooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo0?oooooo;_ooool003oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0?oooooo;oooool003oooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0?oooooo<?ooool0
03oooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`17ooooo`;o0000oooooolcoooo
o`00?oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0oooooolcooooo`00?oooool00ol0003oooooooooo`22ooooo`;o0000@oooool2o`000?oooooo
=_ooool003oooooo00?o0000ooooooooool0Q?ooool2o`00043ooooo00?o0000ooooooooool0oooo
oolfooooo`00?oooool3o`0008Kooooo0_l0000looooo`;o0000ooooooliooooo`00?oooool00ol0
003oooooooooo`28ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0oooooolioooo
o`00?oooool00ol0003oooooooooo`29ooooo`;o0000=_ooool2o`000?oooooo??ooool003oooooo
00?o0000ooooooooool0Roooool2o`0003;ooooo0_l0003oooooockooooo000oooooo`03o`000?oo
oooooooo08gooooo0_l0000^ooooo`;o0000oooooom0ooooo`00?oooool00ol0003oooooooooo`2?
ooooo`;o0000:oooool00ol0003oooooooooo`3ooooood3ooooo000oooooo`03o`000?oooooooooo
097ooooo0ol0000Vooooo`;o0000oooooom3ooooo`00?oooool00ol0003oooooooooo`2Dooooo`;o
00008Oooool3o`000?ooooooAOooool003oooooo0ol0002Fooooo`?o00006_ooool4o`000?oooooo
B?ooool003oooooo00?o0000ooooooooool0VOooool4o`0001?ooooo0ol0003oooooodcooooo000o
ooooo`03o`000?oooooooooo09gooooo1_l00005ooooo`So0000oooooom?ooooo`00?oooool00ol0
003oooooooooo`2Sooooo`Go0000oooooomGooooo`00?oooool00ol0003oooooooooo`3ooooooooo
oooo000oooooo`03o`000?oooooooooo0?ooooooooooool003oooooo00?o0000ooooooooool0oooo
ooooooooo`00?oooool00ol0003oooooooooo`3ooooooooooooo000oooooo`03o`000?oooooooooo
0?ooooooooooool003oooooo0ol0003ooooooooooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo000`ooooo`Go0000
00?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0
003o00000_ooool01Ol0003oooooo`000?oooooo00000?oooooom?ooool0037ooooo00?o0000oooo
ool000001?ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool01ol0003oooooo`000?oooooo0000ooooool00000ooooooodooooo`00<Oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`07o`000?oooooo0000ooooool0003oooooo`00003oooooooCooooo000booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003ooooo00;ooooo00Oo0000
ooooool0003oooooo`000?oooooo00000?oooooom?ooool003;ooooo00?o0000ooooooooool00_oo
ool4o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0_l000000ooooooo0000
ooooo`3oooooooCooooo000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0003ooooooooooooo0Oooool003Wooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o0000ooooooooooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {0.224146, -2.03154*^6, \
0.00119084, 60974.7}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The excess free energy per unit area of the interface in J/",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Gamma] = 
      2  NIntegrate[\@\(\(\ \)\(Kc\ \[CapitalDelta]fHom[XB, T]\)\), {XB, 
            XBEq\[Alpha], XBEq\[Beta]}]\)], "Input"],

Cell[BoxData[
    \(0.019961880029250454`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is reasonable--about 20 mJ/",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spinodal decomposition kinetics", "Subsection"],

Cell["Assume an Arrhenius law for the mobility Mc", "Text"],

Cell[BoxData[
    \(Mc[T_] := A0\ Exp[\(-\(Q\/\(N0\ kB\ T\)\)\)]\)], "Input"],

Cell[BoxData[{
    \(\(Q = \ 200000;\)\), "\[IndentingNewLine]", 
    \(\(A0 = 10\^\(-18\);\)\)}], "Input"],

Cell[BoxData[{
    \(Clear[FXBXB]\), "\[IndentingNewLine]", 
    \(\(FXBXB[T_] := 
        Limit[\[PartialD]\_\(XB, XB\)\[CapitalDelta]F[XB, 0, T], 
          XB -> 0.5];\)\)}], "Input"],

Cell["\<\
So the interdiffusivity at 900 K for a solution with XB = 0.5 will \
be\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(T = 900;\)\), "\[IndentingNewLine]", 
    \(DTilde[T_] = Mc[T]\ FXBXB[T]\)}], "Input"],

Cell[BoxData[
    \(\(-1.642339176936557`*^-26\)\)], "Output"]
}, Open  ]],

Cell["The amplification factor given by KoM Eq. 18.47 becomes", "Text"],

Cell[BoxData[
    \(R[\[Beta]_, 
        T_] := \ \(-Mc[T]\) \((FXBXB[T]\/VMolar\  + \ 
            2\ Kc\ \[Beta]\^2)\) \[Beta]\^2\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[R[\[Beta], T], {\[Beta], 0, 10\^10}, 
      AxesLabel \[Rule] {"\<Wavenumber, \[Beta]\>", "\<Amplification Factor, \
R(\[Beta])\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-11 0.590526 2.40546 [
[.21429 .57803 -14.25 -12.5 ]
[.21429 .57803 14.25 0 ]
[.40476 .57803 -14.25 -12.5 ]
[.40476 .57803 14.25 0 ]
[.59524 .57803 -14.25 -12.5 ]
[.59524 .57803 14.25 0 ]
[.78571 .57803 -14.25 -12.5 ]
[.78571 .57803 14.25 0 ]
[.97619 .57803 -16.5 -12.5 ]
[.97619 .57803 16.5 0 ]
[1.025 .59053 0 -6 ]
[1.025 .59053 82 6 ]
[.01131 .10943 -24 -4.5 ]
[.01131 .10943 0 4.5 ]
[.01131 .22971 -30 -4.5 ]
[.01131 .22971 0 4.5 ]
[.01131 .34998 -24 -4.5 ]
[.01131 .34998 0 4.5 ]
[.01131 .47025 -30 -4.5 ]
[.01131 .47025 0 4.5 ]
[.02381 .64303 -80 0 ]
[.02381 .64303 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .59053 m
.21429 .59678 L
s
gsave
.21429 .57803 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.40476 .59053 m
.40476 .59678 L
s
gsave
.40476 .57803 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.59524 .59053 m
.59524 .59678 L
s
gsave
.59524 .57803 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.78571 .59053 m
.78571 .59678 L
s
gsave
.78571 .57803 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.97619 .59053 m
.97619 .59678 L
s
gsave
.97619 .57803 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(10) show
grestore
.125 Mabswid
.07143 .59053 m
.07143 .59428 L
s
.11905 .59053 m
.11905 .59428 L
s
.16667 .59053 m
.16667 .59428 L
s
.2619 .59053 m
.2619 .59428 L
s
.30952 .59053 m
.30952 .59428 L
s
.35714 .59053 m
.35714 .59428 L
s
.45238 .59053 m
.45238 .59428 L
s
.5 .59053 m
.5 .59428 L
s
.54762 .59053 m
.54762 .59428 L
s
.64286 .59053 m
.64286 .59428 L
s
.69048 .59053 m
.69048 .59428 L
s
.7381 .59053 m
.7381 .59428 L
s
.83333 .59053 m
.83333 .59428 L
s
.88095 .59053 m
.88095 .59428 L
s
.92857 .59053 m
.92857 .59428 L
s
.25 Mabswid
0 .59053 m
1 .59053 L
s
gsave
1.025 .59053 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wavenumber) show
123.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
141.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10943 m
.03006 .10943 L
s
[(-0.2)] .01131 .10943 1 0 Mshowa
.02381 .22971 m
.03006 .22971 L
s
[(-0.15)] .01131 .22971 1 0 Mshowa
.02381 .34998 m
.03006 .34998 L
s
[(-0.1)] .01131 .34998 1 0 Mshowa
.02381 .47025 m
.03006 .47025 L
s
[(-0.05)] .01131 .47025 1 0 Mshowa
.125 Mabswid
.02381 .13349 m
.02756 .13349 L
s
.02381 .15754 m
.02756 .15754 L
s
.02381 .1816 m
.02756 .1816 L
s
.02381 .20565 m
.02756 .20565 L
s
.02381 .25376 m
.02756 .25376 L
s
.02381 .27782 m
.02756 .27782 L
s
.02381 .30187 m
.02756 .30187 L
s
.02381 .32593 m
.02756 .32593 L
s
.02381 .37403 m
.02756 .37403 L
s
.02381 .39809 m
.02756 .39809 L
s
.02381 .42214 m
.02756 .42214 L
s
.02381 .4462 m
.02756 .4462 L
s
.02381 .49431 m
.02756 .49431 L
s
.02381 .51836 m
.02756 .51836 L
s
.02381 .54242 m
.02756 .54242 L
s
.02381 .56647 m
.02756 .56647 L
s
.02381 .08538 m
.02756 .08538 L
s
.02381 .06132 m
.02756 .06132 L
s
.02381 .03727 m
.02756 .03727 L
s
.02381 .01322 m
.02756 .01322 L
s
.02381 .61458 m
.02756 .61458 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Amplification) show
147.000 13.000 moveto
(Factor) show
183.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
195.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(H) show
207.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
213.000 13.000 moveto
(L) show
219.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .59053 m
.02499 .59053 L
.02605 .59053 L
.02729 .59053 L
.02846 .59054 L
.03053 .59055 L
.03279 .59057 L
.03527 .5906 L
.0379 .59064 L
.04262 .59073 L
.05205 .59099 L
.06244 .5914 L
.07293 .59192 L
.0842 .5926 L
.10458 .5941 L
.1458 .59783 L
.1664 .59974 L
.18551 .60133 L
.19503 .60201 L
.204 .60254 L
.20896 .60278 L
.21433 .603 L
.21922 .60315 L
.22152 .60321 L
.22371 .60325 L
.22488 .60327 L
.22616 .60329 L
.22723 .6033 L
.2284 .60331 L
.22967 .60332 L
.23037 .60332 L
.23102 .60332 L
.23219 .60332 L
.23344 .60331 L
.23454 .60331 L
.23575 .6033 L
.23701 .60328 L
.23818 .60326 L
.24028 .60322 L
.24253 .60317 L
.2452 .60308 L
.2481 .60297 L
.25336 .60269 L
.25847 .60234 L
.26319 .60194 L
.27289 .60086 L
.28196 .59952 L
.29191 .59764 L
.3026 .5951 L
.32377 .58824 L
Mistroke
.34387 .57915 L
.36372 .56729 L
.38212 .55337 L
.4213 .51263 L
.44275 .48287 L
.46293 .44929 L
.50154 .36784 L
.54259 .25224 L
.58213 .10745 L
Mfstroke
.58213 .10745 m
.60543 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0053ooooo00?o0000ooooooooool0
k?ooool00ol0003oooooooooo`3nooooo`00D?ooool00ol0003oooooooooo`3/ooooo`03o`000?oo
oooooooo0?kooooo001@ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool0o_ooool0
053ooooo00?o0000ooooooooool0joooool00ol0003oooooooooo`3oooooo`00D?ooool00ol0003o
ooooooooo`3[ooooo`03o`000?oooooooooo0?oooooo001@ooooo`03o`000?oooooooooo0>_ooooo
00?o0000ooooooooool0ooooool0053ooooo0_l0003/ooooo`03o`000?oooooooooo0?oooooo001@
ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool0ooooool0053ooooo00?o0000oooo
ooooool0j_ooool00ol0003oooooooooo`3oooooo`7ooooo001@ooooo`03o`000?oooooooooo0>[o
oooo00?o0000ooooooooool0ooooool1ooooo`00D?ooool00ol0003oooooooooo`3Zooooo`03o`00
0?oooooooooo0?oooooo0Oooool0053ooooo00?o0000ooooooooool0j_ooool00ol0003ooooooooo
o`3oooooo`7ooooo001@ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool0ooooool1
ooooo`00D?ooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo0?oooooo0_ooool0053o
oooo00?o0000ooooooooool0jOooool00ol0003oooooooooo`3oooooo`;ooooo001@ooooo`03o`00
0?oooooooooo0>Wooooo00?o0000ooooooooool0ooooool2ooooo`00D?ooool2o`000>[ooooo00?o
0000ooooooooool0ooooool2ooooo`00D?ooool00ol0003oooooooooo`3Yooooo`03o`000?oooooo
oooo0?oooooo0_ooool0053ooooo00?o0000ooooooooool0j?ooool00ol0003oooooooooo`3ooooo
o`?ooooo001@ooooo`03o`000?oooooooooo0>Sooooo00?o0000ooooooooool0ooooool3ooooo`00
D?ooool00ol0003oooooooooo`3Xooooo`03o`000?oooooooooo0?oooooo0oooool0053ooooo00?o
0000ooooooooool0j?ooool00ol0003oooooooooo`3oooooo`?ooooo001@ooooo`03o`000?oooooo
oooo0>Sooooo00?o0000ooooooooool0ooooool3ooooo`00D?ooool00ol0003oooooooooo`3Woooo
o`03o`000?oooooooooo0?oooooo1?ooool0053ooooo00?o0000ooooooooool0ioooool00ol0003o
ooooooooo`3oooooo`Cooooo001@ooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0
ooooool4ooooo`00D?ooool2o`000>Sooooo00?o0000ooooooooool0ooooool4ooooo`00D?ooool0
0ol0003oooooooooo`3Wooooo`03o`000?oooooooooo0?oooooo1?ooool0053ooooo00?o0000oooo
ooooool0i_ooool00ol0003oooooooooo`3oooooo`Gooooo001@ooooo`03o`000?oooooooooo0>Ko
oooo00?o0000ooooooooool0ooooool5ooooo`00D?ooool00ol0003oooooooooo`3Vooooo`03o`00
0?oooooooooo0?oooooo1Oooool0053ooooo00?o0000ooooooooool0i_ooool00ol0003ooooooooo
o`3oooooo`Gooooo001@ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool0ooooool5
ooooo`00D?ooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo0?oooooo1_ooool0053o
oooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`3oooooo`Kooooo001@ooooo`03o`00
0?oooooooooo0>Gooooo00?o0000ooooooooool0ooooool6ooooo`00D?ooool2o`000>Kooooo00?o
0000ooooooooool0ooooool6ooooo`00D?ooool00ol0003oooooooooo`3Uooooo`03o`000?oooooo
oooo0?oooooo1_ooool0053ooooo00?o0000ooooooooool0i?ooool00ol0003oooooooooo`3ooooo
o`Oooooo001@ooooo`03o`000?oooooooooo0>Cooooo00?o0000ooooooooool0ooooool7ooooo`00
D?ooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo0?oooooo1oooool0053ooooo00?o
0000ooooooooool0i?ooool00ol0003oooooooooo`3oooooo`Oooooo001@ooooo`03o`000?oooooo
oooo0>Cooooo00?o0000ooooooooool0ooooool7ooooo`00>_ooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00007ooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool0ooooool8
ooooo`00>Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool0hoooool00ol0003oooooooooo`3oooooo`Sooooo000booooo`Go00000_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0hooo
ool00ol0003oooooooooo`3oooooo`Sooooo000iooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool01_ooool3o`000>?ooooo00?o0000ooooooooool0ooooool8ooooo`00>Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`3Sooooo`03o`000?oooooooooo0?oooooo2?ooool003Wooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0h_ooool00ol0003o
ooooooooo`3oooooo`Wooooo000jooooo`;o00002Oooool3o`0000Sooooo00?o0000ooooooooool0
h_ooool00ol0003oooooooooo`3oooooo`Wooooo001@ooooo`03o`000?oooooooooo0>;ooooo00?o
0000ooooooooool0ooooool9ooooo`00D?ooool00ol0003oooooooooo`3Rooooo`03o`000?oooooo
oooo0?oooooo2Oooool0053ooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`3ooooo
o`[ooooo001@ooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool0ooooool:ooooo`00
D?ooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo0?oooooo2_ooool0053ooooo0_l0
003Qooooo`03o`000?oooooooooo0?oooooo2oooool0053ooooo00?o0000ooooooooool0h?ooool0
0ol0003oooooooooo`3oooooo`_ooooo001@ooooo`03o`000?oooooooooo0>3ooooo00?o0000oooo
ooooool0ooooool;ooooo`00D?ooool00ol0003oooooooooo`3Pooooo`03o`000?oooooooooo0?oo
oooo2oooool0053ooooo00?o0000ooooooooool0goooool00ol0003oooooooooo`3oooooo`cooooo
001@ooooo`03o`000?oooooooooo0=oooooo00?o0000ooooooooool0ooooool<ooooo`00D?ooool0
0ol0003oooooooooo`3Oooooo`03o`000?oooooooooo0?oooooo3?ooool0053ooooo00?o0000oooo
ooooool0goooool00ol0003oooooooooo`3oooooo`cooooo001@ooooo`03o`000?oooooooooo0=ko
oooo00?o0000ooooooooool0ooooool=ooooo`00D?ooool00ol0003oooooooooo`3Nooooo`03o`00
0?oooooooooo0?oooooo3Oooool0053ooooo0_l0003Oooooo`03o`000?oooooooooo0?oooooo3Ooo
ool0053ooooo00?o0000ooooooooool0gOooool00ol0003oooooooooo`3oooooo`kooooo001@oooo
o`03o`000?oooooooooo0=gooooo00?o0000ooooooooool0ooooool>ooooo`00D?ooool00ol0003o
ooooooooo`3Mooooo`03o`000?oooooooooo0?oooooo3_ooool0053ooooo00?o0000ooooooooool0
gOooool00ol0003oooooooooo`3oooooo`kooooo001@ooooo`03o`000?oooooooooo0=cooooo00?o
0000ooooooooool0ooooool?ooooo`00D?ooool00ol0003oooooooooo`3Looooo`03o`000?oooooo
oooo0?oooooo3oooool0053ooooo00?o0000ooooooooool0g?ooool00ol0003oooooooooo`3ooooo
o`oooooo001@ooooo`03o`000?oooooooooo0=cooooo00?o0000ooooooooool0ooooool?ooooo`00
D?ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo0?oooooo4?ooool0053ooooo0_l0
003Looooo`03o`000?oooooooooo0?oooooo4?ooool0053ooooo00?o0000ooooooooool0foooool0
0ol0003oooooooooo`3ooooooa3ooooo001@ooooo`03o`000?oooooooooo0=[ooooo00?o0000oooo
ooooool0oooooolAooooo`00D?ooool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo0?oo
oooo4Oooool0053ooooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`3ooooooa7ooooo
001@ooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0oooooolAooooo`00D?ooool0
0ol0003oooooooooo`3Iooooo`03o`000?oooooooooo0?oooooo4_ooool0053ooooo00?o0000oooo
ooooool0fOooool00ol0003oooooooooo`3ooooooa;ooooo001@ooooo`03o`000?oooooooooo0=Wo
oooo00?o0000ooooooooool0oooooolBooooo`00D?ooool00ol0003oooooooooo`3Iooooo`03o`00
0?oooooooooo0?oooooo4_ooool0053ooooo0_l0003Iooooo`03o`000?oooooooooo0?oooooo4ooo
ool0053ooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`3ooooooa?ooooo001@oooo
o`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool0oooooolCooooo`00D?ooool00ol0003o
ooooooooo`3Gooooo`03o`000?oooooooooo0?oooooo5?ooool0053ooooo00?o0000ooooooooool0
eoooool00ol0003oooooooooo`3ooooooaCooooo001@ooooo`03o`000?oooooooooo0=Oooooo00?o
0000ooooooooool0oooooolDooooo`00D?ooool00ol0003oooooooooo`3Gooooo`03o`000?oooooo
oooo0?oooooo5?ooool0053ooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`3ooooo
oaGooooo000dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000So
oooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`3ooooooaGooooo000cooooo`04o`00
0?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`3ooooooaGooooo000/ooooo`Go
00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool3o`000=Kooooo00?o0000ooooooooool0oooooolEooooo`00<oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3Eooooo`03o`000?oooooooooo0?oooooo5_ooool003?ooooo00Co0000oooooooo
oooo00002Oooool01?l0003oooooooooooooool4o`0000Sooooo00?o0000ooooooooool0eOooool0
0ol0003oooooooooo`3ooooooaKooooo000cooooo`04o`000?ooooooooooo`0000Sooooo0_l00003
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0eOooool00ol0003oooooooooo`3o
oooooaKooooo000dooooo`;o00002_ooool01?l0003oooooooooooooool5o`0000Oooooo00?o0000
ooooooooool0e?ooool00ol0003oooooooooo`3ooooooaOooooo001@ooooo`03o`000?oooooooooo
0=Cooooo00?o0000ooooooooool0oooooolGooooo`00D?ooool00ol0003oooooooooo`3Dooooo`03
o`000?oooooooooo0?oooooo5oooool0053ooooo00?o0000ooooooooool0e?ooool00ol0003ooooo
ooooo`3ooooooaOooooo001@ooooo`03o`000?oooooooooo0=?ooooo00?o0000ooooooooool0oooo
oolHooooo`00D?ooool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo0?oooooo6?ooool0
053ooooo0_l0003Dooooo`03o`000?oooooooooo0?oooooo6?ooool0053ooooo00?o0000oooooooo
ool0d_ooool00ol0003oooooooooo`3ooooooaWooooo001@ooooo`03o`000?oooooooooo0=;ooooo
00?o0000ooooooooool0oooooolIooooo`00D?ooool00ol0003oooooooooo`3Booooo`03o`000?oo
oooooooo0?oooooo6Oooool0053ooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`3o
oooooa[ooooo001@ooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool0oooooolJoooo
o`00D?ooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo0?oooooo6_ooool0053ooooo
00?o0000ooooooooool0d?ooool00ol0003oooooooooo`3ooooooa_ooooo001@ooooo`03o`000?oo
oooooooo0=3ooooo00?o0000ooooooooool0oooooolKooooo`00D?ooool00ol0003oooooooooo`3@
ooooo`03o`000?oooooooooo0?oooooo6oooool0053ooooo0_l0003@ooooo`03o`000?oooooooooo
0?oooooo7?ooool0053ooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`3ooooooaco
oooo001@ooooo`03o`000?oooooooooo0<oooooo00?o0000ooooooooool0oooooolLooooo`00D?oo
ool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo0?oooooo7Oooool0053ooooo00?o0000
ooooooooool0c_ooool00ol0003oooooooooo`3ooooooagooooo001@ooooo`03o`000?oooooooooo
0<kooooo00?o0000ooooooooool0oooooolMooooo`00D?ooool00ol0003oooooooooo`3=ooooo`03
o`000?oooooooooo0?oooooo7_ooool0053ooooo00?o0000ooooooooool0cOooool00ol0003ooooo
ooooo`3ooooooakooooo001@ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0oooo
oolOooooo`00D?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo0?oooooo7oooool0
053ooooo0_l0003=ooooo`03o`000?oooooooooo0?oooooo7oooool0053ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`3oooooob3ooooo001@ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool0oooooolPooooo`00D?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo0?oooooo8?ooool0053ooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`3o
ooooob7ooooo001@ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool0oooooolQoooo
o`00D?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo0?oooooo8Oooool0053ooooo
00?o0000ooooooooool0bOooool00ol0003oooooooooo`3oooooob;ooooo001@ooooo`03o`000?oo
oooooooo0<Wooooo00?o0000ooooooooool0oooooolRooooo`00D?ooool00ol0003oooooooooo`39
ooooo`03o`000?oooooooooo0?oooooo8_ooool0053ooooo0_l00039ooooo`03o`000?oooooooooo
0?oooooo8oooool0053ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`3oooooob?o
oooo001@ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0oooooolTooooo`00D?oo
ool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo0?oooooo9?ooool0053ooooo00?o0000
ooooooooool0aoooool00ol0003oooooooooo`3oooooobCooooo001@ooooo`03o`000?oooooooooo
0<Kooooo00?o0000ooooooooool0oooooolUooooo`00D?ooool00ol0003oooooooooo`36ooooo`03
o`000?oooooooooo0?oooooo9Oooool003[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00008ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0oooooolUooooo`00>Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
aOooool00ol0003oooooooooo`3oooooobKooooo000booooo`Go00000_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0aOooool00ol0003ooooo
ooooo`3oooooobKooooo000iooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1oooool3o`000<Gooooo00?o0000ooooooooool0oooooolVooooo`00>Oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0a?ooool00ol0003ooooo
ooooo`3oooooobOooooo000iooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`00
0?oooooooooo0<Cooooo00?o0000ooooooooool0oooooolWooooo`00>_ooool2o`0000[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo0?oooooo9ooo
ool0053ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`3oooooobSooooo001@oooo
o`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0oooooolXooooo`00D?ooool00ol0003o
ooooooooo`33ooooo`03o`000?oooooooooo0?oooooo:?ooool0053ooooo00?o0000ooooooooool0
`_ooool00ol0003oooooooooo`3oooooobWooooo001@ooooo`03o`000?oooooooooo0<;ooooo00?o
0000ooooooooool0oooooolYooooo`00D?ooool00ol0003oooooooooo`31ooooo`03o`000?oooooo
oooo0?oooooo:_ooool0053ooooo0_l00032ooooo`03o`000?oooooooooo0?oooooo:_ooool0053o
oooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`3oooooob_ooooo001@ooooo`03o`00
0?oooooooooo0<3ooooo00?o0000ooooooooool0ooooool[ooooo`00D?ooool00ol0003ooooooooo
o`2oooooo`03o`000?oooooooooo0?oooooo;?ooool0053ooooo00?o0000ooooooooool0_oooool0
0ol0003oooooooooo`3oooooobcooooo001@ooooo`03o`000?oooooooooo0;kooooo00?o0000oooo
ooooool0ooooool]ooooo`00D?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo0?oo
oooo;Oooool0053ooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`3oooooobgooooo
001@ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0ooooool^ooooo`00D?ooool0
0ol0003oooooooooo`2mooooo`03o`000?oooooooooo0?oooooo;_ooool0053ooooo0_l0002moooo
o`03o`000?oooooooooo0?oooooo;oooool0053ooooo00?o0000ooooooooool0_?ooool00ol0003o
ooooooooo`3ooooooboooooo001@ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool0
ooooool`ooooo`00D?ooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo0?oooooo<?oo
ool0053ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`3ooooooc7ooooo001@oooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0oooooolaooooo`00D?ooool00ol0003o
ooooooooo`2iooooo`03o`000?oooooooooo0?oooooo<_ooool0053ooooo00?o0000ooooooooool0
^Oooool00ol0003oooooooooo`3ooooooc;ooooo001@ooooo`03o`000?oooooooooo0;Sooooo00?o
0000ooooooooool0oooooolcooooo`00D?ooool00ol0003oooooooooo`2hooooo`03o`000?oooooo
oooo0?oooooo<oooool0053ooooo0_l0002hooooo`03o`000?oooooooooo0?oooooo=?ooool0053o
oooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`3oooooocCooooo001@ooooo`03o`00
0?oooooooooo0;Kooooo00?o0000ooooooooool0ooooooleooooo`00D?ooool00ol0003ooooooooo
o`2fooooo`03o`000?oooooooooo0?oooooo=Oooool0053ooooo00?o0000ooooooooool0]_ooool0
0ol0003oooooooooo`3oooooocGooooo001@ooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool0oooooolfooooo`00D?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo0?oo
oooo=_ooool0053ooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`3oooooocOooooo
001@ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0oooooolgooooo`00D?ooool2
o`000;Cooooo00?o0000ooooooooool0oooooolhooooo`00D?ooool00ol0003oooooooooo`2coooo
o`03o`000?oooooooooo0?oooooo>?ooool0053ooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`3oooooocWooooo001@ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
ooooooliooooo`00D?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo0?oooooo>_oo
ool0053ooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`3ooooooc_ooooo001@oooo
o`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0oooooolkooooo`00D?ooool00ol0003o
ooooooooo`2_ooooo`03o`000?oooooooooo0?oooooo??ooool003Cooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`?o00002?ooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo0?oooooo?Oooool003?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2^oooo
o`03o`000?oooooooooo0?oooooo?Oooool002cooooo1Ol00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`?o0000[Oooool0
0ol0003oooooooooo`3oooooockooooo000cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0oooooolnooooo`00<oooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooo`000?ooool01?l00008ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0
ooooooloooooo`00<oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00002oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo0?oooooo@?ooool003Co
oooo0_l0000:ooooo`;o00000_ooool5o`0000Oooooo00?o0000ooooooooool0Zoooool00ol0003o
ooooooooo`3ooooood3ooooo001@ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0
oooooom1ooooo`00D?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo0?oooooo@_oo
ool0053ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`3ooooood;ooooo001@oooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0oooooom3ooooo`00D?ooool00ol0003o
ooooooooo`2Wooooo`03o`000?oooooooooo0?ooooooA?ooool0053ooooo0_l0002Wooooo`03o`00
0?oooooooooo0?ooooooAOooool0053ooooo00?o0000ooooooooool0Y_ooool00ol0003ooooooooo
o`3oooooodGooooo001@ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0oooooom6
ooooo`00D?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo0?ooooooAoooool0053o
oooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`3oooooodSooooo001@ooooo`03o`00
0?oooooooooo0:?ooooo00?o0000ooooooooool0oooooom8ooooo`00D?ooool00ol0003ooooooooo
o`2Rooooo`03o`000?oooooooooo0?ooooooBOooool0053ooooo00?o0000ooooooooool0XOooool0
0ol0003oooooooooo`3ooooood[ooooo001@ooooo`03o`000?oooooooooo0:3ooooo00?o0000oooo
ooooool0oooooom;ooooo`00D?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo0?oo
ooooBoooool0053ooooo0_l0002Pooooo`03o`000?oooooooooo0?ooooooC?ooool0053ooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`3oooooodgooooo001@ooooo`03o`000?oooooo
oooo09gooooo00?o0000ooooooooool0oooooom>ooooo`00D?ooool00ol0003oooooooooo`2Loooo
o`03o`000?oooooooooo0?ooooooCoooool0053ooooo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`3ooooooe3ooooo001@ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
oooooomAooooo`00D?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo0?ooooooD_oo
ool0053ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`3ooooooe?ooooo001@oooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0oooooomDooooo`00D?ooool00ol0003o
ooooooooo`2Fooooo`03o`000?oooooooooo0?ooooooEOooool0053ooooo0_l0002Fooooo`03o`00
0?oooooooooo0?ooooooE_ooool0053ooooo00?o0000ooooooooool0U?ooool00ol0003ooooooooo
o`3ooooooeOooooo001@ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0oooooomH
ooooo`00D?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo0?ooooooFOooool0053o
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`3ooooooe[ooooo001@ooooo`03o`00
0?oooooooooo03gooooo1Ol00002ooooo`05o`000?ooooooooooooooool000001oooool3o`0000Co
oooo0_l0000dooooo`Co000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`05ooooo`?o
00001?ooool2o`0003Cooooo0ol00003ooooo`05o`000?ooooooooooooooool000001oooool3o`00
00Cooooo0_l0000dooooo`?o00000oooool01Ol0003ooooooooooooooooo000000Oooooo0ol00004
ooooo`;o0000<Oooool3o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o00001?oo
ool2o`0005cooooo001@ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000booooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000Foooool0053ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000aooooo`Go00001?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0003;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0005_ooooo001@ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000<Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000booooo`Co00001?ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<oooool3o`0000Cooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00037o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000Foooool0053ooooo00?o0000ooooooooool0?Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000<?ooool01Ol0003oooooo`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000<_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00037ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Kooooo`00D?ooool2
o`0003kooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00001?ooool01?l0003ooooooooo
ool0000^ooooo`;o00000oooool2o`0000oooooo0_l00004ooooo`04o`000?ooooooooooo`0003?o
oooo00?o0000ooooooooool03oooool2o`0000Cooooo00Co0000oooooooooooo0000<_ooool01Ol0
003ooooooooooooooooo000000kooooo0_l00004ooooo`04o`000?ooooooooooo`00033ooooo0_l0
000@ooooo`;o00001?ooool01?l0003oooooooooool0001Kooooo`00D?ooool00ol0003ooooooooo
o`0nooooo`?o00004?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0002Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`;o0000<?ooool2o`00013ooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0
000_ooooo`?o00004?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0002gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000?ooooo00?o
0000ooooooooool0D?ooool0053ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0T
ooooo`;o00009Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0B?ooool01ol0003ooooooooooooooooo0000ooooool00000DOooool0053ooooo00?o
0000ooooooooool0G?ooool3o`0002Cooooo0_l0000Uooooo`?o0000C?ooool3o`0004cooooo0ol0
001:ooooo`07o`000?ooooooooooooooool0003oooooo`00001Aooooo`00D?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
o`00001<ooooo`03o`000?oooooo000004cooooo00?o0000ooooool00000B_ooool01ol0003ooooo
oooooooooooo0000ooooool00000DOooool0053ooooo00?o0000ooooooooool0G?ooool2o`0002;o
oooo0_l0000Xooooo`;o0000COooool2o`0004gooooo0_l0001:ooooo`;o00001?ooool00ol0003o
ooooooooo`1@ooooo`00D?ooool00ol0003oooooooooo`1nooooo`;o0000oooooomJooooo`03o`00
0?oooooooooo017ooooo001@ooooo`03o`000?oooooooooo07_ooooo0ol0003ooooooegooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`00D?ooool00ol0003oooooooooo`1i
ooooo`;o0000oooooolRooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooo
oooo00;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`000008ooooool0003o
0000ooooool0003oooooo`000?ooool4o`0000?ooooo0ol00002ooooo`?o00001_ooool00ol0003o
ooooooooo`06ooooo`04o`000?oooooo0000o`0000Kooooo001@ooooo`03o`000?oooooooooo07Oo
oooo0_l0003oooooobCooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00002ooooo`0:o`000?oo
ooooooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00006ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00001Oooool004Kooooo
ool0002No`0000cooooo00?o0000ooooool000000oooool3o`0000?ooooo00?o0000ooooool00000
0_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool02_l0003oooooooooool0003ooooo
o`000?oooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool01Ol00002ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooo00001Oooool0053ooooo00?o0000oooooooo
ool04?oooolCo`000003ooooool0003ooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00oooooo0ol0000Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04oooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool02_l0003oooooooooool0003oooooo`000?oooooo0000
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
o`00013ooooo00?o0000ooooool000001_ooool0053ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`Wo00002oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03?ooool3o`000003ooooool0003ooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooo0000ooooool000000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00;ooooo0ol00003ooooo`?o00000_oo
ool2o`000003ooooool0003o000000kooooo00Co0000oooooooooooo00001Oooool0053ooooo00?o
0000ooooooooool0;?ooool8o`0001Oooooo00?o0000ooooooooool06oooool5o`0002cooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04oooool01Ol0003oooooo`000?oooooo000002Kooooo00?o0000ooooooooool0
7?ooool2o`0000Kooooo001@ooooo`03o`000?oooooooooo03Cooooo3_l0000Oooooo`So0000oooo
oolcooooo`Ko00009?ooool2o`0002Kooooo001@ooooo`03o`000?oooooooooo04;ooooo7ol0003o
ooooohgooooo001@ooooo`03o`000?oooooooooo0?ooooook_ooool0053ooooo00?o0000oooooooo
ool0ooooooo^ooooo`00D?ooool00ol0003oooooooooo`3oooooonkooooo001@ooooo`03o`000?oo
oooooooo0?ooooook_ooool0053ooooo0_l0003oooooonoooooo001@ooooo`03o`000?oooooooooo
0?ooooook_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_oo
ool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo003ooooooooooooo@_ooool000kooooo0ol0001[ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooojGooooo000?
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo0?ooooooY?ooool000;ooooo0_l000000ooooooo0000o`000002
o`000004ooooool0003oooooo`0000;ooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol0
00000ooooooo0000o`000003o`000003ooooool0003o000000?o00000_ooool3o`0000?ooooo1?l0
0003ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001_oo
ool3o`0000Cooooo1?l00002ooooo`?o00001?ooool2o`0000?ooooo0ol00002ooooo`?o00001_oo
ool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`04o`00
0?oooooo0000o`0000Gooooo00?o0000ooooooooool0oooooonSooooo`000_ooool02ol0003ooooo
oooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`00017ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0oooooonSooooo`000_ooool5o`000006ooooool0003oooooo`000?oooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00002oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool03oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3ooooooj?ooooo0003
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00004?ooool3o`0000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo0?ooooooXoooool000?o
oooo00?o0000ooooool000000_ooool2o`000004ooooool0003oooooooooo`Co00001?ooool01?l0
003oooooooooooooool3o`0000Cooooo1?l000001?oooooo0000o`000?l00004ooooo`?o00000ooo
ool2o`0000?ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l00009ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`?o00000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000003_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo00000?ooooooY_ooool000Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool0oooo
oonUooooo`000oooool2o`0000oooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo0_l00003
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0C
ooooo`Go00003_ooool00ol0003oooooooooo`0Jooooo`Co0000oooooongooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooo
oooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;o
oooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooo
oooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_oo
ool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooo
oooood;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2.03639*^9, -0.284639, \
2.54542*^7, 0.0010078}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Find kinetic and thermodynamic wavelengths at 900 K", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolMax = Solve[\[PartialD]\_q\ R[q] == 0, q]\)], "Input"],

Cell[BoxData[
    \({{q \[Rule] \(-2.180881144943709`*^9\)}, {q \[Rule] 0.`}, {q \[Rule] 
          2.180881144943709`*^9}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Lambda]Max = \((2  \[Pi]/q)\) /. 
        SolMax[\([3]\)]\), "\[IndentingNewLine]", 
    \(RMax = R[q] /. SolMax[\([3]\)]\)}], "Input"],

Cell[BoxData[
    \(2.8810305970808706`*^-9\)], "Output"],

Cell[BoxData[
    \(0.005318412360077195`\)], "Output"]
}, Open  ]],

Cell["\<\
1 / RMax would be a good estimate of the \"characteristic time\" \
that it would take a spinodal microstructure to develop.  In this case it \
would be about 200 s.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolZero = FindRoot[R[p] \[Equal] 0, {p, 4\[Times]10\^9}]\)], "Input"],

Cell[BoxData[
    \({p \[Rule] 3.0842316931031566`*^9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda]Crit = \((2  \[Pi]/p)\) /. SolZero\)], "Input"],

Cell[BoxData[
    \(2.0371962720018115`*^-9\)], "Output"]
}, Open  ]],

Cell["\<\
So at T = 900 K we find \[Lambda]crit = 2.04 nm and  \[Lambda]max = \
2.88 nm.  \
\>", "Text"],

Cell["\<\
Now plot the R(\[Beta],T) surface to get an idea of the temperature \
dependence of \[Beta]Max and R(\[Beta]Max)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[R[\[Beta], T], {\[Beta], 0, 5\[Times]10\^9}, {T, 800, 1000}, 
      PlotRange \[Rule] { .01, \(-0.01\)}, PlotPoints \[Rule] 50, 
      ViewPoint \[Rule] {\(-1.3\), 2.4, 1. }, 
      AxesLabel \[Rule] {"\<\[Beta]\>", "\<T\>", "\<R(\[Beta])\>"}]\)], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .62761 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.7446e-16 1.06667 -0.158251 1.06667 [
[.71243 -0.01333 -3.10136 -9 ]
[.71243 -0.01333 2.89864 0 ]
[.55529 .0286 -14.3086 -12.5 ]
[.55529 .0286 14.1914 0 ]
[.40931 .06756 -13.9216 -12.5 ]
[.40931 .06756 14.5784 0 ]
[.27333 .10386 -13.5662 -12.5 ]
[.27333 .10386 14.9338 0 ]
[.14638 .13776 -13.2386 -12.5 ]
[.14638 .13776 15.2614 0 ]
[.02756 .16948 -12.9357 -12.5 ]
[.02756 .16948 15.5643 0 ]
[.34252 .0194 -4.82111 -12 ]
[.34252 .0194 5.17889 0 ]
[.41218 .64094 -9.1831 0 ]
[.41218 .64094 8.8169 9 ]
[.32842 .60866 -9.31139 0 ]
[.32842 .60866 8.68861 9 ]
[.23335 .57202 -9.45868 0 ]
[.23335 .57202 8.54132 9 ]
[.12454 .53007 -9.62954 0 ]
[.12454 .53007 8.37046 9 ]
[-0.00122 .48158 -13.1068 0 ]
[-0.00122 .48158 10.8932 9 ]
[.22996 .6386 -5.25482 0 ]
[.22996 .6386 4.74518 12 ]
[.01345 .18619 -30 -3.30209 ]
[.01345 .18619 0 5.69791 ]
[.00706 .25467 -36 -3.38623 ]
[.00706 .25467 0 5.61377 ]
[.0005 .32488 -6 -3.4728 ]
[.0005 .32488 0 5.5272 ]
[-0.00622 .39689 -30 -3.56192 ]
[-0.00622 .39689 0 5.43808 ]
[-0.0131 .47077 -24 -3.6537 ]
[-0.0131 .47077 0 5.3463 ]
[-0.06449 .33972 -28 -4.6304 ]
[-0.06449 .33972 0 7.3696 ]
[ 0 0 0 0 ]
[ 1 .62761 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.71288 0 m
.02634 .18276 L
s
.71288 0 m
.7131 .00666 L
s
[(0)] .71243 -0.01333 .03379 1 Mshowa
.55534 .04194 m
.55537 .0486 L
s
gsave
.55529 .0286 -14.3086 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.409 .08089 m
.40885 .08756 L
s
gsave
.40931 .06756 -13.9216 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.27269 .11718 m
.27238 .12384 L
s
gsave
.27333 .10386 -13.5662 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.14543 .15106 m
.14496 .15771 L
s
gsave
.14638 .13776 -13.2386 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.02634 .18276 m
.02573 .1894 L
s
gsave
.02756 .16948 -12.9357 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.125 Mabswid
.68041 .00864 m
.68052 .01264 L
s
.64844 .01715 m
.64853 .02115 L
s
.61694 .02554 m
.61701 .02954 L
s
.58591 .0338 m
.58595 .0378 L
s
.52522 .04996 m
.52521 .05396 L
s
.49553 .05786 m
.4955 .06186 L
s
.46627 .06565 m
.46622 .06965 L
s
.43743 .07332 m
.43736 .07732 L
s
.38097 .08835 m
.38086 .09235 L
s
.35333 .09571 m
.3532 .09971 L
s
.32608 .10297 m
.32593 .10696 L
s
.2992 .11012 m
.29903 .11412 L
s
.24655 .12414 m
.24634 .12813 L
s
.22076 .131 m
.22053 .135 L
s
.19531 .13778 m
.19506 .14177 L
s
.1702 .14446 m
.16994 .14845 L
s
.12098 .15756 m
.12068 .16155 L
s
.09686 .16399 m
.09654 .16797 L
s
.07305 .17032 m
.07271 .17431 L
s
.04954 .17658 m
.04919 .18057 L
s
gsave
.34252 .0194 -65.8211 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.41245 .62761 m
0 .46831 L
s
.41245 .62761 m
.41259 .62095 L
s
[(800)] .41218 .64094 .02034 -1 Mshowa
.32888 .59533 m
.32911 .58867 L
s
[(850)] .32842 .60866 .0346 -1 Mshowa
.23403 .5587 m
.23437 .55204 L
s
[(900)] .23335 .57202 .05096 -1 Mshowa
.12547 .51677 m
.12594 .51012 L
s
[(950)] .12454 .53007 .06995 -1 Mshowa
0 .46831 m
.00061 .46167 L
s
[(1000)] -0.00122 .48158 .09223 -1 Mshowa
.125 Mabswid
.39654 .62147 m
.39663 .61747 L
s
.38024 .61517 m
.38035 .61117 L
s
.36354 .60872 m
.36366 .60472 L
s
.34643 .60211 m
.34655 .59811 L
s
.31088 .58838 m
.31103 .58438 L
s
.29241 .58125 m
.29258 .57725 L
s
.27346 .57393 m
.27364 .56993 L
s
.25401 .56642 m
.2542 .56242 L
s
.21351 .55077 m
.21373 .54678 L
s
.19241 .54263 m
.19265 .53863 L
s
.17073 .53425 m
.17098 .53026 L
s
.14842 .52563 m
.14869 .52164 L
s
.10185 .50765 m
.10215 .50366 L
s
.07753 .49825 m
.07784 .49426 L
s
.05247 .48857 m
.0528 .48458 L
s
.02664 .47859 m
.02698 .47461 L
s
gsave
.22996 .6386 -66.2548 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.02634 .18276 m
0 .46831 L
s
.02634 .18276 m
.03278 .18104 L
s
[(-0.01)] .01345 .18619 1 -0.2662 Mshowa
.02 .25147 m
.02647 .24987 L
s
[(-0.005)] .00706 .25467 1 -0.24751 Mshowa
.0135 .32192 m
.02 .32043 L
s
[(0)] .0005 .32488 1 -0.22827 Mshowa
.00684 .39417 m
.01336 .39281 L
s
[(0.005)] -0.00622 .39689 1 -0.20846 Mshowa
0 .46831 m
.00655 .46707 L
s
[(0.01)] -0.0131 .47077 1 -0.18807 Mshowa
.125 Mabswid
.02508 .19636 m
.02895 .19535 L
s
.02382 .21004 m
.02769 .20904 L
s
.02255 .22378 m
.02643 .22279 L
s
.02128 .23759 m
.02516 .23661 L
s
.01871 .26542 m
.0226 .26447 L
s
.01742 .27944 m
.02131 .2785 L
s
.01612 .29352 m
.02001 .29261 L
s
.01481 .30769 m
.01871 .30678 L
s
.01218 .33622 m
.01609 .33535 L
s
.01086 .3506 m
.01476 .34974 L
s
.00952 .36505 m
.01343 .3642 L
s
.00818 .37957 m
.0121 .37874 L
s
.00548 .40885 m
.0094 .40805 L
s
.00412 .4236 m
.00805 .42281 L
s
.00276 .43842 m
.00668 .43765 L
s
.00138 .45333 m
.00531 .45257 L
s
gsave
-0.06449 .33972 -89 -8.6304 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.97971 .29706 m
1 .55211 L
s
1 .55211 m
.7241 .33213 L
s
.7241 .33213 m
.71288 0 L
s
.71288 0 m
.97971 .29706 L
s
.41706 .40126 m
.02634 .18276 L
s
.02634 .18276 m
0 .46831 L
s
0 .46831 m
.41245 .62761 L
s
.41245 .62761 m
.41706 .40126 L
s
.97971 .29706 m
1 .55211 L
s
1 .55211 m
.41245 .62761 L
s
.41245 .62761 m
.41706 .40126 L
s
.41706 .40126 m
.97971 .29706 L
s
.71288 0 m
.02634 .18276 L
s
.02634 .18276 m
0 .46831 L
s
0 .46831 m
.7241 .33213 L
s
.7241 .33213 m
.71288 0 L
s
0 0 m
1 0 L
1 .62761 L
0 .62761 L
closepath
clip
newpath
.5 Mabswid
.422 .667 .963 r
.42528 .4994 .41908 .49347 .40886 .49178 .41508 .49821 Metetra
.42 .683 .971 r
.43555 .50036 .42936 .49488 .41908 .49347 .42528 .4994 Metetra
.419 .698 .979 r
.44588 .50109 .43971 .49603 .42936 .49488 .43555 .50036 Metetra
.418 .712 .985 r
.45628 .50159 .45013 .49693 .43971 .49603 .44588 .50109 Metetra
.417 .726 .989 r
.46675 .50189 .46062 .49758 .45013 .49693 .45628 .50159 Metetra
.416 .738 .992 r
.47727 .50199 .47117 .498 .46062 .49758 .46675 .50189 Metetra
.416 .75 .994 r
.48786 .50189 .48179 .49819 .47117 .498 .47727 .50199 Metetra
.416 .76 .995 r
.49851 .50162 .49248 .49817 .48179 .49819 .48786 .50189 Metetra
.416 .77 .996 r
.50923 .50117 .50322 .49794 .49248 .49817 .49851 .50162 Metetra
.417 .778 .995 r
.52 .50055 .51404 .49753 .50322 .49794 .50923 .50117 Metetra
.419 .786 .995 r
.53084 .49977 .52491 .49693 .51404 .49753 .52 .50055 Metetra
.421 .793 .994 r
.54174 .49885 .53584 .49616 .52491 .49693 .53084 .49977 Metetra
.424 .8 .993 r
.5527 .49779 .54684 .49522 .53584 .49616 .54174 .49885 Metetra
.427 .805 .992 r
.56372 .4966 .5579 .49414 .54684 .49522 .5527 .49779 Metetra
.431 .811 .991 r
.5748 .49528 .56902 .4929 .5579 .49414 .56372 .4966 Metetra
.435 .815 .99 r
.58594 .49385 .5802 .49154 .56902 .4929 .5748 .49528 Metetra
.439 .82 .99 r
.59714 .4923 .59145 .49004 .5802 .49154 .58594 .49385 Metetra
.444 .824 .99 r
.6084 .49066 .60275 .48843 .59145 .49004 .59714 .4923 Metetra
.449 .827 .99 r
.61972 .48893 .61411 .48671 .60275 .48843 .6084 .49066 Metetra
.455 .83 .99 r
.6311 .4871 .62554 .4849 .61411 .48671 .61972 .48893 Metetra
.46 .833 .991 r
.64254 .4852 .63702 .48298 .62554 .4849 .6311 .4871 Metetra
.466 .836 .991 r
.65404 .48323 .64857 .48099 .63702 .48298 .64254 .4852 Metetra
.471 .838 .992 r
.6656 .48119 .66018 .47892 .64857 .48099 .65404 .48323 Metetra
.477 .839 .993 r
.67723 .47909 .67185 .47678 .66018 .47892 .6656 .48119 Metetra
.482 .841 .993 r
.68891 .47694 .68358 .47458 .67185 .47678 .67723 .47909 Metetra
.487 .842 .994 r
.70066 .47474 .69538 .47232 .68358 .47458 .68891 .47694 Metetra
.492 .842 .995 r
.71247 .4725 .70724 .47002 .69538 .47232 .70066 .47474 Metetra
.497 .843 .996 r
.72435 .47022 .71916 .46767 .70724 .47002 .71247 .4725 Metetra
.501 .843 .997 r
.73628 .46792 .73114 .46529 .71916 .46767 .72435 .47022 Metetra
.505 .842 .997 r
.74829 .46559 .74319 .46289 .73114 .46529 .73628 .46792 Metetra
.509 .842 .998 r
.76035 .46323 .75531 .46045 .74319 .46289 .74829 .46559 Metetra
.512 .841 .998 r
.77249 .46087 .76749 .45801 .75531 .46045 .76035 .46323 Metetra
.515 .84 .999 r
.78469 .45849 .77974 .45555 .76749 .45801 .77249 .46087 Metetra
.518 .839 .999 r
.79695 .4561 .79206 .45308 .77974 .45555 .78469 .45849 Metetra
.52 .838 .999 r
.80929 .45372 .80444 .45061 .79206 .45308 .79695 .4561 Metetra
.522 .836 .999 r
.82169 .45133 .8169 .44814 .80444 .45061 .80929 .45372 Metetra
.523 .835 .999 r
.83417 .44895 .82942 .44568 .8169 .44814 .82169 .45133 Metetra
.524 .833 1 r
.84671 .44658 .84201 .44323 .82942 .44568 .83417 .44895 Metetra
.525 .832 1 r
.85933 .44422 .85468 .4408 .84201 .44323 .84671 .44658 Metetra
.526 .83 1 r
.87201 .44187 .86742 .43838 .85468 .4408 .85933 .44422 Metetra
.526 .828 1 r
.88478 .43954 .88024 .43598 .86742 .43838 .87201 .44187 Metetra
.526 .827 .999 r
.89761 .43723 .89313 .43361 .88024 .43598 .88478 .43954 Metetra
.525 .825 .999 r
.91052 .43494 .90609 .43126 .89313 .43361 .89761 .43723 Metetra
.525 .824 .999 r
.92351 .43268 .91914 .42894 .90609 .43126 .91052 .43494 Metetra
.523 .822 .999 r
.93658 .43044 .93226 .42665 .91914 .42894 .92351 .43268 Metetra
.522 .821 .999 r
.94972 .42822 .94546 .42439 .93226 .42665 .93658 .43044 Metetra
.521 .819 .999 r
.96294 .42604 .95874 .42217 .94546 .42439 .94972 .42822 Metetra
.519 .818 .999 r
.97624 .42388 .9721 .41998 .95874 .42217 .96294 .42604 Metetra
.517 .817 .999 r
.98963 .42175 .98555 .41783 .9721 .41998 .97624 .42388 Metetra
.408 .639 .951 r
.41908 .49347 .41283 .48687 .4026 .48459 .40886 .49178 Metetra
.407 .657 .961 r
.42936 .49488 .42312 .48882 .41283 .48687 .41908 .49347 Metetra
.406 .675 .97 r
.43971 .49603 .43349 .49047 .42312 .48882 .42936 .49488 Metetra
.405 .691 .978 r
.45013 .49693 .44393 .49182 .43349 .49047 .43971 .49603 Metetra
.404 .707 .984 r
.46062 .49758 .45444 .49289 .44393 .49182 .45013 .49693 Metetra
.403 .721 .988 r
.47117 .498 .46502 .49368 .45444 .49289 .46062 .49758 Metetra
.403 .735 .992 r
.48179 .49819 .47567 .49421 .46502 .49368 .47117 .498 Metetra
.403 .747 .993 r
.49248 .49817 .48638 .4945 .47567 .49421 .48179 .49819 Metetra
.403 .758 .994 r
.50322 .49794 .49716 .49455 .48638 .4945 .49248 .49817 Metetra
.404 .768 .994 r
.51404 .49753 .50801 .49437 .49716 .49455 .50322 .49794 Metetra
.406 .777 .993 r
.52491 .49693 .51892 .49399 .50801 .49437 .51404 .49753 Metetra
.408 .786 .992 r
.53584 .49616 .52989 .4934 .51892 .49399 .52491 .49693 Metetra
.411 .793 .991 r
.54684 .49522 .54093 .49262 .52989 .4934 .53584 .49616 Metetra
.415 .8 .99 r
.5579 .49414 .55203 .49166 .54093 .49262 .54684 .49522 Metetra
.419 .806 .989 r
.56902 .4929 .56319 .49054 .55203 .49166 .5579 .49414 Metetra
.424 .812 .988 r
.5802 .49154 .57441 .48925 .56319 .49054 .56902 .4929 Metetra
.429 .817 .988 r
.59145 .49004 .5857 .48783 .57441 .48925 .5802 .49154 Metetra
.434 .822 .987 r
.60275 .48843 .59705 .48626 .5857 .48783 .59145 .49004 Metetra
.44 .826 .987 r
.61411 .48671 .60845 .48457 .59705 .48626 .60275 .48843 Metetra
.446 .83 .988 r
.62554 .4849 .61992 .48276 .60845 .48457 .61411 .48671 Metetra
.453 .833 .988 r
.63702 .48298 .63146 .48085 .61992 .48276 .62554 .4849 Metetra
.459 .836 .989 r
.64857 .48099 .64305 .47883 .63146 .48085 .63702 .48298 Metetra
.465 .839 .99 r
.66018 .47892 .6547 .47673 .64305 .47883 .64857 .48099 Metetra
.472 .841 .991 r
.67185 .47678 .66642 .47455 .6547 .47673 .66018 .47892 Metetra
.478 .842 .992 r
.68358 .47458 .6782 .4723 .66642 .47455 .67185 .47678 Metetra
.484 .844 .993 r
.69538 .47232 .69004 .46998 .6782 .4723 .68358 .47458 Metetra
.489 .845 .994 r
.70724 .47002 .70195 .46761 .69004 .46998 .69538 .47232 Metetra
.495 .845 .995 r
.71916 .46767 .71392 .4652 .70195 .46761 .70724 .47002 Metetra
.5 .845 .995 r
.73114 .46529 .72595 .46274 .71392 .4652 .71916 .46767 Metetra
.504 .845 .996 r
.74319 .46289 .73805 .46025 .72595 .46274 .73114 .46529 Metetra
.508 .845 .997 r
.75531 .46045 .75022 .45773 .73805 .46025 .74319 .46289 Metetra
.512 .844 .998 r
.76749 .45801 .76245 .45519 .75022 .45773 .75531 .46045 Metetra
.515 .843 .998 r
.77974 .45555 .77474 .45264 .76245 .45519 .76749 .45801 Metetra
.518 .842 .999 r
.79206 .45308 .78711 .45009 .77474 .45264 .77974 .45555 Metetra
.521 .841 .999 r
.80444 .45061 .79954 .44753 .78711 .45009 .79206 .45308 Metetra
.523 .839 .999 r
.8169 .44814 .81205 .44497 .79954 .44753 .80444 .45061 Metetra
.525 .837 .999 r
.82942 .44568 .82462 .44242 .81205 .44497 .8169 .44814 Metetra
.526 .836 .999 r
.84201 .44323 .83727 .43989 .82462 .44242 .82942 .44568 Metetra
.527 .834 .999 r
.85468 .4408 .84999 .43737 .83727 .43989 .84201 .44323 Metetra
.527 .832 .999 r
.86742 .43838 .86278 .43488 .84999 .43737 .85468 .4408 Metetra
.528 .83 .999 r
.88024 .43598 .87565 .43241 .86278 .43488 .86742 .43838 Metetra
.527 .828 .999 r
.89313 .43361 .88859 .42996 .87565 .43241 .88024 .43598 Metetra
.527 .826 .999 r
.90609 .43126 .90161 .42755 .88859 .42996 .89313 .43361 Metetra
.526 .825 .999 r
.91914 .42894 .91471 .42517 .90161 .42755 .90609 .43126 Metetra
.525 .823 .999 r
.93226 .42665 .92789 .42283 .91471 .42517 .91914 .42894 Metetra
.523 .821 .999 r
.94546 .42439 .94115 .42053 .92789 .42283 .93226 .42665 Metetra
.521 .82 .999 r
.95874 .42217 .95449 .41826 .94115 .42053 .94546 .42439 Metetra
.519 .818 .999 r
.9721 .41998 .96791 .41604 .95449 .41826 .95874 .42217 Metetra
.517 .817 .999 r
.98555 .41783 .98142 .41386 .96791 .41604 .9721 .41998 Metetra
.394 .609 .935 r
.41283 .48687 .40654 .47947 .39631 .47651 .4026 .48459 Metetra
.393 .629 .948 r
.42312 .48882 .41685 .48206 .40654 .47947 .41283 .48687 Metetra
.391 .648 .959 r
.43349 .49047 .42723 .48429 .41685 .48206 .42312 .48882 Metetra
.39 .666 .969 r
.44393 .49182 .43768 .48618 .42723 .48429 .43349 .49047 Metetra
.389 .684 .977 r
.45444 .49289 .44822 .48774 .43768 .48618 .44393 .49182 Metetra
.389 .701 .983 r
.46502 .49368 .45882 .48897 .44822 .48774 .45444 .49289 Metetra
.388 .716 .988 r
.47567 .49421 .46949 .48991 .45882 .48897 .46502 .49368 Metetra
.388 .731 .991 r
.48638 .4945 .48023 .49056 .46949 .48991 .47567 .49421 Metetra
.389 .744 .992 r
.49716 .49455 .49104 .49094 .48023 .49056 .48638 .4945 Metetra
.39 .756 .992 r
.50801 .49437 .50192 .49105 .49104 .49094 .49716 .49455 Metetra
.392 .767 .992 r
.51892 .49399 .51287 .49092 .50192 .49105 .50801 .49437 Metetra
.394 .776 .991 r
.52989 .4934 .52388 .49055 .51287 .49092 .51892 .49399 Metetra
.397 .785 .99 r
.54093 .49262 .53495 .48996 .52388 .49055 .52989 .4934 Metetra
.401 .793 .988 r
.55203 .49166 .54609 .48916 .53495 .48996 .54093 .49262 Metetra
.406 .8 .987 r
.56319 .49054 .55729 .48817 .54609 .48916 .55203 .49166 Metetra
.411 .807 .986 r
.57441 .48925 .56856 .48699 .55729 .48817 .56319 .49054 Metetra
.417 .813 .985 r
.5857 .48783 .57989 .48565 .56856 .48699 .57441 .48925 Metetra
.423 .819 .984 r
.59705 .48626 .59128 .48414 .57989 .48565 .5857 .48783 Metetra
.43 .824 .984 r
.60845 .48457 .60274 .48249 .59128 .48414 .59705 .48626 Metetra
.437 .828 .984 r
.61992 .48276 .61425 .4807 .60274 .48249 .60845 .48457 Metetra
.444 .832 .985 r
.63146 .48085 .62583 .47879 .61425 .4807 .61992 .48276 Metetra
.451 .836 .986 r
.64305 .47883 .63747 .47677 .62583 .47879 .63146 .48085 Metetra
.459 .839 .987 r
.6547 .47673 .64917 .47464 .63747 .47677 .64305 .47883 Metetra
.466 .842 .988 r
.66642 .47455 .66094 .47242 .64917 .47464 .6547 .47673 Metetra
.473 .844 .989 r
.6782 .4723 .67276 .47011 .66094 .47242 .66642 .47455 Metetra
.48 .846 .99 r
.69004 .46998 .68465 .46774 .67276 .47011 .6782 .4723 Metetra
.486 .847 .992 r
.70195 .46761 .69661 .4653 .68465 .46774 .69004 .46998 Metetra
.492 .848 .993 r
.71392 .4652 .70863 .4628 .69661 .4653 .70195 .46761 Metetra
.498 .848 .994 r
.72595 .46274 .72071 .46026 .70863 .4628 .71392 .4652 Metetra
.503 .848 .995 r
.73805 .46025 .73286 .45768 .72071 .46026 .72595 .46274 Metetra
.508 .848 .996 r
.75022 .45773 .74507 .45507 .73286 .45768 .73805 .46025 Metetra
.512 .847 .997 r
.76245 .45519 .75735 .45244 .74507 .45507 .75022 .45773 Metetra
.516 .846 .998 r
.77474 .45264 .7697 .44979 .75735 .45244 .76245 .45519 Metetra
.519 .845 .998 r
.78711 .45009 .78211 .44713 .7697 .44979 .77474 .45264 Metetra
.522 .843 .999 r
.79954 .44753 .7946 .44448 .78211 .44713 .78711 .45009 Metetra
.525 .842 .999 r
.81205 .44497 .80715 .44182 .7946 .44448 .79954 .44753 Metetra
.526 .84 .999 r
.82462 .44242 .81978 .43918 .80715 .44182 .81205 .44497 Metetra
.528 .838 .999 r
.83727 .43989 .83248 .43655 .81978 .43918 .82462 .44242 Metetra
.529 .836 .999 r
.84999 .43737 .84525 .43395 .83248 .43655 .83727 .43989 Metetra
.529 .834 .999 r
.86278 .43488 .85809 .43137 .84525 .43395 .84999 .43737 Metetra
.529 .832 .999 r
.87565 .43241 .87102 .42882 .85809 .43137 .86278 .43488 Metetra
.529 .83 .999 r
.88859 .42996 .88401 .4263 .87102 .42882 .87565 .43241 Metetra
.528 .828 .999 r
.90161 .42755 .89709 .42382 .88401 .4263 .88859 .42996 Metetra
.527 .826 .999 r
.91471 .42517 .91024 .42138 .89709 .42382 .90161 .42755 Metetra
.526 .824 .999 r
.92789 .42283 .92348 .41898 .91024 .42138 .91471 .42517 Metetra
.524 .822 .999 r
.94115 .42053 .9368 .41662 .92348 .41898 .92789 .42283 Metetra
.522 .82 .999 r
.95449 .41826 .95019 .41432 .9368 .41662 .94115 .42053 Metetra
.52 .818 .999 r
.96791 .41604 .96368 .41206 .95019 .41432 .95449 .41826 Metetra
.517 .817 .999 r
.98142 .41386 .97725 .40985 .96368 .41206 .96791 .41604 Metetra
.378 .576 .917 r
.40654 .47947 .40022 .47115 .39 .46738 .39631 .47651 Metetra
.376 .597 .932 r
.41685 .48206 .41053 .47448 .40022 .47115 .40654 .47947 Metetra
.375 .617 .946 r
.42723 .48429 .42092 .47739 .41053 .47448 .41685 .48206 Metetra
.374 .638 .958 r
.43768 .48618 .43139 .47991 .42092 .47739 .42723 .48429 Metetra
.373 .658 .968 r
.44822 .48774 .44194 .48204 .43139 .47991 .43768 .48618 Metetra
.373 .677 .976 r
.45882 .48897 .45256 .4838 .44194 .48204 .44822 .48774 Metetra
.372 .695 .982 r
.46949 .48991 .46326 .48522 .45256 .4838 .45882 .48897 Metetra
.372 .712 .987 r
.48023 .49056 .47403 .48629 .46326 .48522 .46949 .48991 Metetra
.373 .727 .989 r
.49104 .49094 .48487 .48705 .47403 .48629 .48023 .49056 Metetra
.374 .741 .99 r
.50192 .49105 .49578 .48751 .48487 .48705 .49104 .49094 Metetra
.376 .754 .99 r
.51287 .49092 .50676 .48768 .49578 .48751 .50192 .49105 Metetra
.378 .765 .989 r
.52388 .49055 .5178 .48758 .50676 .48768 .51287 .49092 Metetra
.382 .775 .988 r
.53495 .48996 .52892 .48722 .5178 .48758 .52388 .49055 Metetra
.386 .785 .986 r
.54609 .48916 .5401 .48661 .52892 .48722 .53495 .48996 Metetra
.391 .793 .984 r
.55729 .48817 .55134 .48578 .5401 .48661 .54609 .48916 Metetra
.397 .801 .983 r
.56856 .48699 .56265 .48474 .55134 .48578 .55729 .48817 Metetra
.404 .808 .981 r
.57989 .48565 .57402 .4835 .56265 .48474 .56856 .48699 Metetra
.411 .815 .981 r
.59128 .48414 .58546 .48208 .57402 .4835 .57989 .48565 Metetra
.418 .821 .98 r
.60274 .48249 .59696 .48048 .58546 .48208 .59128 .48414 Metetra
.426 .826 .981 r
.61425 .4807 .60852 .47872 .59696 .48048 .60274 .48249 Metetra
.434 .831 .981 r
.62583 .47879 .62014 .47683 .60852 .47872 .61425 .4807 Metetra
.443 .835 .982 r
.63747 .47677 .63183 .47479 .62014 .47683 .62583 .47879 Metetra
.451 .839 .983 r
.64917 .47464 .64358 .47264 .63183 .47479 .63747 .47677 Metetra
.459 .843 .985 r
.66094 .47242 .65539 .47038 .64358 .47264 .64917 .47464 Metetra
.467 .845 .986 r
.67276 .47011 .66727 .46803 .65539 .47038 .66094 .47242 Metetra
.475 .848 .988 r
.68465 .46774 .67921 .46559 .66727 .46803 .67276 .47011 Metetra
.482 .849 .989 r
.69661 .4653 .69121 .46308 .67921 .46559 .68465 .46774 Metetra
.489 .851 .991 r
.70863 .4628 .70328 .4605 .69121 .46308 .69661 .4653 Metetra
.496 .851 .992 r
.72071 .46026 .71541 .45787 .70328 .4605 .70863 .4628 Metetra
.502 .851 .994 r
.73286 .45768 .72761 .45519 .71541 .45787 .72071 .46026 Metetra
.507 .851 .995 r
.74507 .45507 .73987 .45248 .72761 .45519 .73286 .45768 Metetra
.512 .851 .996 r
.75735 .45244 .7522 .44974 .73987 .45248 .74507 .45507 Metetra
.517 .85 .997 r
.7697 .44979 .7646 .44699 .7522 .44974 .75735 .45244 Metetra
.52 .848 .997 r
.78211 .44713 .77707 .44423 .7646 .44699 .7697 .44979 Metetra
.524 .847 .998 r
.7946 .44448 .7896 .44146 .77707 .44423 .78211 .44713 Metetra
.526 .845 .999 r
.80715 .44182 .80221 .43871 .7896 .44146 .7946 .44448 Metetra
.528 .843 .999 r
.81978 .43918 .81488 .43596 .80221 .43871 .80715 .44182 Metetra
.53 .841 .999 r
.83248 .43655 .82763 .43323 .81488 .43596 .81978 .43918 Metetra
.531 .838 .999 r
.84525 .43395 .84046 .43053 .82763 .43323 .83248 .43655 Metetra
.531 .836 .999 r
.85809 .43137 .85336 .42785 .84046 .43053 .84525 .43395 Metetra
.532 .834 .999 r
.87102 .42882 .86633 .42521 .85336 .42785 .85809 .43137 Metetra
.531 .831 .999 r
.88401 .4263 .87938 .42261 .86633 .42521 .87102 .42882 Metetra
.53 .829 .999 r
.89709 .42382 .89251 .42006 .87938 .42261 .88401 .4263 Metetra
.529 .827 .999 r
.91024 .42138 .90573 .41755 .89251 .42006 .89709 .42382 Metetra
.527 .825 .999 r
.92348 .41898 .91902 .41509 .90573 .41755 .91024 .42138 Metetra
.525 .823 .999 r
.9368 .41662 .93239 .41268 .91902 .41509 .92348 .41898 Metetra
.523 .821 .999 r
.95019 .41432 .94585 .41033 .93239 .41268 .9368 .41662 Metetra
.52 .819 .999 r
.96368 .41206 .9594 .40803 .94585 .41033 .95019 .41432 Metetra
.517 .817 .999 r
.97725 .40985 .97303 .40579 .9594 .40803 .96368 .41206 Metetra
.36 .54 .896 r
.40022 .47115 .39388 .46172 .38366 .45703 .39 .46738 Metetra
.359 .562 .913 r
.41053 .47448 .40419 .46592 .39388 .46172 .40022 .47115 Metetra
.358 .584 .929 r
.42092 .47739 .41458 .46963 .40419 .46592 .41053 .47448 Metetra
.356 .606 .943 r
.43139 .47991 .42506 .47288 .41458 .46963 .42092 .47739 Metetra
.355 .628 .956 r
.44194 .48204 .43561 .47568 .42506 .47288 .43139 .47991 Metetra
.355 .649 .966 r
.45256 .4838 .44625 .47806 .43561 .47568 .44194 .48204 Metetra
.354 .67 .975 r
.46326 .48522 .45697 .48004 .44625 .47806 .45256 .4838 Metetra
.354 .689 .981 r
.47403 .48629 .46776 .48162 .45697 .48004 .46326 .48522 Metetra
.355 .707 .985 r
.48487 .48705 .47863 .48284 .46776 .48162 .47403 .48629 Metetra
.356 .723 .987 r
.49578 .48751 .48957 .4837 .47863 .48284 .48487 .48705 Metetra
.358 .738 .988 r
.50676 .48768 .50058 .48423 .48957 .4837 .49578 .48751 Metetra
.361 .751 .987 r
.5178 .48758 .51167 .48445 .50058 .48423 .50676 .48768 Metetra
.365 .763 .985 r
.52892 .48722 .52282 .48436 .51167 .48445 .5178 .48758 Metetra
.369 .774 .983 r
.5401 .48661 .53404 .484 .52282 .48436 .52892 .48722 Metetra
.375 .784 .981 r
.55134 .48578 .54532 .48336 .53404 .484 .5401 .48661 Metetra
.381 .794 .979 r
.56265 .48474 .55667 .48249 .54532 .48336 .55134 .48578 Metetra
.388 .802 .978 r
.57402 .4835 .56809 .48138 .55667 .48249 .56265 .48474 Metetra
.396 .81 .977 r
.58546 .48208 .57957 .48005 .56809 .48138 .57402 .4835 Metetra
.405 .817 .976 r
.59696 .48048 .59112 .47853 .57957 .48005 .58546 .48208 Metetra
.414 .823 .976 r
.60852 .47872 .60273 .47682 .59112 .47853 .59696 .48048 Metetra
.423 .829 .977 r
.62014 .47683 .6144 .47495 .60273 .47682 .60852 .47872 Metetra
.433 .834 .978 r
.63183 .47479 .62613 .47292 .6144 .47495 .62014 .47683 Metetra
.442 .839 .979 r
.64358 .47264 .63793 .47075 .62613 .47292 .63183 .47479 Metetra
.452 .843 .981 r
.65539 .47038 .64979 .46846 .63793 .47075 .64358 .47264 Metetra
.461 .846 .983 r
.66727 .46803 .66172 .46605 .64979 .46846 .65539 .47038 Metetra
.47 .849 .985 r
.67921 .46559 .67371 .46355 .66172 .46605 .66727 .46803 Metetra
.478 .852 .987 r
.69121 .46308 .68576 .46096 .67371 .46355 .67921 .46559 Metetra
.486 .853 .988 r
.70328 .4605 .69788 .4583 .68576 .46096 .69121 .46308 Metetra
.494 .854 .99 r
.71541 .45787 .71006 .45557 .69788 .4583 .70328 .4605 Metetra
.501 .855 .992 r
.72761 .45519 .72231 .45279 .71006 .45557 .71541 .45787 Metetra
.507 .855 .993 r
.73987 .45248 .73462 .44997 .72231 .45279 .72761 .45519 Metetra
.513 .854 .995 r
.7522 .44974 .747 .44712 .73462 .44997 .73987 .45248 Metetra
.517 .853 .996 r
.7646 .44699 .75945 .44426 .747 .44712 .7522 .44974 Metetra
.522 .852 .997 r
.77707 .44423 .77197 .44138 .75945 .44426 .7646 .44699 Metetra
.525 .85 .997 r
.7896 .44146 .78455 .4385 .77197 .44138 .77707 .44423 Metetra
.528 .848 .998 r
.80221 .43871 .79721 .43562 .78455 .4385 .7896 .44146 Metetra
.531 .846 .998 r
.81488 .43596 .80994 .43276 .79721 .43562 .80221 .43871 Metetra
.532 .844 .999 r
.82763 .43323 .82274 .42992 .80994 .43276 .81488 .43596 Metetra
.533 .841 .999 r
.84046 .43053 .83562 .42711 .82274 .42992 .82763 .43323 Metetra
.534 .839 .999 r
.85336 .42785 .84857 .42434 .83562 .42711 .84046 .43053 Metetra
.534 .836 .999 r
.86633 .42521 .8616 .4216 .84857 .42434 .85336 .42785 Metetra
.533 .833 .999 r
.87938 .42261 .8747 .41891 .8616 .4216 .86633 .42521 Metetra
.532 .831 .999 r
.89251 .42006 .88789 .41627 .8747 .41891 .87938 .42261 Metetra
.531 .828 .999 r
.90573 .41755 .90116 .41369 .88789 .41627 .89251 .42006 Metetra
.529 .826 .999 r
.91902 .41509 .91451 .41116 .90116 .41369 .90573 .41755 Metetra
.527 .823 .999 r
.93239 .41268 .92794 .4087 .91451 .41116 .91902 .41509 Metetra
.524 .821 .999 r
.94585 .41033 .94146 .4063 .92794 .4087 .93239 .41268 Metetra
.521 .819 .999 r
.9594 .40803 .95507 .40396 .94146 .4063 .94585 .41033 Metetra
.517 .817 .999 r
.97303 .40579 .96876 .40169 .95507 .40396 .9594 .40803 Metetra
.342 .502 .873 r
.39388 .46172 .38752 .45102 .37732 .44525 .38366 .45703 Metetra
.34 .524 .891 r
.40419 .46592 .39782 .45621 .38752 .45102 .39388 .46172 Metetra
.338 .547 .908 r
.41458 .46963 .4082 .46085 .39782 .45621 .40419 .46592 Metetra
.337 .57 .925 r
.42506 .47288 .41868 .46496 .4082 .46085 .41458 .46963 Metetra
.336 .594 .94 r
.43561 .47568 .42925 .46855 .41868 .46496 .42506 .47288 Metetra
.335 .617 .954 r
.44625 .47806 .4399 .47165 .42925 .46855 .43561 .47568 Metetra
.335 .64 .965 r
.45697 .48004 .45063 .47429 .4399 .47165 .44625 .47806 Metetra
.334 .662 .973 r
.46776 .48162 .46145 .47647 .45063 .47429 .45697 .48004 Metetra
.335 .682 .979 r
.47863 .48284 .47234 .47822 .46145 .47647 .46776 .48162 Metetra
.336 .702 .983 r
.48957 .4837 .48331 .47956 .47234 .47822 .47863 .48284 Metetra
.338 .719 .984 r
.50058 .48423 .49435 .48052 .48331 .47956 .48957 .4837 Metetra
.341 .735 .984 r
.51167 .48445 .50547 .48111 .49435 .48052 .50058 .48423 Metetra
.345 .749 .983 r
.52282 .48436 .51666 .48136 .50547 .48111 .51167 .48445 Metetra
.35 .762 .98 r
.53404 .484 .52791 .48127 .51666 .48136 .52282 .48436 Metetra
.356 .774 .978 r
.54532 .48336 .53924 .48088 .52791 .48127 .53404 .484 Metetra
.364 .784 .976 r
.55667 .48249 .55064 .48021 .53924 .48088 .54532 .48336 Metetra
.372 .794 .974 r
.56809 .48138 .5621 .47926 .55064 .48021 .55667 .48249 Metetra
.381 .803 .972 r
.57957 .48005 .57362 .47807 .5621 .47926 .56809 .48138 Metetra
.39 .811 .971 r
.59112 .47853 .58521 .47664 .57362 .47807 .57957 .48005 Metetra
.4 .819 .971 r
.60273 .47682 .59687 .475 .58521 .47664 .59112 .47853 Metetra
.411 .826 .972 r
.6144 .47495 .60859 .47316 .59687 .475 .60273 .47682 Metetra
.422 .832 .973 r
.62613 .47292 .62038 .47115 .60859 .47316 .6144 .47495 Metetra
.432 .838 .974 r
.63793 .47075 .63222 .46897 .62038 .47115 .62613 .47292 Metetra
.443 .843 .976 r
.64979 .46846 .64414 .46665 .63222 .46897 .63793 .47075 Metetra
.454 .847 .978 r
.66172 .46605 .65611 .4642 .64414 .46665 .64979 .46846 Metetra
.464 .851 .981 r
.67371 .46355 .66815 .46163 .65611 .4642 .66172 .46605 Metetra
.474 .854 .983 r
.68576 .46096 .68025 .45896 .66815 .46163 .67371 .46355 Metetra
.483 .856 .985 r
.69788 .4583 .69242 .4562 .68025 .45896 .68576 .46096 Metetra
.492 .857 .988 r
.71006 .45557 .70465 .45338 .69242 .4562 .69788 .4583 Metetra
.499 .858 .99 r
.72231 .45279 .71695 .45049 .70465 .45338 .71006 .45557 Metetra
.506 .858 .992 r
.73462 .44997 .72931 .44755 .71695 .45049 .72231 .45279 Metetra
.513 .858 .993 r
.747 .44712 .74175 .44459 .72931 .44755 .73462 .44997 Metetra
.518 .857 .995 r
.75945 .44426 .75424 .44159 .74175 .44459 .747 .44712 Metetra
.523 .856 .996 r
.77197 .44138 .76681 .43859 .75424 .44159 .75945 .44426 Metetra
.527 .854 .997 r
.78455 .4385 .77945 .43558 .76681 .43859 .77197 .44138 Metetra
.53 .852 .997 r
.79721 .43562 .79216 .43258 .77945 .43558 .78455 .4385 Metetra
.533 .85 .998 r
.80994 .43276 .80494 .42959 .79216 .43258 .79721 .43562 Metetra
.535 .847 .998 r
.82274 .42992 .81779 .42663 .80494 .42959 .80994 .43276 Metetra
.536 .844 .999 r
.83562 .42711 .83072 .42371 .81779 .42663 .82274 .42992 Metetra
.537 .841 .999 r
.84857 .42434 .84373 .42082 .83072 .42371 .83562 .42711 Metetra
.537 .838 .999 r
.8616 .4216 .85681 .41798 .84373 .42082 .84857 .42434 Metetra
.536 .836 .999 r
.8747 .41891 .86997 .41519 .85681 .41798 .8616 .4216 Metetra
.535 .833 .999 r
.88789 .41627 .88322 .41246 .86997 .41519 .8747 .41891 Metetra
.533 .83 .999 r
.90116 .41369 .89654 .4098 .88322 .41246 .88789 .41627 Metetra
.531 .827 .999 r
.91451 .41116 .90995 .4072 .89654 .4098 .90116 .41369 Metetra
.528 .824 .999 r
.92794 .4087 .92344 .40467 .90995 .4072 .91451 .41116 Metetra
.525 .822 .999 r
.94146 .4063 .93702 .40222 .92344 .40467 .92794 .4087 Metetra
.522 .819 .999 r
.95507 .40396 .95069 .39985 .93702 .40222 .94146 .4063 Metetra
.518 .817 .999 r
.96876 .40169 .96444 .39755 .95069 .39985 .95507 .40396 Metetra
.323 .464 .847 r
.38752 .45102 .38115 .43881 .37098 .43179 .37732 .44525 Metetra
.32 .485 .866 r
.39782 .45621 .39143 .44516 .38115 .43881 .38752 .45102 Metetra
.318 .508 .885 r
.4082 .46085 .4018 .45088 .39143 .44516 .39782 .45621 Metetra
.317 .531 .904 r
.41868 .46496 .41228 .45598 .4018 .45088 .4082 .46085 Metetra
.315 .556 .921 r
.42925 .46855 .42284 .4605 .41228 .45598 .41868 .46496 Metetra
.314 .581 .937 r
.4399 .47165 .4335 .46444 .42284 .4605 .42925 .46855 Metetra
.313 .606 .951 r
.45063 .47429 .44425 .46784 .4335 .46444 .4399 .47165 Metetra
.313 .631 .962 r
.46145 .47647 .45508 .47072 .44425 .46784 .45063 .47429 Metetra
.313 .654 .971 r
.47234 .47822 .46599 .4731 .45508 .47072 .46145 .47647 Metetra
.314 .676 .976 r
.48331 .47956 .47699 .47502 .46599 .4731 .47234 .47822 Metetra
.317 .696 .979 r
.49435 .48052 .48806 .47648 .47699 .47502 .48331 .47956 Metetra
.32 .715 .98 r
.50547 .48111 .49921 .47752 .48806 .47648 .49435 .48052 Metetra
.324 .732 .979 r
.51666 .48136 .51043 .47816 .49921 .47752 .50547 .48111 Metetra
.329 .747 .977 r
.52791 .48127 .52173 .47841 .51043 .47816 .51666 .48136 Metetra
.336 .76 .975 r
.53924 .48088 .5331 .47831 .52173 .47841 .52791 .48127 Metetra
.344 .773 .972 r
.55064 .48021 .54453 .47788 .5331 .47831 .53924 .48088 Metetra
.353 .784 .969 r
.5621 .47926 .55604 .47714 .54453 .47788 .55064 .48021 Metetra
.363 .795 .967 r
.57362 .47807 .56761 .4761 .55604 .47714 .5621 .47926 Metetra
.374 .804 .966 r
.58521 .47664 .57925 .4748 .56761 .4761 .57362 .47807 Metetra
.385 .813 .965 r
.59687 .475 .59095 .47325 .57925 .4748 .58521 .47664 Metetra
.397 .822 .966 r
.60859 .47316 .60272 .47147 .59095 .47325 .59687 .475 Metetra
.409 .829 .967 r
.62038 .47115 .61456 .46948 .60272 .47147 .60859 .47316 Metetra
.422 .836 .969 r
.63222 .46897 .62645 .46731 .61456 .46948 .62038 .47115 Metetra
.434 .842 .971 r
.64414 .46665 .63842 .46496 .62645 .46731 .63222 .46897 Metetra
.446 .847 .973 r
.65611 .4642 .65044 .46246 .63842 .46496 .64414 .46665 Metetra
.458 .852 .976 r
.66815 .46163 .66253 .45983 .65044 .46246 .65611 .4642 Metetra
.469 .855 .979 r
.68025 .45896 .67469 .45708 .66253 .45983 .66815 .46163 Metetra
.479 .858 .982 r
.69242 .4562 .6869 .45423 .67469 .45708 .68025 .45896 Metetra
.489 .86 .985 r
.70465 .45338 .69919 .4513 .6869 .45423 .69242 .4562 Metetra
.498 .862 .987 r
.71695 .45049 .71154 .4483 .69919 .4513 .70465 .45338 Metetra
.506 .862 .989 r
.72931 .44755 .72395 .44524 .71154 .4483 .71695 .45049 Metetra
.513 .862 .991 r
.74175 .44459 .73644 .44214 .72395 .44524 .72931 .44755 Metetra
.519 .861 .993 r
.75424 .44159 .74899 .43901 .73644 .44214 .74175 .44459 Metetra
.525 .86 .995 r
.76681 .43859 .76161 .43587 .74899 .43901 .75424 .44159 Metetra
.529 .858 .996 r
.77945 .43558 .7743 .43272 .76161 .43587 .76681 .43859 Metetra
.533 .856 .997 r
.79216 .43258 .78706 .42958 .7743 .43272 .77945 .43558 Metetra
.536 .853 .998 r
.80494 .42959 .79989 .42646 .78706 .42958 .79216 .43258 Metetra
.538 .851 .998 r
.81779 .42663 .8128 .42337 .79989 .42646 .80494 .42959 Metetra
.539 .848 .998 r
.83072 .42371 .82578 .42031 .8128 .42337 .81779 .42663 Metetra
.54 .844 .999 r
.84373 .42082 .83884 .41731 .82578 .42031 .83072 .42371 Metetra
.54 .841 .999 r
.85681 .41798 .85198 .41435 .83884 .41731 .84373 .42082 Metetra
.539 .838 .999 r
.86997 .41519 .86519 .41146 .85198 .41435 .85681 .41798 Metetra
.538 .835 .999 r
.88322 .41246 .87849 .40863 .86519 .41146 .86997 .41519 Metetra
.536 .831 .999 r
.89654 .4098 .89187 .40588 .87849 .40863 .88322 .41246 Metetra
.533 .828 .999 r
.90995 .4072 .90534 .4032 .89187 .40588 .89654 .4098 Metetra
.53 .825 .999 r
.92344 .40467 .91889 .40061 .90534 .4032 .90995 .4072 Metetra
.526 .823 .999 r
.93702 .40222 .93253 .3981 .91889 .40061 .92344 .40467 Metetra
.522 .82 .999 r
.95069 .39985 .94626 .39568 .93253 .3981 .93702 .40222 Metetra
.518 .817 .999 r
.96444 .39755 .96008 .39335 .94626 .39568 .95069 .39985 Metetra
.304 .425 .82 r
.38115 .43881 .37479 .42485 .36465 .41639 .37098 .43179 Metetra
.3 .445 .839 r
.39143 .44516 .38503 .43254 .37479 .42485 .38115 .43881 Metetra
.298 .467 .859 r
.4018 .45088 .39539 .43951 .38503 .43254 .39143 .44516 Metetra
.295 .49 .879 r
.41228 .45598 .40585 .44577 .39539 .43951 .4018 .45088 Metetra
.293 .515 .899 r
.42284 .4605 .41641 .45135 .40585 .44577 .41228 .45598 Metetra
.291 .541 .917 r
.4335 .46444 .42707 .45627 .41641 .45135 .42284 .4605 Metetra
.29 .568 .934 r
.44425 .46784 .43782 .46057 .42707 .45627 .4335 .46444 Metetra
.289 .595 .948 r
.45508 .47072 .44866 .46426 .43782 .46057 .44425 .46784 Metetra
.29 .621 .959 r
.46599 .4731 .45959 .46739 .44866 .46426 .45508 .47072 Metetra
.291 .646 .968 r
.47699 .47502 .47061 .46997 .45959 .46739 .46599 .4731 Metetra
.293 .669 .973 r
.48806 .47648 .48171 .47203 .47061 .46997 .47699 .47502 Metetra
.296 .691 .975 r
.49921 .47752 .49289 .4736 .48171 .47203 .48806 .47648 Metetra
.3 .711 .975 r
.51043 .47816 .50415 .4747 .49289 .4736 .49921 .47752 Metetra
.306 .728 .973 r
.52173 .47841 .51548 .47536 .50415 .4747 .51043 .47816 Metetra
.314 .745 .971 r
.5331 .47831 .52689 .47561 .51548 .47536 .52173 .47841 Metetra
.322 .759 .967 r
.54453 .47788 .53836 .47548 .52689 .47561 .5331 .47831 Metetra
.332 .772 .964 r
.55604 .47714 .54991 .47498 .53836 .47548 .54453 .47788 Metetra
.343 .785 .962 r
.56761 .4761 .56153 .47414 .54991 .47498 .55604 .47714 Metetra
.355 .796 .96 r
.57925 .4748 .57322 .473 .56153 .47414 .56761 .4761 Metetra
.368 .806 .959 r
.59095 .47325 .58497 .47156 .57322 .473 .57925 .4748 Metetra
.381 .816 .959 r
.60272 .47147 .59679 .46986 .58497 .47156 .59095 .47325 Metetra
.395 .825 .96 r
.61456 .46948 .60867 .46792 .59679 .46986 .60272 .47147 Metetra
.409 .833 .962 r
.62645 .46731 .62062 .46576 .60867 .46792 .61456 .46948 Metetra
.423 .84 .965 r
.63842 .46496 .63263 .4634 .62062 .46576 .62645 .46731 Metetra
.437 .847 .968 r
.65044 .46246 .64471 .46086 .63263 .4634 .63842 .46496 Metetra
.45 .852 .971 r
.66253 .45983 .65685 .45817 .64471 .46086 .65044 .46246 Metetra
.463 .857 .974 r
.67469 .45708 .66906 .45534 .65685 .45817 .66253 .45983 Metetra
.475 .861 .978 r
.6869 .45423 .68133 .45239 .66906 .45534 .67469 .45708 Metetra
.486 .863 .981 r
.69919 .4513 .69367 .44935 .68133 .45239 .6869 .45423 Metetra
.496 .865 .984 r
.71154 .4483 .70607 .44622 .69367 .44935 .69919 .4513 Metetra
.505 .866 .987 r
.72395 .44524 .71854 .44303 .70607 .44622 .71154 .4483 Metetra
.514 .866 .989 r
.73644 .44214 .73107 .43979 .71854 .44303 .72395 .44524 Metetra
.521 .866 .991 r
.74899 .43901 .74367 .43652 .73107 .43979 .73644 .44214 Metetra
.527 .864 .993 r
.76161 .43587 .75635 .43322 .74367 .43652 .74899 .43901 Metetra
.532 .862 .995 r
.7743 .43272 .76909 .42993 .75635 .43322 .76161 .43587 Metetra
.536 .86 .996 r
.78706 .42958 .7819 .42664 .76909 .42993 .7743 .43272 Metetra
.539 .857 .997 r
.79989 .42646 .79479 .42337 .7819 .42664 .78706 .42958 Metetra
.541 .854 .998 r
.8128 .42337 .80775 .42013 .79479 .42337 .79989 .42646 Metetra
.543 .851 .998 r
.82578 .42031 .82078 .41694 .80775 .42013 .8128 .42337 Metetra
.543 .848 .998 r
.83884 .41731 .8339 .4138 .82078 .41694 .82578 .42031 Metetra
.543 .844 .999 r
.85198 .41435 .84709 .41072 .8339 .4138 .83884 .41731 Metetra
.542 .84 .999 r
.86519 .41146 .86036 .40771 .84709 .41072 .85198 .41435 Metetra
.54 .837 .999 r
.87849 .40863 .87371 .40478 .86036 .40771 .86519 .41146 Metetra
.538 .833 .999 r
.89187 .40588 .88715 .40193 .87371 .40478 .87849 .40863 Metetra
.535 .83 .999 r
.90534 .4032 .90068 .39917 .88715 .40193 .89187 .40588 Metetra
.532 .827 .999 r
.91889 .40061 .91429 .39651 .90068 .39917 .90534 .4032 Metetra
.528 .823 .999 r
.93253 .3981 .92799 .39394 .91429 .39651 .91889 .40061 Metetra
.523 .82 .999 r
.94626 .39568 .94178 .39148 .92799 .39394 .93253 .3981 Metetra
.518 .817 .999 r
.96008 .39335 .95567 .38911 .94178 .39148 .94626 .39568 Metetra
.285 .387 .792 r
.37479 .42485 .36844 .40885 .35836 .39874 .36465 .41639 Metetra
.28 .405 .811 r
.38503 .43254 .37864 .41809 .36844 .40885 .37479 .42485 Metetra
.277 .425 .831 r
.39539 .43951 .38896 .4265 .37864 .41809 .38503 .43254 Metetra
.273 .448 .852 r
.40585 .44577 .3994 .43409 .38896 .4265 .39539 .43951 Metetra
.27 .472 .873 r
.41641 .45135 .40995 .44091 .3994 .43409 .40585 .44577 Metetra
.268 .499 .893 r
.42707 .45627 .4206 .44697 .40995 .44091 .41641 .45135 Metetra
.266 .526 .912 r
.43782 .46057 .43135 .45231 .4206 .44697 .42707 .45627 Metetra
.265 .555 .93 r
.44866 .46426 .4422 .45696 .43135 .45231 .43782 .46057 Metetra
.264 .583 .944 r
.45959 .46739 .45314 .46095 .4422 .45696 .44866 .46426 Metetra
.265 .611 .956 r
.47061 .46997 .46418 .46431 .45314 .46095 .45959 .46739 Metetra
.267 .638 .964 r
.48171 .47203 .4753 .46707 .46418 .46431 .47061 .46997 Metetra
.27 .663 .968 r
.49289 .4736 .48651 .46926 .4753 .46707 .48171 .47203 Metetra
.275 .686 .97 r
.50415 .4747 .4978 .47092 .48651 .46926 .49289 .4736 Metetra
.281 .706 .969 r
.51548 .47536 .50916 .47206 .4978 .47092 .50415 .4747 Metetra
.289 .725 .966 r
.52689 .47561 .52061 .47273 .50916 .47206 .51548 .47536 Metetra
.298 .742 .963 r
.53836 .47548 .53213 .47295 .52061 .47273 .52689 .47561 Metetra
.309 .758 .959 r
.54991 .47498 .54372 .47275 .53213 .47295 .53836 .47548 Metetra
.321 .772 .956 r
.56153 .47414 .55539 .47216 .54372 .47275 .54991 .47498 Metetra
.335 .785 .954 r
.57322 .473 .56712 .47121 .55539 .47216 .56153 .47414 Metetra
.349 .798 .952 r
.58497 .47156 .57892 .46992 .56712 .47121 .57322 .473 Metetra
.364 .809 .952 r
.59679 .46986 .59079 .46833 .57892 .46992 .58497 .47156 Metetra
.38 .819 .953 r
.60867 .46792 .60272 .46645 .59079 .46833 .59679 .46986 Metetra
.395 .829 .955 r
.62062 .46576 .61472 .46432 .60272 .46645 .60867 .46792 Metetra
.411 .838 .957 r
.63263 .4634 .62679 .46196 .61472 .46432 .62062 .46576 Metetra
.427 .845 .961 r
.64471 .46086 .63892 .4594 .62679 .46196 .63263 .4634 Metetra
.442 .852 .965 r
.65685 .45817 .65111 .45665 .63892 .4594 .64471 .46086 Metetra
.456 .858 .969 r
.66906 .45534 .66337 .45374 .65111 .45665 .65685 .45817 Metetra
.47 .863 .973 r
.68133 .45239 .6757 .45069 .66337 .45374 .66906 .45534 Metetra
.483 .866 .977 r
.69367 .44935 .68809 .44753 .6757 .45069 .68133 .45239 Metetra
.494 .869 .98 r
.70607 .44622 .70054 .44428 .68809 .44753 .69367 .44935 Metetra
.505 .87 .984 r
.71854 .44303 .71306 .44094 .70054 .44428 .70607 .44622 Metetra
.514 .871 .987 r
.73107 .43979 .72565 .43755 .71306 .44094 .71854 .44303 Metetra
.522 .87 .989 r
.74367 .43652 .7383 .43412 .72565 .43755 .73107 .43979 Metetra
.529 .869 .992 r
.75635 .43322 .75103 .43067 .7383 .43412 .74367 .43652 Metetra
.535 .867 .993 r
.76909 .42993 .76382 .42721 .75103 .43067 .75635 .43322 Metetra
.539 .865 .995 r
.7819 .42664 .77669 .42376 .76382 .42721 .76909 .42993 Metetra
.543 .862 .996 r
.79479 .42337 .78963 .42033 .77669 .42376 .7819 .42664 Metetra
.545 .859 .997 r
.80775 .42013 .80264 .41694 .78963 .42033 .79479 .42337 Metetra
.547 .855 .998 r
.82078 .41694 .81573 .41359 .80264 .41694 .80775 .42013 Metetra
.547 .851 .998 r
.8339 .4138 .8289 .41031 .81573 .41359 .82078 .41694 Metetra
.547 .847 .998 r
.84709 .41072 .84215 .40709 .8289 .41031 .8339 .4138 Metetra
.546 .843 .999 r
.86036 .40771 .85547 .40396 .84215 .40709 .84709 .41072 Metetra
.544 .839 .999 r
.87371 .40478 .86888 .40091 .85547 .40396 .86036 .40771 Metetra
.541 .835 .999 r
.88715 .40193 .88238 .39796 .86888 .40091 .87371 .40478 Metetra
.538 .832 .999 r
.90068 .39917 .89596 .39511 .88238 .39796 .88715 .40193 Metetra
.534 .828 .999 r
.91429 .39651 .90964 .39237 .89596 .39511 .90068 .39917 Metetra
.529 .824 .999 r
.92799 .39394 .9234 .38974 .90964 .39237 .91429 .39651 Metetra
.524 .821 .999 r
.94178 .39148 .93725 .38722 .9234 .38974 .92799 .39394 Metetra
.519 .818 .999 r
.95567 .38911 .9512 .38482 .93725 .38722 .94178 .39148 Metetra
.266 .35 .763 r
.36844 .40885 .36212 .3905 .35211 .37849 .35836 .39874 Metetra
.261 .366 .782 r
.37864 .41809 .37227 .40152 .36212 .3905 .36844 .40885 Metetra
.256 .384 .802 r
.38896 .4265 .38255 .41158 .37227 .40152 .37864 .41809 Metetra
.251 .405 .822 r
.3994 .43409 .39295 .42071 .38255 .41158 .38896 .4265 Metetra
.247 .428 .844 r
.40995 .44091 .40347 .42895 .39295 .42071 .3994 .43409 Metetra
.244 .454 .866 r
.4206 .44697 .4141 .43633 .40347 .42895 .40995 .44091 Metetra
.241 .481 .887 r
.43135 .45231 .42484 .44288 .4141 .43633 .4206 .44697 Metetra
.239 .511 .907 r
.4422 .45696 .43569 .44864 .42484 .44288 .43135 .45231 Metetra
.237 .541 .925 r
.45314 .46095 .44665 .45364 .43569 .44864 .4422 .45696 Metetra
.237 .571 .94 r
.46418 .46431 .45769 .45791 .44665 .45364 .45314 .46095 Metetra
.239 .601 .951 r
.4753 .46707 .46883 .46149 .45769 .45791 .46418 .46431 Metetra
.242 .629 .959 r
.48651 .46926 .48007 .46442 .46883 .46149 .4753 .46707 Metetra
.247 .656 .963 r
.4978 .47092 .49138 .46673 .48007 .46442 .48651 .46926 Metetra
.253 .68 .963 r
.50916 .47206 .50279 .46845 .49138 .46673 .4978 .47092 Metetra
.261 .702 .961 r
.52061 .47273 .51427 .46961 .50279 .46845 .50916 .47206 Metetra
.272 .722 .958 r
.53213 .47295 .52583 .47026 .51427 .46961 .52061 .47273 Metetra
.284 .741 .954 r
.54372 .47275 .53746 .47042 .52583 .47026 .53213 .47295 Metetra
.297 .757 .95 r
.55539 .47216 .54917 .47013 .53746 .47042 .54372 .47275 Metetra
.312 .773 .947 r
.56712 .47121 .56095 .46942 .54917 .47013 .55539 .47216 Metetra
.328 .787 .945 r
.57892 .46992 .5728 .46832 .56095 .46942 .56712 .47121 Metetra
.345 .8 .944 r
.59079 .46833 .58472 .46686 .5728 .46832 .57892 .46992 Metetra
.362 .812 .945 r
.60272 .46645 .59671 .46508 .58472 .46686 .59079 .46833 Metetra
.38 .824 .947 r
.61472 .46432 .60876 .463 .59671 .46508 .60272 .46645 Metetra
.398 .834 .949 r
.62679 .46196 .62088 .46065 .60876 .463 .61472 .46432 Metetra
.416 .843 .953 r
.63892 .4594 .63306 .45807 .62088 .46065 .62679 .46196 Metetra
.433 .851 .957 r
.65111 .45665 .64531 .45527 .63306 .45807 .63892 .4594 Metetra
.449 .858 .962 r
.66337 .45374 .65763 .45228 .64531 .45527 .65111 .45665 Metetra
.465 .864 .967 r
.6757 .45069 .67 .44914 .65763 .45228 .66337 .45374 Metetra
.479 .869 .971 r
.68809 .44753 .68245 .44586 .67 .44914 .6757 .45069 Metetra
.492 .872 .976 r
.70054 .44428 .69495 .44247 .68245 .44586 .68809 .44753 Metetra
.504 .874 .98 r
.71306 .44094 .70753 .43898 .69495 .44247 .70054 .44428 Metetra
.515 .875 .984 r
.72565 .43755 .72017 .43543 .70753 .43898 .71306 .44094 Metetra
.524 .875 .987 r
.7383 .43412 .73288 .43183 .72017 .43543 .72565 .43755 Metetra
.531 .874 .989 r
.75103 .43067 .74566 .42821 .73288 .43183 .7383 .43412 Metetra
.538 .872 .992 r
.76382 .42721 .7585 .42457 .74566 .42821 .75103 .43067 Metetra
.543 .87 .994 r
.77669 .42376 .77142 .42095 .7585 .42457 .76382 .42721 Metetra
.547 .867 .995 r
.78963 .42033 .78442 .41734 .77142 .42095 .77669 .42376 Metetra
.549 .863 .996 r
.80264 .41694 .79748 .41378 .78442 .41734 .78963 .42033 Metetra
.551 .859 .997 r
.81573 .41359 .81063 .41027 .79748 .41378 .80264 .41694 Metetra
.551 .855 .998 r
.8289 .41031 .82385 .40683 .81063 .41027 .81573 .41359 Metetra
.551 .851 .998 r
.84215 .40709 .83715 .40347 .82385 .40683 .8289 .41031 Metetra
.55 .846 .998 r
.85547 .40396 .85053 .40019 .83715 .40347 .84215 .40709 Metetra
.547 .842 .998 r
.86888 .40091 .864 .39702 .85053 .40019 .85547 .40396 Metetra
.544 .838 .999 r
.88238 .39796 .87756 .39396 .864 .39702 .86888 .40091 Metetra
.541 .833 .999 r
.89596 .39511 .8912 .39101 .87756 .39396 .88238 .39796 Metetra
.536 .829 .999 r
.90964 .39237 .90493 .38818 .8912 .39101 .89596 .39511 Metetra
.531 .825 .999 r
.9234 .38974 .91875 .38548 .90493 .38818 .90964 .39237 Metetra
.525 .821 .999 r
.93725 .38722 .93267 .38292 .91875 .38548 .9234 .38974 Metetra
.519 .818 .999 r
.9512 .38482 .94669 .38048 .93267 .38292 .93725 .38722 Metetra
.248 .314 .736 r
.36212 .3905 .35586 .36943 .34573 .36138 .35211 .37849 Metetra
.242 .328 .753 r
.37227 .40152 .36593 .38247 .35586 .36943 .36212 .3905 Metetra
.236 .344 .772 r
.38255 .41158 .37615 .39443 .36593 .38247 .37227 .40152 Metetra
.23 .363 .792 r
.39295 .42071 .3865 .40534 .37615 .39443 .38255 .41158 Metetra
.225 .384 .813 r
.40347 .42895 .39698 .41522 .3865 .40534 .39295 .42071 Metetra
.22 .408 .836 r
.4141 .43633 .40759 .42412 .39698 .41522 .40347 .42895 Metetra
.215 .435 .859 r
.42484 .44288 .41831 .43207 .40759 .42412 .4141 .43633 Metetra
.212 .464 .881 r
.43569 .44864 .42916 .43912 .41831 .43207 .42484 .44288 Metetra
.21 .494 .902 r
.44665 .45364 .44011 .44529 .42916 .43912 .43569 .44864 Metetra
.209 .526 .92 r
.45769 .45791 .45116 .45063 .44011 .44529 .44665 .45364 Metetra
.209 .559 .935 r
.46883 .46149 .46232 .45517 .45116 .45063 .45769 .45791 Metetra
.212 .591 .946 r
.48007 .46442 .47357 .45896 .46232 .45517 .46883 .46149 Metetra
.216 .621 .953 r
.49138 .46673 .48491 .46203 .47357 .45896 .48007 .46442 Metetra
.223 .649 .955 r
.50279 .46845 .49634 .46442 .48491 .46203 .49138 .46673 Metetra
.232 .675 .955 r
.51427 .46961 .50786 .46618 .49634 .46442 .50279 .46845 Metetra
.243 .699 .952 r
.52583 .47026 .51946 .46734 .50786 .46618 .51427 .46961 Metetra
.256 .72 .948 r
.53746 .47042 .53114 .46793 .51946 .46734 .52583 .47026 Metetra
.27 .74 .944 r
.54917 .47013 .54289 .468 .53114 .46793 .53746 .47042 Metetra
.287 .757 .94 r
.56095 .46942 .55472 .46759 .54289 .468 .54917 .47013 Metetra
.305 .774 .937 r
.5728 .46832 .56662 .46672 .55472 .46759 .56095 .46942 Metetra
.324 .789 .936 r
.58472 .46686 .57859 .46544 .56662 .46672 .5728 .46832 Metetra
.343 .803 .936 r
.59671 .46508 .59063 .46379 .57859 .46544 .58472 .46686 Metetra
.363 .817 .938 r
.60876 .463 .60273 .46178 .59063 .46379 .59671 .46508 Metetra
.383 .829 .941 r
.62088 .46065 .6149 .45947 .60273 .46178 .60876 .463 Metetra
.403 .84 .945 r
.63306 .45807 .62714 .45688 .6149 .45947 .62088 .46065 Metetra
.423 .85 .949 r
.64531 .45527 .63945 .45404 .62714 .45688 .63306 .45807 Metetra
.441 .858 .955 r
.65763 .45228 .65181 .45098 .63945 .45404 .64531 .45527 Metetra
.459 .865 .96 r
.67 .44914 .66425 .44774 .65181 .45098 .65763 .45228 Metetra
.475 .871 .966 r
.68245 .44586 .67674 .44434 .66425 .44774 .67 .44914 Metetra
.49 .875 .971 r
.69495 .44247 .68931 .4408 .67674 .44434 .68245 .44586 Metetra
.503 .878 .976 r
.70753 .43898 .70194 .43716 .68931 .4408 .69495 .44247 Metetra
.515 .879 .98 r
.72017 .43543 .71463 .43344 .70194 .43716 .70753 .43898 Metetra
.525 .88 .984 r
.73288 .43183 .72739 .42967 .71463 .43344 .72017 .43543 Metetra
.534 .879 .987 r
.74566 .42821 .74023 .42585 .72739 .42967 .73288 .43183 Metetra
.541 .877 .99 r
.7585 .42457 .75313 .42203 .74023 .42585 .74566 .42821 Metetra
.547 .875 .992 r
.77142 .42095 .7661 .41821 .75313 .42203 .7585 .42457 Metetra
.551 .872 .994 r
.78442 .41734 .77915 .41442 .7661 .41821 .77142 .42095 Metetra
.554 .868 .995 r
.79748 .41378 .79227 .41067 .77915 .41442 .78442 .41734 Metetra
.556 .864 .996 r
.81063 .41027 .80547 .40698 .79227 .41067 .79748 .41378 Metetra
.556 .859 .997 r
.82385 .40683 .81874 .40337 .80547 .40698 .81063 .41027 Metetra
.556 .854 .997 r
.83715 .40347 .8321 .39985 .81874 .40337 .82385 .40683 Metetra
.554 .85 .998 r
.85053 .40019 .84554 .39642 .8321 .39985 .83715 .40347 Metetra
.552 .845 .998 r
.864 .39702 .85906 .39311 .84554 .39642 .85053 .40019 Metetra
.548 .84 .998 r
.87756 .39396 .87268 .38993 .85906 .39311 .864 .39702 Metetra
.544 .835 .999 r
.8912 .39101 .88638 .38687 .87268 .38993 .87756 .39396 Metetra
.539 .831 .999 r
.90493 .38818 .90017 .38396 .88638 .38687 .8912 .39101 Metetra
.533 .826 .999 r
.91875 .38548 .91406 .38119 .90017 .38396 .90493 .38818 Metetra
.527 .822 .999 r
.93267 .38292 .92804 .37856 .91406 .38119 .91875 .38548 Metetra
.519 .818 .999 r
.94669 .38048 .94212 .3761 .92804 .37856 .93267 .38292 Metetra
.228 .381 .809 r
.35586 .36943 .34934 .35544 .33886 .35754 .34573 .36138 Metetra
.224 .293 .725 r
.36593 .38247 .35965 .36059 .34934 .35544 .35586 .36943 Metetra
.217 .306 .742 r
.37615 .39443 .36979 .37472 .35965 .36059 .36593 .38247 Metetra
.21 .322 .761 r
.3865 .40534 .38007 .38765 .36979 .37472 .37615 .39443 Metetra
.203 .341 .782 r
.39698 .41522 .3905 .39942 .38007 .38765 .3865 .40534 Metetra
.196 .363 .804 r
.40759 .42412 .40107 .41007 .3905 .39942 .39698 .41522 Metetra
.191 .387 .827 r
.41831 .43207 .41177 .41964 .40107 .41007 .40759 .42412 Metetra
.186 .415 .851 r
.42916 .43912 .42259 .42817 .41177 .41964 .41831 .43207 Metetra
.182 .445 .874 r
.44011 .44529 .43353 .4357 .42259 .42817 .42916 .43912 Metetra
.179 .478 .895 r
.45116 .45063 .44458 .44227 .43353 .4357 .44011 .44529 Metetra
.179 .512 .914 r
.46232 .45517 .45575 .44794 .44458 .44227 .45116 .45063 Metetra
.18 .546 .929 r
.47357 .45896 .46701 .45273 .45575 .44794 .46232 .45517 Metetra
.184 .58 .939 r
.48491 .46203 .47838 .4567 .46701 .45273 .47357 .45896 Metetra
.191 .613 .945 r
.49634 .46442 .48984 .45989 .47838 .4567 .48491 .46203 Metetra
.2 .643 .947 r
.50786 .46618 .50138 .46235 .48984 .45989 .49634 .46442 Metetra
.211 .67 .945 r
.51946 .46734 .51302 .46411 .50138 .46235 .50786 .46618 Metetra
.225 .696 .942 r
.53114 .46793 .52474 .46522 .51302 .46411 .51946 .46734 Metetra
.241 .718 .937 r
.54289 .468 .53654 .46573 .52474 .46522 .53114 .46793 Metetra
.26 .739 .933 r
.55472 .46759 .54841 .46568 .53654 .46573 .54289 .468 Metetra
.279 .758 .929 r
.56662 .46672 .56036 .4651 .54841 .46568 .55472 .46759 Metetra
.3 .776 .927 r
.57859 .46544 .57238 .46405 .56036 .4651 .56662 .46672 Metetra
.322 .793 .927 r
.59063 .46379 .58447 .46255 .57238 .46405 .57859 .46544 Metetra
.345 .808 .928 r
.60273 .46178 .59663 .46066 .58447 .46255 .59063 .46379 Metetra
.367 .822 .931 r
.6149 .45947 .60886 .4584 .59663 .46066 .60273 .46178 Metetra
.39 .835 .935 r
.62714 .45688 .62115 .45582 .60886 .4584 .6149 .45947 Metetra
.412 .847 .941 r
.63945 .45404 .63351 .45296 .62115 .45582 .62714 .45688 Metetra
.432 .857 .947 r
.65181 .45098 .64594 .44984 .63351 .45296 .63945 .45404 Metetra
.452 .866 .953 r
.66425 .44774 .65843 .4465 .64594 .44984 .65181 .45098 Metetra
.471 .873 .959 r
.67674 .44434 .67098 .44297 .65843 .4465 .66425 .44774 Metetra
.488 .878 .965 r
.68931 .4408 .6836 .43929 .67098 .44297 .67674 .44434 Metetra
.503 .882 .971 r
.70194 .43716 .69628 .43549 .6836 .43929 .68931 .4408 Metetra
.516 .884 .976 r
.71463 .43344 .70903 .43159 .69628 .43549 .70194 .43716 Metetra
.528 .885 .98 r
.72739 .42967 .72185 .42762 .70903 .43159 .71463 .43344 Metetra
.537 .884 .984 r
.74023 .42585 .73474 .42361 .72185 .42762 .72739 .42967 Metetra
.545 .883 .988 r
.75313 .42203 .74769 .41958 .73474 .42361 .74023 .42585 Metetra
.551 .88 .99 r
.7661 .41821 .76072 .41556 .74769 .41958 .75313 .42203 Metetra
.556 .877 .992 r
.77915 .41442 .77382 .41156 .76072 .41556 .7661 .41821 Metetra
.559 .873 .994 r
.79227 .41067 .787 .40761 .77382 .41156 .77915 .41442 Metetra
.561 .868 .995 r
.80547 .40698 .80025 .40373 .787 .40761 .79227 .41067 Metetra
.561 .864 .996 r
.81874 .40337 .81358 .39993 .80025 .40373 .80547 .40698 Metetra
.561 .858 .997 r
.8321 .39985 .82699 .39624 .81358 .39993 .81874 .40337 Metetra
.559 .853 .997 r
.84554 .39642 .84049 .39265 .82699 .39624 .8321 .39985 Metetra
.556 .848 .998 r
.85906 .39311 .85407 .38919 .84049 .39265 .84554 .39642 Metetra
.552 .843 .998 r
.87268 .38993 .86774 .38587 .85407 .38919 .85906 .39311 Metetra
.547 .837 .998 r
.88638 .38687 .8815 .3827 .86774 .38587 .87268 .38993 Metetra
.542 .832 .999 r
.90017 .38396 .89535 .37969 .8815 .3827 .88638 .38687 Metetra
.535 .827 .999 r
.91406 .38119 .9093 .37684 .89535 .37969 .90017 .38396 Metetra
.528 .823 .999 r
.92804 .37856 .92335 .37416 .9093 .37684 .91406 .38119 Metetra
.52 .818 .999 r
.94212 .3761 .9375 .37166 .92335 .37416 .92804 .37856 Metetra
.557 .81 .993 r
.34934 .35544 .34244 .35154 .33193 .35366 .33886 .35754 Metetra
.302 .48 .868 r
.35965 .36059 .353 .34941 .34244 .35154 .34934 .35544 Metetra
.199 .271 .713 r
.36979 .37472 .36349 .35205 .353 .34941 .35965 .36059 Metetra
.19 .284 .731 r
.38007 .38765 .37369 .3673 .36349 .35205 .36979 .37472 Metetra
.182 .3 .75 r
.3905 .39942 .38405 .38122 .37369 .3673 .38007 .38765 Metetra
.174 .319 .771 r
.40107 .41007 .39456 .39388 .38405 .38122 .3905 .39942 Metetra
.167 .34 .794 r
.41177 .41964 .40521 .40531 .39456 .39388 .40107 .41007 Metetra
.16 .366 .818 r
.42259 .42817 .416 .41555 .40521 .40531 .41177 .41964 Metetra
.154 .395 .842 r
.43353 .4357 .42693 .42465 .416 .41555 .42259 .42817 Metetra
.15 .427 .866 r
.44458 .44227 .43797 .43265 .42693 .42465 .43353 .4357 Metetra
.148 .461 .888 r
.45575 .44794 .44913 .43962 .43797 .43265 .44458 .44227 Metetra
.148 .497 .907 r
.46701 .45273 .46041 .44558 .44913 .43962 .45575 .44794 Metetra
.151 .534 .922 r
.47838 .4567 .47179 .4506 .46041 .44558 .46701 .45273 Metetra
.156 .57 .932 r
.48984 .45989 .48327 .45473 .47179 .4506 .47838 .4567 Metetra
.165 .605 .937 r
.50138 .46235 .49485 .458 .48327 .45473 .48984 .45989 Metetra
.177 .637 .937 r
.51302 .46411 .50652 .46048 .49485 .458 .50138 .46235 Metetra
.192 .667 .935 r
.52474 .46522 .51827 .46222 .50652 .46048 .51302 .46411 Metetra
.21 .693 .93 r
.53654 .46573 .53011 .46325 .51827 .46222 .52474 .46522 Metetra
.23 .718 .925 r
.54841 .46568 .54203 .46363 .53011 .46325 .53654 .46573 Metetra
.252 .74 .921 r
.56036 .4651 .55403 .46341 .54203 .46363 .54841 .46568 Metetra
.275 .761 .918 r
.57238 .46405 .5661 .46264 .55403 .46341 .56036 .4651 Metetra
.299 .78 .917 r
.58447 .46255 .57825 .46135 .5661 .46264 .57238 .46405 Metetra
.324 .798 .918 r
.59663 .46066 .59046 .45961 .57825 .46135 .58447 .46255 Metetra
.35 .814 .921 r
.60886 .4584 .60275 .45744 .59046 .45961 .59663 .46066 Metetra
.375 .829 .926 r
.62115 .45582 .6151 .4549 .60275 .45744 .60886 .4584 Metetra
.399 .843 .931 r
.63351 .45296 .62751 .45202 .6151 .4549 .62115 .45582 Metetra
.423 .855 .938 r
.64594 .44984 .63999 .44884 .62751 .45202 .63351 .45296 Metetra
.445 .865 .945 r
.65843 .4465 .65254 .44542 .63999 .44884 .64594 .44984 Metetra
.466 .874 .952 r
.67098 .44297 .66515 .44177 .65254 .44542 .65843 .4465 Metetra
.485 .881 .959 r
.6836 .43929 .67783 .43794 .66515 .44177 .67098 .44297 Metetra
.502 .885 .965 r
.69628 .43549 .69057 .43397 .67783 .43794 .6836 .43929 Metetra
.517 .888 .971 r
.70903 .43159 .70337 .42988 .69057 .43397 .69628 .43549 Metetra
.53 .89 .977 r
.72185 .42762 .71625 .42571 .70337 .42988 .70903 .43159 Metetra
.541 .89 .981 r
.73474 .42361 .72919 .42149 .71625 .42571 .72185 .42762 Metetra
.55 .889 .985 r
.74769 .41958 .7422 .41724 .72919 .42149 .73474 .42361 Metetra
.556 .886 .988 r
.76072 .41556 .75528 .413 .7422 .41724 .74769 .41958 Metetra
.562 .883 .991 r
.77382 .41156 .76844 .40878 .75528 .413 .76072 .41556 Metetra
.565 .878 .993 r
.787 .40761 .78167 .40462 .76844 .40878 .77382 .41156 Metetra
.567 .873 .994 r
.80025 .40373 .79498 .40052 .78167 .40462 .787 .40761 Metetra
.567 .868 .995 r
.81358 .39993 .80836 .39653 .79498 .40052 .80025 .40373 Metetra
.566 .863 .996 r
.82699 .39624 .82183 .39264 .80836 .39653 .81358 .39993 Metetra
.564 .857 .997 r
.84049 .39265 .83538 .38888 .82183 .39264 .82699 .39624 Metetra
.561 .851 .997 r
.85407 .38919 .84902 .38526 .83538 .38888 .84049 .39265 Metetra
.556 .845 .998 r
.86774 .38587 .86275 .3818 .84902 .38526 .85407 .38919 Metetra
.551 .84 .998 r
.8815 .3827 .87657 .3785 .86275 .3818 .86774 .38587 Metetra
.545 .834 .998 r
.89535 .37969 .89048 .37538 .87657 .3785 .8815 .3827 Metetra
.537 .829 .999 r
.9093 .37684 .9045 .37245 .89048 .37538 .89535 .37969 Metetra
.529 .824 .999 r
.92335 .37416 .91861 .36971 .9045 .37245 .9093 .37684 Metetra
.52 .819 .999 r
.9375 .37166 .93283 .36716 .91861 .36971 .92335 .37416 Metetra
.557 .81 .993 r
.34244 .35154 .33547 .3476 .32492 .34974 .33193 .35366 Metetra
.557 .81 .993 r
.353 .34941 .34607 .34545 .33547 .3476 .34244 .35154 Metetra
.38 .583 .922 r
.36349 .35205 .35673 .34329 .34607 .34545 .353 .34941 Metetra
.172 .248 .701 r
.37369 .3673 .36736 .34386 .35673 .34329 .36349 .35205 Metetra
.163 .261 .719 r
.38405 .38122 .37763 .36024 .36736 .34386 .37369 .3673 Metetra
.153 .277 .738 r
.39456 .39388 .38807 .37519 .37763 .36024 .38405 .38122 Metetra
.144 .295 .76 r
.40521 .40531 .39867 .38875 .38807 .37519 .39456 .39388 Metetra
.136 .318 .783 r
.416 .41555 .40941 .40095 .39867 .38875 .40521 .40531 Metetra
.128 .344 .808 r
.42693 .42465 .4203 .41186 .40941 .40095 .416 .41555 Metetra
.122 .374 .833 r
.43797 .43265 .43133 .42152 .4203 .41186 .42693 .42465 Metetra
.117 .408 .857 r
.44913 .43962 .44248 .42999 .43133 .42152 .43797 .43265 Metetra
.115 .444 .88 r
.46041 .44558 .45375 .43732 .44248 .42999 .44913 .43962 Metetra
.117 .483 .899 r
.47179 .4506 .46514 .44357 .45375 .43732 .46041 .44558 Metetra
.121 .522 .914 r
.48327 .45473 .47664 .44879 .46514 .44357 .47179 .4506 Metetra
.129 .561 .923 r
.49485 .458 .48824 .45303 .47664 .44879 .48327 .45473 Metetra
.141 .598 .927 r
.50652 .46048 .49994 .45635 .48824 .45303 .49485 .458 Metetra
.157 .632 .927 r
.51827 .46222 .51174 .45882 .49994 .45635 .50652 .46048 Metetra
.176 .664 .923 r
.53011 .46325 .52362 .46048 .51174 .45882 .51827 .46222 Metetra
.197 .693 .918 r
.54203 .46363 .53558 .46139 .52362 .46048 .53011 .46325 Metetra
.222 .719 .914 r
.55403 .46341 .54763 .4616 .53558 .46139 .54203 .46363 Metetra
.247 .743 .91 r
.5661 .46264 .55975 .46117 .54763 .4616 .55403 .46341 Metetra
.274 .765 .908 r
.57825 .46135 .57195 .46016 .55975 .46117 .5661 .46264 Metetra
.302 .785 .909 r
.59046 .45961 .58422 .4586 .57195 .46016 .57825 .46135 Metetra
.331 .805 .911 r
.60275 .45744 .59656 .45656 .58422 .4586 .59046 .45961 Metetra
.359 .822 .915 r
.6151 .4549 .60897 .45408 .59656 .45656 .60275 .45744 Metetra
.386 .838 .921 r
.62751 .45202 .62144 .45122 .60897 .45408 .6151 .4549 Metetra
.412 .852 .928 r
.63999 .44884 .63398 .44801 .62144 .45122 .62751 .45202 Metetra
.437 .864 .936 r
.65254 .44542 .64658 .4445 .63398 .44801 .63999 .44884 Metetra
.461 .875 .944 r
.66515 .44177 .65925 .44073 .64658 .4445 .65254 .44542 Metetra
.482 .883 .952 r
.67783 .43794 .67199 .43676 .65925 .44073 .66515 .44177 Metetra
.501 .889 .959 r
.69057 .43397 .68479 .43261 .67199 .43676 .67783 .43794 Metetra
.518 .893 .966 r
.70337 .42988 .69765 .42833 .68479 .43261 .69057 .43397 Metetra
.532 .895 .972 r
.71625 .42571 .71058 .42394 .69765 .42833 .70337 .42988 Metetra
.544 .895 .977 r
.72919 .42149 .72358 .4195 .71058 .42394 .71625 .42571 Metetra
.554 .894 .982 r
.7422 .41724 .73665 .41502 .72358 .4195 .72919 .42149 Metetra
.562 .892 .986 r
.75528 .413 .74978 .41054 .73665 .41502 .7422 .41724 Metetra
.568 .888 .989 r
.76844 .40878 .763 .40608 .74978 .41054 .75528 .413 Metetra
.571 .884 .991 r
.78167 .40462 .77628 .40168 .763 .40608 .76844 .40878 Metetra
.573 .879 .993 r
.79498 .40052 .78964 .39736 .77628 .40168 .78167 .40462 Metetra
.574 .873 .994 r
.80836 .39653 .80309 .39315 .78964 .39736 .79498 .40052 Metetra
.572 .867 .995 r
.82183 .39264 .81661 .38905 .80309 .39315 .80836 .39653 Metetra
.57 .861 .996 r
.83538 .38888 .83022 .3851 .81661 .38905 .82183 .39264 Metetra
.566 .855 .997 r
.84902 .38526 .84392 .38131 .83022 .3851 .83538 .38888 Metetra
.561 .848 .997 r
.86275 .3818 .8577 .37769 .84392 .38131 .84902 .38526 Metetra
.555 .842 .998 r
.87657 .3785 .87158 .37427 .8577 .37769 .86275 .3818 Metetra
.548 .836 .998 r
.89048 .37538 .88556 .37104 .87158 .37427 .87657 .3785 Metetra
.54 .83 .999 r
.9045 .37245 .89963 .36801 .88556 .37104 .89048 .37538 Metetra
.531 .824 .999 r
.91861 .36971 .91381 .36521 .89963 .36801 .9045 .37245 Metetra
.521 .819 .999 r
.93283 .36716 .9281 .36262 .91381 .36521 .91861 .36971 Metetra
.557 .81 .993 r
.33547 .3476 .32842 .34362 .31785 .34578 .32492 .34974 Metetra
.557 .81 .993 r
.34607 .34545 .33906 .34145 .32842 .34362 .33547 .3476 Metetra
.557 .81 .993 r
.35673 .34329 .34975 .33927 .33906 .34145 .34607 .34545 Metetra
.453 .679 .961 r
.36736 .34386 .3605 .33707 .34975 .33927 .35673 .34329 Metetra
.145 .225 .689 r
.37763 .36024 .37128 .33606 .3605 .33707 .36736 .34386 Metetra
.134 .238 .707 r
.38807 .37519 .38162 .35362 .37128 .33606 .37763 .36024 Metetra
.124 .253 .726 r
.39867 .38875 .39214 .3696 .38162 .35362 .38807 .37519 Metetra
.113 .272 .748 r
.40941 .40095 .40283 .38406 .39214 .3696 .39867 .38875 Metetra
.104 .295 .772 r
.4203 .41186 .41367 .39705 .40283 .38406 .40941 .40095 Metetra
.095 .322 .797 r
.43133 .42152 .42466 .40862 .41367 .39705 .4203 .41186 Metetra
.088 .353 .823 r
.44248 .42999 .4358 .41883 .42466 .40862 .43133 .42152 Metetra
.084 .388 .848 r
.45375 .43732 .44706 .42774 .4358 .41883 .44248 .42999 Metetra
.083 .428 .871 r
.46514 .44357 .45845 .4354 .44706 .42774 .45375 .43732 Metetra
.085 .469 .89 r
.47664 .44879 .46996 .44189 .45845 .4354 .46514 .44357 Metetra
.092 .511 .905 r
.48824 .45303 .48158 .44727 .46996 .44189 .47664 .44879 Metetra
.103 .553 .913 r
.49994 .45635 .49331 .45159 .48158 .44727 .48824 .45303 Metetra
.119 .592 .916 r
.51174 .45882 .50513 .45492 .49331 .45159 .49994 .45635 Metetra
.139 .629 .915 r
.52362 .46048 .51705 .45733 .50513 .45492 .51174 .45882 Metetra
.163 .663 .911 r
.53558 .46139 .52906 .45887 .51705 .45733 .52362 .46048 Metetra
.189 .694 .906 r
.54763 .4616 .54115 .45961 .52906 .45887 .53558 .46139 Metetra
.217 .722 .902 r
.55975 .46117 .55333 .4596 .54115 .45961 .54763 .4616 Metetra
.247 .747 .9 r
.57195 .46016 .56558 .45892 .55333 .4596 .55975 .46117 Metetra
.278 .771 .899 r
.58422 .4586 .5779 .45761 .56558 .45892 .57195 .46016 Metetra
.31 .793 .901 r
.59656 .45656 .5903 .45574 .5779 .45761 .58422 .4586 Metetra
.341 .813 .905 r
.60897 .45408 .60276 .45337 .5903 .45574 .59656 .45656 Metetra
.372 .832 .911 r
.62144 .45122 .6153 .45054 .60276 .45337 .60897 .45408 Metetra
.401 .848 .918 r
.63398 .44801 .6279 .44731 .6153 .45054 .62144 .45122 Metetra
.429 .862 .927 r
.64658 .4445 .64056 .44374 .6279 .44731 .63398 .44801 Metetra
.455 .875 .935 r
.65925 .44073 .65329 .43986 .64056 .44374 .64658 .4445 Metetra
.479 .884 .944 r
.67199 .43676 .66608 .43574 .65329 .43986 .65925 .44073 Metetra
.5 .892 .952 r
.68479 .43261 .67894 .43141 .66608 .43574 .67199 .43676 Metetra
.519 .897 .96 r
.69765 .42833 .69186 .42693 .67894 .43141 .68479 .43261 Metetra
.535 .9 .967 r
.71058 .42394 .70485 .42232 .69186 .42693 .69765 .42833 Metetra
.549 .901 .973 r
.72358 .4195 .71791 .41764 .70485 .42232 .71058 .42394 Metetra
.559 .9 .979 r
.73665 .41502 .73103 .41291 .71791 .41764 .72358 .4195 Metetra
.568 .898 .983 r
.74978 .41054 .74423 .40818 .73103 .41291 .73665 .41502 Metetra
.574 .895 .986 r
.763 .40608 .75749 .40347 .74423 .40818 .74978 .41054 Metetra
.578 .89 .989 r
.77628 .40168 .77083 .39882 .75749 .40347 .763 .40608 Metetra
.58 .884 .991 r
.78964 .39736 .78425 .39426 .77083 .39882 .77628 .40168 Metetra
.581 .878 .993 r
.80309 .39315 .79775 .38981 .78425 .39426 .78964 .39736 Metetra
.579 .872 .994 r
.81661 .38905 .81133 .38549 .79775 .38981 .80309 .39315 Metetra
.576 .865 .995 r
.83022 .3851 .825 .38133 .81133 .38549 .81661 .38905 Metetra
.572 .858 .996 r
.84392 .38131 .83875 .37735 .825 .38133 .83022 .3851 Metetra
.566 .852 .997 r
.8577 .37769 .8526 .37357 .83875 .37735 .84392 .38131 Metetra
.56 .845 .997 r
.87158 .37427 .86654 .37 .8526 .37357 .8577 .37769 Metetra
.552 .838 .998 r
.88556 .37104 .88057 .36664 .86654 .37 .87158 .37427 Metetra
.543 .832 .999 r
.89963 .36801 .89471 .36353 .88057 .36664 .88556 .37104 Metetra
.533 .825 .999 r
.91381 .36521 .90896 .36065 .89471 .36353 .89963 .36801 Metetra
.521 .819 .999 r
.9281 .36262 .92331 .35802 .90896 .36065 .91381 .36521 Metetra
.557 .81 .993 r
.32842 .34362 .32131 .3396 .3107 .34178 .31785 .34578 Metetra
.557 .81 .993 r
.33906 .34145 .33198 .33741 .32131 .3396 .32842 .34362 Metetra
.557 .81 .993 r
.34975 .33927 .34271 .3352 .33198 .33741 .33906 .34145 Metetra
.557 .81 .993 r
.3605 .33707 .35349 .33298 .34271 .3352 .34975 .33927 Metetra
.512 .754 .983 r
.37128 .33606 .36434 .33075 .35349 .33298 .3605 .33707 Metetra
.117 .202 .677 r
.38162 .35362 .37524 .32873 .36434 .33075 .37128 .33606 Metetra
.105 .214 .694 r
.39214 .3696 .38566 .34747 .37524 .32873 .38162 .35362 Metetra
.093 .229 .714 r
.40283 .38406 .39627 .3645 .38566 .34747 .39214 .3696 Metetra
.082 .248 .736 r
.41367 .39705 .40705 .37986 .39627 .3645 .40283 .38406 Metetra
.071 .271 .76 r
.42466 .40862 .41799 .39362 .40705 .37986 .41367 .39705 Metetra
.062 .299 .786 r
.4358 .41883 .42909 .40583 .41799 .39362 .42466 .40862 Metetra
.055 .332 .812 r
.44706 .42774 .44033 .41656 .42909 .40583 .4358 .41883 Metetra
.051 .37 .838 r
.45845 .4354 .45172 .42588 .44033 .41656 .44706 .42774 Metetra
.05 .412 .862 r
.46996 .44189 .46323 .43385 .45172 .42588 .45845 .4354 Metetra
.055 .456 .881 r
.48158 .44727 .47486 .44055 .46323 .43385 .46996 .44189 Metetra
.065 .501 .895 r
.49331 .45159 .48661 .44604 .47486 .44055 .48158 .44727 Metetra
.08 .546 .903 r
.50513 .45492 .49846 .45039 .48661 .44604 .49331 .45159 Metetra
.101 .589 .905 r
.51705 .45733 .51041 .45368 .49846 .45039 .50513 .45492 Metetra
.125 .628 .904 r
.52906 .45887 .52246 .45597 .51041 .45368 .51705 .45733 Metetra
.154 .664 .9 r
.54115 .45961 .5346 .45734 .52246 .45597 .52906 .45887 Metetra
.185 .697 .895 r
.55333 .4596 .54683 .45786 .5346 .45734 .54115 .45961 Metetra
.218 .727 .892 r
.56558 .45892 .55913 .45759 .54683 .45786 .55333 .4596 Metetra
.253 .755 .891 r
.5779 .45761 .57151 .4566 .55913 .45759 .56558 .45892 Metetra
.288 .78 .892 r
.5903 .45574 .58396 .45495 .57151 .4566 .5779 .45761 Metetra
.322 .803 .895 r
.60276 .45337 .59649 .45272 .58396 .45495 .5903 .45574 Metetra
.356 .824 .901 r
.6153 .45054 .60908 .44997 .59649 .45272 .60276 .45337 Metetra
.389 .843 .908 r
.6279 .44731 .62174 .44675 .60908 .44997 .6153 .45054 Metetra
.42 .86 .917 r
.64056 .44374 .63447 .44312 .62174 .44675 .6279 .44731 Metetra
.449 .874 .926 r
.65329 .43986 .64725 .43915 .63447 .44312 .64056 .44374 Metetra
.475 .886 .936 r
.66608 .43574 .66011 .43489 .64725 .43915 .65329 .43986 Metetra
.499 .895 .945 r
.67894 .43141 .67303 .43038 .66011 .43489 .66608 .43574 Metetra
.52 .901 .954 r
.69186 .42693 .68601 .42569 .67303 .43038 .67894 .43141 Metetra
.538 .905 .962 r
.70485 .42232 .69906 .42085 .68601 .42569 .69186 .42693 Metetra
.553 .907 .969 r
.71791 .41764 .71217 .41592 .69906 .42085 .70485 .42232 Metetra
.565 .906 .975 r
.73103 .41291 .72535 .41093 .71217 .41592 .71791 .41764 Metetra
.574 .904 .98 r
.74423 .40818 .7386 .40593 .72535 .41093 .73103 .41291 Metetra
.581 .901 .984 r
.75749 .40347 .75193 .40095 .7386 .40593 .74423 .40818 Metetra
.586 .896 .987 r
.77083 .39882 .76533 .39603 .75193 .40095 .75749 .40347 Metetra
.588 .89 .99 r
.78425 .39426 .7788 .39121 .76533 .39603 .77083 .39882 Metetra
.588 .884 .992 r
.79775 .38981 .79235 .3865 .7788 .39121 .78425 .39426 Metetra
.586 .877 .993 r
.81133 .38549 .80599 .38195 .79235 .3865 .79775 .38981 Metetra
.583 .87 .995 r
.825 .38133 .81971 .37757 .80599 .38195 .81133 .38549 Metetra
.578 .862 .996 r
.83875 .37735 .83353 .37339 .81971 .37757 .825 .38133 Metetra
.572 .855 .996 r
.8526 .37357 .84743 .36942 .83353 .37339 .83875 .37735 Metetra
.564 .848 .997 r
.86654 .37 .86143 .36569 .84743 .36942 .8526 .37357 Metetra
.556 .84 .998 r
.88057 .36664 .87553 .36221 .86143 .36569 .86654 .37 Metetra
.546 .833 .998 r
.89471 .36353 .88974 .35899 .87553 .36221 .88057 .36664 Metetra
.534 .826 .999 r
.90896 .36065 .90405 .35604 .88974 .35899 .89471 .36353 Metetra
.522 .819 .999 r
.92331 .35802 .91847 .35336 .90405 .35604 .90896 .36065 Metetra
.557 .81 .993 r
.32131 .3396 .31412 .33554 .30348 .33775 .3107 .34178 Metetra
.557 .81 .993 r
.33198 .33741 .32483 .33333 .31412 .33554 .32131 .3396 Metetra
.557 .81 .993 r
.34271 .3352 .33559 .3311 .32483 .33333 .33198 .33741 Metetra
.557 .81 .993 r
.35349 .33298 .34641 .32886 .33559 .3311 .34271 .3352 Metetra
.557 .81 .993 r
.36434 .33075 .3573 .3266 .34641 .32886 .35349 .33298 Metetra
.549 .801 .992 r
.37524 .32873 .36824 .32434 .3573 .3266 .36434 .33075 Metetra
.084 .176 .663 r
.38566 .34747 .37925 .32206 .36824 .32434 .37524 .32873 Metetra
.075 .19 .681 r
.39627 .3645 .38975 .34184 .37925 .32206 .38566 .34747 Metetra
.062 .205 .701 r
.40705 .37986 .40045 .35992 .38975 .34184 .39627 .3645 Metetra
.049 .224 .723 r
.41799 .39362 .41132 .37617 .40045 .35992 .40705 .37986 Metetra
.038 .248 .748 r
.42909 .40583 .42237 .39068 .41132 .37617 .41799 .39362 Metetra
.028 .277 .774 r
.44033 .41656 .43358 .40351 .42237 .39068 .42909 .40583 Metetra
.021 .312 .801 r
.45172 .42588 .44495 .41474 .43358 .40351 .44033 .41656 Metetra
.017 .352 .828 r
.46323 .43385 .45645 .42443 .44495 .41474 .45172 .42588 Metetra
.019 .397 .852 r
.47486 .44055 .46809 .43266 .45645 .42443 .46323 .43385 Metetra
.027 .445 .871 r
.48661 .44604 .47985 .43952 .46809 .43266 .47486 .44055 Metetra
.04 .494 .885 r
.49846 .45039 .49172 .44507 .47985 .43952 .48661 .44604 Metetra
.06 .542 .893 r
.51041 .45368 .50371 .4494 .49172 .44507 .49846 .45039 Metetra
.086 .588 .894 r
.52246 .45597 .51579 .45259 .50371 .4494 .51041 .45368 Metetra
.117 .63 .893 r
.5346 .45734 .52798 .45471 .51579 .45259 .52246 .45597 Metetra
.151 .669 .889 r
.54683 .45786 .54025 .45585 .52798 .45471 .5346 .45734 Metetra
.187 .704 .885 r
.55913 .45759 .5526 .45609 .54025 .45585 .54683 .45786 Metetra
.225 .736 .883 r
.57151 .4566 .56504 .45549 .5526 .45609 .55913 .45759 Metetra
.264 .765 .884 r
.58396 .45495 .57755 .45414 .56504 .45549 .57151 .4566 Metetra
.302 .791 .886 r
.59649 .45272 .59013 .45211 .57755 .45414 .58396 .45495 Metetra
.34 .816 .892 r
.60908 .44997 .60279 .44947 .59013 .45211 .59649 .45272 Metetra
.376 .837 .899 r
.62174 .44675 .61551 .4463 .60279 .44947 .60908 .44997 Metetra
.41 .856 .908 r
.63447 .44312 .6283 .44265 .61551 .4463 .62174 .44675 Metetra
.443 .873 .918 r
.64725 .43915 .64115 .4386 .6283 .44265 .63447 .44312 Metetra
.472 .886 .928 r
.66011 .43489 .65406 .4342 .64115 .4386 .64725 .43915 Metetra
.498 .897 .938 r
.67303 .43038 .66704 .42952 .65406 .4342 .66011 .43489 Metetra
.521 .905 .947 r
.68601 .42569 .68009 .42461 .66704 .42952 .67303 .43038 Metetra
.541 .91 .956 r
.69906 .42085 .69319 .41954 .68009 .42461 .68601 .42569 Metetra
.558 .912 .964 r
.71217 .41592 .70637 .41434 .69319 .41954 .69906 .42085 Metetra
.571 .912 .97 r
.72535 .41093 .71961 .40908 .70637 .41434 .71217 .41592 Metetra
.582 .911 .976 r
.7386 .40593 .73292 .4038 .71961 .40908 .72535 .41093 Metetra
.589 .907 .981 r
.75193 .40095 .7463 .39853 .73292 .4038 .7386 .40593 Metetra
.594 .902 .985 r
.76533 .39603 .75975 .39332 .7463 .39853 .75193 .40095 Metetra
.596 .896 .988 r
.7788 .39121 .77329 .38822 .75975 .39332 .76533 .39603 Metetra
.596 .89 .99 r
.79235 .3865 .7869 .38324 .77329 .38822 .7788 .39121 Metetra
.594 .882 .992 r
.80599 .38195 .80059 .37843 .7869 .38324 .79235 .3865 Metetra
.59 .875 .993 r
.81971 .37757 .81437 .37381 .80059 .37843 .80599 .38195 Metetra
.585 .867 .995 r
.83353 .37339 .82824 .36942 .81437 .37381 .81971 .37757 Metetra
.578 .859 .996 r
.84743 .36942 .84221 .36526 .82824 .36942 .83353 .37339 Metetra
.57 .851 .997 r
.86143 .36569 .85627 .36136 .84221 .36526 .84743 .36942 Metetra
.56 .843 .997 r
.87553 .36221 .87043 .35774 .85627 .36136 .86143 .36569 Metetra
.549 .835 .998 r
.88974 .35899 .8847 .35441 .87043 .35774 .87553 .36221 Metetra
.536 .827 .999 r
.90405 .35604 .89908 .35138 .8847 .35441 .88974 .35899 Metetra
.523 .82 .999 r
.91847 .35336 .91356 .34865 .89908 .35138 .90405 .35604 Metetra
.557 .81 .993 r
.31412 .33554 .30686 .33144 .29619 .33367 .30348 .33775 Metetra
.557 .81 .993 r
.32483 .33333 .3176 .3292 .30686 .33144 .31412 .33554 Metetra
.557 .81 .993 r
.33559 .3311 .3284 .32695 .3176 .3292 .32483 .33333 Metetra
.557 .81 .993 r
.34641 .32886 .33926 .32469 .3284 .32695 .33559 .3311 Metetra
.557 .81 .993 r
.3573 .3266 .35018 .32241 .33926 .32469 .34641 .32886 Metetra
.557 .81 .993 r
.36824 .32434 .36116 .32012 .35018 .32241 .3573 .3266 Metetra
.557 .81 .993 r
.37925 .32206 .3722 .31782 .36116 .32012 .36824 .32434 Metetra
.065 .159 .652 r
.38975 .34184 .3833 .31563 .3722 .31782 .37925 .32206 Metetra
.044 .166 .667 r
.40045 .35992 .39389 .33677 .3833 .31563 .38975 .34184 Metetra
.03 .181 .687 r
.41132 .37617 .40468 .35588 .39389 .33677 .40045 .35992 Metetra
.016 .2 .71 r
.42237 .39068 .41566 .37302 .40468 .35588 .41132 .37617 Metetra
.004 .225 .735 r
.43358 .40351 .42682 .38826 .41566 .37302 .42237 .39068 Metetra
0 .255 .762 r
.44495 .41474 .43815 .40167 .42682 .38826 .43358 .40351 Metetra
0 .292 .79 r
.45645 .42443 .44964 .41335 .43815 .40167 .44495 .41474 Metetra
0 .335 .817 r
.46809 .43266 .46126 .42336 .44964 .41335 .45645 .42443 Metetra
0 .384 .842 r
.47985 .43952 .47303 .43181 .46126 .42336 .46809 .43266 Metetra
.001 .435 .862 r
.49172 .44507 .48492 .43876 .47303 .43181 .47985 .43952 Metetra
.02 .489 .876 r
.50371 .4494 .49693 .44432 .48492 .43876 .49172 .44507 Metetra
.045 .541 .883 r
.51579 .45259 .50905 .44857 .49693 .44432 .50371 .4494 Metetra
.077 .59 .885 r
.52798 .45471 .52127 .45159 .50905 .44857 .51579 .45259 Metetra
.114 .635 .883 r
.54025 .45585 .53359 .45349 .52127 .45159 .52798 .45471 Metetra
.154 .676 .88 r
.5526 .45609 .546 .45434 .53359 .45349 .54025 .45585 Metetra
.196 .714 .878 r
.56504 .45549 .55849 .45423 .546 .45434 .5526 .45609 Metetra
.238 .747 .877 r
.57755 .45414 .57106 .45326 .55849 .45423 .56504 .45549 Metetra
.281 .778 .879 r
.59013 .45211 .5837 .45149 .57106 .45326 .57755 .45414 Metetra
.322 .806 .884 r
.60279 .44947 .59642 .44902 .5837 .45149 .59013 .45211 Metetra
.362 .83 .891 r
.61551 .4463 .6092 .44593 .59642 .44902 .60279 .44947 Metetra
.4 .852 .899 r
.6283 .44265 .62205 .44229 .6092 .44593 .61551 .4463 Metetra
.436 .871 .909 r
.64115 .4386 .63497 .43818 .62205 .44229 .6283 .44265 Metetra
.468 .886 .92 r
.65406 .4342 .64795 .43366 .63497 .43818 .64115 .4386 Metetra
.497 .899 .93 r
.66704 .42952 .66099 .42881 .64795 .43366 .65406 .4342 Metetra
.523 .908 .941 r
.68009 .42461 .67409 .4237 .66099 .42881 .66704 .42952 Metetra
.545 .914 .95 r
.69319 .41954 .68726 .41838 .67409 .4237 .68009 .42461 Metetra
.563 .918 .959 r
.70637 .41434 .7005 .41292 .68726 .41838 .69319 .41954 Metetra
.578 .919 .966 r
.71961 .40908 .7138 .40737 .7005 .41292 .70637 .41434 Metetra
.589 .917 .972 r
.73292 .4038 .72717 .40178 .7138 .40737 .71961 .40908 Metetra
.597 .914 .978 r
.7463 .39853 .74061 .39621 .72717 .40178 .73292 .4038 Metetra
.602 .909 .982 r
.75975 .39332 .75412 .3907 .74061 .39621 .7463 .39853 Metetra
.605 .903 .985 r
.77329 .38822 .76771 .38529 .75412 .3907 .75975 .39332 Metetra
.605 .896 .988 r
.7869 .38324 .78138 .38003 .76771 .38529 .77329 .38822 Metetra
.603 .888 .99 r
.80059 .37843 .79513 .37494 .78138 .38003 .7869 .38324 Metetra
.598 .88 .992 r
.81437 .37381 .80897 .37007 .79513 .37494 .80059 .37843 Metetra
.592 .871 .994 r
.82824 .36942 .8229 .36544 .80897 .37007 .81437 .37381 Metetra
.585 .862 .995 r
.84221 .36526 .83692 .36107 .8229 .36544 .82824 .36942 Metetra
.575 .854 .996 r
.85627 .36136 .85104 .35699 .83692 .36107 .84221 .36526 Metetra
.564 .845 .997 r
.87043 .35774 .86527 .35322 .85104 .35699 .85627 .36136 Metetra
.552 .837 .998 r
.8847 .35441 .8796 .34977 .86527 .35322 .87043 .35774 Metetra
.539 .828 .999 r
.89908 .35138 .89404 .34666 .8796 .34977 .8847 .35441 Metetra
.523 .82 .999 r
.91356 .34865 .9086 .34389 .89404 .34666 .89908 .35138 Metetra
.557 .81 .993 r
.30686 .33144 .29953 .3273 .28882 .32955 .29619 .33367 Metetra
.557 .81 .993 r
.3176 .3292 .3103 .32504 .29953 .3273 .30686 .33144 Metetra
.557 .81 .993 r
.3284 .32695 .32114 .32276 .3103 .32504 .3176 .3292 Metetra
.557 .81 .993 r
.33926 .32469 .33203 .32047 .32114 .32276 .3284 .32695 Metetra
.557 .81 .993 r
.35018 .32241 .34299 .31817 .33203 .32047 .33926 .32469 Metetra
.557 .81 .993 r
.36116 .32012 .35401 .31586 .34299 .31817 .35018 .32241 Metetra
.557 .81 .993 r
.3722 .31782 .36508 .31353 .35401 .31586 .36116 .32012 Metetra
.552 .805 .992 r
.3833 .31563 .37623 .31119 .36508 .31353 .3722 .31782 Metetra
.029 .131 .636 r
.39389 .33677 .3874 .30995 .37623 .31119 .3833 .31563 Metetra
.014 .142 .654 r
.40468 .35588 .39808 .33229 .3874 .30995 .39389 .33677 Metetra
0 .157 .674 r
.41566 .37302 .40898 .35242 .39808 .33229 .40468 .35588 Metetra
0 .177 .696 r
.42682 .38826 .42007 .37041 .40898 .35242 .41566 .37302 Metetra
0 .202 .722 r
.43815 .40167 .43134 .38634 .42007 .37041 .42682 .38826 Metetra
0 .235 .75 r
.44964 .41335 .44279 .4003 .43134 .38634 .43815 .40167 Metetra
0 .274 .779 r
.46126 .42336 .4544 .41238 .44279 .4003 .44964 .41335 Metetra
0 .321 .807 r
.47303 .43181 .46616 .42266 .4544 .41238 .46126 .42336 Metetra
0 .373 .833 r
.48492 .43876 .47806 .43126 .46616 .42266 .47303 .43181 Metetra
0 .429 .853 r
.49693 .44432 .49009 .43825 .47806 .43126 .48492 .43876 Metetra
.004 .487 .867 r
.50905 .44857 .50224 .44374 .49009 .43825 .49693 .44432 Metetra
.036 .543 .875 r
.52127 .45159 .5145 .44784 .50224 .44374 .50905 .44857 Metetra
.075 .596 .877 r
.53359 .45349 .52686 .45064 .5145 .44784 .52127 .45159 Metetra
.118 .645 .876 r
.546 .45434 .53931 .45223 .52686 .45064 .53359 .45349 Metetra
.164 .688 .874 r
.55849 .45423 .55186 .45273 .53931 .45223 .546 .45434 Metetra
.211 .728 .873 r
.57106 .45326 .56448 .45222 .55186 .45273 .55849 .45423 Metetra
.258 .763 .874 r
.5837 .45149 .57719 .4508 .56448 .45222 .57106 .45326 Metetra
.304 .794 .877 r
.59642 .44902 .58997 .44857 .57719 .4508 .5837 .45149 Metetra
.348 .822 .884 r
.6092 .44593 .60281 .44561 .58997 .44857 .59642 .44902 Metetra
.39 .847 .892 r
.62205 .44229 .61573 .44202 .60281 .44561 .6092 .44593 Metetra
.429 .868 .902 r
.63497 .43818 .62871 .43787 .61573 .44202 .62205 .44229 Metetra
.465 .886 .912 r
.64795 .43366 .64175 .43326 .62871 .43787 .63497 .43818 Metetra
.497 .9 .923 r
.66099 .42881 .65486 .42825 .64175 .43326 .64795 .43366 Metetra
.525 .911 .934 r
.67409 .4237 .66803 .42293 .65486 .42825 .66099 .42881 Metetra
.549 .919 .944 r
.68726 .41838 .68126 .41737 .66803 .42293 .67409 .4237 Metetra
.569 .923 .953 r
.7005 .41292 .69456 .41163 .68126 .41737 .68726 .41838 Metetra
.585 .924 .961 r
.7138 .40737 .70792 .40578 .69456 .41163 .7005 .41292 Metetra
.597 .923 .968 r
.72717 .40178 .72135 .39988 .70792 .40578 .7138 .40737 Metetra
.606 .92 .974 r
.74061 .39621 .73485 .39399 .72135 .39988 .72717 .40178 Metetra
.612 .915 .979 r
.75412 .3907 .74842 .38816 .73485 .39399 .74061 .39621 Metetra
.614 .909 .983 r
.76771 .38529 .76207 .38243 .74842 .38816 .75412 .3907 Metetra
.614 .902 .986 r
.78138 .38003 .77579 .37686 .76207 .38243 .76771 .38529 Metetra
.612 .893 .989 r
.79513 .37494 .7896 .37148 .77579 .37686 .78138 .38003 Metetra
.607 .885 .991 r
.80897 .37007 .8035 .36633 .7896 .37148 .79513 .37494 Metetra
.6 .876 .992 r
.8229 .36544 .81749 .36145 .8035 .36633 .80897 .37007 Metetra
.592 .866 .994 r
.83692 .36107 .83157 .35686 .81749 .36145 .8229 .36544 Metetra
.581 .857 .995 r
.85104 .35699 .84576 .35259 .83157 .35686 .83692 .36107 Metetra
.569 .848 .997 r
.86527 .35322 .86004 .34866 .84576 .35259 .85104 .35699 Metetra
.556 .839 .998 r
.8796 .34977 .87444 .34509 .86004 .34866 .86527 .35322 Metetra
.541 .83 .999 r
.89404 .34666 .88895 .34189 .87444 .34509 .8796 .34977 Metetra
.524 .821 .999 r
.9086 .34389 .90358 .33906 .88895 .34189 .89404 .34666 Metetra
.557 .81 .993 r
.29953 .3273 .29212 .32311 .28137 .32538 .28882 .32955 Metetra
.557 .81 .993 r
.3103 .32504 .30293 .32083 .29212 .32311 .29953 .3273 Metetra
.557 .81 .993 r
.32114 .32276 .3138 .31853 .30293 .32083 .3103 .32504 Metetra
.557 .81 .993 r
.33203 .32047 .32473 .31622 .3138 .31853 .32114 .32276 Metetra
.557 .81 .993 r
.34299 .31817 .33572 .31389 .32473 .31622 .33203 .32047 Metetra
.557 .81 .993 r
.35401 .31586 .34678 .31155 .33572 .31389 .34299 .31817 Metetra
.557 .81 .993 r
.36508 .31353 .35789 .3092 .34678 .31155 .35401 .31586 Metetra
.557 .81 .993 r
.37623 .31119 .36907 .30684 .35789 .3092 .36508 .31353 Metetra
.516 .759 .985 r
.3874 .30995 .38032 .30446 .36907 .30684 .37623 .31119 Metetra
0 .107 .622 r
.39808 .33229 .39156 .30491 .38032 .30446 .3874 .30995 Metetra
0 .118 .64 r
.40898 .35242 .40233 .32843 .39156 .30491 .39808 .33229 Metetra
0 .133 .66 r
.42007 .37041 .41333 .34955 .40233 .32843 .40898 .35242 Metetra
0 .154 .683 r
.43134 .38634 .42454 .36835 .41333 .34955 .42007 .37041 Metetra
0 .181 .709 r
.44279 .4003 .43594 .38493 .42454 .36835 .43134 .38634 Metetra
0 .216 .738 r
.4544 .41238 .44751 .39938 .43594 .38493 .44279 .4003 Metetra
0 .258 .769 r
.46616 .42266 .45926 .4118 .44751 .39938 .4544 .41238 Metetra
0 .309 .798 r
.47806 .43126 .47115 .42229 .45926 .4118 .46616 .42266 Metetra
0 .366 .825 r
.49009 .43825 .48319 .43096 .47115 .42229 .47806 .43126 Metetra
0 .427 .846 r
.50224 .44374 .49536 .43792 .48319 .43096 .49009 .43825 Metetra
0 .49 .861 r
.5145 .44784 .50765 .44328 .49536 .43792 .50224 .44374 Metetra
.034 .551 .869 r
.52686 .45064 .52005 .44716 .50765 .44328 .5145 .44784 Metetra
.08 .607 .872 r
.53931 .45223 .53255 .44965 .52005 .44716 .52686 .45064 Metetra
.13 .659 .871 r
.55186 .45273 .54514 .45088 .53255 .44965 .53931 .45223 Metetra
.182 .705 .871 r
.56448 .45222 .55783 .45095 .54514 .45088 .55186 .45273 Metetra
.234 .746 .871 r
.57719 .4508 .57059 .44997 .55783 .45095 .56448 .45222 Metetra
.285 .782 .874 r
.58997 .44857 .58343 .44805 .57059 .44997 .57719 .4508 Metetra
.333 .814 .879 r
.60281 .44561 .59634 .44529 .58343 .44805 .58997 .44857 Metetra
.38 .841 .886 r
.61573 .44202 .60933 .4418 .59634 .44529 .60281 .44561 Metetra
.422 .865 .895 r
.62871 .43787 .62237 .43766 .60933 .4418 .61573 .44202 Metetra
.461 .885 .906 r
.64175 .43326 .63548 .43297 .62237 .43766 .62871 .43787 Metetra
.496 .902 .917 r
.65486 .42825 .64866 .42783 .63548 .43297 .64175 .43326 Metetra
.527 .914 .927 r
.66803 .42293 .66189 .42231 .64866 .42783 .65486 .42825 Metetra
.553 .923 .938 r
.68126 .41737 .67519 .41651 .66189 .42231 .66803 .42293 Metetra
.575 .928 .947 r
.69456 .41163 .68855 .41049 .67519 .41651 .68126 .41737 Metetra
.593 .93 .956 r
.70792 .40578 .70197 .40433 .68855 .41049 .69456 .41163 Metetra
.606 .93 .964 r
.72135 .39988 .71546 .39811 .70197 .40433 .70792 .40578 Metetra
.616 .927 .97 r
.73485 .39399 .72902 .39188 .71546 .39811 .72135 .39988 Metetra
.621 .922 .975 r
.74842 .38816 .74265 .3857 .72902 .39188 .73485 .39399 Metetra
.624 .915 .98 r
.76207 .38243 .75636 .37964 .74265 .3857 .74842 .38816 Metetra
.624 .908 .983 r
.77579 .37686 .77015 .37374 .75636 .37964 .76207 .38243 Metetra
.621 .899 .986 r
.7896 .37148 .78401 .36805 .77015 .37374 .77579 .37686 Metetra
.616 .89 .989 r
.8035 .36633 .79797 .36261 .78401 .36805 .7896 .37148 Metetra
.608 .88 .991 r
.81749 .36145 .81202 .35746 .79797 .36261 .8035 .36633 Metetra
.599 .87 .993 r
.83157 .35686 .82616 .35263 .81202 .35746 .81749 .36145 Metetra
.588 .86 .995 r
.84576 .35259 .84041 .34816 .82616 .35263 .83157 .35686 Metetra
.575 .851 .996 r
.86004 .34866 .85476 .34406 .84041 .34816 .84576 .35259 Metetra
.56 .841 .997 r
.87444 .34509 .86922 .34035 .85476 .34406 .86004 .34866 Metetra
.543 .831 .998 r
.88895 .34189 .8838 .33705 .86922 .34035 .87444 .34509 Metetra
.525 .821 .999 r
.90358 .33906 .8985 .33418 .8838 .33705 .88895 .34189 Metetra
.557 .81 .993 r
.29212 .32311 .28463 .31888 .27385 .32118 .28137 .32538 Metetra
.557 .81 .993 r
.30293 .32083 .29548 .31657 .28463 .31888 .29212 .32311 Metetra
.557 .81 .993 r
.3138 .31853 .30638 .31425 .29548 .31657 .30293 .32083 Metetra
.557 .81 .993 r
.32473 .31622 .31735 .31191 .30638 .31425 .3138 .31853 Metetra
.557 .81 .993 r
.33572 .31389 .32838 .30957 .31735 .31191 .32473 .31622 Metetra
.557 .81 .993 r
.34678 .31155 .33947 .3072 .32838 .30957 .33572 .31389 Metetra
.557 .81 .993 r
.35789 .3092 .35063 .30483 .33947 .3072 .34678 .31155 Metetra
.557 .81 .993 r
.36907 .30684 .36184 .30244 .35063 .30483 .35789 .3092 Metetra
.557 .81 .993 r
.38032 .30446 .37313 .30004 .36184 .30244 .36907 .30684 Metetra
.454 .679 .961 r
.39156 .30491 .38448 .29762 .37313 .30004 .38032 .30446 Metetra
0 .084 .608 r
.40233 .32843 .39576 .30051 .38448 .29762 .39156 .30491 Metetra
0 .095 .626 r
.41333 .34955 .40664 .32518 .39576 .30051 .40233 .32843 Metetra
0 .111 .646 r
.42454 .36835 .41775 .34726 .40664 .32518 .41333 .34955 Metetra
0 .133 .67 r
.43594 .38493 .42908 .36684 .41775 .34726 .42454 .36835 Metetra
0 .162 .697 r
.44751 .39938 .44061 .38401 .42908 .36684 .43594 .38493 Metetra
0 .199 .728 r
.45926 .4118 .45232 .39888 .44061 .38401 .44751 .39938 Metetra
0 .245 .759 r
.47115 .42229 .4642 .41157 .45232 .39888 .45926 .4118 Metetra
0 .3 .791 r
.48319 .43096 .47624 .4222 .4642 .41157 .47115 .42229 Metetra
0 .363 .819 r
.49536 .43792 .48842 .43087 .47624 .4222 .48319 .43096 Metetra
0 .43 .842 r
.50765 .44328 .50073 .43772 .48842 .43087 .49536 .43792 Metetra
0 .498 .858 r
.52005 .44716 .51316 .44287 .50073 .43772 .50765 .44328 Metetra
.041 .564 .867 r
.53255 .44965 .52571 .44643 .51316 .44287 .52005 .44716 Metetra
.094 .624 .87 r
.54514 .45088 .53835 .44855 .52571 .44643 .53255 .44965 Metetra
.151 .678 .871 r
.55783 .45095 .55109 .44933 .53835 .44855 .54514 .45088 Metetra
.208 .726 .871 r
.57059 .44997 .56391 .44891 .55109 .44933 .55783 .45095 Metetra
.264 .767 .873 r
.58343 .44805 .57681 .44739 .56391 .44891 .57059 .44997 Metetra
.318 .804 .877 r
.59634 .44529 .58979 .44491 .57681 .44739 .58343 .44805 Metetra
.369 .835 .883 r
.60933 .4418 .60284 .44157 .58979 .44491 .59634 .44529 Metetra
.415 .862 .891 r
.62237 .43766 .61595 .43749 .60284 .44157 .60933 .4418 Metetra
.458 .884 .901 r
.63548 .43297 .62913 .43277 .61595 .43749 .62237 .43766 Metetra
.496 .903 .911 r
.64866 .42783 .64237 .42751 .62913 .43277 .63548 .43297 Metetra
.53 .917 .922 r
.66189 .42231 .65567 .42181 .64237 .42751 .64866 .42783 Metetra
.558 .927 .932 r
.67519 .41651 .66904 .41577 .65567 .42181 .66189 .42231 Metetra
.582 .933 .942 r
.68855 .41049 .68246 .40948 .66904 .41577 .67519 .41651 Metetra
.601 .936 .951 r
.70197 .40433 .69595 .40301 .68246 .40948 .68855 .41049 Metetra
.615 .936 .959 r
.71546 .39811 .70951 .39645 .69595 .40301 .70197 .40433 Metetra
.625 .933 .966 r
.72902 .39188 .72313 .38987 .70951 .39645 .71546 .39811 Metetra
.632 .928 .972 r
.74265 .3857 .73682 .38334 .72313 .38987 .72902 .39188 Metetra
.635 .922 .976 r
.75636 .37964 .75059 .37692 .73682 .38334 .74265 .3857 Metetra
.634 .914 .981 r
.77015 .37374 .76443 .37067 .75059 .37692 .75636 .37964 Metetra
.631 .905 .984 r
.78401 .36805 .77836 .36465 .76443 .37067 .77015 .37374 Metetra
.625 .895 .987 r
.79797 .36261 .79237 .3589 .77836 .36465 .78401 .36805 Metetra
.617 .885 .989 r
.81202 .35746 .80648 .35346 .79237 .3589 .79797 .36261 Metetra
.607 .875 .992 r
.82616 .35263 .82068 .34838 .80648 .35346 .81202 .35746 Metetra
.595 .864 .994 r
.84041 .34816 .83499 .34369 .82068 .34838 .82616 .35263 Metetra
.58 .853 .995 r
.85476 .34406 .84941 .33941 .83499 .34369 .84041 .34816 Metetra
.564 .843 .997 r
.86922 .34035 .86394 .33556 .84941 .33941 .85476 .34406 Metetra
.546 .832 .998 r
.8838 .33705 .87858 .33217 .86394 .33556 .86922 .34035 Metetra
.526 .822 .999 r
.8985 .33418 .89336 .32924 .87858 .33217 .8838 .33705 Metetra
.557 .81 .993 r
.28463 .31888 .27707 .31461 .26625 .31693 .27385 .32118 Metetra
.557 .81 .993 r
.29548 .31657 .28795 .31227 .27707 .31461 .28463 .31888 Metetra
.557 .81 .993 r
.30638 .31425 .29889 .30993 .28795 .31227 .29548 .31657 Metetra
.557 .81 .993 r
.31735 .31191 .30989 .30757 .29889 .30993 .30638 .31425 Metetra
.557 .81 .993 r
.32838 .30957 .32096 .30519 .30989 .30757 .31735 .31191 Metetra
.557 .81 .993 r
.33947 .3072 .33209 .30281 .32096 .30519 .32838 .30957 Metetra
.557 .81 .993 r
.35063 .30483 .34328 .30041 .33209 .30281 .33947 .3072 Metetra
.557 .81 .993 r
.36184 .30244 .35454 .29799 .34328 .30041 .35063 .30483 Metetra
.557 .81 .993 r
.37313 .30004 .36586 .29556 .35454 .29799 .36184 .30244 Metetra
.557 .81 .993 r
.38448 .29762 .37725 .29312 .36586 .29556 .37313 .30004 Metetra
.372 .572 .916 r
.39576 .30051 .3887 .29066 .37725 .29312 .38448 .29762 Metetra
0 .062 .595 r
.40664 .32518 .40002 .29679 .3887 .29066 .39576 .30051 Metetra
0 .073 .612 r
.41775 .34726 .41101 .32257 .40002 .29679 .40664 .32518 Metetra
0 .09 .633 r
.42908 .36684 .42224 .34555 .41101 .32257 .41775 .34726 Metetra
0 .113 .658 r
.44061 .38401 .4337 .36584 .42224 .34555 .42908 .36684 Metetra
0 .144 .686 r
.45232 .39888 .44536 .38353 .4337 .36584 .44061 .38401 Metetra
0 .185 .718 r
.4642 .41157 .45721 .39876 .44536 .38353 .45232 .39888 Metetra
0 .235 .752 r
.47624 .4222 .46923 .41165 .45721 .39876 .4642 .41157 Metetra
0 .296 .786 r
.48842 .43087 .48142 .42232 .46923 .41165 .47624 .4222 Metetra
0 .365 .816 r
.50073 .43772 .49374 .43091 .48142 .42232 .48842 .43087 Metetra
0 .438 .841 r
.51316 .44287 .5062 .43756 .49374 .43091 .50073 .43772 Metetra
0 .512 .858 r
.52571 .44643 .51878 .4424 .5062 .43756 .51316 .44287 Metetra
.056 .582 .868 r
.53835 .44855 .53147 .44558 .51878 .4424 .52571 .44643 Metetra
.118 .646 .873 r
.55109 .44933 .54426 .44723 .53147 .44558 .53835 .44855 Metetra
.18 .702 .874 r
.56391 .44891 .55715 .4475 .54426 .44723 .55109 .44933 Metetra
.242 .751 .876 r
.57681 .44739 .57011 .4465 .55715 .4475 .56391 .44891 Metetra
.302 .793 .878 r
.58979 .44491 .58315 .44439 .57011 .4465 .57681 .44739 Metetra
.357 .828 .883 r
.60284 .44157 .59627 .44129 .58315 .44439 .58979 .44491 Metetra
.409 .858 .889 r
.61595 .43749 .60945 .43732 .59627 .44129 .60284 .44157 Metetra
.455 .883 .898 r
.62913 .43277 .6227 .43261 .60945 .43732 .61595 .43749 Metetra
.497 .903 .907 r
.64237 .42751 .63601 .42727 .6227 .43261 .62913 .43277 Metetra
.533 .919 .917 r
.65567 .42181 .64938 .42142 .63601 .42727 .64237 .42751 Metetra
.563 .93 .927 r
.66904 .41577 .66281 .41515 .64938 .42142 .65567 .42181 Metetra
.589 .937 .937 r
.68246 .40948 .6763 .40858 .66281 .41515 .66904 .41577 Metetra
.609 .941 .946 r
.69595 .40301 .68986 .4018 .6763 .40858 .68246 .40948 Metetra
.625 .941 .954 r
.70951 .39645 .70347 .3949 .68986 .4018 .69595 .40301 Metetra
.636 .939 .961 r
.72313 .38987 .71716 .38795 .70347 .3949 .70951 .39645 Metetra
.643 .934 .968 r
.73682 .38334 .73091 .38105 .71716 .38795 .72313 .38987 Metetra
.646 .928 .973 r
.75059 .37692 .74474 .37426 .73091 .38105 .73682 .38334 Metetra
.645 .92 .977 r
.76443 .37067 .75865 .36765 .74474 .37426 .75059 .37692 Metetra
.642 .91 .981 r
.77836 .36465 .77263 .36128 .75865 .36765 .76443 .37067 Metetra
.635 .9 .985 r
.79237 .3589 .78671 .3552 .77263 .36128 .77836 .36465 Metetra
.626 .89 .988 r
.80648 .35346 .80087 .34946 .78671 .3552 .79237 .3589 Metetra
.615 .879 .99 r
.82068 .34838 .81514 .34411 .80087 .34946 .80648 .35346 Metetra
.602 .868 .993 r
.83499 .34369 .82951 .33919 .81514 .34411 .82068 .34838 Metetra
.586 .856 .995 r
.84941 .33941 .84399 .33471 .82951 .33919 .83499 .34369 Metetra
.569 .845 .996 r
.86394 .33556 .85859 .33072 .84399 .33471 .84941 .33941 Metetra
.549 .834 .998 r
.87858 .33217 .8733 .32722 .85859 .33072 .86394 .33556 Metetra
.527 .822 .999 r
.89336 .32924 .88815 .32423 .8733 .32722 .87858 .33217 Metetra
.557 .81 .993 r
.27707 .31461 .26943 .31029 .25857 .31263 .26625 .31693 Metetra
.557 .81 .993 r
.28795 .31227 .28034 .30793 .26943 .31029 .27707 .31461 Metetra
.557 .81 .993 r
.29889 .30993 .29132 .30556 .28034 .30793 .28795 .31227 Metetra
.557 .81 .993 r
.30989 .30757 .30236 .30317 .29132 .30556 .29889 .30993 Metetra
.557 .81 .993 r
.32096 .30519 .31346 .30078 .30236 .30317 .30989 .30757 Metetra
.557 .81 .993 r
.33209 .30281 .32463 .29836 .31346 .30078 .32096 .30519 Metetra
.557 .81 .993 r
.34328 .30041 .33586 .29594 .32463 .29836 .33209 .30281 Metetra
.557 .81 .993 r
.35454 .29799 .34715 .2935 .33586 .29594 .34328 .30041 Metetra
.557 .81 .993 r
.36586 .29556 .35852 .29104 .34715 .2935 .35454 .29799 Metetra
.557 .81 .993 r
.37725 .29312 .36994 .28857 .35852 .29104 .36586 .29556 Metetra
.557 .81 .993 r
.3887 .29066 .38144 .28609 .36994 .28857 .37725 .29312 Metetra
.281 .452 .852 r
.40002 .29679 .393 .28359 .38144 .28609 .3887 .29066 Metetra
0 .04 .581 r
.41101 .32257 .40434 .29374 .393 .28359 .40002 .29679 Metetra
0 .053 .599 r
.42224 .34555 .41545 .32058 .40434 .29374 .41101 .32257 Metetra
0 .07 .62 r
.4337 .36584 .42681 .3444 .41545 .32058 .42224 .34555 Metetra
0 .096 .646 r
.44536 .38353 .4384 .36532 .42681 .3444 .4337 .36584 Metetra
0 .13 .677 r
.45721 .39876 .4502 .38346 .4384 .36532 .44536 .38353 Metetra
0 .174 .711 r
.46923 .41165 .46219 .39896 .4502 .38346 .45721 .39876 Metetra
0 .23 .747 r
.48142 .42232 .47437 .41195 .46219 .39896 .46923 .41165 Metetra
0 .297 .784 r
.49374 .43091 .4867 .42257 .47437 .41195 .48142 .42232 Metetra
0 .373 .818 r
.5062 .43756 .49918 .43099 .4867 .42257 .49374 .43091 Metetra
0 .453 .844 r
.51878 .4424 .51179 .43735 .49918 .43099 .5062 .43756 Metetra
.017 .533 .863 r
.53147 .44558 .52452 .4418 .51179 .43735 .51878 .4424 Metetra
.082 .607 .874 r
.54426 .44723 .53736 .4445 .52452 .4418 .53147 .44558 Metetra
.15 .674 .879 r
.55715 .4475 .55029 .4456 .53736 .4445 .54426 .44723 Metetra
.219 .731 .881 r
.57011 .4465 .56332 .44527 .55029 .4456 .55715 .4475 Metetra
.284 .78 .883 r
.58315 .44439 .57643 .44364 .56332 .44527 .57011 .4465 Metetra
.345 .82 .886 r
.59627 .44129 .58961 .44086 .57643 .44364 .58315 .44439 Metetra
.402 .854 .891 r
.60945 .43732 .60286 .43709 .58961 .44086 .59627 .44129 Metetra
.452 .882 .897 r
.6227 .43261 .61618 .43244 .60286 .43709 .60945 .43732 Metetra
.497 .904 .905 r
.63601 .42727 .62956 .42707 .61618 .43244 .6227 .43261 Metetra
.536 .921 .914 r
.64938 .42142 .643 .42109 .62956 .42707 .63601 .42727 Metetra
.569 .934 .923 r
.66281 .41515 .6565 .41462 .643 .42109 .64938 .42142 Metetra
.597 .942 .933 r
.6763 .40858 .67006 .40779 .6565 .41462 .66281 .41515 Metetra
.618 .946 .941 r
.68986 .4018 .68369 .40069 .67006 .40779 .6763 .40858 Metetra
.635 .947 .95 r
.70347 .3949 .69737 .39344 .68369 .40069 .68986 .4018 Metetra
.647 .945 .957 r
.71716 .38795 .71112 .38613 .69737 .39344 .70347 .3949 Metetra
.654 .94 .963 r
.73091 .38105 .72494 .37884 .71112 .38613 .71716 .38795 Metetra
.657 .934 .969 r
.74474 .37426 .73882 .37167 .72494 .37884 .73091 .38105 Metetra
.656 .926 .974 r
.75865 .36765 .75279 .36467 .73882 .37167 .74474 .37426 Metetra
.652 .916 .978 r
.77263 .36128 .76684 .35794 .75279 .36467 .75865 .36765 Metetra
.646 .906 .982 r
.78671 .3552 .78097 .35151 .76684 .35794 .77263 .36128 Metetra
.636 .895 .986 r
.80087 .34946 .7952 .34546 .78097 .35151 .78671 .3552 Metetra
.624 .883 .989 r
.81514 .34411 .80953 .33982 .7952 .34546 .80087 .34946 Metetra
.609 .872 .991 r
.82951 .33919 .82396 .33465 .80953 .33982 .81514 .34411 Metetra
.592 .86 .994 r
.84399 .33471 .83851 .32997 .82396 .33465 .82951 .33919 Metetra
.573 .847 .996 r
.85859 .33072 .85317 .32582 .83851 .32997 .84399 .33471 Metetra
.552 .835 .998 r
.8733 .32722 .86796 .32221 .85317 .32582 .85859 .33072 Metetra
.528 .823 .999 r
.88815 .32423 .88288 .31917 .86796 .32221 .8733 .32722 Metetra
.557 .81 .993 r
.26943 .31029 .2617 .30593 .25082 .3083 .25857 .31263 Metetra
.557 .81 .993 r
.28034 .30793 .27265 .30354 .2617 .30593 .26943 .31029 Metetra
.557 .81 .993 r
.29132 .30556 .28366 .30115 .27265 .30354 .28034 .30793 Metetra
.557 .81 .993 r
.30236 .30317 .29474 .29874 .28366 .30115 .29132 .30556 Metetra
.557 .81 .993 r
.31346 .30078 .30588 .29631 .29474 .29874 .30236 .30317 Metetra
.557 .81 .993 r
.32463 .29836 .31709 .29387 .30588 .29631 .31346 .30078 Metetra
.557 .81 .993 r
.33586 .29594 .32835 .29142 .31709 .29387 .32463 .29836 Metetra
.557 .81 .993 r
.34715 .2935 .33969 .28895 .32835 .29142 .33586 .29594 Metetra
.557 .81 .993 r
.35852 .29104 .35109 .28647 .33969 .28895 .34715 .2935 Metetra
.557 .81 .993 r
.36994 .28857 .36256 .28398 .35109 .28647 .35852 .29104 Metetra
.557 .81 .993 r
.38144 .28609 .37409 .28146 .36256 .28398 .36994 .28857 Metetra
.557 .81 .993 r
.393 .28359 .3857 .27894 .37409 .28146 .38144 .28609 Metetra
.196 .337 .781 r
.40434 .29374 .39737 .2764 .3857 .27894 .393 .28359 Metetra
0 .021 .568 r
.41545 .32058 .40872 .29134 .39737 .2764 .40434 .29374 Metetra
0 .034 .586 r
.42681 .3444 .41996 .31917 .40872 .29134 .41545 .32058 Metetra
0 .053 .609 r
.4384 .36532 .43145 .34376 .41996 .31917 .42681 .3444 Metetra
0 .081 .636 r
.4502 .38346 .44318 .36524 .43145 .34376 .4384 .36532 Metetra
0 .118 .669 r
.46219 .39896 .45513 .38373 .44318 .36524 .4502 .38346 Metetra
0 .168 .706 r
.47437 .41195 .46727 .3994 .45513 .38373 .46219 .39896 Metetra
0 .23 .746 r
.4867 .42257 .4796 .41239 .46727 .3994 .47437 .41195 Metetra
0 .304 .786 r
.49918 .43099 .49208 .42287 .4796 .41239 .4867 .42257 Metetra
0 .388 .823 r
.51179 .43735 .50472 .43101 .49208 .42287 .49918 .43099 Metetra
0 .475 .853 r
.52452 .4418 .51748 .43697 .50472 .43101 .51179 .43735 Metetra
.045 .561 .873 r
.53736 .4445 .53037 .44094 .51748 .43697 .52452 .4418 Metetra
.118 .639 .885 r
.55029 .4456 .54336 .44307 .53037 .44094 .53736 .4445 Metetra
.193 .707 .89 r
.56332 .44527 .55644 .44355 .54336 .44307 .55029 .4456 Metetra
.265 .764 .892 r
.57643 .44364 .56961 .44254 .55644 .44355 .56332 .44527 Metetra
.333 .811 .894 r
.58961 .44086 .58286 .4402 .56961 .44254 .57643 .44364 Metetra
.395 .849 .896 r
.60286 .43709 .59618 .4367 .58286 .4402 .58961 .44086 Metetra
.45 .88 .9 r
.61618 .43244 .60957 .4322 .59618 .4367 .60286 .43709 Metetra
.498 .904 .906 r
.62956 .42707 .62303 .42685 .60957 .4322 .61618 .43244 Metetra
.54 .923 .913 r
.643 .42109 .63654 .42078 .62303 .42685 .62956 .42707 Metetra
.575 .937 .921 r
.6565 .41462 .65011 .41414 .63654 .42078 .643 .42109 Metetra
.605 .946 .929 r
.67006 .40779 .66374 .40706 .65011 .41414 .6565 .41462 Metetra
.628 .951 .937 r
.68369 .40069 .67743 .39967 .66374 .40706 .67006 .40779 Metetra
.645 .952 .945 r
.69737 .39344 .69119 .39207 .67743 .39967 .68369 .40069 Metetra
.658 .95 .952 r
.71112 .38613 .705 .38438 .69119 .39207 .69737 .39344 Metetra
.665 .946 .959 r
.72494 .37884 .71888 .37671 .705 .38438 .71112 .38613 Metetra
.669 .939 .965 r
.73882 .37167 .73284 .36913 .71888 .37671 .72494 .37884 Metetra
.668 .931 .97 r
.75279 .36467 .74686 .36174 .73284 .36913 .73882 .37167 Metetra
.664 .922 .975 r
.76684 .35794 .76097 .35462 .74686 .36174 .75279 .36467 Metetra
.656 .911 .979 r
.78097 .35151 .77517 .34783 .76097 .35462 .76684 .35794 Metetra
.646 .9 .983 r
.7952 .34546 .78946 .34144 .77517 .34783 .78097 .35151 Metetra
.633 .888 .987 r
.80953 .33982 .80385 .33551 .78946 .34144 .7952 .34546 Metetra
.617 .875 .99 r
.82396 .33465 .81835 .33008 .80385 .33551 .80953 .33982 Metetra
.599 .863 .993 r
.83851 .32997 .83296 .32518 .81835 .33008 .82396 .33465 Metetra
.578 .85 .995 r
.85317 .32582 .84769 .32086 .83296 .32518 .83851 .32997 Metetra
.555 .837 .998 r
.86796 .32221 .86255 .31714 .84769 .32086 .85317 .32582 Metetra
.529 .823 .999 r
.88288 .31917 .87754 .31404 .86255 .31714 .86796 .32221 Metetra
.557 .81 .993 r
.2617 .30593 .2539 .30152 .24297 .30391 .25082 .3083 Metetra
.557 .81 .993 r
.27265 .30354 .26488 .29911 .2539 .30152 .2617 .30593 Metetra
.557 .81 .993 r
.28366 .30115 .27593 .29668 .26488 .29911 .27265 .30354 Metetra
.557 .81 .993 r
.29474 .29874 .28704 .29425 .27593 .29668 .28366 .30115 Metetra
.557 .81 .993 r
.30588 .29631 .29822 .2918 .28704 .29425 .29474 .29874 Metetra
.557 .81 .993 r
.31709 .29387 .30946 .28933 .29822 .2918 .30588 .29631 Metetra
.557 .81 .993 r
.32835 .29142 .32077 .28685 .30946 .28933 .31709 .29387 Metetra
.557 .81 .993 r
.33969 .28895 .33214 .28436 .32077 .28685 .32835 .29142 Metetra
.557 .81 .993 r
.35109 .28647 .34359 .28185 .33214 .28436 .33969 .28895 Metetra
.557 .81 .993 r
.36256 .28398 .35509 .27933 .34359 .28185 .35109 .28647 Metetra
.557 .81 .993 r
.37409 .28146 .36667 .27679 .35509 .27933 .36256 .28398 Metetra
.557 .81 .993 r
.3857 .27894 .37832 .27424 .36667 .27679 .37409 .28146 Metetra
.557 .81 .993 r
.39737 .2764 .39003 .27167 .37832 .27424 .3857 .27894 Metetra
.123 .239 .712 r
.40872 .29134 .40181 .26909 .39003 .27167 .39737 .2764 Metetra
0 .002 .556 r
.41996 .31917 .41317 .28957 .40181 .26909 .40872 .29134 Metetra
0 .017 .575 r
.43145 .34376 .42454 .31831 .41317 .28957 .41996 .31917 Metetra
0 .039 .599 r
.44318 .36524 .43618 .34358 .42454 .31831 .43145 .34376 Metetra
0 .069 .629 r
.45513 .38373 .44805 .36551 .43618 .34358 .44318 .36524 Metetra
0 .111 .664 r
.46727 .3994 .46015 .38426 .44805 .36551 .45513 .38373 Metetra
0 .166 .705 r
.4796 .41239 .47245 .39999 .46015 .38426 .46727 .3994 Metetra
0 .235 .749 r
.49208 .42287 .48494 .41288 .47245 .39999 .4796 .41239 Metetra
0 .318 .794 r
.50472 .43101 .49758 .4231 .48494 .41288 .49208 .42287 Metetra
0 .41 .834 r
.51748 .43697 .51037 .43086 .49758 .4231 .50472 .43101 Metetra
.007 .504 .866 r
.53037 .44094 .52329 .43632 .51037 .43086 .51748 .43697 Metetra
.084 .595 .887 r
.54336 .44307 .53633 .4397 .52329 .43632 .53037 .44094 Metetra
.165 .675 .899 r
.55644 .44355 .54947 .44118 .53633 .4397 .54336 .44307 Metetra
.244 .743 .904 r
.56961 .44254 .56271 .44094 .54947 .44118 .55644 .44355 Metetra
.319 .798 .905 r
.58286 .4402 .57602 .43918 .56271 .44094 .56961 .44254 Metetra
.387 .843 .906 r
.59618 .4367 .58942 .43608 .57602 .43918 .58286 .4402 Metetra
.447 .877 .907 r
.60957 .4322 .60288 .43181 .58942 .43608 .59618 .4367 Metetra
.5 .904 .91 r
.62303 .42685 .6164 .42654 .60288 .43181 .60957 .4322 Metetra
.544 .925 .915 r
.63654 .42078 .62999 .42044 .6164 .42654 .62303 .42685 Metetra
.582 .939 .921 r
.65011 .41414 .64364 .41367 .62999 .42044 .63654 .42078 Metetra
.613 .949 .927 r
.66374 .40706 .65734 .40638 .64364 .41367 .65011 .41414 Metetra
.637 .955 .934 r
.67743 .39967 .6711 .3987 .65734 .40638 .66374 .40706 Metetra
.656 .956 .941 r
.69119 .39207 .68492 .39076 .6711 .3987 .67743 .39967 Metetra
.669 .955 .948 r
.705 .38438 .69881 .3827 .68492 .39076 .69119 .39207 Metetra
.677 .951 .955 r
.71888 .37671 .71275 .37462 .69881 .3827 .705 .38438 Metetra
.68 .944 .961 r
.73284 .36913 .72677 .36664 .71275 .37462 .71888 .37671 Metetra
.68 .936 .966 r
.74686 .36174 .74086 .35884 .72677 .36664 .73284 .36913 Metetra
.675 .927 .972 r
.76097 .35462 .75504 .35132 .74086 .35884 .74686 .36174 Metetra
.667 .916 .976 r
.77517 .34783 .7693 .34415 .75504 .35132 .76097 .35462 Metetra
.656 .904 .981 r
.78946 .34144 .78365 .33742 .7693 .34415 .77517 .34783 Metetra
.642 .892 .985 r
.80385 .33551 .7981 .33117 .78365 .33742 .78946 .34144 Metetra
.625 .879 .988 r
.81835 .33008 .81266 .32546 .7981 .33117 .80385 .33551 Metetra
.606 .866 .992 r
.83296 .32518 .82734 .32035 .81266 .32546 .81835 .33008 Metetra
.583 .852 .995 r
.84769 .32086 .84214 .31585 .82734 .32035 .83296 .32518 Metetra
.558 .838 .997 r
.86255 .31714 .85707 .31201 .84214 .31585 .84769 .32086 Metetra
.53 .824 .999 r
.87754 .31404 .87213 .30884 .85707 .31201 .86255 .31714 Metetra
.557 .81 .993 r
.2539 .30152 .24601 .29706 .23505 .29948 .24297 .30391 Metetra
.557 .81 .993 r
.26488 .29911 .25703 .29462 .24601 .29706 .2539 .30152 Metetra
.557 .81 .993 r
.27593 .29668 .26811 .29218 .25703 .29462 .26488 .29911 Metetra
.557 .81 .993 r
.28704 .29425 .27926 .28971 .26811 .29218 .27593 .29668 Metetra
.557 .81 .993 r
.29822 .2918 .29048 .28724 .27926 .28971 .28704 .29425 Metetra
.557 .81 .993 r
.30946 .28933 .30176 .28475 .29048 .28724 .29822 .2918 Metetra
.557 .81 .993 r
.32077 .28685 .31311 .28224 .30176 .28475 .30946 .28933 Metetra
.557 .81 .993 r
.33214 .28436 .32452 .27972 .31311 .28224 .32077 .28685 Metetra
.557 .81 .993 r
.34359 .28185 .336 .27718 .32452 .27972 .33214 .28436 Metetra
.557 .81 .993 r
.35509 .27933 .34755 .27463 .336 .27718 .34359 .28185 Metetra
.557 .81 .993 r
.36667 .27679 .35917 .27207 .34755 .27463 .35509 .27933 Metetra
.557 .81 .993 r
.37832 .27424 .37085 .26948 .35917 .27207 .36667 .27679 Metetra
.557 .81 .993 r
.39003 .27167 .38261 .26689 .37085 .26948 .37832 .27424 Metetra
.557 .81 .993 r
.40181 .26909 .39443 .26428 .38261 .26689 .39003 .27167 Metetra
.064 .159 .653 r
.41317 .28957 .40633 .26165 .39443 .26428 .40181 .26909 Metetra
0 0 .545 r
.42454 .31831 .4177 .28838 .40633 .26165 .41317 .28957 Metetra
0 .003 .566 r
.43618 .34358 .42921 .31794 .4177 .28838 .42454 .31831 Metetra
0 .027 .592 r
.44805 .36551 .44099 .34378 .42921 .31794 .43618 .34358 Metetra
0 .062 .624 r
.46015 .38426 .45302 .36606 .44099 .34378 .44805 .36551 Metetra
0 .109 .662 r
.47245 .39999 .46528 .38494 .45302 .36606 .46015 .38426 Metetra
0 .17 .707 r
.48494 .41288 .47774 .40062 .46528 .38494 .47245 .39999 Metetra
0 .248 .757 r
.49758 .4231 .49038 .41329 .47774 .40062 .48494 .41288 Metetra
0 .339 .806 r
.51037 .43086 .50319 .42314 .49038 .41329 .49758 .4231 Metetra
0 .439 .85 r
.52329 .43632 .51614 .4304 .50319 .42314 .51037 .43086 Metetra
.047 .541 .884 r
.53633 .4397 .52922 .43527 .51614 .4304 .52329 .43632 Metetra
.133 .635 .906 r
.54947 .44118 .54242 .43796 .52922 .43527 .53633 .4397 Metetra
.22 .716 .916 r
.56271 .44094 .55571 .43869 .54242 .43796 .54947 .44118 Metetra
.303 .782 .919 r
.57602 .43918 .56909 .43766 .55571 .43869 .56271 .44094 Metetra
.378 .834 .919 r
.58942 .43608 .58255 .43508 .56909 .43766 .57602 .43918 Metetra
.444 .873 .918 r
.60288 .43181 .59609 .43115 .58255 .43508 .58942 .43608 Metetra
.501 .904 .918 r
.6164 .42654 .60969 .42607 .59609 .43115 .60288 .43181 Metetra
.549 .926 .919 r
.62999 .42044 .62335 .42001 .60969 .42607 .6164 .42654 Metetra
.589 .942 .922 r
.64364 .41367 .63707 .41316 .62335 .42001 .62999 .42044 Metetra
.622 .952 .927 r
.65734 .40638 .65085 .40568 .63707 .41316 .64364 .41367 Metetra
.647 .958 .932 r
.6711 .3987 .66469 .39774 .65085 .40568 .65734 .40638 Metetra
.667 .96 .938 r
.68492 .39076 .67858 .38949 .66469 .39774 .6711 .3987 Metetra
.68 .959 .944 r
.69881 .3827 .69253 .38106 .67858 .38949 .68492 .39076 Metetra
.689 .955 .95 r
.71275 .37462 .70655 .37258 .69253 .38106 .69881 .3827 Metetra
.692 .949 .957 r
.72677 .36664 .72063 .36418 .70655 .37258 .71275 .37462 Metetra
.692 .941 .962 r
.74086 .35884 .73479 .35596 .72063 .36418 .72677 .36664 Metetra
.687 .931 .968 r
.75504 .35132 .74902 .34803 .73479 .35596 .74086 .35884 Metetra
.678 .921 .973 r
.7693 .34415 .76335 .34047 .74902 .34803 .75504 .35132 Metetra
.667 .909 .978 r
.78365 .33742 .77776 .33337 .76335 .34047 .7693 .34415 Metetra
.652 .896 .982 r
.7981 .33117 .79228 .3268 .77776 .33337 .78365 .33742 Metetra
.634 .883 .987 r
.81266 .32546 .8069 .32081 .79228 .3268 .7981 .33117 Metetra
.613 .869 .991 r
.82734 .32035 .82165 .31546 .8069 .32081 .81266 .32546 Metetra
.589 .855 .994 r
.84214 .31585 .83651 .31078 .82165 .31546 .82734 .32035 Metetra
.562 .84 .997 r
.85707 .31201 .85152 .30682 .83651 .31078 .84214 .31585 Metetra
.532 .824 .999 r
.87213 .30884 .86666 .30358 .85152 .30682 .85707 .31201 Metetra
.557 .81 .993 r
.24601 .29706 .23803 .29255 .22704 .295 .23505 .29948 Metetra
.557 .81 .993 r
.25703 .29462 .24909 .29009 .23803 .29255 .24601 .29706 Metetra
.557 .81 .993 r
.26811 .29218 .26021 .28762 .24909 .29009 .25703 .29462 Metetra
.557 .81 .993 r
.27926 .28971 .2714 .28513 .26021 .28762 .26811 .29218 Metetra
.557 .81 .993 r
.29048 .28724 .28265 .28263 .2714 .28513 .27926 .28971 Metetra
.557 .81 .993 r
.30176 .28475 .29397 .28011 .28265 .28263 .29048 .28724 Metetra
.557 .81 .993 r
.31311 .28224 .30536 .27757 .29397 .28011 .30176 .28475 Metetra
.557 .81 .993 r
.32452 .27972 .31681 .27503 .30536 .27757 .31311 .28224 Metetra
.557 .81 .993 r
.336 .27718 .32833 .27246 .31681 .27503 .32452 .27972 Metetra
.557 .81 .993 r
.34755 .27463 .33992 .26988 .32833 .27246 .336 .27718 Metetra
.557 .81 .993 r
.35917 .27207 .35158 .26729 .33992 .26988 .34755 .27463 Metetra
.557 .81 .993 r
.37085 .26948 .36331 .26468 .35158 .26729 .35917 .27207 Metetra
.557 .81 .993 r
.38261 .26689 .3751 .26205 .36331 .26468 .37085 .26948 Metetra
.557 .81 .993 r
.39443 .26428 .38697 .25941 .3751 .26205 .38261 .26689 Metetra
.557 .81 .993 r
.40633 .26165 .39892 .25676 .38697 .25941 .39443 .26428 Metetra
.018 .096 .603 r
.4177 .28838 .41093 .25408 .39892 .25676 .40633 .26165 Metetra
0 0 .536 r
.42921 .31794 .4223 .2877 .41093 .25408 .4177 .28838 Metetra
0 0 .558 r
.44099 .34378 .43396 .31797 .4223 .2877 .42921 .31794 Metetra
0 .019 .586 r
.45302 .36606 .44589 .34427 .43396 .31797 .44099 .34378 Metetra
0 .059 .622 r
.46528 .38494 .45809 .36677 .44589 .34427 .45302 .36606 Metetra
0 .112 .665 r
.47774 .40062 .47051 .38567 .45809 .36677 .46528 .38494 Metetra
0 .181 .715 r
.49038 .41329 .48314 .40117 .47051 .38567 .47774 .40062 Metetra
0 .267 .769 r
.50319 .42314 .49595 .41349 .48314 .40117 .49038 .41329 Metetra
0 .368 .824 r
.51614 .4304 .50892 .42285 .49595 .41349 .50319 .42314 Metetra
.01 .477 .871 r
.52922 .43527 .52203 .4295 .50892 .42285 .51614 .4304 Metetra
.099 .583 .906 r
.54242 .43796 .53527 .43366 .52203 .4295 .52922 .43527 Metetra
.193 .679 .927 r
.55571 .43869 .54862 .43557 .53527 .43366 .54242 .43796 Metetra
.284 .758 .935 r
.56909 .43766 .56207 .43546 .54862 .43557 .55571 .43869 Metetra
.367 .82 .935 r
.58255 .43508 .5756 .43357 .56207 .43546 .56909 .43766 Metetra
.44 .867 .932 r
.59609 .43115 .58921 .43012 .5756 .43357 .58255 .43508 Metetra
.502 .901 .929 r
.60969 .42607 .60288 .42532 .58921 .43012 .59609 .43115 Metetra
.554 .926 .927 r
.62335 .42001 .61662 .41939 .60288 .42532 .60969 .42607 Metetra
.596 .943 .927 r
.63707 .41316 .63042 .41253 .61662 .41939 .62335 .42001 Metetra
.631 .955 .928 r
.65085 .40568 .64427 .40493 .63042 .41253 .63707 .41316 Metetra
.658 .961 .931 r
.66469 .39774 .65818 .39676 .64427 .40493 .65085 .40568 Metetra
.678 .964 .936 r
.67858 .38949 .67215 .38821 .65818 .39676 .66469 .39774 Metetra
.692 .963 .941 r
.69253 .38106 .68617 .37942 .67215 .38821 .67858 .38949 Metetra
.701 .959 .946 r
.70655 .37258 .70026 .37055 .68617 .37942 .69253 .38106 Metetra
.704 .953 .952 r
.72063 .36418 .71441 .36173 .70026 .37055 .70655 .37258 Metetra
.703 .945 .958 r
.73479 .35596 .72863 .35309 .71441 .36173 .72063 .36418 Metetra
.698 .936 .964 r
.74902 .34803 .74294 .34474 .72863 .35309 .73479 .35596 Metetra
.69 .925 .969 r
.76335 .34047 .75732 .33679 .74294 .34474 .74902 .34803 Metetra
.677 .913 .975 r
.77776 .33337 .7718 .32931 .75732 .33679 .76335 .34047 Metetra
.661 .9 .98 r
.79228 .3268 .78638 .3224 .7718 .32931 .77776 .33337 Metetra
.642 .887 .985 r
.8069 .32081 .80108 .31611 .78638 .3224 .79228 .3268 Metetra
.62 .873 .989 r
.82165 .31546 .81588 .31052 .80108 .31611 .8069 .32081 Metetra
.594 .858 .993 r
.83651 .31078 .83082 .30565 .81588 .31052 .82165 .31546 Metetra
.565 .842 .997 r
.85152 .30682 .8459 .30156 .83082 .30565 .83651 .31078 Metetra
.533 .825 .999 r
.86666 .30358 .86111 .29825 .8459 .30156 .85152 .30682 Metetra
.557 .81 .993 r
.23803 .29255 .22997 .288 .21895 .29047 .22704 .295 Metetra
.557 .81 .993 r
.24909 .29009 .24107 .28551 .22997 .288 .23803 .29255 Metetra
.557 .81 .993 r
.26021 .28762 .25223 .28301 .24107 .28551 .24909 .29009 Metetra
.557 .81 .993 r
.2714 .28513 .26345 .2805 .25223 .28301 .26021 .28762 Metetra
.557 .81 .993 r
.28265 .28263 .27474 .27796 .26345 .2805 .2714 .28513 Metetra
.557 .81 .993 r
.29397 .28011 .2861 .27542 .27474 .27796 .28265 .28263 Metetra
.557 .81 .993 r
.30536 .27757 .29752 .27286 .2861 .27542 .29397 .28011 Metetra
.557 .81 .993 r
.31681 .27503 .30901 .27028 .29752 .27286 .30536 .27757 Metetra
.557 .81 .993 r
.32833 .27246 .32058 .26769 .30901 .27028 .31681 .27503 Metetra
.557 .81 .993 r
.33992 .26988 .33221 .26508 .32058 .26769 .32833 .27246 Metetra
.557 .81 .993 r
.35158 .26729 .34391 .26246 .33221 .26508 .33992 .26988 Metetra
.557 .81 .993 r
.36331 .26468 .35568 .25982 .34391 .26246 .35158 .26729 Metetra
.557 .81 .993 r
.3751 .26205 .36752 .25717 .35568 .25982 .36331 .26468 Metetra
.557 .81 .993 r
.38697 .25941 .37943 .25449 .36752 .25717 .3751 .26205 Metetra
.557 .81 .993 r
.39892 .25676 .39142 .25181 .37943 .25449 .38697 .25941 Metetra
.557 .81 .993 r
.41093 .25408 .40348 .2491 .39142 .25181 .39892 .25676 Metetra
0 0 .521 r
.4223 .2877 .41548 .25218 .40348 .2491 .41093 .25408 Metetra
0 0 .528 r
.43396 .31797 .42698 .28745 .41548 .25218 .4223 .2877 Metetra
0 0 .553 r
.44589 .34427 .4388 .31831 .42698 .28745 .43396 .31797 Metetra
0 .016 .584 r
.45809 .36677 .4509 .34494 .4388 .31831 .44589 .34427 Metetra
0 .06 .623 r
.47051 .38567 .46326 .36753 .4509 .34494 .45809 .36677 Metetra
0 .12 .671 r
.48314 .40117 .47585 .3863 .46326 .36753 .47051 .38567 Metetra
0 .198 .727 r
.49595 .41349 .48865 .40149 .47585 .3863 .48314 .40117 Metetra
0 .294 .787 r
.50892 .42285 .50163 .41333 .48865 .40149 .49595 .41349 Metetra
0 .404 .846 r
.52203 .4295 .51476 .42209 .50163 .41333 .50892 .42285 Metetra
.063 .52 .896 r
.53527 .43366 .52804 .42801 .51476 .42209 .52203 .4295 Metetra
.162 .63 .93 r
.54862 .43557 .54144 .43136 .52804 .42801 .53527 .43366 Metetra
.261 .725 .948 r
.56207 .43546 .55495 .43239 .54144 .43136 .54862 .43557 Metetra
.353 .8 .952 r
.5756 .43357 .56855 .43138 .55495 .43239 .56207 .43546 Metetra
.433 .856 .949 r
.58921 .43012 .58223 .42856 .56855 .43138 .5756 .43357 Metetra
.501 .896 .943 r
.60288 .42532 .59598 .42418 .58223 .42856 .58921 .43012 Metetra
.557 .925 .938 r
.61662 .41939 .60979 .41849 .59598 .42418 .60288 .42532 Metetra
.603 .944 .934 r
.63042 .41253 .62367 .4117 .60979 .41849 .61662 .41939 Metetra
.639 .956 .932 r
.64427 .40493 .6376 .40403 .62367 .4117 .63042 .41253 Metetra
.667 .963 .932 r
.65818 .39676 .65159 .39569 .6376 .40403 .64427 .40493 Metetra
.689 .966 .935 r
.67215 .38821 .66563 .38688 .65159 .39569 .65818 .39676 Metetra
.703 .965 .938 r
.68617 .37942 .67973 .37776 .66563 .38688 .67215 .38821 Metetra
.712 .962 .943 r
.70026 .37055 .69388 .36851 .67973 .37776 .68617 .37942 Metetra
.716 .956 .948 r
.71441 .36173 .70811 .35928 .69388 .36851 .70026 .37055 Metetra
.715 .949 .954 r
.72863 .35309 .7224 .35022 .70811 .35928 .71441 .36173 Metetra
.71 .939 .96 r
.74294 .34474 .73677 .34144 .7224 .35022 .72863 .35309 Metetra
.701 .929 .966 r
.75732 .33679 .75122 .33308 .73677 .34144 .74294 .34474 Metetra
.688 .917 .972 r
.7718 .32931 .76577 .32522 .75122 .33308 .75732 .33679 Metetra
.671 .904 .977 r
.78638 .3224 .78041 .31796 .76577 .32522 .7718 .32931 Metetra
.651 .89 .983 r
.80108 .31611 .79517 .31137 .78041 .31796 .78638 .3224 Metetra
.627 .876 .988 r
.81588 .31052 .81005 .30552 .79517 .31137 .80108 .31611 Metetra
.6 .86 .993 r
.83082 .30565 .82506 .30046 .81005 .30552 .81588 .31052 Metetra
.569 .844 .996 r
.8459 .30156 .8402 .29623 .82506 .30046 .83082 .30565 Metetra
.534 .826 .999 r
.86111 .29825 .8555 .29286 .8402 .29623 .8459 .30156 Metetra
.557 .81 .993 r
.22997 .288 .22183 .2834 .21076 .2859 .21895 .29047 Metetra
.557 .81 .993 r
.24107 .28551 .23296 .28088 .22183 .2834 .22997 .288 Metetra
.557 .81 .993 r
.25223 .28301 .24415 .27835 .23296 .28088 .24107 .28551 Metetra
.557 .81 .993 r
.26345 .2805 .25541 .27581 .24415 .27835 .25223 .28301 Metetra
.557 .81 .993 r
.27474 .27796 .26674 .27325 .25541 .27581 .26345 .2805 Metetra
.557 .81 .993 r
.2861 .27542 .27814 .27068 .26674 .27325 .27474 .27796 Metetra
.557 .81 .993 r
.29752 .27286 .2896 .26809 .27814 .27068 .2861 .27542 Metetra
.557 .81 .993 r
.30901 .27028 .30113 .26548 .2896 .26809 .29752 .27286 Metetra
.557 .81 .993 r
.32058 .26769 .31273 .26286 .30113 .26548 .30901 .27028 Metetra
.557 .81 .993 r
.33221 .26508 .32441 .26023 .31273 .26286 .32058 .26769 Metetra
.557 .81 .993 r
.34391 .26246 .33615 .25757 .32441 .26023 .33221 .26508 Metetra
.557 .81 .993 r
.35568 .25982 .34796 .25491 .33615 .25757 .34391 .26246 Metetra
.557 .81 .993 r
.36752 .25717 .35985 .25222 .34796 .25491 .35568 .25982 Metetra
.557 .81 .993 r
.37943 .25449 .3718 .24952 .35985 .25222 .36752 .25717 Metetra
.557 .81 .993 r
.39142 .25181 .38383 .2468 .3718 .24952 .37943 .25449 Metetra
.557 .81 .993 r
.40348 .2491 .39594 .24407 .38383 .2468 .39142 .25181 Metetra
.363 .563 .912 r
.41548 .25218 .40811 .24132 .39594 .24407 .40348 .2491 Metetra
0 0 .502 r
.42698 .28745 .4201 .25153 .40811 .24132 .41548 .25218 Metetra
0 0 .523 r
.4388 .31831 .43176 .28753 .4201 .25153 .42698 .28745 Metetra
0 0 .55 r
.4509 .34494 .44374 .31884 .43176 .28753 .4388 .31831 Metetra
0 .016 .585 r
.46326 .36753 .45601 .34565 .44374 .31884 .4509 .34494 Metetra
0 .067 .629 r
.47585 .3863 .46854 .36819 .45601 .34565 .46326 .36753 Metetra
0 .135 .682 r
.48865 .40149 .4813 .3867 .46854 .36819 .47585 .3863 Metetra
0 .222 .744 r
.50163 .41333 .49428 .40143 .4813 .3867 .48865 .40149 Metetra
0 .328 .81 r
.51476 .42209 .50743 .41267 .49428 .40143 .50163 .41333 Metetra
.027 .447 .872 r
.52804 .42801 .52073 .42068 .50743 .41267 .51476 .42209 Metetra
.126 .569 .922 r
.54144 .43136 .53418 .42577 .52073 .42068 .52804 .42801 Metetra
.232 .679 .954 r
.55495 .43239 .54774 .42821 .53418 .42577 .54144 .43136 Metetra
.334 .77 .967 r
.56855 .43138 .5614 .42829 .54774 .42821 .55495 .43239 Metetra
.423 .838 .967 r
.58223 .42856 .57515 .42629 .5614 .42829 .56855 .43138 Metetra
.498 .887 .96 r
.59598 .42418 .58898 .4225 .57515 .42629 .58223 .42856 Metetra
.56 .92 .951 r
.60979 .41849 .60287 .41717 .58898 .4225 .59598 .42418 Metetra
.609 .942 .943 r
.62367 .4117 .61682 .41056 .60287 .41717 .60979 .41849 Metetra
.647 .956 .938 r
.6376 .40403 .63083 .40291 .61682 .41056 .62367 .4117 Metetra
.677 .964 .935 r
.65159 .39569 .6449 .39447 .63083 .40291 .6376 .40403 Metetra
.699 .967 .935 r
.66563 .38688 .65902 .38544 .6449 .39447 .65159 .39569 Metetra
.714 .967 .936 r
.67973 .37776 .67319 .37602 .65902 .38544 .66563 .38688 Metetra
.723 .964 .94 r
.69388 .36851 .68742 .36642 .67319 .37602 .67973 .37776 Metetra
.727 .959 .944 r
.70811 .35928 .70172 .35679 .68742 .36642 .69388 .36851 Metetra
.727 .952 .95 r
.7224 .35022 .71608 .34731 .70172 .35679 .70811 .35928 Metetra
.721 .943 .955 r
.73677 .34144 .73052 .33812 .71608 .34731 .7224 .35022 Metetra
.712 .932 .962 r
.75122 .33308 .74504 .32934 .73052 .33812 .73677 .34144 Metetra
.698 .921 .968 r
.76577 .32522 .75965 .32109 .74504 .32934 .75122 .33308 Metetra
.681 .908 .974 r
.78041 .31796 .77437 .31347 .75965 .32109 .76577 .32522 Metetra
.66 .894 .981 r
.79517 .31137 .78919 .30657 .77437 .31347 .78041 .31796 Metetra
.635 .879 .986 r
.81005 .30552 .80414 .30047 .78919 .30657 .79517 .31137 Metetra
.606 .863 .992 r
.82506 .30046 .81922 .2952 .80414 .30047 .81005 .30552 Metetra
.573 .845 .996 r
.8402 .29623 .83444 .29084 .81922 .2952 .82506 .30046 Metetra
.536 .826 .999 r
.8555 .29286 .84981 .28739 .83444 .29084 .8402 .29623 Metetra
.557 .81 .993 r
.22183 .2834 .21359 .27874 .20249 .28127 .21076 .2859 Metetra
.557 .81 .993 r
.23296 .28088 .22476 .2762 .21359 .27874 .22183 .2834 Metetra
.557 .81 .993 r
.24415 .27835 .23599 .27365 .22476 .2762 .23296 .28088 Metetra
.557 .81 .993 r
.25541 .27581 .24729 .27108 .23599 .27365 .24415 .27835 Metetra
.557 .81 .993 r
.26674 .27325 .25866 .26849 .24729 .27108 .25541 .27581 Metetra
.557 .81 .993 r
.27814 .27068 .27009 .26589 .25866 .26849 .26674 .27325 Metetra
.557 .81 .993 r
.2896 .26809 .28159 .26327 .27009 .26589 .27814 .27068 Metetra
.557 .81 .993 r
.30113 .26548 .29317 .26063 .28159 .26327 .2896 .26809 Metetra
.557 .81 .993 r
.31273 .26286 .30481 .25798 .29317 .26063 .30113 .26548 Metetra
.557 .81 .993 r
.32441 .26023 .31652 .25532 .30481 .25798 .31273 .26286 Metetra
.557 .81 .993 r
.33615 .25757 .3283 .25264 .31652 .25532 .32441 .26023 Metetra
.557 .81 .993 r
.34796 .25491 .34016 .24994 .3283 .25264 .33615 .25757 Metetra
.557 .81 .993 r
.35985 .25222 .35209 .24722 .34016 .24994 .34796 .25491 Metetra
.557 .81 .993 r
.3718 .24952 .36409 .24449 .35209 .24722 .35985 .25222 Metetra
.557 .81 .993 r
.38383 .2468 .37616 .24174 .36409 .24449 .3718 .24952 Metetra
.557 .81 .993 r
.39594 .24407 .38831 .23898 .37616 .24174 .38383 .2468 Metetra
.557 .81 .993 r
.40811 .24132 .40053 .2362 .38831 .23898 .39594 .24407 Metetra
.195 .34 .784 r
.4201 .25153 .41283 .2334 .40053 .2362 .40811 .24132 Metetra
0 0 .497 r
.43176 .28753 .42481 .25122 .41283 .2334 .4201 .25153 Metetra
0 0 .52 r
.44374 .31884 .43663 .2878 .42481 .25122 .43176 .28753 Metetra
0 0 .55 r
.45601 .34565 .44878 .31941 .43663 .2878 .44374 .31884 Metetra
0 .022 .589 r
.46854 .36819 .46122 .34625 .44878 .31941 .45601 .34565 Metetra
0 .079 .638 r
.4813 .3867 .47394 .36859 .46122 .34625 .46854 .36819 Metetra
0 .156 .697 r
.49428 .40143 .48688 .38668 .47394 .36859 .4813 .3867 Metetra
0 .253 .765 r
.50743 .41267 .50003 .40082 .48688 .38668 .49428 .40143 Metetra
0 .369 .835 r
.52073 .42068 .51335 .41132 .50003 .40082 .50743 .41267 Metetra
.089 .495 .9 r
.53418 .42577 .52683 .41848 .51335 .41132 .52073 .42068 Metetra
.198 .619 .948 r
.54774 .42821 .54044 .42262 .52683 .41848 .53418 .42577 Metetra
.308 .726 .975 r
.5614 .42829 .55416 .42406 .54044 .42262 .54774 .42821 Metetra
.407 .81 .982 r
.57515 .42629 .56797 .42312 .55416 .42406 .5614 .42829 Metetra
.492 .871 .977 r
.58898 .4225 .58187 .42009 .56797 .42312 .57515 .42629 Metetra
.559 .911 .966 r
.60287 .41717 .59584 .41529 .58187 .42009 .58898 .4225 Metetra
.613 .937 .955 r
.61682 .41056 .60988 .40899 .59584 .41529 .60287 .41717 Metetra
.654 .954 .946 r
.63083 .40291 .62397 .40147 .60988 .40899 .61682 .41056 Metetra
.685 .963 .94 r
.6449 .39447 .63812 .393 .62397 .40147 .63083 .40291 Metetra
.708 .967 .936 r
.65902 .38544 .65231 .38382 .63812 .393 .6449 .39447 Metetra
.724 .967 .936 r
.67319 .37602 .66657 .37416 .65231 .38382 .65902 .38544 Metetra
.734 .965 .937 r
.68742 .36642 .68087 .36423 .66657 .37416 .67319 .37602 Metetra
.738 .96 .941 r
.70172 .35679 .69524 .35423 .68087 .36423 .68742 .36642 Metetra
.738 .953 .946 r
.71608 .34731 .70968 .34435 .69524 .35423 .70172 .35679 Metetra
.732 .945 .951 r
.73052 .33812 .72419 .33474 .70968 .34435 .71608 .34731 Metetra
.723 .935 .958 r
.74504 .32934 .73878 .32555 .72419 .33474 .73052 .33812 Metetra
.709 .924 .964 r
.75965 .32109 .75346 .31691 .73878 .32555 .74504 .32934 Metetra
.691 .911 .971 r
.77437 .31347 .76824 .30893 .75346 .31691 .75965 .32109 Metetra
.669 .897 .978 r
.78919 .30657 .78314 .30172 .76824 .30893 .77437 .31347 Metetra
.642 .882 .985 r
.80414 .30047 .79815 .29535 .78314 .30172 .78919 .30657 Metetra
.612 .865 .991 r
.81922 .2952 .8133 .28988 .79815 .29535 .80414 .30047 Metetra
.577 .847 .995 r
.83444 .29084 .8286 .28537 .8133 .28988 .81922 .2952 Metetra
.537 .827 .999 r
.84981 .28739 .84405 .28185 .8286 .28537 .83444 .29084 Metetra
.557 .81 .993 r
.21359 .27874 .20527 .27404 .19413 .2766 .20249 .28127 Metetra
.557 .81 .993 r
.22476 .2762 .21647 .27147 .20527 .27404 .21359 .27874 Metetra
.557 .81 .993 r
.23599 .27365 .22774 .26889 .21647 .27147 .22476 .2762 Metetra
.557 .81 .993 r
.24729 .27108 .23908 .26629 .22774 .26889 .23599 .27365 Metetra
.557 .81 .993 r
.25866 .26849 .25048 .26367 .23908 .26629 .24729 .27108 Metetra
.557 .81 .993 r
.27009 .26589 .26195 .26104 .25048 .26367 .25866 .26849 Metetra
.557 .81 .993 r
.28159 .26327 .2735 .25839 .26195 .26104 .27009 .26589 Metetra
.557 .81 .993 r
.29317 .26063 .28511 .25573 .2735 .25839 .28159 .26327 Metetra
.557 .81 .993 r
.30481 .25798 .29679 .25305 .28511 .25573 .29317 .26063 Metetra
.557 .81 .993 r
.31652 .25532 .30854 .25035 .29679 .25305 .30481 .25798 Metetra
.557 .81 .993 r
.3283 .25264 .32037 .24764 .30854 .25035 .31652 .25532 Metetra
.557 .81 .993 r
.34016 .24994 .33227 .24491 .32037 .24764 .3283 .25264 Metetra
.557 .81 .993 r
.35209 .24722 .34424 .24217 .33227 .24491 .34016 .24994 Metetra
.557 .81 .993 r
.36409 .24449 .35628 .2394 .34424 .24217 .35209 .24722 Metetra
.557 .81 .993 r
.37616 .24174 .3684 .23662 .35628 .2394 .36409 .24449 Metetra
.557 .81 .993 r
.38831 .23898 .3806 .23383 .3684 .23662 .37616 .24174 Metetra
.557 .81 .993 r
.40053 .2362 .39287 .23101 .3806 .23383 .38831 .23898 Metetra
.557 .81 .993 r
.41283 .2334 .40522 .22818 .39287 .23101 .40053 .2362 Metetra
.089 .197 .683 r
.42481 .25122 .41764 .22533 .40522 .22818 .41283 .2334 Metetra
0 0 .494 r
.43663 .2878 .42961 .25112 .41764 .22533 .42481 .25122 Metetra
0 0 .519 r
.44878 .31941 .4416 .28813 .42961 .25112 .43663 .2878 Metetra
0 0 .553 r
.46122 .34625 .45393 .31987 .4416 .28813 .44878 .31941 Metetra
0 .032 .597 r
.47394 .36859 .46656 .34659 .45393 .31987 .46122 .34625 Metetra
0 .098 .651 r
.48688 .38668 .47945 .36855 .46656 .34659 .47394 .36859 Metetra
0 .183 .716 r
.50003 .40082 .49257 .38608 .47945 .36855 .48688 .38668 Metetra
0 .29 .789 r
.51335 .41132 .5059 .39949 .49257 .38608 .50003 .40082 Metetra
.051 .414 .863 r
.52683 .41848 .5194 .40912 .5059 .39949 .51335 .41132 Metetra
.16 .545 .926 r
.54044 .42262 .53305 .41531 .5194 .40912 .52683 .41848 Metetra
.275 .668 .97 r
.55416 .42406 .54682 .41841 .53305 .41531 .54044 .42262 Metetra
.384 .769 .99 r
.56797 .42312 .5607 .41878 .54682 .41841 .55416 .42406 Metetra
.479 .844 .991 r
.58187 .42009 .57467 .41675 .5607 .41878 .56797 .42312 Metetra
.555 .895 .981 r
.59584 .41529 .58872 .41266 .57467 .41675 .58187 .42009 Metetra
.614 .928 .968 r
.60988 .40899 .60283 .40684 .58872 .41266 .59584 .41529 Metetra
.659 .948 .956 r
.62397 .40147 .617 .39958 .60283 .40684 .60988 .40899 Metetra
.692 .959 .946 r
.63812 .393 .63123 .39119 .617 .39958 .62397 .40147 Metetra
.717 .965 .939 r
.65231 .38382 .64551 .38194 .63123 .39119 .63812 .393 Metetra
.734 .966 .936 r
.66657 .37416 .65985 .37209 .64551 .38194 .65231 .38382 Metetra
.744 .965 .936 r
.68087 .36423 .67423 .36189 .65985 .37209 .66657 .37416 Metetra
.748 .96 .938 r
.69524 .35423 .68868 .35156 .67423 .36189 .68087 .36423 Metetra
.748 .954 .942 r
.70968 .34435 .70319 .34129 .68868 .35156 .69524 .35423 Metetra
.743 .946 .947 r
.72419 .33474 .71777 .33128 .70319 .34129 .70968 .34435 Metetra
.733 .937 .954 r
.73878 .32555 .73243 .32169 .71777 .33128 .72419 .33474 Metetra
.719 .926 .961 r
.75346 .31691 .74718 .31266 .73243 .32169 .73878 .32555 Metetra
.7 .914 .968 r
.76824 .30893 .76203 .30433 .74718 .31266 .75346 .31691 Metetra
.677 .9 .976 r
.78314 .30172 .777 .2968 .76203 .30433 .76824 .30893 Metetra
.65 .885 .983 r
.79815 .29535 .79209 .29016 .777 .2968 .78314 .30172 Metetra
.618 .868 .99 r
.8133 .28988 .80731 .28449 .79209 .29016 .79815 .29535 Metetra
.581 .849 .995 r
.8286 .28537 .82268 .27984 .80731 .28449 .8133 .28988 Metetra
.538 .828 .999 r
.84405 .28185 .83821 .27624 .82268 .27984 .8286 .28537 Metetra
.557 .81 .993 r
.20527 .27404 .19685 .26929 .18568 .27187 .19413 .2766 Metetra
.557 .81 .993 r
.21647 .27147 .20809 .26669 .19685 .26929 .20527 .27404 Metetra
.557 .81 .993 r
.22774 .26889 .2194 .26407 .20809 .26669 .21647 .27147 Metetra
.557 .81 .993 r
.23908 .26629 .23077 .26145 .2194 .26407 .22774 .26889 Metetra
.557 .81 .993 r
.25048 .26367 .24221 .2588 .23077 .26145 .23908 .26629 Metetra
.557 .81 .993 r
.26195 .26104 .25373 .25614 .24221 .2588 .25048 .26367 Metetra
.557 .81 .993 r
.2735 .25839 .26531 .25346 .25373 .25614 .26195 .26104 Metetra
.557 .81 .993 r
.28511 .25573 .27696 .25077 .26531 .25346 .2735 .25839 Metetra
.557 .81 .993 r
.29679 .25305 .28868 .24806 .27696 .25077 .28511 .25573 Metetra
.557 .81 .993 r
.30854 .25035 .30048 .24533 .28868 .24806 .29679 .25305 Metetra
.557 .81 .993 r
.32037 .24764 .31235 .24259 .30048 .24533 .30854 .25035 Metetra
.557 .81 .993 r
.33227 .24491 .32429 .23983 .31235 .24259 .32037 .24764 Metetra
.557 .81 .993 r
.34424 .24217 .3363 .23705 .32429 .23983 .33227 .24491 Metetra
.557 .81 .993 r
.35628 .2394 .34839 .23426 .3363 .23705 .34424 .24217 Metetra
.557 .81 .993 r
.3684 .23662 .36056 .23145 .34839 .23426 .35628 .2394 Metetra
.557 .81 .993 r
.3806 .23383 .3728 .22862 .36056 .23145 .3684 .23662 Metetra
.557 .81 .993 r
.39287 .23101 .38511 .22577 .3728 .22862 .3806 .23383 Metetra
.557 .81 .993 r
.40522 .22818 .39751 .22291 .38511 .22577 .39287 .23101 Metetra
.557 .81 .993 r
.41764 .22533 .40998 .22002 .39751 .22291 .40522 .22818 Metetra
.022 .106 .613 r
.42961 .25112 .42253 .21712 .40998 .22002 .41764 .22533 Metetra
0 0 .493 r
.4416 .28813 .43451 .25108 .42253 .21712 .42961 .25112 Metetra
0 0 .522 r
.45393 .31987 .44668 .28835 .43451 .25108 .4416 .28813 Metetra
0 0 .56 r
.46656 .34659 .45919 .32005 .44668 .28835 .45393 .31987 Metetra
0 .048 .608 r
.47945 .36855 .47201 .34647 .45919 .32005 .46656 .34659 Metetra
0 .121 .668 r
.49257 .38608 .48509 .36791 .47201 .34647 .47945 .36855 Metetra
0 .216 .739 r
.5059 .39949 .4984 .38472 .48509 .36791 .49257 .38608 Metetra
.016 .332 .816 r
.5194 .40912 .5119 .39725 .4984 .38472 .5059 .39949 Metetra
.119 .463 .89 r
.53305 .41531 .52558 .40589 .5119 .39725 .5194 .40912 Metetra
.236 .595 .949 r
.54682 .41841 .53939 .41101 .52558 .40589 .53305 .41531 Metetra
.353 .712 .986 r
.5607 .41878 .55333 .413 .53939 .41101 .54682 .41841 Metetra
.457 .804 .998 r
.57467 .41675 .56737 .41223 .55333 .413 .5607 .41878 Metetra
.543 .869 .994 r
.58872 .41266 .58149 .40909 .56737 .41223 .57467 .41675 Metetra
.61 .912 .981 r
.60283 .40684 .59568 .40392 .58149 .40909 .58872 .41266 Metetra
.66 .938 .966 r
.617 .39958 .60994 .39708 .59568 .40392 .60283 .40684 Metetra
.697 .953 .953 r
.63123 .39119 .62425 .3889 .60994 .39708 .617 .39958 Metetra
.723 .96 .944 r
.64551 .38194 .63861 .37969 .62425 .3889 .63123 .39119 Metetra
.741 .963 .938 r
.65985 .37209 .65303 .36975 .63861 .37969 .64551 .38194 Metetra
.752 .963 .935 r
.67423 .36189 .66749 .35934 .65303 .36975 .65985 .37209 Metetra
.757 .959 .936 r
.68868 .35156 .68202 .34871 .66749 .35934 .67423 .36189 Metetra
.757 .954 .939 r
.70319 .34129 .69661 .3381 .68202 .34871 .68868 .35156 Metetra
.752 .947 .943 r
.71777 .33128 .71126 .32772 .69661 .3381 .70319 .34129 Metetra
.742 .938 .95 r
.73243 .32169 .726 .31774 .71126 .32772 .71777 .33128 Metetra
.728 .928 .957 r
.74718 .31266 .74082 .30834 .726 .31774 .73243 .32169 Metetra
.709 .916 .965 r
.76203 .30433 .75575 .29965 .74082 .30834 .74718 .31266 Metetra
.686 .903 .973 r
.777 .2968 .77078 .29181 .75575 .29965 .76203 .30433 Metetra
.657 .887 .981 r
.79209 .29016 .78594 .2849 .77078 .29181 .777 .2968 Metetra
.623 .87 .989 r
.80731 .28449 .80124 .27902 .78594 .2849 .79209 .29016 Metetra
.584 .851 .995 r
.82268 .27984 .81669 .27423 .80124 .27902 .80731 .28449 Metetra
.54 .828 .999 r
.83821 .27624 .8323 .27056 .81669 .27423 .82268 .27984 Metetra
.557 .81 .993 r
.19685 .26929 .18834 .26448 .17713 .26709 .18568 .27187 Metetra
.557 .81 .993 r
.20809 .26669 .19962 .26185 .18834 .26448 .19685 .26929 Metetra
.557 .81 .993 r
.2194 .26407 .21096 .25921 .19962 .26185 .20809 .26669 Metetra
.557 .81 .993 r
.23077 .26145 .22237 .25655 .21096 .25921 .2194 .26407 Metetra
.557 .81 .993 r
.24221 .2588 .23385 .25388 .22237 .25655 .23077 .26145 Metetra
.557 .81 .993 r
.25373 .25614 .24541 .25119 .23385 .25388 .24221 .2588 Metetra
.557 .81 .993 r
.26531 .25346 .25703 .24848 .24541 .25119 .25373 .25614 Metetra
.557 .81 .993 r
.27696 .25077 .26872 .24575 .25703 .24848 .26531 .25346 Metetra
.557 .81 .993 r
.28868 .24806 .28049 .24301 .26872 .24575 .27696 .25077 Metetra
.557 .81 .993 r
.30048 .24533 .29232 .24026 .28049 .24301 .28868 .24806 Metetra
.557 .81 .993 r
.31235 .24259 .30423 .23748 .29232 .24026 .30048 .24533 Metetra
.557 .81 .993 r
.32429 .23983 .31622 .23469 .30423 .23748 .31235 .24259 Metetra
.557 .81 .993 r
.3363 .23705 .32828 .23188 .31622 .23469 .32429 .23983 Metetra
.557 .81 .993 r
.34839 .23426 .34041 .22906 .32828 .23188 .3363 .23705 Metetra
.557 .81 .993 r
.36056 .23145 .35262 .22621 .34041 .22906 .34839 .23426 Metetra
.557 .81 .993 r
.3728 .22862 .36491 .22335 .35262 .22621 .36056 .23145 Metetra
.557 .81 .993 r
.38511 .22577 .37727 .22047 .36491 .22335 .3728 .22862 Metetra
.557 .81 .993 r
.39751 .22291 .38971 .21757 .37727 .22047 .38511 .22577 Metetra
.557 .81 .993 r
.40998 .22002 .40223 .21465 .38971 .21757 .39751 .22291 Metetra
.557 .81 .993 r
.42253 .21712 .41483 .21172 .40223 .21465 .40998 .22002 Metetra
0 .045 .563 r
.43451 .25108 .42751 .20877 .41483 .21172 .42253 .21712 Metetra
0 0 .494 r
.44668 .28835 .43951 .25094 .42751 .20877 .43451 .25108 Metetra
0 0 .527 r
.45919 .32005 .45187 .28828 .43951 .25094 .44668 .28835 Metetra
0 .006 .569 r
.47201 .34647 .46458 .31976 .45187 .28828 .45919 .32005 Metetra
0 .068 .623 r
.48509 .36791 .47758 .3457 .46458 .31976 .47201 .34647 Metetra
0 .151 .688 r
.4984 .38472 .49085 .36646 .47758 .3457 .48509 .36791 Metetra
0 .255 .763 r
.5119 .39725 .50435 .3824 .49085 .36646 .4984 .38472 Metetra
.078 .378 .841 r
.52558 .40589 .51803 .39394 .50435 .3824 .5119 .39725 Metetra
.192 .512 .913 r
.53939 .41101 .53188 .40148 .51803 .39394 .52558 .40589 Metetra
.312 .641 .966 r
.55333 .413 .54587 .40544 .53188 .40148 .53939 .41101 Metetra
.426 .75 .994 r
.56737 .41223 .55997 .40625 .54587 .40544 .55333 .413 Metetra
.523 .831 1 r
.58149 .40909 .57416 .40431 .55997 .40625 .56737 .41223 Metetra
.599 .886 .991 r
.59568 .40392 .58843 .40004 .57416 .40431 .58149 .40909 Metetra
.656 .921 .976 r
.60994 .39708 .60276 .39381 .58843 .40004 .59568 .40392 Metetra
.698 .941 .961 r
.62425 .3889 .61716 .386 .60276 .39381 .60994 .39708 Metetra
.727 .953 .949 r
.63861 .37969 .63161 .37696 .61716 .386 .62425 .3889 Metetra
.747 .958 .94 r
.65303 .36975 .64611 .36702 .63161 .37696 .63861 .37969 Metetra
.759 .959 .935 r
.66749 .35934 .66066 .35648 .64611 .36702 .65303 .36975 Metetra
.765 .957 .934 r
.68202 .34871 .67526 .34563 .66066 .35648 .66749 .35934 Metetra
.765 .952 .936 r
.69661 .3381 .68993 .33473 .67526 .34563 .68202 .34871 Metetra
.761 .946 .94 r
.71126 .32772 .70466 .324 .68993 .33473 .69661 .3381 Metetra
.751 .938 .946 r
.726 .31774 .71947 .31367 .70466 .324 .71126 .32772 Metetra
.737 .929 .953 r
.74082 .30834 .73437 .30391 .71947 .31367 .726 .31774 Metetra
.718 .918 .962 r
.75575 .29965 .74937 .29488 .73437 .30391 .74082 .30834 Metetra
.694 .905 .971 r
.77078 .29181 .76448 .28673 .74937 .29488 .75575 .29965 Metetra
.664 .89 .979 r
.78594 .2849 .77971 .27957 .76448 .28673 .77078 .29181 Metetra
.629 .872 .987 r
.80124 .27902 .79509 .27348 .77971 .27957 .78594 .2849 Metetra
.588 .852 .994 r
.81669 .27423 .81061 .26855 .79509 .27348 .80124 .27902 Metetra
.541 .829 .998 r
.8323 .27056 .8263 .2648 .81061 .26855 .81669 .27423 Metetra
.557 .81 .993 r
.18834 .26448 .17974 .25962 .16849 .26226 .17713 .26709 Metetra
.557 .81 .993 r
.19962 .26185 .19105 .25696 .17974 .25962 .18834 .26448 Metetra
.557 .81 .993 r
.21096 .25921 .20243 .25429 .19105 .25696 .19962 .26185 Metetra
.557 .81 .993 r
.22237 .25655 .21388 .2516 .20243 .25429 .21096 .25921 Metetra
.557 .81 .993 r
.23385 .25388 .2254 .2489 .21388 .2516 .22237 .25655 Metetra
.557 .81 .993 r
.24541 .25119 .23699 .24617 .2254 .2489 .23385 .25388 Metetra
.557 .81 .993 r
.25703 .24848 .24865 .24344 .23699 .24617 .24541 .25119 Metetra
.557 .81 .993 r
.26872 .24575 .26039 .24068 .24865 .24344 .25703 .24848 Metetra
.557 .81 .993 r
.28049 .24301 .27219 .23791 .26039 .24068 .26872 .24575 Metetra
.557 .81 .993 r
.29232 .24026 .28407 .23512 .27219 .23791 .28049 .24301 Metetra
.557 .81 .993 r
.30423 .23748 .29603 .23231 .28407 .23512 .29232 .24026 Metetra
.557 .81 .993 r
.31622 .23469 .30805 .22949 .29603 .23231 .30423 .23748 Metetra
.557 .81 .993 r
.32828 .23188 .32016 .22665 .30805 .22949 .31622 .23469 Metetra
.557 .81 .993 r
.34041 .22906 .33233 .22379 .32016 .22665 .32828 .23188 Metetra
.557 .81 .993 r
.35262 .22621 .34459 .22091 .33233 .22379 .34041 .22906 Metetra
.557 .81 .993 r
.36491 .22335 .35692 .21802 .34459 .22091 .35262 .22621 Metetra
.557 .81 .993 r
.37727 .22047 .36933 .2151 .35692 .21802 .36491 .22335 Metetra
.557 .81 .993 r
.38971 .21757 .38182 .21217 .36933 .2151 .37727 .22047 Metetra
.557 .81 .993 r
.40223 .21465 .39439 .20922 .38182 .21217 .38971 .21757 Metetra
.557 .81 .993 r
.41483 .21172 .40704 .20625 .39439 .20922 .40223 .21465 Metetra
.557 .81 .993 r
.42751 .20877 .41977 .20326 .40704 .20625 .41483 .21172 Metetra
0 0 .486 r
.43951 .25094 .43246 .20683 .41977 .20326 .42751 .20877 Metetra
0 0 .498 r
.45187 .28828 .44463 .2505 .43246 .20683 .43951 .25094 Metetra
0 0 .535 r
.46458 .31976 .45718 .28773 .44463 .2505 .45187 .28828 Metetra
0 .023 .582 r
.47758 .3457 .47008 .31881 .45718 .28773 .46458 .31976 Metetra
0 .094 .64 r
.49085 .36646 .48328 .3441 .47008 .31881 .47758 .3457 Metetra
0 .184 .71 r
.50435 .3824 .49674 .36401 .48328 .3441 .49085 .36646 Metetra
.04 .296 .787 r
.51803 .39394 .51043 .37895 .49674 .36401 .50435 .3824 Metetra
.146 .425 .865 r
.53188 .40148 .52429 .38937 .51043 .37895 .51803 .39394 Metetra
.266 .558 .931 r
.54587 .40544 .53832 .39572 .52429 .38937 .53188 .40148 Metetra
.386 .68 .976 r
.55997 .40625 .55247 .39847 .53832 .39572 .54587 .40544 Metetra
.493 .779 .995 r
.57416 .40431 .56672 .39806 .55247 .39847 .55997 .40625 Metetra
.58 .849 .995 r
.58843 .40004 .58107 .39494 .56672 .39806 .57416 .40431 Metetra
.646 .896 .984 r
.60276 .39381 .59549 .38955 .58107 .39494 .58843 .40004 Metetra
.694 .924 .969 r
.61716 .386 .60996 .3823 .59549 .38955 .60276 .39381 Metetra
.727 .941 .954 r
.63161 .37696 .6245 .37359 .60996 .3823 .61716 .386 Metetra
.75 .949 .944 r
.64611 .36702 .63908 .36378 .6245 .37359 .63161 .37696 Metetra
.764 .952 .937 r
.66066 .35648 .65372 .35323 .63908 .36378 .64611 .36702 Metetra
.771 .952 .933 r
.67526 .34563 .66841 .34224 .65372 .35323 .66066 .35648 Metetra
.772 .949 .934 r
.68993 .33473 .68316 .3311 .66841 .34224 .67526 .34563 Metetra
.768 .944 .937 r
.70466 .324 .69797 .32009 .68316 .3311 .68993 .33473 Metetra
.759 .938 .943 r
.71947 .31367 .71286 .30944 .69797 .32009 .70466 .324 Metetra
.745 .929 .95 r
.73437 .30391 .72784 .29935 .71286 .30944 .71947 .31367 Metetra
.726 .919 .959 r
.74937 .29488 .74291 .29001 .72784 .29935 .73437 .30391 Metetra
.701 .906 .968 r
.76448 .28673 .75809 .28156 .74291 .29001 .74937 .29488 Metetra
.671 .892 .978 r
.77971 .27957 .7734 .27415 .75809 .28156 .76448 .28673 Metetra
.635 .875 .986 r
.79509 .27348 .78885 .26786 .7734 .27415 .77971 .27957 Metetra
.592 .854 .994 r
.81061 .26855 .80446 .26279 .78885 .26786 .79509 .27348 Metetra
.542 .83 .998 r
.8263 .2648 .82023 .25896 .80446 .26279 .81061 .26855 Metetra
.557 .81 .993 r
.17974 .25962 .17104 .2547 .15975 .25737 .16849 .26226 Metetra
.557 .81 .993 r
.19105 .25696 .18238 .25201 .17104 .2547 .17974 .25962 Metetra
.557 .81 .993 r
.20243 .25429 .1938 .24931 .18238 .25201 .19105 .25696 Metetra
.557 .81 .993 r
.21388 .2516 .20529 .24659 .1938 .24931 .20243 .25429 Metetra
.557 .81 .993 r
.2254 .2489 .21685 .24386 .20529 .24659 .21388 .2516 Metetra
.557 .81 .993 r
.23699 .24617 .22848 .24111 .21685 .24386 .2254 .2489 Metetra
.557 .81 .993 r
.24865 .24344 .24018 .23834 .22848 .24111 .23699 .24617 Metetra
.557 .81 .993 r
.26039 .24068 .25196 .23555 .24018 .23834 .24865 .24344 Metetra
.557 .81 .993 r
.27219 .23791 .26381 .23275 .25196 .23555 .26039 .24068 Metetra
.557 .81 .993 r
.28407 .23512 .27573 .22993 .26381 .23275 .27219 .23791 Metetra
.557 .81 .993 r
.29603 .23231 .28772 .22709 .27573 .22993 .28407 .23512 Metetra
.557 .81 .993 r
.30805 .22949 .29979 .22423 .28772 .22709 .29603 .23231 Metetra
.557 .81 .993 r
.32016 .22665 .31194 .22136 .29979 .22423 .30805 .22949 Metetra
.557 .81 .993 r
.33233 .22379 .32417 .21846 .31194 .22136 .32016 .22665 Metetra
.557 .81 .993 r
.34459 .22091 .33647 .21555 .32417 .21846 .33233 .22379 Metetra
.557 .81 .993 r
.35692 .21802 .34885 .21262 .33647 .21555 .34459 .22091 Metetra
.557 .81 .993 r
.36933 .2151 .3613 .20968 .34885 .21262 .35692 .21802 Metetra
.557 .81 .993 r
.38182 .21217 .37384 .20671 .3613 .20968 .36933 .2151 Metetra
.557 .81 .993 r
.39439 .20922 .38646 .20372 .37384 .20671 .38182 .21217 Metetra
.557 .81 .993 r
.40704 .20625 .39916 .20072 .38646 .20372 .39439 .20922 Metetra
.557 .81 .993 r
.41977 .20326 .41194 .1977 .39916 .20072 .40704 .20625 Metetra
.346 .543 .903 r
.43246 .20683 .4248 .19465 .41194 .1977 .41977 .20326 Metetra
0 0 .474 r
.44463 .2505 .4375 .20591 .4248 .19465 .43246 .20683 Metetra
0 0 .505 r
.45718 .28773 .44986 .24958 .4375 .20591 .44463 .2505 Metetra
0 0 .545 r
.47008 .31881 .46262 .28649 .44986 .24958 .45718 .28773 Metetra
0 .045 .597 r
.48328 .3441 .47572 .31699 .46262 .28649 .47008 .31881 Metetra
0 .123 .659 r
.49674 .36401 .48912 .34147 .47572 .31699 .48328 .3441 Metetra
.006 .222 .732 r
.51043 .37895 .50277 .36039 .48912 .34147 .49674 .36401 Metetra
.102 .34 .81 r
.52429 .38937 .51664 .3742 .50277 .36039 .51043 .37895 Metetra
.216 .47 .884 r
.53832 .39572 .53068 .38341 .51664 .3742 .52429 .38937 Metetra
.337 .599 .943 r
.55247 .39847 .54488 .3885 .53068 .38341 .53832 .39572 Metetra
.453 .712 .979 r
.56672 .39806 .55919 .38998 .54488 .3885 .55247 .39847 Metetra
.551 .799 .991 r
.58107 .39494 .57361 .38834 .55919 .38998 .56672 .39806 Metetra
.627 .86 .986 r
.59549 .38955 .5881 .38407 .57361 .38834 .58107 .39494 Metetra
.683 .899 .974 r
.60996 .3823 .60266 .37761 .5881 .38407 .59549 .38955 Metetra
.723 .923 .96 r
.6245 .37359 .61728 .36942 .60266 .37761 .60996 .3823 Metetra
.749 .936 .947 r
.63908 .36378 .63195 .35991 .61728 .36942 .6245 .37359 Metetra
.766 .943 .938 r
.65372 .35323 .64668 .34947 .63195 .35991 .63908 .36378 Metetra
.775 .945 .934 r
.66841 .34224 .66145 .33844 .64668 .34947 .65372 .35323 Metetra
.777 .944 .932 r
.68316 .3311 .67629 .32717 .66145 .33844 .66841 .34224 Metetra
.774 .941 .935 r
.69797 .32009 .69118 .31593 .67629 .32717 .68316 .3311 Metetra
.766 .936 .94 r
.71286 .30944 .70615 .30501 .69118 .31593 .69797 .32009 Metetra
.752 .928 .947 r
.72784 .29935 .72121 .29463 .70615 .30501 .71286 .30944 Metetra
.733 .919 .956 r
.74291 .29001 .73636 .285 .72121 .29463 .72784 .29935 Metetra
.708 .908 .966 r
.75809 .28156 .75162 .27628 .73636 .285 .74291 .29001 Metetra
.677 .894 .976 r
.7734 .27415 .76701 .26863 .75162 .27628 .75809 .28156 Metetra
.64 .876 .985 r
.78885 .26786 .78254 .26216 .76701 .26863 .7734 .27415 Metetra
.595 .855 .993 r
.80446 .26279 .79822 .25695 .78254 .26216 .78885 .26786 Metetra
.544 .83 .998 r
.82023 .25896 .81408 .25305 .79822 .25695 .80446 .26279 Metetra
.557 .81 .993 r
.17104 .2547 .16224 .24973 .15092 .25243 .15975 .25737 Metetra
.557 .81 .993 r
.18238 .25201 .17362 .24701 .16224 .24973 .17104 .2547 Metetra
.557 .81 .993 r
.1938 .24931 .18508 .24428 .17362 .24701 .18238 .25201 Metetra
.557 .81 .993 r
.20529 .24659 .19661 .24153 .18508 .24428 .1938 .24931 Metetra
.557 .81 .993 r
.21685 .24386 .20821 .23876 .19661 .24153 .20529 .24659 Metetra
.557 .81 .993 r
.22848 .24111 .21988 .23598 .20821 .23876 .21685 .24386 Metetra
.557 .81 .993 r
.24018 .23834 .23162 .23318 .21988 .23598 .22848 .24111 Metetra
.557 .81 .993 r
.25196 .23555 .24343 .23036 .23162 .23318 .24018 .23834 Metetra
.557 .81 .993 r
.26381 .23275 .25532 .22753 .24343 .23036 .25196 .23555 Metetra
.557 .81 .993 r
.27573 .22993 .26729 .22467 .25532 .22753 .26381 .23275 Metetra
.557 .81 .993 r
.28772 .22709 .27933 .2218 .26729 .22467 .27573 .22993 Metetra
.557 .81 .993 r
.29979 .22423 .29144 .21891 .27933 .2218 .28772 .22709 Metetra
.557 .81 .993 r
.31194 .22136 .30363 .216 .29144 .21891 .29979 .22423 Metetra
.557 .81 .993 r
.32417 .21846 .3159 .21308 .30363 .216 .31194 .22136 Metetra
.557 .81 .993 r
.33647 .21555 .32825 .21013 .3159 .21308 .32417 .21846 Metetra
.557 .81 .993 r
.34885 .21262 .34067 .20717 .32825 .21013 .33647 .21555 Metetra
.557 .81 .993 r
.3613 .20968 .35318 .20418 .34067 .20717 .34885 .21262 Metetra
.557 .81 .993 r
.37384 .20671 .36576 .20118 .35318 .20418 .3613 .20968 Metetra
.557 .81 .993 r
.38646 .20372 .37843 .19816 .36576 .20118 .37384 .20671 Metetra
.557 .81 .993 r
.39916 .20072 .39118 .19512 .37843 .19816 .38646 .20372 Metetra
.557 .81 .993 r
.41194 .1977 .40401 .19206 .39118 .19512 .39916 .20072 Metetra
.557 .81 .993 r
.4248 .19465 .41692 .18898 .40401 .19206 .41194 .1977 Metetra
.177 .32 .771 r
.4375 .20591 .42992 .18588 .41692 .18898 .4248 .19465 Metetra
0 0 .479 r
.44986 .24958 .44265 .20451 .42992 .18588 .4375 .20591 Metetra
0 0 .514 r
.46262 .28649 .45522 .24797 .44265 .20451 .44986 .24958 Metetra
0 .004 .558 r
.47572 .31699 .46818 .28437 .45522 .24797 .46262 .28649 Metetra
0 .071 .613 r
.48912 .34147 .48148 .31411 .46818 .28437 .47572 .31699 Metetra
0 .156 .679 r
.50277 .36039 .49508 .33763 .48148 .31411 .48912 .34147 Metetra
.061 .261 .754 r
.51664 .3742 .50892 .35542 .49508 .33763 .50277 .36039 Metetra
.166 .383 .83 r
.53068 .38341 .52298 .36801 .50892 .35542 .51664 .3742 Metetra
.284 .512 .898 r
.54488 .3885 .5372 .37592 .52298 .36801 .53068 .38341 Metetra
.403 .634 .949 r
.55919 .38998 .55156 .37971 .5372 .37592 .54488 .3885 Metetra
.511 .736 .976 r
.57361 .38834 .56604 .37992 .55156 .37971 .55919 .38998 Metetra
.599 .813 .982 r
.5881 .38407 .58061 .37708 .56604 .37992 .57361 .38834 Metetra
.665 .865 .975 r
.60266 .37761 .59525 .37169 .58061 .37708 .5881 .38407 Metetra
.712 .899 .963 r
.61728 .36942 .60995 .36426 .59525 .37169 .60266 .37761 Metetra
.744 .919 .951 r
.63195 .35991 .62472 .35524 .60995 .36426 .61728 .36942 Metetra
.764 .93 .941 r
.64668 .34947 .63953 .34506 .62472 .35524 .63195 .35991 Metetra
.776 .936 .934 r
.66145 .33844 .65439 .33414 .63953 .34506 .64668 .34947 Metetra
.78 .937 .932 r
.67629 .32717 .66931 .32282 .65439 .33414 .66145 .33844 Metetra
.778 .936 .933 r
.69118 .31593 .68429 .31146 .66931 .32282 .67629 .32717 Metetra
.771 .932 .937 r
.70615 .30501 .69935 .30034 .68429 .31146 .69118 .31593 Metetra
.758 .927 .944 r
.72121 .29463 .71448 .28972 .69935 .30034 .70615 .30501 Metetra
.739 .919 .953 r
.73636 .285 .72971 .27984 .71448 .28972 .72121 .29463 Metetra
.714 .908 .963 r
.75162 .27628 .74506 .27088 .72971 .27984 .73636 .285 Metetra
.683 .895 .974 r
.76701 .26863 .76052 .26301 .74506 .27088 .75162 .27628 Metetra
.644 .878 .984 r
.78254 .26216 .77613 .25636 .76052 .26301 .76701 .26863 Metetra
.598 .857 .993 r
.79822 .25695 .7919 .25102 .77613 .25636 .78254 .26216 Metetra
.545 .831 .998 r
.81408 .25305 .80784 .24706 .7919 .25102 .79822 .25695 Metetra
.557 .81 .993 r
.16224 .24973 .15334 .2447 .14198 .24743 .15092 .25243 Metetra
.557 .81 .993 r
.17362 .24701 .16476 .24196 .15334 .2447 .16224 .24973 Metetra
.557 .81 .993 r
.18508 .24428 .17626 .23919 .16476 .24196 .17362 .24701 Metetra
.557 .81 .993 r
.19661 .24153 .18782 .23641 .17626 .23919 .18508 .24428 Metetra
.557 .81 .993 r
.20821 .23876 .19946 .23361 .18782 .23641 .19661 .24153 Metetra
.557 .81 .993 r
.21988 .23598 .21117 .2308 .19946 .23361 .20821 .23876 Metetra
.557 .81 .993 r
.23162 .23318 .22295 .22796 .21117 .2308 .21988 .23598 Metetra
.557 .81 .993 r
.24343 .23036 .23481 .22511 .22295 .22796 .23162 .23318 Metetra
.557 .81 .993 r
.25532 .22753 .24674 .22224 .23481 .22511 .24343 .23036 Metetra
.557 .81 .993 r
.26729 .22467 .25875 .21936 .24674 .22224 .25532 .22753 Metetra
.557 .81 .993 r
.27933 .2218 .27083 .21645 .25875 .21936 .26729 .22467 Metetra
.557 .81 .993 r
.29144 .21891 .28299 .21353 .27083 .21645 .27933 .2218 Metetra
.557 .81 .993 r
.30363 .216 .29522 .21059 .28299 .21353 .29144 .21891 Metetra
.557 .81 .993 r
.3159 .21308 .30754 .20762 .29522 .21059 .30363 .216 Metetra
.557 .81 .993 r
.32825 .21013 .31993 .20465 .30754 .20762 .3159 .21308 Metetra
.557 .81 .993 r
.34067 .20717 .3324 .20165 .31993 .20465 .32825 .21013 Metetra
.557 .81 .993 r
.35318 .20418 .34496 .19863 .3324 .20165 .34067 .20717 Metetra
.557 .81 .993 r
.36576 .20118 .35759 .19559 .34496 .19863 .35318 .20418 Metetra
.557 .81 .993 r
.37843 .19816 .37031 .19253 .35759 .19559 .36576 .20118 Metetra
.557 .81 .993 r
.39118 .19512 .38311 .18945 .37031 .19253 .37843 .19816 Metetra
.557 .81 .993 r
.40401 .19206 .39599 .18636 .38311 .18945 .39118 .19512 Metetra
.557 .81 .993 r
.41692 .18898 .40895 .18324 .39599 .18636 .40401 .19206 Metetra
.557 .81 .993 r
.42992 .18588 .42201 .1801 .40895 .18324 .41692 .18898 Metetra
.081 .19 .679 r
.44265 .20451 .43514 .17694 .42201 .1801 .42992 .18588 Metetra
0 0 .486 r
.45522 .24797 .44792 .20242 .43514 .17694 .44265 .20451 Metetra
0 0 .524 r
.46818 .28437 .4607 .24547 .44792 .20242 .45522 .24797 Metetra
0 .026 .573 r
.48148 .31411 .47387 .28118 .4607 .24547 .46818 .28437 Metetra
0 .099 .631 r
.49508 .33763 .48738 .30999 .47387 .28118 .48148 .31411 Metetra
.024 .191 .699 r
.50892 .35542 .50118 .3324 .48738 .30999 .49508 .33763 Metetra
.118 .301 .773 r
.52298 .36801 .51521 .34896 .50118 .3324 .50892 .35542 Metetra
.229 .424 .846 r
.5372 .37592 .52945 .36023 .51521 .34896 .52298 .36801 Metetra
.347 .549 .907 r
.55156 .37971 .54385 .36682 .52945 .36023 .5372 .37592 Metetra
.461 .662 .949 r
.56604 .37992 .55838 .3693 .54385 .36682 .55156 .37971 Metetra
.559 .754 .968 r
.58061 .37708 .57301 .36826 .55838 .3693 .56604 .37992 Metetra
.636 .821 .971 r
.59525 .37169 .58773 .36426 .57301 .36826 .58061 .37708 Metetra
.693 .866 .964 r
.60995 .36426 .60252 .35786 .58773 .36426 .59525 .37169 Metetra
.732 .895 .953 r
.62472 .35524 .61737 .34957 .60252 .35786 .60995 .36426 Metetra
.758 .913 .943 r
.63953 .34506 .63227 .33986 .61737 .34957 .62472 .35524 Metetra
.773 .923 .936 r
.65439 .33414 .64722 .3292 .63227 .33986 .63953 .34506 Metetra
.78 .928 .932 r
.66931 .32282 .66223 .31798 .64722 .3292 .65439 .33414 Metetra
.78 .929 .932 r
.68429 .31146 .6773 .30659 .66223 .31798 .66931 .32282 Metetra
.774 .928 .935 r
.69935 .30034 .69244 .29535 .6773 .30659 .68429 .31146 Metetra
.762 .924 .942 r
.71448 .28972 .70766 .28457 .69244 .29535 .69935 .30034 Metetra
.744 .917 .951 r
.72971 .27984 .72298 .27449 .70766 .28457 .71448 .28972 Metetra
.719 .908 .961 r
.74506 .27088 .7384 .26533 .72298 .27449 .72971 .27984 Metetra
.687 .895 .972 r
.76052 .26301 .75395 .25728 .7384 .26533 .74506 .27088 Metetra
.648 .879 .983 r
.77613 .25636 .76964 .25047 .75395 .25728 .76052 .26301 Metetra
.601 .858 .992 r
.7919 .25102 .78549 .24502 .76964 .25047 .77613 .25636 Metetra
.546 .832 .998 r
.80784 .24706 .80151 .24098 .78549 .24502 .7919 .25102 Metetra
.557 .81 .993 r
.15334 .2447 .14434 .23962 .13295 .24238 .14198 .24743 Metetra
.557 .81 .993 r
.16476 .24196 .1558 .23684 .14434 .23962 .15334 .2447 Metetra
.557 .81 .993 r
.17626 .23919 .16733 .23404 .1558 .23684 .16476 .24196 Metetra
.557 .81 .993 r
.18782 .23641 .17894 .23123 .16733 .23404 .17626 .23919 Metetra
.557 .81 .993 r
.19946 .23361 .19061 .2284 .17894 .23123 .18782 .23641 Metetra
.557 .81 .993 r
.21117 .2308 .20236 .22555 .19061 .2284 .19946 .23361 Metetra
.557 .81 .993 r
.22295 .22796 .21419 .22269 .20236 .22555 .21117 .2308 Metetra
.557 .81 .993 r
.23481 .22511 .22609 .2198 .21419 .22269 .22295 .22796 Metetra
.557 .81 .993 r
.24674 .22224 .23806 .2169 .22609 .2198 .23481 .22511 Metetra
.557 .81 .993 r
.25875 .21936 .25011 .21398 .23806 .2169 .24674 .22224 Metetra
.557 .81 .993 r
.27083 .21645 .26223 .21104 .25011 .21398 .25875 .21936 Metetra
.557 .81 .993 r
.28299 .21353 .27444 .20808 .26223 .21104 .27083 .21645 Metetra
.557 .81 .993 r
.29522 .21059 .28672 .2051 .27444 .20808 .28299 .21353 Metetra
.557 .81 .993 r
.30754 .20762 .29908 .20211 .28672 .2051 .29522 .21059 Metetra
.557 .81 .993 r
.31993 .20465 .31152 .19909 .29908 .20211 .30754 .20762 Metetra
.557 .81 .993 r
.3324 .20165 .32404 .19606 .31152 .19909 .31993 .20465 Metetra
.557 .81 .993 r
.34496 .19863 .33664 .193 .32404 .19606 .3324 .20165 Metetra
.557 .81 .993 r
.35759 .19559 .34932 .18993 .33664 .193 .34496 .19863 Metetra
.557 .81 .993 r
.37031 .19253 .36209 .18684 .34932 .18993 .35759 .19559 Metetra
.557 .81 .993 r
.38311 .18945 .37493 .18372 .36209 .18684 .37031 .19253 Metetra
.557 .81 .993 r
.39599 .18636 .38787 .18059 .37493 .18372 .38311 .18945 Metetra
.557 .81 .993 r
.40895 .18324 .40089 .17743 .38787 .18059 .39599 .18636 Metetra
.557 .81 .993 r
.42201 .1801 .41399 .17425 .40089 .17743 .40895 .18324 Metetra
.557 .81 .993 r
.43514 .17694 .42718 .17106 .41399 .17425 .42201 .1801 Metetra
.024 .112 .619 r
.44792 .20242 .44046 .16784 .42718 .17106 .43514 .17694 Metetra
0 0 .495 r
.4607 .24547 .45332 .19944 .44046 .16784 .44792 .20242 Metetra
0 0 .537 r
.47387 .28118 .46632 .24189 .45332 .19944 .4607 .24547 Metetra
0 .05 .588 r
.48738 .30999 .4797 .27673 .46632 .24189 .47387 .28118 Metetra
0 .13 .649 r
.50118 .3324 .49341 .30446 .4797 .27673 .48738 .30999 Metetra
.074 .227 .718 r
.51521 .34896 .50741 .32565 .49341 .30446 .50118 .3324 Metetra
.175 .34 .79 r
.52945 .36023 .52163 .34089 .50741 .32565 .51521 .34896 Metetra
.288 .461 .858 r
.54385 .36682 .53605 .35081 .52163 .34089 .52945 .36023 Metetra
.404 .58 .911 r
.55838 .3693 .55062 .35605 .53605 .35081 .54385 .36682 Metetra
.51 .683 .945 r
.57301 .36826 .56531 .35725 .55062 .35605 .55838 .3693 Metetra
.598 .765 .959 r
.58773 .36426 .5801 .35502 .56531 .35725 .57301 .36826 Metetra
.666 .824 .96 r
.60252 .35786 .59497 .34998 .5801 .35502 .58773 .36426 Metetra
.714 .864 .953 r
.61737 .34957 .60991 .34268 .59497 .34998 .60252 .35786 Metetra
.746 .89 .944 r
.63227 .33986 .6249 .33368 .60991 .34268 .61737 .34957 Metetra
.766 .906 .937 r
.64722 .3292 .63994 .32348 .6249 .33368 .63227 .33986 Metetra
.777 .916 .932 r
.66223 .31798 .65504 .31252 .63994 .32348 .64722 .3292 Metetra
.779 .92 .932 r
.6773 .30659 .6702 .30124 .65504 .31252 .66223 .31798 Metetra
.775 .921 .934 r
.69244 .29535 .68543 .29 .6702 .30124 .6773 .30659 Metetra
.764 .92 .94 r
.70766 .28457 .70074 .27913 .68543 .29 .69244 .29535 Metetra
.747 .915 .949 r
.72298 .27449 .71614 .26892 .70074 .27913 .70766 .28457 Metetra
.723 .907 .959 r
.7384 .26533 .73165 .25962 .71614 .26892 .72298 .27449 Metetra
.691 .896 .971 r
.75395 .25728 .74729 .25142 .73165 .25962 .7384 .26533 Metetra
.652 .88 .982 r
.76964 .25047 .76306 .24448 .74729 .25142 .75395 .25728 Metetra
.604 .859 .992 r
.78549 .24502 .77899 .23892 .76306 .24448 .76964 .25047 Metetra
.547 .832 .998 r
.80151 .24098 .7951 .23482 .77899 .23892 .78549 .24502 Metetra
.557 .81 .993 r
.14434 .23962 .13524 .23448 .12381 .23727 .13295 .24238 Metetra
.557 .81 .993 r
.1558 .23684 .14674 .23166 .13524 .23448 .14434 .23962 Metetra
.557 .81 .993 r
.16733 .23404 .15831 .22884 .14674 .23166 .1558 .23684 Metetra
.557 .81 .993 r
.17894 .23123 .16995 .22599 .15831 .22884 .16733 .23404 Metetra
.557 .81 .993 r
.19061 .2284 .18167 .22313 .16995 .22599 .17894 .23123 Metetra
.557 .81 .993 r
.20236 .22555 .19346 .22025 .18167 .22313 .19061 .2284 Metetra
.557 .81 .993 r
.21419 .22269 .20532 .21735 .19346 .22025 .20236 .22555 Metetra
.557 .81 .993 r
.22609 .2198 .21726 .21443 .20532 .21735 .21419 .22269 Metetra
.557 .81 .993 r
.23806 .2169 .22927 .21149 .21726 .21443 .22609 .2198 Metetra
.557 .81 .993 r
.25011 .21398 .24137 .20854 .22927 .21149 .23806 .2169 Metetra
.557 .81 .993 r
.26223 .21104 .25354 .20556 .24137 .20854 .25011 .21398 Metetra
.557 .81 .993 r
.27444 .20808 .26578 .20257 .25354 .20556 .26223 .21104 Metetra
.557 .81 .993 r
.28672 .2051 .27811 .19956 .26578 .20257 .27444 .20808 Metetra
.557 .81 .993 r
.29908 .20211 .29051 .19653 .27811 .19956 .28672 .2051 Metetra
.557 .81 .993 r
.31152 .19909 .303 .19348 .29051 .19653 .29908 .20211 Metetra
.557 .81 .993 r
.32404 .19606 .31557 .1904 .303 .19348 .31152 .19909 Metetra
.557 .81 .993 r
.33664 .193 .32822 .18731 .31557 .1904 .32404 .19606 Metetra
.557 .81 .993 r
.34932 .18993 .34095 .1842 .32822 .18731 .33664 .193 Metetra
.557 .81 .993 r
.36209 .18684 .35376 .18107 .34095 .1842 .34932 .18993 Metetra
.557 .81 .993 r
.37493 .18372 .36666 .17792 .35376 .18107 .36209 .18684 Metetra
.557 .81 .993 r
.38787 .18059 .37965 .17474 .36666 .17792 .37493 .18372 Metetra
.557 .81 .993 r
.40089 .17743 .39272 .17155 .37965 .17474 .38787 .18059 Metetra
.557 .81 .993 r
.41399 .17425 .40588 .16833 .39272 .17155 .40089 .17743 Metetra
.557 .81 .993 r
.42718 .17106 .41912 .1651 .40588 .16833 .41399 .17425 Metetra
.557 .81 .993 r
.44046 .16784 .43246 .16184 .41912 .1651 .42718 .17106 Metetra
0 .063 .58 r
.45332 .19944 .44588 .15856 .43246 .16184 .44046 .16784 Metetra
0 0 .505 r
.46632 .24189 .45885 .1954 .44588 .15856 .45332 .19944 Metetra
0 .008 .55 r
.4797 .27673 .47206 .23706 .45885 .1954 .46632 .24189 Metetra
0 .077 .604 r
.49341 .30446 .48566 .27087 .47206 .23706 .4797 .27673 Metetra
.034 .161 .667 r
.50741 .32565 .49958 .2974 .48566 .27087 .49341 .30446 Metetra
.124 .262 .735 r
.52163 .34089 .51377 .31727 .49958 .2974 .50741 .32565 Metetra
.229 .376 .804 r
.53605 .35081 .52818 .33115 .51377 .31727 .52163 .34089 Metetra
.342 .494 .865 r
.55062 .35605 .54278 .3397 .52818 .33115 .53605 .35081 Metetra
.452 .605 .911 r
.56531 .35725 .55752 .34363 .54278 .3397 .55062 .35605 Metetra
.55 .699 .939 r
.5801 .35502 .57237 .34361 .55752 .34363 .56531 .35725 Metetra
.628 .773 .949 r
.59497 .34998 .58731 .3403 .57237 .34361 .5801 .35502 Metetra
.687 .825 .949 r
.60991 .34268 .60233 .33434 .58731 .3403 .59497 .34998 Metetra
.728 .861 .944 r
.6249 .33368 .61741 .32632 .60233 .33434 .60991 .34268 Metetra
.754 .885 .938 r
.63994 .32348 .63255 .31681 .61741 .32632 .6249 .33368 Metetra
.769 .9 .933 r
.65504 .31252 .64774 .30632 .63255 .31681 .63994 .32348 Metetra
.775 .909 .932 r
.6702 .30124 .663 .29531 .64774 .30632 .65504 .31252 Metetra
.774 .913 .934 r
.68543 .29 .67832 .28419 .663 .29531 .6702 .30124 Metetra
.764 .914 .939 r
.70074 .27913 .69372 .27335 .67832 .28419 .68543 .29 Metetra
.748 .911 .948 r
.71614 .26892 .70921 .2631 .69372 .27335 .70074 .27913 Metetra
.725 .905 .958 r
.73165 .25962 .72481 .25372 .70921 .2631 .71614 .26892 Metetra
.694 .895 .97 r
.74729 .25142 .74053 .24541 .72481 .25372 .73165 .25962 Metetra
.654 .88 .982 r
.76306 .24448 .75639 .23838 .74053 .24541 .74729 .25142 Metetra
.605 .859 .992 r
.77899 .23892 .77241 .23274 .75639 .23838 .76306 .24448 Metetra
.547 .832 .998 r
.7951 .23482 .78861 .22858 .77241 .23274 .77899 .23892 Metetra
.557 .81 .993 r
.13524 .23448 .12603 .22927 .11456 .2321 .12381 .23727 Metetra
.557 .81 .993 r
.14674 .23166 .13757 .22643 .12603 .22927 .13524 .23448 Metetra
.557 .81 .993 r
.15831 .22884 .14917 .22357 .13757 .22643 .14674 .23166 Metetra
.557 .81 .993 r
.16995 .22599 .16086 .22069 .14917 .22357 .15831 .22884 Metetra
.557 .81 .993 r
.18167 .22313 .17261 .21779 .16086 .22069 .16995 .22599 Metetra
.557 .81 .993 r
.19346 .22025 .18444 .21488 .17261 .21779 .18167 .22313 Metetra
.557 .81 .993 r
.20532 .21735 .19635 .21195 .18444 .21488 .19346 .22025 Metetra
.557 .81 .993 r
.21726 .21443 .20833 .20899 .19635 .21195 .20532 .21735 Metetra
.557 .81 .993 r
.22927 .21149 .22039 .20602 .20833 .20899 .21726 .21443 Metetra
.557 .81 .993 r
.24137 .20854 .23252 .20303 .22039 .20602 .22927 .21149 Metetra
.557 .81 .993 r
.25354 .20556 .24473 .20002 .23252 .20303 .24137 .20854 Metetra
.557 .81 .993 r
.26578 .20257 .25703 .19699 .24473 .20002 .25354 .20556 Metetra
.557 .81 .993 r
.27811 .19956 .2694 .19395 .25703 .19699 .26578 .20257 Metetra
.557 .81 .993 r
.29051 .19653 .28185 .19088 .2694 .19395 .27811 .19956 Metetra
.557 .81 .993 r
.303 .19348 .29438 .18779 .28185 .19088 .29051 .19653 Metetra
.557 .81 .993 r
.31557 .1904 .307 .18468 .29438 .18779 .303 .19348 Metetra
.557 .81 .993 r
.32822 .18731 .3197 .18155 .307 .18468 .31557 .1904 Metetra
.557 .81 .993 r
.34095 .1842 .33248 .1784 .3197 .18155 .32822 .18731 Metetra
.557 .81 .993 r
.35376 .18107 .34534 .17523 .33248 .1784 .34095 .1842 Metetra
.557 .81 .993 r
.36666 .17792 .35829 .17204 .34534 .17523 .35376 .18107 Metetra
.557 .81 .993 r
.37965 .17474 .37133 .16883 .35829 .17204 .36666 .17792 Metetra
.557 .81 .993 r
.39272 .17155 .38445 .1656 .37133 .16883 .37965 .17474 Metetra
.557 .81 .993 r
.40588 .16833 .39766 .16234 .38445 .1656 .39272 .17155 Metetra
.557 .81 .993 r
.41912 .1651 .41097 .15906 .39766 .16234 .40588 .16833 Metetra
.557 .81 .993 r
.43246 .16184 .42436 .15576 .41097 .15906 .41912 .1651 Metetra
.557 .81 .993 r
.44588 .15856 .43784 .15244 .42436 .15576 .43246 .16184 Metetra
0 .031 .553 r
.45885 .1954 .45141 .1491 .43784 .15244 .44588 .15856 Metetra
0 0 .517 r
.47206 .23706 .46452 .19013 .45141 .1491 .45885 .1954 Metetra
0 .031 .564 r
.48566 .27087 .47794 .23083 .46452 .19013 .47206 .23706 Metetra
0 .104 .62 r
.49958 .2974 .49175 .26348 .47794 .23083 .48566 .27087 Metetra
.077 .193 .683 r
.51377 .31727 .50588 .28872 .49175 .26348 .49958 .2974 Metetra
.173 .296 .75 r
.52818 .33115 .52026 .30722 .50588 .28872 .51377 .31727 Metetra
.279 .409 .815 r
.54278 .3397 .53486 .31971 .52026 .30722 .52818 .33115 Metetra
.389 .522 .87 r
.55752 .34363 .54963 .32693 .53486 .31971 .54278 .3397 Metetra
.493 .625 .909 r
.57237 .34361 .56454 .32961 .54963 .32693 .55752 .34363 Metetra
.581 .711 .932 r
.58731 .3403 .57955 .32848 .56454 .32961 .57237 .34361 Metetra
.651 .777 .941 r
.60233 .33434 .59465 .32424 .57955 .32848 .58731 .3403 Metetra
.702 .825 .941 r
.61741 .32632 .60981 .31754 .59465 .32424 .60233 .33434 Metetra
.736 .858 .938 r
.63255 .31681 .62504 .309 .60981 .31754 .61741 .32632 Metetra
.757 .88 .934 r
.64774 .30632 .64033 .29921 .62504 .309 .63255 .31681 Metetra
.768 .894 .933 r
.663 .29531 .65568 .28866 .64033 .29921 .64774 .30632 Metetra
.769 .902 .934 r
.67832 .28419 .6711 .27785 .65568 .28866 .663 .29531 Metetra
.762 .906 .939 r
.69372 .27335 .68659 .26716 .6711 .27785 .67832 .28419 Metetra
.748 .906 .947 r
.70921 .2631 .70217 .25698 .68659 .26716 .69372 .27335 Metetra
.726 .902 .958 r
.72481 .25372 .71786 .24759 .70217 .25698 .70921 .2631 Metetra
.695 .894 .969 r
.74053 .24541 .73367 .23925 .71786 .24759 .72481 .25372 Metetra
.655 .88 .981 r
.75639 .23838 .74962 .23216 .73367 .23925 .74053 .24541 Metetra
.606 .86 .991 r
.77241 .23274 .76573 .22646 .74962 .23216 .75639 .23838 Metetra
.548 .832 .998 r
.78861 .22858 .78202 .22224 .76573 .22646 .77241 .23274 Metetra
.557 .81 .993 r
.12603 .22927 .11672 .22401 .10521 .22687 .11456 .2321 Metetra
.557 .81 .993 r
.13757 .22643 .12829 .22114 .11672 .22401 .12603 .22927 Metetra
.557 .81 .993 r
.14917 .22357 .13994 .21824 .12829 .22114 .13757 .22643 Metetra
.557 .81 .993 r
.16086 .22069 .15166 .21533 .13994 .21824 .14917 .22357 Metetra
.557 .81 .993 r
.17261 .21779 .16345 .2124 .15166 .21533 .16086 .22069 Metetra
.557 .81 .993 r
.18444 .21488 .17532 .20945 .16345 .2124 .17261 .21779 Metetra
.557 .81 .993 r
.19635 .21195 .18727 .20648 .17532 .20945 .18444 .21488 Metetra
.557 .81 .993 r
.20833 .20899 .19929 .20349 .18727 .20648 .19635 .21195 Metetra
.557 .81 .993 r
.22039 .20602 .21139 .20049 .19929 .20349 .20833 .20899 Metetra
.557 .81 .993 r
.23252 .20303 .22357 .19746 .21139 .20049 .22039 .20602 Metetra
.557 .81 .993 r
.24473 .20002 .23583 .19442 .22357 .19746 .23252 .20303 Metetra
.557 .81 .993 r
.25703 .19699 .24817 .19135 .23583 .19442 .24473 .20002 Metetra
.557 .81 .993 r
.2694 .19395 .26058 .18827 .24817 .19135 .25703 .19699 Metetra
.557 .81 .993 r
.28185 .19088 .27308 .18516 .26058 .18827 .2694 .19395 Metetra
.557 .81 .993 r
.29438 .18779 .28566 .18204 .27308 .18516 .28185 .19088 Metetra
.557 .81 .993 r
.307 .18468 .29832 .17889 .28566 .18204 .29438 .18779 Metetra
.557 .81 .993 r
.3197 .18155 .31107 .17572 .29832 .17889 .307 .18468 Metetra
.557 .81 .993 r
.33248 .1784 .3239 .17253 .31107 .17572 .3197 .18155 Metetra
.557 .81 .993 r
.34534 .17523 .33682 .16932 .3239 .17253 .33248 .1784 Metetra
.557 .81 .993 r
.35829 .17204 .34982 .16609 .33682 .16932 .34534 .17523 Metetra
.557 .81 .993 r
.37133 .16883 .36291 .16284 .34982 .16609 .35829 .17204 Metetra
.557 .81 .993 r
.38445 .1656 .37608 .15957 .36291 .16284 .37133 .16883 Metetra
.557 .81 .993 r
.39766 .16234 .38935 .15627 .37608 .15957 .38445 .1656 Metetra
.557 .81 .993 r
.41097 .15906 .4027 .15295 .38935 .15627 .39766 .16234 Metetra
.557 .81 .993 r
.42436 .15576 .41615 .14961 .4027 .15295 .41097 .15906 Metetra
.557 .81 .993 r
.43784 .15244 .42969 .14625 .41615 .14961 .42436 .15576 Metetra
.557 .81 .993 r
.45141 .1491 .44332 .14286 .42969 .14625 .43784 .15244 Metetra
0 .011 .536 r
.46452 .19013 .45704 .13945 .44332 .14286 .45141 .1491 Metetra
0 0 .529 r
.47794 .23083 .47031 .18351 .45704 .13945 .46452 .19013 Metetra
0 .054 .578 r
.49175 .26348 .48396 .2231 .47031 .18351 .47794 .23083 Metetra
.035 .132 .635 r
.50588 .28872 .49798 .25449 .48396 .2231 .49175 .26348 Metetra
.12 .224 .698 r
.52026 .30722 .51231 .27838 .49798 .25449 .50588 .28872 Metetra
.218 .328 .763 r
.53486 .31971 .52689 .2955 .51231 .27838 .52026 .30722 Metetra
.324 .438 .823 r
.54963 .32693 .54167 .30664 .52689 .2955 .53486 .31971 Metetra
.429 .545 .872 r
.56454 .32961 .55661 .3126 .54167 .30664 .54963 .32693 Metetra
.525 .641 .906 r
.57955 .32848 .57168 .31415 .55661 .3126 .56454 .32961 Metetra
.605 .72 .926 r
.59465 .32424 .58685 .31206 .57168 .31415 .57955 .32848 Metetra
.667 .78 .934 r
.60981 .31754 .6021 .30706 .58685 .31206 .59465 .32424 Metetra
.71 .824 .935 r
.62504 .309 .61742 .29984 .6021 .30706 .60981 .31754 Metetra
.739 .854 .934 r
.64033 .29921 .63281 .29102 .61742 .29984 .62504 .309 Metetra
.755 .875 .934 r
.65568 .28866 .64825 .28118 .63281 .29102 .64033 .29921 Metetra
.761 .889 .935 r
.6711 .27785 .66377 .27085 .64825 .28118 .65568 .28866 Metetra
.757 .897 .94 r
.68659 .26716 .67936 .26049 .66377 .27085 .6711 .27785 Metetra
.745 .9 .947 r
.70217 .25698 .69503 .2505 .67936 .26049 .68659 .26716 Metetra
.724 .898 .958 r
.71786 .24759 .71082 .24121 .69503 .2505 .70217 .25698 Metetra
.695 .891 .969 r
.73367 .23925 .72672 .2329 .71082 .24121 .71786 .24759 Metetra
.655 .879 .981 r
.74962 .23216 .74276 .22581 .72672 .2329 .73367 .23925 Metetra
.606 .859 .991 r
.76573 .22646 .75896 .22008 .74276 .22581 .74962 .23216 Metetra
.548 .832 .998 r
.78202 .22224 .77534 .21582 .75896 .22008 .76573 .22646 Metetra
.557 .81 .993 r
.11672 .22401 .10729 .21869 .09575 .22158 .10521 .22687 Metetra
.557 .81 .993 r
.12829 .22114 .11891 .21578 .10729 .21869 .11672 .22401 Metetra
.557 .81 .993 r
.13994 .21824 .13059 .21285 .11891 .21578 .12829 .22114 Metetra
.557 .81 .993 r
.15166 .21533 .14235 .2099 .13059 .21285 .13994 .21824 Metetra
.557 .81 .993 r
.16345 .2124 .15419 .20694 .14235 .2099 .15166 .21533 Metetra
.557 .81 .993 r
.17532 .20945 .1661 .20395 .15419 .20694 .16345 .2124 Metetra
.557 .81 .993 r
.18727 .20648 .17809 .20095 .1661 .20395 .17532 .20945 Metetra
.557 .81 .993 r
.19929 .20349 .19015 .19793 .17809 .20095 .18727 .20648 Metetra
.557 .81 .993 r
.21139 .20049 .20229 .19489 .19015 .19793 .19929 .20349 Metetra
.557 .81 .993 r
.22357 .19746 .21451 .19182 .20229 .19489 .21139 .20049 Metetra
.557 .81 .993 r
.23583 .19442 .22682 .18874 .21451 .19182 .22357 .19746 Metetra
.557 .81 .993 r
.24817 .19135 .2392 .18564 .22682 .18874 .23583 .19442 Metetra
.557 .81 .993 r
.26058 .18827 .25166 .18252 .2392 .18564 .24817 .19135 Metetra
.557 .81 .993 r
.27308 .18516 .2642 .17937 .25166 .18252 .26058 .18827 Metetra
.557 .81 .993 r
.28566 .18204 .27683 .17621 .2642 .17937 .27308 .18516 Metetra
.557 .81 .993 r
.29832 .17889 .28954 .17303 .27683 .17621 .28566 .18204 Metetra
.557 .81 .993 r
.31107 .17572 .30234 .16982 .28954 .17303 .29832 .17889 Metetra
.557 .81 .993 r
.3239 .17253 .31522 .16659 .30234 .16982 .31107 .17572 Metetra
.557 .81 .993 r
.33682 .16932 .32819 .16334 .31522 .16659 .3239 .17253 Metetra
.557 .81 .993 r
.34982 .16609 .34124 .16007 .32819 .16334 .33682 .16932 Metetra
.557 .81 .993 r
.36291 .16284 .35438 .15678 .34124 .16007 .34982 .16609 Metetra
.557 .81 .993 r
.37608 .15957 .36761 .15347 .35438 .15678 .36291 .16284 Metetra
.557 .81 .993 r
.38935 .15627 .38093 .15013 .36761 .15347 .37608 .15957 Metetra
.557 .81 .993 r
.4027 .15295 .39434 .14677 .38093 .15013 .38935 .15627 Metetra
.557 .81 .993 r
.41615 .14961 .40784 .14339 .39434 .14677 .4027 .15295 Metetra
.557 .81 .993 r
.42969 .14625 .42144 .13998 .40784 .14339 .41615 .14961 Metetra
.557 .81 .993 r
.44332 .14286 .43512 .13655 .42144 .13998 .42969 .14625 Metetra
.557 .81 .993 r
.45704 .13945 .44891 .1331 .43512 .13655 .44332 .14286 Metetra
0 0 .525 r
.47031 .18351 .46278 .12962 .44891 .1331 .45704 .13945 Metetra
0 .011 .541 r
.48396 .2231 .47624 .17543 .46278 .12962 .47031 .18351 Metetra
0 .078 .592 r
.49798 .25449 .49011 .21383 .47624 .17543 .48396 .2231 Metetra
.071 .159 .65 r
.51231 .27838 .50435 .24389 .49011 .21383 .49798 .25449 Metetra
.159 .252 .712 r
.52689 .2955 .51887 .26641 .50435 .24389 .51231 .27838 Metetra
.258 .356 .773 r
.54167 .30664 .53364 .28218 .51887 .26641 .52689 .2955 Metetra
.362 .463 .829 r
.55661 .3126 .5486 .29205 .53364 .28218 .54167 .30664 Metetra
.462 .564 .873 r
.57168 .31415 .56372 .29686 .5486 .29205 .55661 .3126 Metetra
.55 .654 .904 r
.58685 .31206 .57895 .29744 .56372 .29686 .57168 .31415 Metetra
.622 .726 .921 r
.6021 .30706 .59428 .29459 .57895 .29744 .58685 .31206 Metetra
.676 .782 .93 r
.61742 .29984 .60969 .28906 .59428 .29459 .6021 .30706 Metetra
.714 .823 .933 r
.63281 .29102 .62516 .28155 .60969 .28906 .61742 .29984 Metetra
.737 .852 .934 r
.64825 .28118 .64071 .2727 .62516 .28155 .63281 .29102 Metetra
.748 .871 .937 r
.66377 .27085 .65632 .2631 .64071 .2727 .64825 .28118 Metetra
.748 .884 .941 r
.67936 .26049 .67201 .25325 .65632 .2631 .66377 .27085 Metetra
.739 .891 .949 r
.69503 .2505 .68779 .2436 .67201 .25325 .67936 .26049 Metetra
.72 .892 .958 r
.71082 .24121 .70367 .23453 .68779 .2436 .69503 .2505 Metetra
.692 .888 .97 r
.72672 .2329 .71967 .22636 .70367 .23453 .71082 .24121 Metetra
.654 .877 .981 r
.74276 .22581 .7358 .21932 .71967 .22636 .72672 .2329 Metetra
.605 .859 .991 r
.75896 .22008 .75209 .2136 .7358 .21932 .74276 .22581 Metetra
.547 .832 .998 r
.77534 .21582 .76856 .20931 .75209 .2136 .75896 .22008 Metetra
.557 .81 .993 r
.10729 .21869 .09776 .2133 .08619 .21623 .09575 .22158 Metetra
.557 .81 .993 r
.11891 .21578 .10941 .21036 .09776 .2133 .10729 .21869 Metetra
.557 .81 .993 r
.13059 .21285 .12114 .2074 .10941 .21036 .11891 .21578 Metetra
.557 .81 .993 r
.14235 .2099 .13293 .20442 .12114 .2074 .13059 .21285 Metetra
.557 .81 .993 r
.15419 .20694 .14481 .20141 .13293 .20442 .14235 .2099 Metetra
.557 .81 .993 r
.1661 .20395 .15676 .19839 .14481 .20141 .15419 .20694 Metetra
.557 .81 .993 r
.17809 .20095 .16879 .19536 .15676 .19839 .1661 .20395 Metetra
.557 .81 .993 r
.19015 .19793 .1809 .1923 .16879 .19536 .17809 .20095 Metetra
.557 .81 .993 r
.20229 .19489 .19308 .18922 .1809 .1923 .19015 .19793 Metetra
.557 .81 .993 r
.21451 .19182 .20535 .18612 .19308 .18922 .20229 .19489 Metetra
.557 .81 .993 r
.22682 .18874 .21769 .183 .20535 .18612 .21451 .19182 Metetra
.557 .81 .993 r
.2392 .18564 .23012 .17986 .21769 .183 .22682 .18874 Metetra
.557 .81 .993 r
.25166 .18252 .24263 .1767 .23012 .17986 .2392 .18564 Metetra
.557 .81 .993 r
.2642 .17937 .25522 .17352 .24263 .1767 .25166 .18252 Metetra
.557 .81 .993 r
.27683 .17621 .2679 .17031 .25522 .17352 .2642 .17937 Metetra
.557 .81 .993 r
.28954 .17303 .28065 .16709 .2679 .17031 .27683 .17621 Metetra
.557 .81 .993 r
.30234 .16982 .2935 .16385 .28065 .16709 .28954 .17303 Metetra
.557 .81 .993 r
.31522 .16659 .30643 .16058 .2935 .16385 .30234 .16982 Metetra
.557 .81 .993 r
.32819 .16334 .31945 .15729 .30643 .16058 .31522 .16659 Metetra
.557 .81 .993 r
.34124 .16007 .33255 .15398 .31945 .15729 .32819 .16334 Metetra
.557 .81 .993 r
.35438 .15678 .34575 .15064 .33255 .15398 .34124 .16007 Metetra
.557 .81 .993 r
.36761 .15347 .35903 .14729 .34575 .15064 .35438 .15678 Metetra
.557 .81 .993 r
.38093 .15013 .37241 .14391 .35903 .14729 .36761 .15347 Metetra
.557 .81 .993 r
.39434 .14677 .38587 .14051 .37241 .14391 .38093 .15013 Metetra
.557 .81 .993 r
.40784 .14339 .39943 .13708 .38587 .14051 .39434 .14677 Metetra
.557 .81 .993 r
.42144 .13998 .41308 .13363 .39943 .13708 .40784 .14339 Metetra
.557 .81 .993 r
.43512 .13655 .42683 .13016 .41308 .13363 .42144 .13998 Metetra
.557 .81 .993 r
.44891 .1331 .44067 .12666 .42683 .13016 .43512 .13655 Metetra
.557 .81 .993 r
.46278 .12962 .45461 .12314 .44067 .12666 .44891 .1331 Metetra
0 0 .52 r
.47624 .17543 .46864 .11962 .45461 .12314 .46278 .12962 Metetra
0 .03 .553 r
.49011 .21383 .48231 .1659 .46864 .11962 .47624 .17543 Metetra
.026 .1 .605 r
.50435 .24389 .4964 .20302 .48231 .1659 .49011 .21383 Metetra
.104 .184 .663 r
.51887 .26641 .51084 .23174 .4964 .20302 .50435 .24389 Metetra
.195 .279 .723 r
.53364 .28218 .52557 .25292 .51084 .23174 .51887 .26641 Metetra
.293 .381 .782 r
.5486 .29205 .54053 .26741 .52557 .25292 .53364 .28218 Metetra
.393 .484 .834 r
.56372 .29686 .55567 .27613 .54053 .26741 .5486 .29205 Metetra
.487 .58 .874 r
.57895 .29744 .57095 .27996 .55567 .27613 .56372 .29686 Metetra
.568 .663 .902 r
.59428 .29459 .58635 .27977 .57095 .27996 .57895 .29744 Metetra
.632 .731 .919 r
.60969 .28906 .60184 .27638 .58635 .27977 .59428 .29459 Metetra
.68 .784 .928 r
.62516 .28155 .6174 .27057 .60184 .27638 .60969 .28906 Metetra
.711 .822 .934 r
.64071 .2727 .63305 .26304 .6174 .27057 .62516 .28155 Metetra
.729 .85 .938 r
.65632 .2631 .64876 .25444 .63305 .26304 .64071 .2727 Metetra
.735 .868 .943 r
.67201 .25325 .66455 .24533 .64876 .25444 .65632 .2631 Metetra
.729 .88 .95 r
.68779 .2436 .68043 .23622 .66455 .24533 .67201 .25325 Metetra
.713 .885 .96 r
.70367 .23453 .69641 .22752 .68043 .23622 .68779 .2436 Metetra
.687 .883 .971 r
.71967 .22636 .71251 .21958 .69641 .22752 .70367 .23453 Metetra
.65 .874 .982 r
.7358 .21932 .72874 .21268 .71251 .21958 .71967 .22636 Metetra
.603 .857 .992 r
.75209 .2136 .74513 .20701 .72874 .21268 .7358 .21932 Metetra
.547 .832 .998 r
.76856 .20931 .76169 .20271 .74513 .20701 .75209 .2136 Metetra
.557 .81 .993 r
.09776 .2133 .08812 .20785 .0765 .21081 .08619 .21623 Metetra
.557 .81 .993 r
.10941 .21036 .0998 .20488 .08812 .20785 .09776 .2133 Metetra
.557 .81 .993 r
.12114 .2074 .11157 .20188 .0998 .20488 .10941 .21036 Metetra
.557 .81 .993 r
.13293 .20442 .12341 .19886 .11157 .20188 .12114 .2074 Metetra
.557 .81 .993 r
.14481 .20141 .13532 .19582 .12341 .19886 .13293 .20442 Metetra
.557 .81 .993 r
.15676 .19839 .14731 .19277 .13532 .19582 .14481 .20141 Metetra
.557 .81 .993 r
.16879 .19536 .15938 .18969 .14731 .19277 .15676 .19839 Metetra
.557 .81 .993 r
.1809 .1923 .17153 .1866 .15938 .18969 .16879 .19536 Metetra
.557 .81 .993 r
.19308 .18922 .18376 .18348 .17153 .1866 .1809 .1923 Metetra
.557 .81 .993 r
.20535 .18612 .19607 .18034 .18376 .18348 .19308 .18922 Metetra
.557 .81 .993 r
.21769 .183 .20846 .17719 .19607 .18034 .20535 .18612 Metetra
.557 .81 .993 r
.23012 .17986 .22093 .17401 .20846 .17719 .21769 .183 Metetra
.557 .81 .993 r
.24263 .1767 .23349 .17081 .22093 .17401 .23012 .17986 Metetra
.557 .81 .993 r
.25522 .17352 .24613 .16759 .23349 .17081 .24263 .1767 Metetra
.557 .81 .993 r
.2679 .17031 .25885 .16435 .24613 .16759 .25522 .17352 Metetra
.557 .81 .993 r
.28065 .16709 .27166 .16108 .25885 .16435 .2679 .17031 Metetra
.557 .81 .993 r
.2935 .16385 .28455 .1578 .27166 .16108 .28065 .16709 Metetra
.557 .81 .993 r
.30643 .16058 .29753 .15449 .28455 .1578 .2935 .16385 Metetra
.557 .81 .993 r
.31945 .15729 .3106 .15116 .29753 .15449 .30643 .16058 Metetra
.557 .81 .993 r
.33255 .15398 .32376 .14781 .3106 .15116 .31945 .15729 Metetra
.557 .81 .993 r
.34575 .15064 .337 .14443 .32376 .14781 .33255 .15398 Metetra
.557 .81 .993 r
.35903 .14729 .35034 .14103 .337 .14443 .34575 .15064 Metetra
.557 .81 .993 r
.37241 .14391 .36377 .13761 .35034 .14103 .35903 .14729 Metetra
.557 .81 .993 r
.38587 .14051 .37729 .13416 .36377 .13761 .37241 .14391 Metetra
.557 .81 .993 r
.39943 .13708 .39091 .13069 .37729 .13416 .38587 .14051 Metetra
.557 .81 .993 r
.41308 .13363 .40462 .1272 .39091 .13069 .39943 .13708 Metetra
.557 .81 .993 r
.42683 .13016 .41842 .12368 .40462 .1272 .41308 .13363 Metetra
.557 .81 .993 r
.44067 .12666 .43232 .12014 .41842 .12368 .42683 .13016 Metetra
.557 .81 .993 r
.45461 .12314 .44632 .11657 .43232 .12014 .44067 .12666 Metetra
.556 .809 .993 r
.46864 .11962 .46042 .11298 .44632 .11657 .45461 .12314 Metetra
0 0 .518 r
.48231 .1659 .47461 .10987 .46042 .11298 .46864 .11962 Metetra
0 .049 .564 r
.4964 .20302 .48851 .15494 .47461 .10987 .48231 .1659 Metetra
.054 .122 .617 r
.51084 .23174 .50282 .19076 .48851 .15494 .4964 .20302 Metetra
.134 .207 .674 r
.52557 .25292 .51747 .21818 .50282 .19076 .51084 .23174 Metetra
.225 .301 .733 r
.54053 .26741 .53239 .23809 .51747 .21818 .52557 .25292 Metetra
.321 .402 .789 r
.55567 .27613 .54754 .25144 .53239 .23809 .54053 .26741 Metetra
.417 .501 .838 r
.57095 .27996 .56285 .25918 .54754 .25144 .55567 .27613 Metetra
.504 .593 .876 r
.58635 .27977 .57831 .26223 .56285 .25918 .57095 .27996 Metetra
.579 .672 .903 r
.60184 .27638 .59387 .2615 .57831 .26223 .58635 .27977 Metetra
.637 .736 .92 r
.6174 .27057 .60953 .25783 .59387 .2615 .60184 .27638 Metetra
.678 .785 .931 r
.63305 .26304 .62527 .252 .60953 .25783 .6174 .27057 Metetra
.704 .822 .938 r
.64876 .25444 .64108 .24473 .62527 .252 .63305 .26304 Metetra
.716 .849 .945 r
.66455 .24533 .65698 .23663 .64108 .24473 .64876 .25444 Metetra
.715 .866 .953 r
.68043 .23622 .67296 .22827 .65698 .23663 .66455 .24533 Metetra
.703 .875 .962 r
.69641 .22752 .68905 .22011 .67296 .22827 .68043 .23622 Metetra
.679 .877 .973 r
.71251 .21958 .70525 .21255 .68905 .22011 .69641 .22752 Metetra
.644 .87 .983 r
.72874 .21268 .72158 .20587 .70525 .21255 .71251 .21958 Metetra
.599 .855 .992 r
.74513 .20701 .73807 .20032 .72158 .20587 .72874 .21268 Metetra
.545 .831 .998 r
.76169 .20271 .75472 .19601 .73807 .20032 .74513 .20701 Metetra
.557 .81 .993 r
.08812 .20785 .07836 .20234 .06671 .20533 .0765 .21081 Metetra
.557 .81 .993 r
.0998 .20488 .09008 .19933 .07836 .20234 .08812 .20785 Metetra
.557 .81 .993 r
.11157 .20188 .10189 .19629 .09008 .19933 .0998 .20488 Metetra
.557 .81 .993 r
.12341 .19886 .11376 .19324 .10189 .19629 .11157 .20188 Metetra
.557 .81 .993 r
.13532 .19582 .12572 .19017 .11376 .19324 .12341 .19886 Metetra
.557 .81 .993 r
.14731 .19277 .13775 .18707 .12572 .19017 .13532 .19582 Metetra
.557 .81 .993 r
.15938 .18969 .14986 .18396 .13775 .18707 .14731 .19277 Metetra
.557 .81 .993 r
.17153 .1866 .16206 .18083 .14986 .18396 .15938 .18969 Metetra
.557 .81 .993 r
.18376 .18348 .17433 .17767 .16206 .18083 .17153 .1866 Metetra
.557 .81 .993 r
.19607 .18034 .18668 .1745 .17433 .17767 .18376 .18348 Metetra
.557 .81 .993 r
.20846 .17719 .19912 .1713 .18668 .1745 .19607 .18034 Metetra
.557 .81 .993 r
.22093 .17401 .21163 .16808 .19912 .1713 .20846 .17719 Metetra
.557 .81 .993 r
.23349 .17081 .22423 .16485 .21163 .16808 .22093 .17401 Metetra
.557 .81 .993 r
.24613 .16759 .23692 .16159 .22423 .16485 .23349 .17081 Metetra
.557 .81 .993 r
.25885 .16435 .24969 .1583 .23692 .16159 .24613 .16759 Metetra
.557 .81 .993 r
.27166 .16108 .26255 .155 .24969 .1583 .25885 .16435 Metetra
.557 .81 .993 r
.28455 .1578 .27549 .15167 .26255 .155 .27166 .16108 Metetra
.557 .81 .993 r
.29753 .15449 .28852 .14832 .27549 .15167 .28455 .1578 Metetra
.557 .81 .993 r
.3106 .15116 .30164 .14495 .28852 .14832 .29753 .15449 Metetra
.557 .81 .993 r
.32376 .14781 .31485 .14155 .30164 .14495 .3106 .15116 Metetra
.557 .81 .993 r
.337 .14443 .32815 .13814 .31485 .14155 .32376 .14781 Metetra
.557 .81 .993 r
.35034 .14103 .34154 .13469 .32815 .13814 .337 .14443 Metetra
.557 .81 .993 r
.36377 .13761 .35503 .13123 .34154 .13469 .35034 .14103 Metetra
.557 .81 .993 r
.37729 .13416 .36861 .12774 .35503 .13123 .36377 .13761 Metetra
.557 .81 .993 r
.39091 .13069 .38228 .12422 .36861 .12774 .37729 .13416 Metetra
.557 .81 .993 r
.40462 .1272 .39605 .12069 .38228 .12422 .39091 .13069 Metetra
.557 .81 .993 r
.41842 .12368 .40991 .11712 .39605 .12069 .40462 .1272 Metetra
.557 .81 .993 r
.43232 .12014 .42387 .11353 .40991 .11712 .41842 .12368 Metetra
.557 .81 .993 r
.44632 .11657 .43793 .10992 .42387 .11353 .43232 .12014 Metetra
.557 .81 .993 r
.46042 .11298 .45209 .10628 .43793 .10992 .44632 .11657 Metetra
.541 .791 .99 r
.47461 .10987 .46635 .10262 .45209 .10628 .46042 .11298 Metetra
0 .002 .527 r
.48851 .15494 .48071 .09892 .46635 .10262 .47461 .10987 Metetra
.007 .066 .575 r
.50282 .19076 .49484 .14269 .48071 .09892 .48851 .15494 Metetra
.078 .141 .628 r
.51747 .21818 .50937 .17724 .49484 .14269 .50282 .19076 Metetra
.159 .227 .685 r
.53239 .23809 .52423 .20343 .50937 .17724 .51747 .21818 Metetra
.249 .321 .742 r
.54754 .25144 .53935 .2222 .52423 .20343 .53239 .23809 Metetra
.342 .419 .796 r
.56285 .25918 .55468 .23458 .53935 .2222 .54754 .25144 Metetra
.433 .515 .843 r
.57831 .26223 .57017 .24154 .55468 .23458 .56285 .25918 Metetra
.515 .603 .88 r
.59387 .2615 .5858 .24405 .57017 .24154 .57831 .26223 Metetra
.583 .679 .906 r
.60953 .25783 .60154 .24304 .5858 .24405 .59387 .2615 Metetra
.634 .74 .925 r
.62527 .252 .61737 .23936 .60154 .24304 .60953 .25783 Metetra
.67 .788 .937 r
.64108 .24473 .63328 .23378 .61737 .23936 .62527 .252 Metetra
.689 .823 .947 r
.65698 .23663 .64929 .22702 .63328 .23378 .64108 .24473 Metetra
.695 .848 .956 r
.67296 .22827 .66538 .21967 .64929 .22702 .65698 .23663 Metetra
.687 .862 .965 r
.68905 .22011 .68157 .21226 .66538 .21967 .67296 .22827 Metetra
.667 .868 .975 r
.70525 .21255 .69788 .20522 .68157 .21226 .68905 .22011 Metetra
.635 .865 .985 r
.72158 .20587 .71432 .19889 .69788 .20522 .70525 .21255 Metetra
.593 .852 .993 r
.73807 .20032 .7309 .1935 .71432 .19889 .72158 .20587 Metetra
.543 .83 .998 r
.75472 .19601 .74765 .18922 .7309 .1935 .73807 .20032 Metetra
.557 .81 .993 r
.07836 .20234 .06848 .19676 .05679 .19979 .06671 .20533 Metetra
.557 .81 .993 r
.09008 .19933 .08025 .19371 .06848 .19676 .07836 .20234 Metetra
.557 .81 .993 r
.10189 .19629 .09209 .19064 .08025 .19371 .09008 .19933 Metetra
.557 .81 .993 r
.11376 .19324 .104 .18755 .09209 .19064 .10189 .19629 Metetra
.557 .81 .993 r
.12572 .19017 .116 .18444 .104 .18755 .11376 .19324 Metetra
.557 .81 .993 r
.13775 .18707 .12807 .18131 .116 .18444 .12572 .19017 Metetra
.557 .81 .993 r
.14986 .18396 .14023 .17816 .12807 .18131 .13775 .18707 Metetra
.557 .81 .993 r
.16206 .18083 .15246 .17499 .14023 .17816 .14986 .18396 Metetra
.557 .81 .993 r
.17433 .17767 .16478 .1718 .15246 .17499 .16206 .18083 Metetra
.557 .81 .993 r
.18668 .1745 .17717 .16858 .16478 .1718 .17433 .17767 Metetra
.557 .81 .993 r
.19912 .1713 .18965 .16535 .17717 .16858 .18668 .1745 Metetra
.557 .81 .993 r
.21163 .16808 .20222 .16209 .18965 .16535 .19912 .1713 Metetra
.557 .81 .993 r
.22423 .16485 .21486 .15881 .20222 .16209 .21163 .16808 Metetra
.557 .81 .993 r
.23692 .16159 .2276 .15551 .21486 .15881 .22423 .16485 Metetra
.557 .81 .993 r
.24969 .1583 .24042 .15219 .2276 .15551 .23692 .16159 Metetra
.557 .81 .993 r
.26255 .155 .25332 .14884 .24042 .15219 .24969 .1583 Metetra
.557 .81 .993 r
.27549 .15167 .26632 .14547 .25332 .14884 .26255 .155 Metetra
.557 .81 .993 r
.28852 .14832 .2794 .14208 .26632 .14547 .27549 .15167 Metetra
.557 .81 .993 r
.30164 .14495 .29257 .13866 .2794 .14208 .28852 .14832 Metetra
.557 .81 .993 r
.31485 .14155 .30583 .13523 .29257 .13866 .30164 .14495 Metetra
.557 .81 .993 r
.32815 .13814 .31919 .13176 .30583 .13523 .31485 .14155 Metetra
.557 .81 .993 r
.34154 .13469 .33263 .12828 .31919 .13176 .32815 .13814 Metetra
.557 .81 .993 r
.35503 .13123 .34617 .12477 .33263 .12828 .34154 .13469 Metetra
.557 .81 .993 r
.36861 .12774 .35981 .12123 .34617 .12477 .35503 .13123 Metetra
.557 .81 .993 r
.38228 .12422 .37354 .11767 .35981 .12123 .36861 .12774 Metetra
.557 .81 .993 r
.39605 .12069 .38736 .11409 .37354 .11767 .38228 .12422 Metetra
.557 .81 .993 r
.40991 .11712 .40129 .11048 .38736 .11409 .39605 .12069 Metetra
.557 .81 .993 r
.42387 .11353 .41531 .10684 .40129 .11048 .40991 .11712 Metetra
.557 .81 .993 r
.43793 .10992 .42943 .10318 .41531 .10684 .42387 .11353 Metetra
.557 .81 .993 r
.45209 .10628 .44365 .09949 .42943 .10318 .43793 .10992 Metetra
.557 .81 .993 r
.46635 .10262 .45798 .09578 .44365 .09949 .45209 .10628 Metetra
.557 .81 .993 r
.48071 .09892 .4724 .09204 .45798 .09578 .46635 .10262 Metetra
0 .005 .531 r
.49484 .14269 .48693 .08827 .4724 .09204 .48071 .09892 Metetra
.025 .081 .584 r
.50937 .17724 .5013 .12936 .48693 .08827 .49484 .14269 Metetra
.097 .157 .637 r
.52423 .20343 .51605 .16273 .5013 .12936 .50937 .17724 Metetra
.179 .243 .694 r
.53935 .2222 .53111 .1878 .51605 .16273 .52423 .20343 Metetra
.266 .337 .75 r
.55468 .23458 .54643 .20562 .53111 .1878 .53935 .2222 Metetra
.356 .433 .803 r
.57017 .24154 .56195 .21722 .54643 .20562 .55468 .23458 Metetra
.442 .527 .849 r
.5858 .24405 .57763 .22364 .56195 .21722 .57017 .24154 Metetra
.518 .612 .885 r
.60154 .24304 .59344 .22588 .57763 .22364 .5858 .24405 Metetra
.58 .685 .913 r
.61737 .23936 .60936 .22485 .59344 .22588 .60154 .24304 Metetra
.626 .745 .933 r
.63328 .23378 .62537 .22142 .60936 .22485 .61737 .23936 Metetra
.655 .791 .947 r
.64929 .22702 .64148 .21635 .62537 .22142 .63328 .23378 Metetra
.668 .824 .959 r
.66538 .21967 .65768 .21032 .64148 .21635 .64929 .22702 Metetra
.666 .846 .969 r
.68157 .21226 .67398 .2039 .65768 .21032 .66538 .21967 Metetra
.651 .857 .978 r
.69788 .20522 .6904 .19757 .67398 .2039 .68157 .21226 Metetra
.623 .857 .987 r
.71432 .19889 .70694 .1917 .6904 .19757 .69788 .20522 Metetra
.585 .848 .994 r
.7309 .1935 .72363 .18656 .70694 .1917 .71432 .19889 Metetra
.54 .828 .999 r
.74765 .18922 .74048 .18232 .72363 .18656 .7309 .1935 Metetra
.557 .81 .993 r
.06848 .19676 .05849 .19111 .04676 .19418 .05679 .19979 Metetra
.557 .81 .993 r
.08025 .19371 .07029 .18803 .05849 .19111 .06848 .19676 Metetra
.557 .81 .993 r
.09209 .19064 .08217 .18492 .07029 .18803 .08025 .19371 Metetra
.557 .81 .993 r
.104 .18755 .09413 .18179 .08217 .18492 .09209 .19064 Metetra
.557 .81 .993 r
.116 .18444 .10616 .17865 .09413 .18179 .104 .18755 Metetra
.557 .81 .993 r
.12807 .18131 .11828 .17548 .10616 .17865 .116 .18444 Metetra
.557 .81 .993 r
.14023 .17816 .13048 .17229 .11828 .17548 .12807 .18131 Metetra
.557 .81 .993 r
.15246 .17499 .14275 .16908 .13048 .17229 .14023 .17816 Metetra
.557 .81 .993 r
.16478 .1718 .15511 .16584 .14275 .16908 .15246 .17499 Metetra
.557 .81 .993 r
.17717 .16858 .16755 .16259 .15511 .16584 .16478 .1718 Metetra
.557 .81 .993 r
.18965 .16535 .18008 .15932 .16755 .16259 .17717 .16858 Metetra
.557 .81 .993 r
.20222 .16209 .19268 .15602 .18008 .15932 .18965 .16535 Metetra
.557 .81 .993 r
.21486 .15881 .20538 .1527 .19268 .15602 .20222 .16209 Metetra
.557 .81 .993 r
.2276 .15551 .21816 .14936 .20538 .1527 .21486 .15881 Metetra
.557 .81 .993 r
.24042 .15219 .23103 .14599 .21816 .14936 .2276 .15551 Metetra
.557 .81 .993 r
.25332 .14884 .24398 .1426 .23103 .14599 .24042 .15219 Metetra
.557 .81 .993 r
.26632 .14547 .25703 .13919 .24398 .1426 .25332 .14884 Metetra
.557 .81 .993 r
.2794 .14208 .27016 .13576 .25703 .13919 .26632 .14547 Metetra
.557 .81 .993 r
.29257 .13866 .28338 .1323 .27016 .13576 .2794 .14208 Metetra
.557 .81 .993 r
.30583 .13523 .2967 .12881 .28338 .1323 .29257 .13866 Metetra
.557 .81 .993 r
.31919 .13176 .31011 .12531 .2967 .12881 .30583 .13523 Metetra
.557 .81 .993 r
.33263 .12828 .32361 .12178 .31011 .12531 .31919 .13176 Metetra
.557 .81 .993 r
.34617 .12477 .3372 .11822 .32361 .12178 .33263 .12828 Metetra
.557 .81 .993 r
.35981 .12123 .35089 .11464 .3372 .11822 .34617 .12477 Metetra
.557 .81 .993 r
.37354 .11767 .36468 .11103 .35089 .11464 .35981 .12123 Metetra
.557 .81 .993 r
.38736 .11409 .37857 .1074 .36468 .11103 .37354 .11767 Metetra
.557 .81 .993 r
.40129 .11048 .39255 .10375 .37857 .1074 .38736 .11409 Metetra
.557 .81 .993 r
.41531 .10684 .40663 .10006 .39255 .10375 .40129 .11048 Metetra
.557 .81 .993 r
.42943 .10318 .42082 .09635 .40663 .10006 .41531 .10684 Metetra
.557 .81 .993 r
.44365 .09949 .4351 .09262 .42082 .09635 .42943 .10318 Metetra
.557 .81 .993 r
.45798 .09578 .44949 .08885 .4351 .09262 .44365 .09949 Metetra
.557 .81 .993 r
.4724 .09204 .46398 .08506 .44949 .08885 .45798 .09578 Metetra
.557 .81 .993 r
.48693 .08827 .47858 .08125 .46398 .08506 .4724 .09204 Metetra
0 .019 .543 r
.5013 .12936 .49328 .0774 .47858 .08125 .48693 .08827 Metetra
.039 .094 .592 r
.51605 .16273 .5079 .11527 .49328 .0774 .5013 .12936 Metetra
.111 .17 .645 r
.53111 .1878 .52286 .14758 .5079 .11527 .51605 .16273 Metetra
.191 .256 .702 r
.54643 .20562 .53813 .17172 .52286 .14758 .53111 .1878 Metetra
.276 .349 .758 r
.56195 .21722 .55365 .18878 .53813 .17172 .54643 .20562 Metetra
.362 .444 .811 r
.57763 .22364 .56936 .19985 .55365 .18878 .56195 .21722 Metetra
.443 .536 .857 r
.59344 .22588 .58523 .20599 .56936 .19985 .57763 .22364 Metetra
.514 .62 .894 r
.60936 .22485 .60123 .2082 .58523 .20599 .59344 .22588 Metetra
.57 .691 .923 r
.62537 .22142 .61734 .20741 .60123 .2082 .60936 .22485 Metetra
.609 .75 .944 r
.64148 .21635 .63355 .20446 .61734 .20741 .62537 .22142 Metetra
.631 .794 .96 r
.65768 .21032 .64986 .2001 .63355 .20446 .64148 .21635 Metetra
.637 .824 .972 r
.67398 .2039 .66627 .19495 .64986 .2001 .65768 .21032 Metetra
.628 .842 .982 r
.6904 .19757 .6828 .18955 .66627 .19495 .67398 .2039 Metetra
.606 .847 .99 r
.70694 .1917 .69946 .18429 .6828 .18955 .6904 .19757 Metetra
.574 .842 .995 r
.72363 .18656 .71625 .1795 .69946 .18429 .70694 .1917 Metetra
.536 .826 .999 r
.74048 .18232 .7332 .17533 .71625 .1795 .72363 .18656 Metetra
.557 .81 .993 r
.05849 .19111 .04838 .1854 .03661 .1885 .04676 .19418 Metetra
.557 .81 .993 r
.07029 .18803 .06022 .18228 .04838 .1854 .05849 .19111 Metetra
.557 .81 .993 r
.08217 .18492 .07213 .17913 .06022 .18228 .07029 .18803 Metetra
.557 .81 .993 r
.09413 .18179 .08413 .17597 .07213 .17913 .08217 .18492 Metetra
.557 .81 .993 r
.10616 .17865 .09621 .17278 .08413 .17597 .09413 .18179 Metetra
.557 .81 .993 r
.11828 .17548 .10836 .16957 .09621 .17278 .10616 .17865 Metetra
.557 .81 .993 r
.13048 .17229 .1206 .16634 .10836 .16957 .11828 .17548 Metetra
.557 .81 .993 r
.14275 .16908 .13292 .16309 .1206 .16634 .13048 .17229 Metetra
.557 .81 .993 r
.15511 .16584 .14532 .15982 .13292 .16309 .14275 .16908 Metetra
.557 .81 .993 r
.16755 .16259 .15781 .15653 .14532 .15982 .15511 .16584 Metetra
.557 .81 .993 r
.18008 .15932 .17038 .15321 .15781 .15653 .16755 .16259 Metetra
.557 .81 .993 r
.19268 .15602 .18303 .14987 .17038 .15321 .18008 .15932 Metetra
.557 .81 .993 r
.20538 .1527 .19577 .14651 .18303 .14987 .19268 .15602 Metetra
.557 .81 .993 r
.21816 .14936 .2086 .14312 .19577 .14651 .20538 .1527 Metetra
.557 .81 .993 r
.23103 .14599 .22152 .13972 .2086 .14312 .21816 .14936 Metetra
.557 .81 .993 r
.24398 .1426 .23452 .13629 .22152 .13972 .23103 .14599 Metetra
.557 .81 .993 r
.25703 .13919 .24762 .13283 .23452 .13629 .24398 .1426 Metetra
.557 .81 .993 r
.27016 .13576 .2608 .12935 .24762 .13283 .25703 .13919 Metetra
.557 .81 .993 r
.28338 .1323 .27408 .12585 .2608 .12935 .27016 .13576 Metetra
.557 .81 .993 r
.2967 .12881 .28745 .12232 .27408 .12585 .28338 .1323 Metetra
.557 .81 .993 r
.31011 .12531 .30091 .11877 .28745 .12232 .2967 .12881 Metetra
.557 .81 .993 r
.32361 .12178 .31447 .11519 .30091 .11877 .31011 .12531 Metetra
.557 .81 .993 r
.3372 .11822 .32812 .11159 .31447 .11519 .32361 .12178 Metetra
.557 .81 .993 r
.35089 .11464 .34187 .10796 .32812 .11159 .3372 .11822 Metetra
.557 .81 .993 r
.36468 .11103 .35571 .10431 .34187 .10796 .35089 .11464 Metetra
.557 .81 .993 r
.37857 .1074 .36966 .10063 .35571 .10431 .36468 .11103 Metetra
.557 .81 .993 r
.39255 .10375 .3837 .09693 .36966 .10063 .37857 .1074 Metetra
.557 .81 .993 r
.40663 .10006 .39784 .09319 .3837 .09693 .39255 .10375 Metetra
.557 .81 .993 r
.42082 .09635 .41209 .08944 .39784 .09319 .40663 .10006 Metetra
.557 .81 .993 r
.4351 .09262 .42644 .08565 .41209 .08944 .42082 .09635 Metetra
.557 .81 .993 r
.44949 .08885 .44089 .08184 .42644 .08565 .4351 .09262 Metetra
.557 .81 .993 r
.46398 .08506 .45545 .07799 .44089 .08184 .44949 .08885 Metetra
.557 .81 .993 r
.47858 .08125 .47011 .07413 .45545 .07799 .46398 .08506 Metetra
.557 .81 .993 r
.49328 .0774 .48489 .07023 .47011 .07413 .47858 .08125 Metetra
0 .038 .558 r
.5079 .11527 .49977 .0663 .48489 .07023 .49328 .0774 Metetra
.047 .103 .599 r
.52286 .14758 .51462 .10083 .49977 .0663 .5079 .11527 Metetra
.117 .18 .652 r
.53813 .17172 .52981 .13224 .51462 .10083 .52286 .14758 Metetra
.195 .265 .709 r
.55365 .18878 .54529 .15565 .52981 .13224 .53813 .17172 Metetra
.277 .357 .766 r
.56936 .19985 .56101 .17219 .54529 .15565 .55365 .18878 Metetra
.359 .452 .82 r
.58523 .20599 .57692 .18298 .56101 .17219 .56936 .19985 Metetra
.436 .543 .867 r
.60123 .2082 .59299 .18908 .57692 .18298 .58523 .20599 Metetra
.501 .626 .906 r
.61734 .20741 .60918 .19151 .59299 .18908 .60123 .2082 Metetra
.551 .697 .937 r
.63355 .20446 .6255 .19118 .60918 .19151 .61734 .20741 Metetra
.584 .754 .959 r
.64986 .2001 .64192 .18888 .6255 .19118 .63355 .20446 Metetra
.599 .796 .975 r
.66627 .19495 .65845 .18533 .64192 .18888 .64986 .2001 Metetra
.598 .822 .985 r
.6828 .18955 .6751 .1811 .65845 .18533 .66627 .19495 Metetra
.584 .834 .992 r
.69946 .18429 .69186 .17665 .6751 .1811 .6828 .18955 Metetra
.559 .834 .997 r
.71625 .1795 .70877 .17229 .69186 .17665 .69946 .18429 Metetra
.53 .824 .999 r
.7332 .17533 .72581 .16823 .70877 .17229 .71625 .1795 Metetra
.557 .81 .993 r
.04838 .1854 .03814 .17962 .02634 .18276 .03661 .1885 Metetra
.557 .81 .993 r
.06022 .18228 .05002 .17645 .03814 .17962 .04838 .1854 Metetra
.557 .81 .993 r
.07213 .17913 .06197 .17327 .05002 .17645 .06022 .18228 Metetra
.557 .81 .993 r
.08413 .17597 .07401 .17007 .06197 .17327 .07213 .17913 Metetra
.557 .81 .993 r
.09621 .17278 .08613 .16684 .07401 .17007 .08413 .17597 Metetra
.557 .81 .993 r
.10836 .16957 .09833 .16359 .08613 .16684 .09621 .17278 Metetra
.557 .81 .993 r
.1206 .16634 .11061 .16033 .09833 .16359 .10836 .16957 Metetra
.557 .81 .993 r
.13292 .16309 .12297 .15703 .11061 .16033 .1206 .16634 Metetra
.557 .81 .993 r
.14532 .15982 .13541 .15372 .12297 .15703 .13292 .16309 Metetra
.557 .81 .993 r
.15781 .15653 .14794 .15039 .13541 .15372 .14532 .15982 Metetra
.557 .81 .993 r
.17038 .15321 .16056 .14703 .14794 .15039 .15781 .15653 Metetra
.557 .81 .993 r
.18303 .14987 .17326 .14365 .16056 .14703 .17038 .15321 Metetra
.557 .81 .993 r
.19577 .14651 .18605 .14024 .17326 .14365 .18303 .14987 Metetra
.557 .81 .993 r
.2086 .14312 .19892 .13682 .18605 .14024 .19577 .14651 Metetra
.557 .81 .993 r
.22152 .13972 .21189 .13336 .19892 .13682 .2086 .14312 Metetra
.557 .81 .993 r
.23452 .13629 .22494 .12989 .21189 .13336 .22152 .13972 Metetra
.557 .81 .993 r
.24762 .13283 .23809 .12639 .22494 .12989 .23452 .13629 Metetra
.557 .81 .993 r
.2608 .12935 .25132 .12287 .23809 .12639 .24762 .13283 Metetra
.557 .81 .993 r
.27408 .12585 .26465 .11932 .25132 .12287 .2608 .12935 Metetra
.557 .81 .993 r
.28745 .12232 .27808 .11575 .26465 .11932 .27408 .12585 Metetra
.557 .81 .993 r
.30091 .11877 .29159 .11215 .27808 .11575 .28745 .12232 Metetra
.557 .81 .993 r
.31447 .11519 .3052 .10852 .29159 .11215 .30091 .11877 Metetra
.557 .81 .993 r
.32812 .11159 .31891 .10487 .3052 .10852 .31447 .11519 Metetra
.557 .81 .993 r
.34187 .10796 .33272 .1012 .31891 .10487 .32812 .11159 Metetra
.557 .81 .993 r
.35571 .10431 .34662 .0975 .33272 .1012 .34187 .10796 Metetra
.557 .81 .993 r
.36966 .10063 .36063 .09377 .34662 .0975 .35571 .10431 Metetra
.557 .81 .993 r
.3837 .09693 .37473 .09002 .36063 .09377 .36966 .10063 Metetra
.557 .81 .993 r
.39784 .09319 .38894 .08623 .37473 .09002 .3837 .09693 Metetra
.557 .81 .993 r
.41209 .08944 .40325 .08242 .38894 .08623 .39784 .09319 Metetra
.557 .81 .993 r
.42644 .08565 .41766 .07859 .40325 .08242 .41209 .08944 Metetra
.557 .81 .993 r
.44089 .08184 .43218 .07472 .41766 .07859 .42644 .08565 Metetra
.557 .81 .993 r
.45545 .07799 .4468 .07083 .43218 .07472 .44089 .08184 Metetra
.557 .81 .993 r
.47011 .07413 .46153 .06691 .4468 .07083 .45545 .07799 Metetra
.557 .81 .993 r
.48489 .07023 .47637 .06296 .46153 .06691 .47011 .07413 Metetra
.557 .81 .993 r
.49977 .0663 .49132 .05898 .47637 .06296 .48489 .07023 Metetra
0 .059 .576 r
.51462 .10083 .50639 .05497 .49132 .05898 .49977 .0663 Metetra
.047 .107 .604 r
.52981 .13224 .52148 .08654 .50639 .05497 .51462 .10083 Metetra
.115 .184 .658 r
.54529 .15565 .53689 .11727 .52148 .08654 .52981 .13224 Metetra
.19 .27 .716 r
.56101 .17219 .55259 .14017 .53689 .11727 .54529 .15565 Metetra
.269 .362 .774 r
.57692 .18298 .56852 .15643 .55259 .14017 .56101 .17219 Metetra
.347 .457 .83 r
.59299 .18908 .58464 .16717 .56852 .15643 .57692 .18298 Metetra
.418 .549 .88 r
.60918 .19151 .60092 .17346 .58464 .16717 .59299 .18908 Metetra
.478 .632 .921 r
.6255 .19118 .61733 .17629 .60092 .17346 .60918 .19151 Metetra
.522 .703 .953 r
.64192 .18888 .63386 .17653 .61733 .17629 .6255 .19118 Metetra
.549 .758 .974 r
.65845 .18533 .65051 .17496 .63386 .17653 .64192 .18888 Metetra
.559 .795 .988 r
.6751 .1811 .66727 .17219 .65051 .17496 .65845 .18533 Metetra
.554 .817 .995 r
.69186 .17665 .68416 .16873 .66727 .17219 .6751 .1811 Metetra
.54 .824 .998 r
.70877 .17229 .70117 .16494 .68416 .16873 .69186 .17665 Metetra
.524 .82 .999 r
.72581 .16823 .71832 .16103 .70117 .16494 .70877 .17229 Metetra
0 g
.25 Mabswid
.97971 .29706 m
1 .55211 L
s
1 .55211 m
.7241 .33213 L
s
.7241 .33213 m
.71288 0 L
s
.71288 0 m
.97971 .29706 L
s
.71288 0 m
.02634 .18276 L
s
.02634 .18276 m
0 .46831 L
s
0 .46831 m
.7241 .33213 L
s
.7241 .33213 m
.71288 0 L
s
.71288 0 m
.02634 .18276 L
s
.71288 0 m
.7131 .00666 L
s
[(0)] .71243 -0.01333 .03379 1 Mshowa
.55534 .04194 m
.55537 .0486 L
s
gsave
.55529 .0286 -14.3086 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.409 .08089 m
.40885 .08756 L
s
gsave
.40931 .06756 -13.9216 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.27269 .11718 m
.27238 .12384 L
s
gsave
.27333 .10386 -13.5662 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.14543 .15106 m
.14496 .15771 L
s
gsave
.14638 .13776 -13.2386 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.02634 .18276 m
.02573 .1894 L
s
gsave
.02756 .16948 -12.9357 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(9) show
grestore
.125 Mabswid
.68041 .00864 m
.68052 .01264 L
s
.64844 .01715 m
.64853 .02115 L
s
.61694 .02554 m
.61701 .02954 L
s
.58591 .0338 m
.58595 .0378 L
s
.52522 .04996 m
.52521 .05396 L
s
.49553 .05786 m
.4955 .06186 L
s
.46627 .06565 m
.46622 .06965 L
s
.43743 .07332 m
.43736 .07732 L
s
.38097 .08835 m
.38086 .09235 L
s
.35333 .09571 m
.3532 .09971 L
s
.32608 .10297 m
.32593 .10696 L
s
.2992 .11012 m
.29903 .11412 L
s
.24655 .12414 m
.24634 .12813 L
s
.22076 .131 m
.22053 .135 L
s
.19531 .13778 m
.19506 .14177 L
s
.1702 .14446 m
.16994 .14845 L
s
.12098 .15756 m
.12068 .16155 L
s
.09686 .16399 m
.09654 .16797 L
s
.07305 .17032 m
.07271 .17431 L
s
.04954 .17658 m
.04919 .18057 L
s
gsave
.34252 .0194 -65.8211 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.41245 .62761 m
0 .46831 L
s
.41245 .62761 m
.41259 .62095 L
s
[(800)] .41218 .64094 .02034 -1 Mshowa
.32888 .59533 m
.32911 .58867 L
s
[(850)] .32842 .60866 .0346 -1 Mshowa
.23403 .5587 m
.23437 .55204 L
s
[(900)] .23335 .57202 .05096 -1 Mshowa
.12547 .51677 m
.12594 .51012 L
s
[(950)] .12454 .53007 .06995 -1 Mshowa
0 .46831 m
.00061 .46167 L
s
[(1000)] -0.00122 .48158 .09223 -1 Mshowa
.125 Mabswid
.39654 .62147 m
.39663 .61747 L
s
.38024 .61517 m
.38035 .61117 L
s
.36354 .60872 m
.36366 .60472 L
s
.34643 .60211 m
.34655 .59811 L
s
.31088 .58838 m
.31103 .58438 L
s
.29241 .58125 m
.29258 .57725 L
s
.27346 .57393 m
.27364 .56993 L
s
.25401 .56642 m
.2542 .56242 L
s
.21351 .55077 m
.21373 .54678 L
s
.19241 .54263 m
.19265 .53863 L
s
.17073 .53425 m
.17098 .53026 L
s
.14842 .52563 m
.14869 .52164 L
s
.10185 .50765 m
.10215 .50366 L
s
.07753 .49825 m
.07784 .49426 L
s
.05247 .48857 m
.0528 .48458 L
s
.02664 .47859 m
.02698 .47461 L
s
gsave
.22996 .6386 -66.2548 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 361.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001JB000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooon[ooooo`;o0000
U?ooool00?ooooooZ_ooool01?l0003oooooooooool0002Cooooo`00oooooonZooooo`04o`000?oo
ooooooooo`0009?ooooo003ooooooj[ooooo00Co0000oooooooooooo0000Toooool00?ooooooZ_oo
ool01?l0003oooooooooool0002Cooooo`00oooooonZooooo`04o`000?ooooooooooo`0009?ooooo
003ooooooj_ooooo0_l0002Dooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?ooooooZ_ooool3o`0009Cooooo
003Zooooo`03o`000?oooooooooo0;Sooooo1?l00002ooooo`03o`000?oooooooooo09;ooooo003Z
ooooo`04o`000?oooooo0000o`000;Cooooo0ol00006ooooo`;o0000Toooool00>_ooooo00Co0000
oooooooooooo0000[oooool4o`0000Wooooo00?o0000ooooool00000T_ooool00>_ooooo00Co0000
oooooooooooo0000Zoooool4o`0000gooooo00Co0000oooooooooooo0000TOooool00>_ooooo00?o
0000ooooool00000Goooool3o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o0000
1?ooool2o`0002kooooo1Ol0000@ooooo`05o`000?ooooooooooooooool00000T?ooool00>_ooooo
00Co0000oooooooooooo0000Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`?o00001?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0SOooool00>co
oooo0_l0001Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Kooooo1?l00007ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2<ooooo`00oooooom?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Looooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Roooool00?ooooooCoooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001kooooo1?l0000P
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0R_ooool00?ooooooC_ooool2o`00
013ooooo0_l00004ooooo`04o`000?ooooooooooo`0001_ooooo0ol00003ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`00oooooom?oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0000Coooo
o`Co00001_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ROooool00?ooooooK_ooool00ol0003oooooooooo`0<ooooo`Co0000:oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08Sooooo003oooooofcooooo0ol0000:ooooo`Co0000
;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Oooooo003oooooofcooooo00?o
0000ooooool000001oooool3o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08Kooooo003oooooofcooooo0_l00004ooooo`Co00001Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0QOooool0
0?ooooooK_ooool4o`0003_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`24oooo
o`00oooooomZooooo`Co0000?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08?o
oooo003oooooofOooooo0ol000000ooooooo0000ooooo`10ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0P_ooool00?ooooooHoooool4o`0000Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo087ooooo003ooooooeoooooo1?l00008
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`21
ooooo`00oooooomKooooo`Co0000C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
083ooooo003ooooooeSooooo1?l0001Aooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Ooooool00?ooooooE?ooool4o`0000?ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo07kooooo003ooooooe3ooooo1?l00007ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1mooooo`00ooooool2
ooooo`Go00000_ooool01Ol0003ooooooooooooooooo000000Oooooo0ol00004ooooo`;o0000;_oo
ool4o`0000_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo07cooooo003oooooo`?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool5o`00063ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1kooooo`00ooooool4ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002Kooooo0ol00004ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1jooooo`00ooooool5ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00027ooooo
1Ol00007ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1iooooo`00ooooool2ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Moooo
o`Go000000?o00nCo`000?ooool0JOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
07Sooooo003oooooo`;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00001?ooool01?l0
003oooooooooool0000Iooooo`Go00001Ol03i<2o`0006Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1hooooo`00ooooool3ooooo`?o00004?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool2o`00017ooooo1Ol00002ohk?oP;o00001Ol03i<2o`0006Wooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`1gooooo`00oooooolSooooo`03o`000?oooooooooo00[o
oooo1_l00006ohk?oP03o`000?l03i?o00nC00Co00nC0_l0001Xooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0M_ooool00?oooooo8Oooool3o`0000Wooooo1Ol00002ohk?oP03o`00
0?n>cokoS/on00KoS/on00?o0000o`0?Tol03i<00ol03i<2o`0006Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1eooooo`00oooooolQooooo`03o`000?oooooo000000Gooooo1Ol0
0007ohk?oP03o`000?n>cokoS/on00CoS/on0ol00004o`0?T`03o`000?l<6i[o000006Oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1dooooo`00oooooolQooooo`;o00000_ooool5
o`0000;oS/on0_l00008ohk?oP03o`000?n>cokoS/on00?o00000_l02Hh00ol0003o00nCo`0?T`02
o`0?T`03o`000?l<6i[o000006Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1c
ooooo`00oooooolQooooo`Ko00001_n>coh00ol0003oS/onohk?oP05ohk?oPCo00001Ol02Hh2o`00
00?o00nC00Co0000o``KV_l<6i[o0000I_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo07;ooooo003ooooooakooooo1Ol00002ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?
o_n>coh01?l00003ohk?oP03o`000?l02Hko00V>00Co00V>00Go0000o`0?Tol03i?o00nCo`000002
o``KVP03o`000?oooooooooo06Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1a
ooooo`00oooooolJooooo`Go00001on>coh00ol0003oS/onohk?oP04ohk?oPCo00002?n>coh00ol0
003o00V>o`09SP03o`09SP;o00000ol03i<00ol0003o31^Jo`00001Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0L?ooool00?oooooo5_ooool5o`0000;oS/on0_l00008ohk?oP03
o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP06ohk?oP03o`000?l02Hko00V>00;o
00V>0_l00003o`0?T`04o`000?l<6i[o31^Jo`0006Gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1`ooooo`00oooooolBooooo`Ko00001_n>coh00ol0003oS/onohk?oP05ohk?oPCo
00002?n>coh00ol0003oS/onohk?oP04ohk?oP?o00000ol02Hh2o`0000?o00nC00Co0000o``KV_l<
6i[o0000IOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06oooooo003oooooo`oo
oooo1Ol00002ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh01?l00003ohk?oP03
o`000?n>cokoS/on00OoS/on00?o0000ohk?o_n>coh00ol00002o`04R`07o`000?l02Hko00V>o`09
S_l0003o31ZIo`000002o`0?T`05o`000?l<6i[o31^Jo``KV_l00000I?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo06kooooo003oooooo`_ooooo1_l00006ohk?oP03o`000?n>coko
S/on00CoS/on1?l00008ohk?oP03o`000?n>cokoS/on00GoS/on1?l00005o`04R`;o00000ol02Hh2
o`0000;o00nC00Go0000o``KV_l<6i[o31^Jo`00001Tooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0KOooool00?oooooo2?ooool4o`0000;oS/on00?o0000ohk?o_l000001on>coh0
0ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP04
o`0000CoS/on00?o0000o`04Rol018/00_l018/2o`0000?o00V>00Go0000o``JVOl0003o00nCo`00
0004o``KVP03o`000?oooooooooo067ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`1/ooooo`00_Oooool3o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o00001?oo
ool2o`0002_ooooo1Ol00006ohk?oP;o00001_n>coh4o`0000SoS/on00?o0000ohk?o_n>coh01?n>
coh4o`0000WoS/on00?o0000o`04Rol018/00_l018/01ol0003o00V>o`09S_l02Hko0000o``JVOl0
00000_l03i<01Ol0003o31^Jo``KV_l<6i[o000006Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`1[ooooo`00_?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Kooooo1Ol00002
ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh01?l00003ohk?oP03o`000?n>coko
S/on00OoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on0ol00003
o`04R`;o00000_l02Hh01_l0003o31ZIo``JVOl0003o00nCo`0000Co31^J00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06[ooooo0030ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002;ooooo1_l00006ohk?oP03o`000?n>cokoS/on00CoS/on1?l00008ohk?oP03o`00
0?n>cokoS/on00GoS/on1?l00008ohk?oP03o`000?n>cokoS/on00Co00000_l00HL01?l0003o00B;
o`04Rol018/2o`0000;o00V>00Ko0000o``JVOl<6YWo0000o`0?Tol00004o``KVP03o`000?oooooo
oooo067ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Yooooo`00__ooool2o`00
00Cooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0001oooooo1?l00003ohk?oP;o00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000
ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP04o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh4
o`0000Ko006700Oo0000o`04Rol018_o00B;o`000?l969Oo000000;o00V>00?o0000o``JVOl<6YT0
0_l00004o``KVP;o0000H_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Sooooo
0030ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo1Ol00007ohk?oP03o`000?n>cokoS/on00Co
S/on1?l00008ohk?oP03o`000?n>cokoS/on00CoS/on1?l00009ohk?oP03o`000?n>cokoS/on00?o
00001?n>coh00ol0003o0067o`01Q`03o`01Q`;o00000_l018/00ol0003o2ARGo`000002o`09SP03
o`000?l<6YWo31ZI00;o00001?l<6iX2o`0006;ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Wooooo`00_?ooool01Ol0003ooooooooooooooooo000000kooooo0_l00004ooooo`04
o`000?ooooooooooo`0000;ooooo0_l0000Dooooo`Co00000on>coh00ol0003oS/onohk?oP06ohk?
oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP06ohk?oP03o`000?n>cokoS/on
00?o00001?n>coh2o`0000KoS/on1?l00008ohk?oP03o`000?l00HOo006700?o006700Co0000o`04
Rol018_o00000_l969L00ol0003o00V>o`000002o``JV@;o00001Ol<6iX2o`00067ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1Wooooo`00_Oooool3o`00013ooooo00?o0000oooo
ooooool00oooool2o`0000Gooooo00?o0000ooooooooool03Oooool4o`000003ohk?o_l0003oS/on
00GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh01?n>coh4o`00
00WoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00OoS/on00?o0000o`01
Qol00HL00_l00HL01?l0003o00B;o`04Rol00002o`THU`03o`000?l02Hko000000?o31ZI0_l00004
o``KVP;o0000HOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06Kooooo003Koooo
o`?o00003?ooool3o`0000?oS/on00?o0000ohk?o_l000001on>coh00ol0003oS/onohk?oP03o`00
00CoS/on00?o0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?
o_n>coh01On>coh4o`0000OoS/on00?o0000ohk?o_n>coh01On>coh3o`0000?o00670_l00002o`04
R`05o`000?l969Oo0000o`09S_l000000ol<6YT2o`0000Co31^J00?o0000oad_Z?l00000H?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo003Kooooo`03o`000?oooooo0000
00Sooooo1?l00007ohk?oP03o`000?n>cokoS/on00GoS/on1?l00008ohk?oP03o`000?n>cokoS/on
00;oS/on1_l00008ohk?oP03o`000?n>cokoS/on00Co00000on>coh00ol0003oS/onohk?oP06ohk?
oP03o`000?n>cokoS/on00Co00000_l008H01?l0003o0067o`01Qol00HL2o`0000;o00B;00Ko0000
o`THUol969Oo0000o`09S_l00003o``JV@03o`000?l<6i[o31^J00;o31^J00?o0000oad_Z?l00000
H?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo003Kooooo`;o00001Ooo
ool4o`0000?oS/on00?o0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP04o`0000CoS/on00?o
0000ohk?o_n>coh01?n>coh6o`0000KoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o
0000ohk?o_n>coh01?n>coh4o`0000Ko002600Co0000o`01Qol00HOo00670_l00002o`04R`06o`00
0?l969Oo2ARGo`000?l02Hko00000ol<6YT00ol0003o31^Jo``KVP02o``KVP04o`000?lM;jSo7BnX
o`0005oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`00g_ooool5o`00
0003ohk?o_l0003oS/on00CoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000WoS/on00?o0000ohk?
o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh00ol00004ohk?
oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh00ol00004oh[:o@03o`000?l008Ko0026
00?o00260_l00002o`01Q`05o`000?l659Go0000o`04Rol000000ol969L2o`0000?o31ZI0_l00003
o``KVP05o`000?lM;jSo7BnXoad_Z?l00000G_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo06;ooooo003Kooooo`Co00001?n>coh2o`0000KoS/on00?o0000ohk?o_n>coh00ol00004
ohk?oP;o00001_n>coh4o`0000SoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000
ohk?o_n>coh01?n>coh4o`0000SoR/[m00?o0000o`00Q_l008H00_l008H2o`0000;o006700Go0000
o`HDUOl0003o00B;o`000003o`THU`;o00000ol<6YT2o`0000Co31^J00Co0000oad_Z?lM;jSo0000
G_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo067ooooo003Gooooo`Co00002On>
coh00ol0003oS/onohk?oP02ohk?oPGo00002On>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o
0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01_n>
coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000oh[:oOn:b_d01_n:b_d00ol0003o0026o`00
QP02o`00QP04o`000?l00HOo0067o`01Q`;o000000?o00B;o`000?l969L00ol969L00ol0003o31ZI
o``JV@02o``JV@;o00000ol<6iX01Ol0003o7BnXoad_Z?lM;jSo000005gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Pooooo`00doooool4o`0000CoS/on0_l00006ohk?oPKo0000
1On>coh2o`0000KoS/on1?l00008ohk?oP03o`000?n>cokoS/on00CoS/on1?l00008ohk?oP03o`00
0?n>cokoS/on00;oS/on1_l00008ohk?oP03o`000?n:b_goR/[m00;oR/[m1Ol00003o`00QP;o0000
0_l00HL01?l0003o1QBEo`000?l00004o`THU`;o00000ol<6YT2o`0000?o31^J00Go0000oad_Z?lM
;jSo7BnXo`00001Mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Goooool00<oo
oooo1Ol00002ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03
o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00Ko
S/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00CoS/on1_l00006ohk?oP03
o`000?n>cokoS/on00CoS/on1_l00004o`00Q004o`000?l008Ko0026o`00QP;o00000_l00HL01Ol0
003o1QBEo`000?l018_o000000?o2ARG0_l00003o``JV@03o`000?lM;ZKo000000;o31^J00?o0000
oad_Z?lM;jP00_lM;jP00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Goooool00<cooooo1Ol00003ohk?oP?o00001On>coh4o`0000SoS/on00?o0000ohk?
o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?
o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh00ol00003ohk?
oP03o`000?l008Co002400Co002400Co0000o`00Q_l008Ko00260_l00002o`01Q`05o`000?l659Go
0000o`04Rol000001?l969L01ol0003o31ZIo``JVOl<6YWo0000oad^Y_l000000_l<6iX00ol0003o
7BnXoad_Z002oad_Z003o`000?oooooooooo05[ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Nooooo`00b?ooool6o`0000SoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`00
0?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP;o00001on>coh00ol0003oS/on
ohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh0
1?n>coh4o`0000OoS/on00?o0000o`00Q?l008@00ol008@2o`0000;o002600Go0000o`4@Tol0003o
0067o`000002o`HDU@;o00001?l969L01Ol0003o31ZIo``JVOl<6YWo000000;o7BjV00Co0000o``K
V_l<6i[o00001?lM;jP00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0GOooool007gooooo0ol00002ooooo`05o`000?ooooooooooooooool000001oooool3
o`0000Cooooo0_l0000/ooooo`Oo00001?n>coh00ol0003oS/onohk?oP04ohk?oPCo00002?n>coh0
0ol0003oS/onohk?oP04ohk?oPCo00002On>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh0
0ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP03
o`0000CoS/on00?o0000ohk?o_n>coh01On>coh00ol0003o0024o`00Q002o`00Q0;o00000_l008H0
1Ol0003o0A2Co`000?l00HOo000000;o1QBE0_l00004o`THU`;o00000_l<6YT01?l0003o7BjVoad^
Y_l00002o``KVP03o`000?lM;jSo7BnX00;o7BnX00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo05cooooo001nooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo
1?l00002ohk?oP04o`000?n>cokoS/ono`0000GoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP;o
00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on0_l00006ohk?oPKo00001On>coh00ol0003o
S/onohk?oP04ohk?oPCo00002?n>coh00ol0003oS/onohk?oP04ohk?oPCo00002?n>coh00ol0003o
S/onohk?oP02ohk?oPCo00000ol008@2o`0000;o002600Go0000o`4@Tol0003o0067o`000002o`HD
U@;o00001?l969L2o`0000?o31ZI00Ko0000oad^Y_lM;ZKo0000o``KV_l00004oad_Z0;o0000F_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo05_ooooo001kooooo`Go00001?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009?oo
ool4o`0000OoS/on00?o0000ohk?o_l000001?n>coh4o`0000WoS/on00?o0000ohk?o_n>coh00_n>
coh5o`0000WoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00KoS/on00?o
0000ohk?o_n>coh00ol00004ohk?oP;o00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o
0000ohk?o_n>coh01?n>coh6o`0000?o002500?o0000o`00Q?l008@00_l008@2o`0000;o002600Go
0000o`4@Tol0003o0067o`000002o`HDU@03o`000?l969Oo2ARG00?o2ARG00Go0000o``JVOl<6YWo
31ZIo`000002oad^YP03o`000?l<6i[o000000Go7BnX0_l0001Iooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0F_ooool007_ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008Oooool4o`00
00?oS/on00?o0000ohk?o_n>coh01On>coh2o`000004ohk?o_l0003o0000o`0000CoS/on0_l00006
ohk?oPKo00001On>coh2o`0000KoS/on1?l00007ohk?oP03o`000?n>cokoS/on00CoS/on1?l00009
ohk?oP03o`000?n>cokoS/on00;oS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh0
0ol0003o0025o`00Q@03o`00Q@03o`000?l008Co002400;o00240_l00002o`00QP05o`000?l149?o
0000o`01Qol000000_l659D00ol0003o2ARGo`THU`03o`THU`;o00000_l<6YT01?l0003o7BjVoad^
Y_lM;ZH2o`0000Go7BnX0_l0001Iooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
FOooool007cooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Mooooo`Co00000_n>coh00ol0003o
S/onohk?oP03ohk?oP03o`000?n>cokoS/on00CoS/on0ol00009ohk?oP03o`000?n>cokoS/on00?o
00001?n>coh00ol0003oS/onohk?oP06ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003o
S/onohk?oP06ohk?oP03o`000?n>cokoS/on00?o00001?n>coh2o`0000KoS/on1_l00005ohk?oP03
o`000?n>cokoS/on00CoS/on1?l00007ohk?oP03o`000?l008Go002500;o00250_l00003o`00Q0;o
00000_l008H01Ol0003o0A2Co`000?l00HOo000000;o1QBE0_l00004o`THU`;o00000_l<6YT01?l0
003o7BjVoad^Y_lM;ZH2o`0000Go7BnX00?o0000oc15]ol00000F?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo05Sooooo001mooooo`;o00003oooool2o`0000Cooooo00Co0000oooo
oooooooo00006Oooool4o`0000CoS/on0ol00006ohk?oP03o`000?n>cokoS/on00?o00000on>coh2
o`0000KoS/on1?l00008ohk?oP03o`000?n>cokoS/on00CoS/on1?l00007ohk?oP03o`000?n>coko
S/on00CoS/on1?l00009ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP06
ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP05ohk?oP03o`000?l008Go
002500;o002500Wo0000o`00Q?l008Co0024o`000?l0393o0000o`00Q_l000000_l149<2o`0000?o
1QBE00?o0000o`THUol969L00_l969L01Ol0003o72^Uo`000?l<6YWo000000Co7BjV0_l00004oad_
Z004o`000?l`AKOo<4Fgo`0005Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1G
ooooo`00O_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`;o00004_ooool4o`0000WoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?
o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000ohk?o_n>coh00ol00004ohk?
oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP;o00001_n>coh4o`00
00OoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh4o`00
00?o002500Wo0000o`00Q?l008Co0024o`000?l0393o0000o`00Q_l000000_l149<2o`0000?o1QBE
00?o0000o`THUol969L00_l969L01Ol0003o72^Uo`000?l<6YWo000000Co7BjV0_l00004oad_Z004
o`000?l`AKOo<4Fgo`0005Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Foooo
o`00W?ooool00ol0003oooooooooo`0;ooooo`Go00000on>coh2o`0000KoS/on1_l00005ohk?oP03
o`000?n>cokoS/on00CoS/on1?l00008ohk?oP03o`000?n>cokoS/on00CoS/on1?l00008ohk?oP03
o`000?n>cokoS/on00;oS/on1Ol00009ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003o
S/onohk?oP06ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP04ohk?oPKo
00000ol008H01?l0003o0025o`00QOl008D2o`0000;o002400Go0000o`0<T?l0003o0026o`000002
o`4@T`;o00000ol659D00ol0003o2ARGo`THU`02o`THU`06o`000?lL:jGo72^Uo`000?l<6YWo0000
1?lM;ZH00ol0003o7BnXoad_Z003oad_Z004o`000?l`AKOo<4Fgo`0005Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1Fooooo`00V_ooool3o`0000Wooooo1_l00002ohk?oP03o`00
0?n>cokoS/on00?oS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on
00?o0000ohk?o_n>coh00ol00004ohk?oP;o00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on
00?o0000ohk?o_n>coh01?n>coh6o`0000GoS/on0_l00006ohk?oPCo00001on>coh00ol0003oS/on
ohk?oP04ohk?oPCo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000o`00Q_l008H0
0ol008H01?l0003o0025o`00QOl008D2o`0000;o002400?o0000o`0<T?l039000_l00003o`4@T`04
o`000?l659Go1QBEo`HDU@;o00001?l969L01Ol0003o72^Uo`000?l<6YWo000000Co7BjV00?o0000
oad_Z?lM;jP00olM;jP01Ol0003o<4Fgoc15]ol`AKOo000005Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`1Eooooo`00V_ooool00ol0003oooooo`000004ooooo`Ko00001On>coh0
0ol0003oS/onohk?oP04ohk?oPCo00002?n>coh00ol0003oS/onohk?oP04ohk?oP?o00002On>coh0
0ol0003oS/onohk?oP02ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000
ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01On>coh0
0ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000OoS/on00?o0000
o`00Q_l008H00_l008H2o`0000;o00250_l00002o`00Q006o`000?l0393o00b@o`000?l008Ko0000
0_l149<2o`0000;o1QBE0_l00004o`THU`05o`000?lL:jGo0000o``JVOl000001?lM;ZH2o`0000Co
7BnX00Go0000oc15]ol`AKOo<4Fgo`00001Eooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0E?ooool009[ooooo0_l00002ooooo`Co00000on>coh00ol0003oS/onohk?oP05ohk?oP03
o`000?n>cokoS/on00?o00001?n>coh2o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o
00001_n>coh6o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>
coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>
coh00ol00003ohk?oP03o`000?n>cokoS/on00KoS/on00?o0000o`00Q_l008H00_l008H02?l0003o
0025o`00QOl0003o00N=o`000?l008Co00000_l039000ol0003o0026o`000002o`4@T`;o00000ol6
59D2o`0000?o2ARG00?o0000oa`[YOlL:jD00_l00005oad^YP;o00000olM;jP00ol0003o<4Fgoc15
]`02oc15]`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`1Cooooo`00Voooool3o`0000?oS/on00?o0000ohk?o_n>coh00_n>coh00ol0003oS/onohk?oP04
ohk?oP?o00002On>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03
o`0000CoS/on00?o0000ohk?o_n>coh01On>coh00ol0003oS/onohk?oP03o`0000CoS/on0_l00007
ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP04ohk?oPKo00001On>coh0
0ol0003oS/onohk?oP04ohk?oPCo00001on>coh00ol0003oS/onohk?oP04ohk?oP?o00000ol008H0
1_l0003o0025o`00QOl0003o00N=o`0000;o002400Go0000o`0<T?l0003o0026o`000003o`4@T`04
o`000?l659Go1QBEo`HDU@;o00000ol969L00ol0003o72^Uoa`[Y@02o`0000Go7BjV0_l00003oad_
Z003o`000?l`AKOo<4Fg00?o<4Fg00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo05;ooooo002Gooooo`Co00000on>coh2o`000003ohk?o_l0003oS/on00Co
S/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh6o`0000GoS/on00?o0000ohk?o_n>
coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh01?n>coh3o`0000WoS/on00?o0000ohk?o_n>
coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00Ko
S/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>
coh00ol00002o`02R@04o`000?l008Ko0026o`00QP;o00000_l008D2o`0000;o002400?o0000o`0<
T?l039000_l00003o`4@T`07o`000?l659Go1QBEo`HDUOl0003o62RSo`000002o`THU`05o`000?lL
:jGo72^Uoa`[YOl000001OlM;ZH00ol0003o<D>eo`000003oad_Z003o`000?l`AKOo<4Fg00;o<4Fg
0_l0001Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0DOooool009?ooooo1Ol0
0008ohk?oP03o`000?n>cokoS/on00;oS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00001?n>
coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00001?n>coh2o`0000OoS/on00?o
0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh6o`0000GoS/on00?o0000ohk?o_n>coh01?n>
coh4o`0000OoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?o_n>coh00_n>
coh5o`0000Go00:900Co0000o`00Q_l008Ko00260_l00002o`00Q@05o`000?l01hgo0000o`00Q?l0
00000_l03902o`0000?o0A2C00Oo0000o`HDUOl659Go1QBEo`000?lH::?o000000;o2ARG00Co0000
oa`[YOlL:jGo72^U0_l00004oad^YP04o`000?la@kGo<D>eo`0000;o7BnX00?o0000oc15]ol`AKL0
0_l`AKL00ol0003oA5c6o`00001Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
D?ooool008oooooo1_l00003ohk?oP;o00001_n>coh5o`0000GoS/on0_l00006ohk?oP?o00002?n>
coh00ol0003oS/onohk?oP04ohk?oP?o00002On>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>
coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?
oP03o`0000CoS/on00?o0000ohk?o_n>coh01On>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o
0000ohk?o_n>coh01?n>coh6o`0000GoS/on0_l00003o`02R@;o00000_l008H2o`0000;o002500Go
0000o`07SOl0003o0024o`000002o`0<T0;o00000ol149<2o`0000;o1QBE00Ko0000oaPXXolH::?o
0000o`THUol00003oa`[Y@;o00001?lM;ZH01?l0003o<D>eoc53]Ol00002oad_Z003o`000?l`AKOo
<4Fg00?o<4Fg00?o0000odALa_l00000DOooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo04oooooo002<ooooo`Go00000on>coh00ol0003oS/onohk?oP03ohk?oP03o`000?n>cokoS/on
00?o00000on>coh00ol0003oS/onohk?oP06ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`00
00OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh6o`0000GoS/on00?o0000ohk?
o_n>coh01?n>coh4o`0000OoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00?o0000ohk?
o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP;o00001on>coh01Ol0
003o00:9o`02ROl00XWo000000;o002600Wo0000o`02R_l0003o0025o`000?l01hgo0000o`00Q?l0
00000ol039001?l0003o0A2Co`4@Tol149<2o`0000;o1QBE00Co0000oaPXXolH::?o00000_l969L0
1Ol0003o72^Uoa`[YOlL:jGo000000Go7BjV00Ko0000oc53]Ola@kGo0000oad_Z?l00005oc15]`04
o`000?m4G<KoA5c6o`00053ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1>oooo
o`00Qoooool5o`0000GoS/on0_l00006ohk?oPCo00001on>coh00ol0003oS/onohk?oP04ohk?oPCo
00002?n>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000Co
S/on0_l00006ohk?oP03o`000?n>cokoS/on00?o00001?n>coh2o`0000KoS/on00?o0000ohk?o_n>
coh00ol00004ohk?oP;o00001_n>coh5o`0000GoS/on0_l00006ohk?oP?o00002On>coh00ol0003o
S/onohk?oP02ohk?oPCo00000_l00XT03?l0003o0026o`00Q_l0003o00::o`000?l008Go0000o`07
SOl0003o0024o`0000?o00b@0_l00003o`4@T`07o`000?l659Go1QBEo`HDUOl0003o62RSo`000002
o`THU`05o`000?lL:jGo72^Uoa`[YOl000001OlM;ZH01?l0003o<D>eoc53]Ola@kD2o`0000Go<4Fg
00Go0000odALa_m4G<KoA5c6o`00001?ooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool0COooool003oooooo0ol00003ooooo`05o`000?ooooooooooooooool000001oooool3o`0000Co
oooo0_l0000Zooooo`Co00000on>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o
00001?n>coh2o`0000KoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP;o00001_n>coh5o`0000Go
S/on0_l00006ohk?oP?o00002On>coh01?l0003oS/onohk?o_n>coh5o`0000WoS/on00Co0000ohk?
o_n>cokoS/on1Ol00009ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000OoS/on00?o0000
ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh6o`0000?o00N=00?o0000o`02ROl00XT00_l00002
o`00QP;o000000Co0025o`000?l01hgo00N=0_l00003o`0<T0;o00000ol149<2o`0000;o1QBE00Ko
0000oaPXXolH::?o0000o`THUol00003oa`[Y@;o00001?lM;ZH01ol0003o<D>eoc53]Ola@kGo0000
oad_Z?l000001?l`AKL00ol0003oA5c6odALaP02odALaP03o`000?oooooooooo04cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1=ooooo`00?_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Gooooo1?l00003ohk?oP03o`000?n>cokoS/on00;oS/on00?o0000ohk?o_n>coh01?n>
coh3o`0000WoS/on00Co0000ohk?o_n>cokoS/on1Ol00009ohk?oP03o`000?n>cokoS/on00?o0000
0on>coh2o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh5o`0000GoS/on
0_l00006ohk?oPGo00001On>coh2o`0000KoS/on1?l00008ohk?oP03o`000?n>cokoS/on00;oS/on
1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003o00N=o`07S@03o`07S@03o`00
0?l00XWo00:900;o00000_l008H01?l0003o00::o`000?l00002o`07S@;o00001?l039001?l0003o
0A2Co`4@Tol149<2o`0000;o1QBE00Ko0000oaPXXolH::?o0000o`THUol00004oa`[Y@;o00000olM
;ZH00ol0003o<D>eoc53]@02oc53]@;o00001Ol`AKL00ol0003oA5c6odALaP02odALaP03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1<ooooo`00@_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Rooooo`Co00000on>coh2o`000003ohk?o_l0003oS/on00CoS/on00?o
0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh5o`0000GoS/on0_l00006ohk?oPCo00002?n>
coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o
0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01On>
coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh6o`0000GoS/on00?o
0000ohk?o_n>coh01?n>coh4o`0000OoS/on00?o0000o`07SOl01hd00_l01hd2o`000003o`02ROl0
003o000000;o002600Ko0000o`02R_l0003o0025o`000?l01hd2o`0000Co00b@00Wo0000o`4@Tol1
49?o0A2Co`000?lC9:3o0000o`HDUOl000000olH::<2o`0000Co72^U0_l00003oad^YP03o`000?la
@kGo<D>e00?o<D>e00?o0000oc15]ol`AKL00ol`AKL00ol0003oA5c6odALaP03odALaP;o0000Booo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04_ooooo0012ooooo`07o`000?oooooo
ooooooooool0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00007_ooool5o`0000SoS/on0_l00003ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000Co
S/on0_l00006ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP04ohk?oPKo
00001On>coh00ol0003oS/onohk?oP04ohk?oPCo00001on>coh00ol0003oS/onohk?oP04ohk?oPCo
00002?n>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?o
S/on00?o0000ohk?o_n>coh01_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>
coh01On>coh01?l0003o00N=o`07SOl01hd2o`00000:o`02ROl0003o0027o`000?l008Ko0000o`02
R_l0003o0025o`0000;o00N=0_l00003o`0<T009o`000?l149?o0A2Co`4@Tol0003o4bBPo`000?l6
59Go000000?o62RS0_l00004oa`[Y@03o`000?l`@K?o000000?o7BjV00?o0000oc53]Ola@kD00_la
@kD00ol0003o<4Fgoc15]`03oc15]`03o`000?m4G<KoA5c600?oA5c600?o0000oeQde?l00000B_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04[ooooo000nooooo`Co00000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Iooooo`Go00000_n>coh00ol0003oS/onohk?oP02o`0000KoS/on1Ol00005ohk?oP;o0000
1_n>coh3o`0000WoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o
00001?n>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003o
S/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP04ohk?oPKo
00001On>coh00ol0003oS/onohk?oP04ohk?oPCo00001on>coh00ol0003oS/onohk?oP04ohk?oPCo
00002?n>coh00ol0003oS/onohk?oP02ohk?oPCo00000ol01hd02ol0003o00:9o`000?l008Oo0000
o`00Q_l0003o00::o`000?l008Go000000;o00N=0_l00003o`0<T0;o00000_l149<01Ol0003o4bBP
o`000?l659Go000000Co62RS0_l00003oa`[Y@04o`000?l`@K?o<46co`0000;o7BjV00?o0000oc53
]Ola@kD00_la@kD2o`0000Co<4Fg00?o0000odALa_m4G<H00om4G<H01?l0003oF7CDoeQde?l00019
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0BOooool003kooooo00?o0000oooo
ooooool04?ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool2o`0001;ooooo1?l00002
ohk?oP05o`000?n>cokoS/onohk?o_l000001?n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l0
0007ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on1Ol00005ohk?oP;o00001_n>
coh3o`0000SoS/on00?o0000ohk?o_n>coh01?n>coh3o`0000SoS/on00?o0000ohk?o_n>coh00_n>
coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on00?o
0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol0
0004ohk?oP03o`000?n>cokoS/on00CoS/on1_l00003o`0@U004o`000?l01hgo00N=o`07S@;o0000
00Go00:9o`000?l0003o0026o`000002o`02RP;o00000_l01hd2o`0000?o00b@0_l00003o`4@T`05
o`000?lC9:3o0000o`HDUOl000000olH::<2o`0000Co72^U00?o0000oc11/ol000000_lM;ZH00ol0
003o<D>eoc53]@03oc53]@;o00000ol`AKL00ol0003oA5c6odALaP04odALaP03o`000?mHM=CoF7CD
00;o0000AOooool3o`0004Kooooo00?o0000ooooooooool0B?ooool003kooooo1Ol0000?ooooo`03
o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00cooooo0ol00007ohk?oP;o
00001_n>coh3o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>
coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o
00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPGo00001On>coh2o`0000Ko
S/on0ol00008ohk?oP03o`000?n>cokoS/on00;oS/on1Ol00008ohk?oP03o`000?n>cokoS/on00;o
S/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003o012Do`0@U002o`0@U004
o`000?l01hgo00N=o`07S@;o000000?o00:9o`000?l008L00_l00002o`02RP;o00000ol01hd00ol0
003o00b@o`0<T002o`0<T009o`000?l149?o0A2Co`4@Tol0003o4bBPo`000?l659Go000000Co62RS
00?o0000oa`[YOlL:jD00_lL:jD01_l0003o<46coc11/ol0003o7BjVo`0000Go<D>e00?o0000odIK
a?l000000ol`AKL00ol0003oA5c6odALaP03odALaP03o`000?mHM=CoF7CD00;oF7CD00?o0000oooo
ooooool0?Oooool5o`0000;oQ]7o0_l00016ooooo`03o`000?oooooooooo04Oooooo001Mooooo`?o
00002_ooool5o`0000;oS/on0_l00007ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000Ko
S/on1Ol00005ohk?oP;o00001_n>coh3o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000So
S/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o
00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPGo00001On>coh00ol0003o
S/onohk?oP04ohk?oPKo00001On>coh00ol0003oS/onohk?oP04ohk?oPCo00002?n>coh01?l0003o
012Do`0@U?l049@2o`0000;o00N=0_l000001ol00XWo0000o`00Qol0003o0026o`000?l00XX00_l0
0003o`07S@03o`000?l0393o00b@00;o00b@0_l00002o`4@T`05o`000?lC9:3o0000o`HDUOl00000
1?lH::<00ol0003o72^Uoa`[Y@02oa`[Y@04o`000?l`@K?o<46coc11/`;o00001Ola@kD01?l0003o
AU_4odIKa?l00002oc15]`03o`000?m4G<KoA5c600?oA5c600?o0000oeQde?mHM=@00omHM=@00ol0
003oooooooooo`0hooooo`Co00001on6dOl00ol0003oQ]7oo`000016ooooo`03o`000?oooooooooo
04Kooooo001Mooooo`03o`000?oooooo000000Kooooo1Ol00003ohk?oP03o`000?n>cokoS/on00;o
S/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o
00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPGo00001On>coh2o`0000Ko
S/on1Ol00005ohk?oP03o`000?n>cokoS/on00CoS/on1?l00008ohk?oP03o`000?n>cokoS/on00;o
S/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP05ohk?oP03
o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o
00001?n>coh00ol0003oS/onohk?oP04ohk?oP?o00000ol049@00ol0003o00N=o`07S@02o`000006
o`02ROl0003o0027o`000?l008Ko00000_l00XX01Ol0003o00N=o`07SOl01hgo000000Co00b@0_l0
0002o`4@T`03o`000?lC9:3o4bBP00;o00001?lH::<2o`0000?o72^U00Oo0000oc11/ol`@K?o<46c
o`000?lM;ZKo000000Co<D>e00Oo0000odIKa?m6FlCoAU_4o`000?l`AKOo000000KoA5c600?o0000
oeQde?mHM=@00omHM=@2o`0003?ooooo1Ol00003oh[Bo`03o`000?n6dOooQ]7o00GoQ]7o00Co0000
ohKAoon6dOoo0000A_ooool00ol0003oooooooooo`15ooooo`00GOooool2o`0000;ooooo1Ol00005
ohk?oP;o00001_n>coh5o`0000GoS/on0_l00006ohk?oP?o00002?n>coh00ol0003oS/onohk?oP02
ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01_n>coh0
0ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oP03o`000?n>cokoS/on00?o00001?n>coh0
0ol0003oS/onohk?oP04ohk?oPKo00001On>coh00ol0003oS/onohk?oP04ohk?oPCo00001on>coh0
0ol0003oS/onohk?oP04ohk?oP?o00002?n>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh0
0ol0003oS/onohk?oP03o`0000;o1QbN00Go0000o`0@U?l049Co012Do`000002o`07S@04o`000?l0
08Co0000o`0000;o00270_l00002o`02RP;o00000_l01hd2o`0000?o00b@00Go0000o`dOWOl0003o
0A2Co`000002oa<TX0;o00001?lH::<00ol0003o;Cjao`000003oa`[Y@04o`000?l`@K?o<46coc11
/`;o00001Ola@kD01?l0003oAU_4odIKa?m6Fl@2o`0000KoA5c600?o0000oeQde?mHM=@00omHM=@0
0ol0003oJhcQo`000002o`0002cooooo1?l00009oh[Bo`03o`000?n6dOooQ]7o00CoQ]7o00?o0000
ohKAool000000_l00015ooooo`03o`000?oooooooooo04Gooooo001Nooooo`Go00000_n>coh00ol0
003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000OoS/on00?o0000ohk?
o_n>coh00ol00003ohk?oP;o00001_n>coh5o`0000GoS/on0_l00006ohk?oP?o00001on>coh00ol0
003oS/onohk?oP04ohk?oPCo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000
ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol00004
ohk?oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh5
o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000Go1QbN0_l00002o`0@U0;o000000?o00N=
o`000?l008@00_l00002o`00Q`;o00000_l00XX2o`0000;o00N=0_l00003o`0<T005o`000?l=7igo
0000o`4@Tol000000olC9:000ol0003o62RSoaPXX`03oaPXX`;o00000olL:jD00ol0003o<46coc11
/`02oc11/`03o`000?la@kGo<D>e00?o<D>e00?o0000odIKa?m6Fl@00_m6Fl@2o`0000GoA5c600?o
0000oeQde?mHM=@01?mHM=@01?l0003oJhcQof^<hOm[S>43o`0002Gooooo1?l00003ohgAoP03o`00
0?n:d_ooR];o00SoR];o00?o0000ohKAoon6dOl01Ol00003ohOBo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0A?ooool005_ooooo1?l00003ohk?oP05o`000?n>cokoS/onohk?o_l00000
1_n>coh3o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh0
0ol00003ohk?oP;o00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oP03o`00
0?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP04ohk?oPGo00001On>coh2o`0000KoS/on
0ol00008ohk?oP03o`000?n>cokoS/on00;oS/on1Ol00008ohk?oP03o`000?n>cokoS/on00;oS/on
1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on00?o0000ohk?o_n>coh0
0ol00004ohk?oP03o`000?l679ko1QbN00?o1QbN00?o0000o`0@U?l049@00_l000001ol01hgo0000
o`00Q?l0003o00:9o`000?l008L00_l00003o`02RP05o`000?l01hgo00N=o`07SOl000000ol03900
1Ol0003o3AnMo`000?l149?o000000?o4bBP0_l00004oaPXX`03o`000?l]?[7o000000;o72^U00?o
0000oc11/ol`@K<00_l`@K<00ol0003o<D>eoc53]@03oc53]@03o`000?m6FlCoAU_400?oAU_40_l0
0004odALaP03o`000?mHM=CoF7CD00CoF7CD00?o0000of^<hOm[S>401?m[S>43o`0001cooooo1_l0
0008ohgAoP03o`000?n:d_ooR];o00KoR];o1?l00003ohOBo`03o`000?n7d_ooQm;o00?oQm;o00?o
0000ooooooooool0@oooool00ol0003oooooooooo`13ooooo`00Eoooool4o`0000?oS/on0_l00002
ohk?oP03o`000?n>cokoS/on00;oS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh5
o`0000GoS/on0_l00006ohk?oP?o00002?n>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh0
1?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>
cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh5o`0000GoS/on00?o
0000ohk?o_n>coh01?n>coh6o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00Co
0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?l679ko1QbN00;o1QbN00?o0000o`0@U?l049@0
0_l00002o`07S@04o`000?l008Co0000o`0000;o002700Go0000o`02R_l00X[o00::o`000003o`07
S@;o00000ol039001Ol0003o3AnMo`000?l149?o000000;o4bBP0_l00004oaPXX`03o`000?l]?[7o
000000;o72^U00?o0000oc11/ol`@K<00_l`@K<2o`0000Co<D>e00?o0000odIKa?m6Fl@00om6Fl@0
0ol0003oFg?Ao`000004odALaP03o`000?mHM=CoF7CD00?oF7CD00?o0000of^<hOm[S>401?m[S>40
0ol0003oNZ7[ogZQj`05o`0000kooooo2Ol00005oho;o003o`000?n=dOkoSM7n00OoSM7n00?o0000
oh[Boon:d_l01Ol00004ohoEo`04o`000?n7d_ooQm;oo`0000CoQm;o0ol00015ooooo`03o`000?oo
oooooooo04;ooooo001Cooooo`Go00002?n>coh2o`0000?oS/on1Ol00008ohk?oP03o`000?n>coko
S/on00?o00000on>coh2o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh5
o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on0_l00006ohk?oP?o00002?n>coh0
0ol0003oS/onohk?oP02ohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006
ohk?oP03o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>coko
S/on00?o00001?n>coh00ol0003oS/onohk?oP04ohk?oPGo00001On>coh00ol0003oS/onohk?oP04
ohk?oP?o00000ol679h2o`0000;o012D0_l000000ol01hgo0000o`00Q002o`0000;o002700Go0000
o`02R_l00X[o00::o`000003o`07S@;o00000ol039001Ol0003o3AnMo`000?l149?o000000?o4bBP
00?o0000oaPXXolH::<00_lH::<01_l0003o;Cjaobdn/Ol0003o72^Uo`0000Go<46c0_l00003oc53
]@03o`000?m6FlCoAU_400?oAU_400?o0000oe]cdOmKLm400_l00002odALaP03o`000?mHM=CoF7CD
00CoF7CD00?o0000of^<hOm[S>401?m[S>400ol0003oNZ7[ogZQj`04ogZQj`ko00001?n<`_T00ol0
003oSl_loho;o008oho;o003o`000?n=dOkoSM7n00GoSM7n1?l0000:ohoEo`03o`000?n7d_oo0000
00Co00000on9dol00ol0003oooooooooo`13ooooo`03o`000?oooooooooo047ooooo001?ooooo`Co
00000on>coh01?l0003oS/ono`000?l00007ohk?oPCo00001On>coh2o`0000KoS/on0ol00008ohk?
oP03o`000?n>cokoS/on00;oS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`00
00KoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`00
00?oS/on0_l00006ohk?oPGo00001On>coh00ol0003oS/onohk?oP04ohk?oPCo00002?n>coh01?l0
003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000
ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00002
oa@`[@04o`000?l679ko1QbNo`HLWP;o00000_l049@2o`000003o`07SOl0003o002400;o00000_l0
08L2o`0000;o00::0_l00002o`07S@03o`000?l66I[o000000;o00b@00Go0000o`dOWOl0003o0A2C
o`000003oa<TX003o`000?lH::?o62RS00;o62RS00Oo0000obdn/Ol]?[7o;Cjao`000?lL:jGo0000
00Co<46c00?o0000odII`_l000000ola@kD00ol0003oAU_4odIKa003odIKa004o`000?mKLm7oFg?A
oe]cd@?o00001_mHM=@00ol0003oJhcQof^<h@04of^<h@03o`000?mjXN_oNZ7[00GoNZ7[00?o0000
ohFclon5/o<01On5/o<00ol0003oS<;iohc2n@07ohc2n@03o`000?n?bocoSl_l00SoSl_l00?o0000
ohgAo_n=dOh01?l00003oiGEo@03o`000?n?eOooSmGo00SoSmGo0ol00008ohWCo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0@?ooool004cooooo1?l00002ohk?oP;o00000_n>coh01?l0
003oS/onohk?o_n>coh2o`0000;oS/on0ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03
o`0000?oS/on0_l00006ohk?oPGo00001On>coh2o`0000KoS/on0ol00008ohk?oP04o`000?n>coko
S/onohk?oPGo00002On>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh0
0ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh0
1?n>coh5o`0000GoS/on0_l00006ohk?oPGo00001On>coh00ol0003oS/onohk?oP04ohk?oPCo0000
2?n>coh01?l0003oS/onohk?o_n>coh5o`0000Go532]0_l00002o`HLWP04o`000?l007ko0000o`0@
U0;o000000?o00N=o`000?l008@00_l00003o`00Q`03o`000?l00X[o00::00;o00000_l01hd00ol0
003o1QVJo`000002o`0<T003o`000?l=7igo3AnM00;o00000olC9:02o`0000Co62RS00Ko0000obdn
/Ol]?[7o0000oa`[YOl00004oc11/`04o`000?m6FL;oAUW2o`0000;o<D>e00?o0000odIKa?m6Fl@0
0om6Fl@00ol0003oFg?Aoe]cd@03oe]cd@;o00001OmHM=@00ol0003oJhcQof^<h@05of^<h@03o`00
0?mjXN_oNZ7[00GoNZ7[00?o0000ohFclon5/o<01On5/o<00ol0003oS<;iohc2n@07ohc2n@03o`00
0?n?bocoSl_l00KoSl_l1?l00008oiGEo@03o`000?n?eOooSmGo00CoSmGo0ol000000onBeoko0000
o`000009ohWCo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0?oooool004[ooooo0_l0
0008ohk?oP;o00000on>coh5o`0000SoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`00
0?n>cokoS/on00?o00000on>coh2o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o0000
1_n>coh4o`0000GoS/on0_l00006ohk?oPGo00001On>coh3o`0000?oS/on1Ol00008ohk?oP04o`00
0?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>
coh01On>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oP03o`000?n>cokoS/on00?o
00001?n>coh00ol0003oS/onohk?oP04ohk?oPGo00001On>coh2o`0000Co532]00Co0000o`HLW_l6
79ko1QbN0_l000000ol049Co0000o`00P@02o`0000;o002400Go0000o`00Qol008Oo0027o`000003
o`02RP04o`000?l01hgo00N=o`0000;o1QVJ00?o0000o`0<T?l000000_l=7id2o`0000Co4bBP00?o
0000oaPXXolH::<00_lH::<01?l0003o;Cjaobdn/Ol]?[42o`0000Co<46c00Oo0000odII`_m6FL;o
AUW2o`000?la@kGo000000GoAU_400?o0000oe]cdOmKLm401?mKLm42o`0000GoF7CD00?o0000of^<
hOm[S>401?m[S>400ol0003oNZ7[ogZQj`05ogZQj`03o`000?n5/o?oQK?c00KoQK?c00?o0000ohc2
nOn<`_T01on<`_T00ol0003oSl_loho;o005o`0000;oVM;l00?o0000oiGEoOnEeOd02?nEeOd00ol0
003oSmGoohoEo`03o`0000GoT]On00?o0000ohWCoon9dol01_n9dol4o`0004Cooooo00?o0000oooo
ooooool0?_ooool002kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o
00002?ooool01?l0003oooooo`000?l00006ohk?oPGo00001On>coh2o`0000KoS/on1?l00005ohk?
oP?o00000on>coh5o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000SoS/on00?o0000ohk?
o_n>coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?
o_n>coh01?n>coh5o`0000GoS/on0_l00006ohk?oPCo00001On>coh2o`0000KoS/on0ol00008ohk?
oP03o`000?n>cokoS/on00;oS/on1Ol00008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh0
0ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01On>coh01?l0003o532]oa@`[OlD
<:d2o`0000;o1QbN00Go0000o`00O_l0003o0000o`00P@02o`0000;o002400Go0000o`00Qol008Oo
0027o`000003o`02RP;o00000_l01hd01Ol0003o1QVJo`000?l0393o000000?o3AnM00?o0000oa<T
X?lC9:000_lC9:02o`0000?o62RS00Co0000obdn/Ol]?[7o;Cja0_l00004oc11/`03o`000?m6FL;o
AUW200;oAUW20_l00006odIKa003o`000?mKLm7oFg?A00?oFg?A00?o0000ofn;gOl000000_l00002
oeQde003o`000?m[S>7oJhcQ00GoJhcQ00?o0000ogZQjomjXN/01OmjXN/00ol0003oQK?cohFcl`05
ohFcl`03o`000?n<`_WoS<;i00KoS<;i1?l00008oiWBo003o`000?nEeOgoUMGm00OoUMGm0ol00008
oi;GoP;o00000_n9dol5o`0000CoR]?o00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0m
ooooo`00;Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000;oS/on0ol00004ohk?oP;o0000
1_n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPCo00001On>coh2o`0000KoS/on
1Ol00005ohk?oP;o00001_n>coh3o`0000SoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03
o`000?n>cokoS/on00?o00001?n>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o
00000on>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000Ko
S/on1Ol00005ohk?oP03o`000?n>cokoS/on00CoS/on1Ol00005ohk?oP?o00000on>coh5o`0000So
S/on00?o0000ohk?o_n>coh00_n>coh4o`0000;o532]0_l00002o`HLWP04o`000?l007ko0000o`0@
U0?o00000_l008@2o`0000;o00270_l00002o`02RP;o00000_l01hd00ol0003o1QVJo`000002o`0<
T003o`000?l=7igo3AnM00;o00000olC9:000ol0003o:3Z_o`000002oaPXX`03o`000?l]?[7o;Cja
00;o;Cja0_l00004oc11/`03o`000?m6FL;oAUW200;oAUW20_l00005odIKa003o`000?mKLm7oFg?A
00CoFg?A00Co0000ofn;gOm_RmgoKh_M0ol00007of^<h@03o`000?mjXN_oNZ7[00KoNZ7[00?o0000
ohFclon5/o<01On5/o<00ol0003oS<;iohc2n@05o`0000;oVL_i00?o0000oiWBo?nId_`02?nId_`0
0ol0003oUMGmoiGEo@03oiGEo@?o00000_nKf?d00ol0003oT]Onoi;GoP06oi;GoPCo00002_n:dol0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo03cooooo000Vooooo`Go00000_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`;o00002On>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on
00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on
0_l00007ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on1?l00005ohk?oP;o0000
1_n>coh3o`0000SoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000OoS/on00?o0000ohk?o_n>coh0
0_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/on
ohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh0
1?n>coh6o`0000?o;E7500Co0000oa@`[OlD<:go532]0_l000002?l679ko0000o`00O_l0003o012D
o`000?l0087o00000ol008@00ol0003o0027o`00Q`02o`0000;o00::0_l00002o`07S@06o`000?l6
6I[o1QVJo`000?l0393o00000_l=7id2o`0000?o4bBP00?o0000obPj[ol000000_lH::<00ol0003o
;Cjaobdn/@03obdn/@03o`000?l`@K?o<46c00;o<46c00?o0000odII`_m6FL800om6FL82o`0000Co
AU_400?o0000oe]cdOmKLm401?mKLm400ol0003oKh_Mofn;g@04ofn;g@?o00001Om[S>400ol0003o
NZ7[ogZQj`05ogZQj`03o`000?n5/o?oQK?c00;oQK?c1_l00008oiW;n@03o`000?nId_coVM;l00So
VM;l00?o0000oiGEoOl000000_l00006oi_Ho@03o`000?nBeokoT]On00?oT]On0ol00002oiGIoP03
o`000?n:doooR]?o00SoR]?o0_l00013ooooo`03o`000?oooooooooo03cooooo000]ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo0_l00007ohk?oPCo00001On>coh2o`0000KoS/on0ol00008ohk?
oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP02ohk?oPGo00002?n>coh0
0ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oP03o`000?n>cokoS/on00?o00000on>coh2
o`0000KoS/on1Ol00005ohk?oP03o`000?n>cokoS/on00CoS/on1Ol00005ohk?oP03o`000?n>coko
S/on00CoS/on1?l00008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?
oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o
0000obeAaOl]DLD00_l]DLD2o`0000;o532]00Ko0000o`00O?l0003o1QbNo`000?l007h2o`000003
o`00POl0003o000000;o002400Go0000o`00Qol008Oo0027o`000002o`02RP05o`000?l04iOo0000
o`07SOl000000_l66IX00ol0003o00b@o`000003o`dOW@03o`000?lC9:3o4bBP00;o4bBP00?o0000
obPj[ol000000_lH::<00ol0003o;Cjaobdn/@02obdn/@03o`000?l`@K?o<46c00;o<46c00?o0000
odII`_m6FL800om6FL800ol0003oG77?o`000003odIKa003o`000?mKLm7oFg?A00CoFg?A00?o0000
ofn;gOm_Rmd01?m_Rmd00ol0003oP:3Woh2Pi`06o`0000CoNZ7[2?l00004oiG1m@03o`000?nIboWo
VL_i00SoVL_i00?o0000oiWBo?nId_`01_nId_`3o`0000[oVmSm00?o0000oi;Go_l000000_l00002
oiGIoP05o`000?nEfOkoUMWnoiGIo_l000001_n:dol3o`000003oh_Dool0003ooooo04?ooooo00?o
0000ooooooooool0>oooool002gooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000;oS/on
0ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPCo0000
1On>coh2o`0000KoS/on1Ol00005ohk?oP;o00001?n>coh5o`0000SoS/on00Co0000ohk?o_n>coko
S/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on00?o0000ohk?o_n>
coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>
coh01?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000SoS/on00Co0000ohk?o_n>
cokoS/on1Ol00008ohk?oP03o`000?l]DLGo;E7500;o;E750_l000001olD<:go0000o`00O?l0003o
1QbNo`000?l007h00_l000000ol0087o0000o`000002o`00Q004o`000?l008Oo0027o`00Q`;o0000
00Ko00::o`000?l04iOo0000o`07SOl00003o`HIVP;o00000ol=7id00ol0003o4bBPoa<TX002oa<T
X003o`000?lX>Zoo000000;o62RS00?o0000obdn/Ol]?[400_l]?[42o`0000?o<46c00?o0000odII
`_m6FL800om6FL801?l0003oG77?oeaacol00003odIKa003o`000?mKLm7oFg?A00CoFg?A00?o0000
ofn;gOm_Rmd01?m_Rmd00ol0003oP:3Woh2Pi`04oh2Pi`Go00001?n=/^l00ol0003oUL7eoiG1m@06
oiG1m@03o`000?nIboWoVL_i00SoVL_i00?o0000oiWBo?nId_`01Ol00002oj3Gn`03o`000?nKf?go
VmSm00SoVmSm0ol00004oiGIoP03o`000?nEfOkoUMWn00;oUMWn00?o0000oh[Coon:dol00ol00005
oh_Do`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool002gooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool3o`0000Sooooo0_l0
0008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on
0_l00006ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on1Ol00005ohk?oP03o`00
0?n>cokoS/on00CoS/on1Ol00005ohk?oP;o00001_n>coh3o`0000SoS/on00Co0000ohk?o_n>coko
S/on1Ol00008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`00
00CoS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?
o_n>coh01?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh3o`0000?o;E750_l000001?lD
<:go0000o`00O?l007`2o`0000;o001n00Co0000o`00POl0087o00000_l008@2o`0000;o00270_l0
0002o`02RP;o000000?o00N=o`000?l66IX00_l66IX2o`0000?o3AnM0_l00003oa<TX006o`000?lX
>Zoo:3Z_o`000?lH::?o00001Ol]?[42o`0000?o<46c00?o0000odII`_m6FL800om6FL800ol0003o
G77?oeaac`02o`000003odIKa?l0003oFg?A00GoFg?A00?o0000ofn;gOm_Rmd01?m_Rmd00ol0003o
P:3Woh2Pi`05oh2Pi`03o`000?n=/^ooSK;_00KoSK;_00?o0000oiG1mOnE`OD01_nE`OD00ol0003o
VL_ioiW;n@07oiW;n@?o00002?nPeo/00ol0003oVmSmoi_Ho@04oi_Ho@?o00000onOfo`01Ol0003o
UMWnoiGIo_nEfOko000000?oUMWn1?l00009oh_Do`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0>Oooool002kooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`;o
00003?ooool2o`0000KoS/on1?l00005ohk?oP;o00001_n>coh3o`0000SoS/on00Co0000ohk?o_n>
cokoS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on00?o0000ohk?
o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00GoS/on00?o0000ohk?o_n>coh00ol00003ohk?
oP03o`000?n>cokoS/on00CoS/on1Ol00005ohk?oP;o00001_n>coh4o`0000GoS/on0ol00003ohk?
oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00004
ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00002oeR;i`;o00000_l]DLD0
1_l0003o001jo`000?lD<:go0000o`00O0;o00000_l007h2o`000004o`00POl0003o0024o`00Q0;o
00000_l008L2o`0000;o00::00Co0000o`0CUol0003o00001?l66IX01?l0003o3AnMo`dOWOl=7id2
o`0000?o4bBP00Ko0000obPj[olX>Zoo0000oaPXXol00005obdn/@03o`000?m4E[oo000000;o<46c
00?o0000odII`_m6FL800om6FL800ol0003oG77?oeaac`02oeaac`;o00001_mKLm400ol0003oKh_M
ofn;g@05ofn;g@03o`000?n0X>OoP:3W00GoP:3W00?o0000ohfbkon=/^l01On=/^l00ol0003oUL7e
oiG1m@07oiG1m@03o`000?nIboWoVL_i00?oVL_i0ol000000onSd_So0000oj3Gn`09oj3Gn`03o`00
0?nKf?goVmSm00?o00001onOfo`00ol0003oUMWnoiGIoP04o`0000CoUm[n00?o0000oh_Doon;e?l0
1On;e?l4o`0004?ooooo00?o0000ooooooooool0>?ooool004Wooooo00?o0000ooooooooool03?oo
ool2o`0000;oS/on0ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l0
0006ohk?oPCo00001On>coh2o`0000KoS/on0ol00008ohk?oP04o`000?n>cokoS/onohk?oPGo0000
2?n>coh00ol0003oS/onohk?oP02ohk?oPGo00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on
00?o0000ohk?o_n>coh01On>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh0
1?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on0ol00003ohk?oPGo0000
2?n>coh01?l0003oS/onohk?o_n>coh5o`0000KoF8_W0_l00002obeAa@04o`000?l007[o0000o`00
00;o001l00?o0000o`00O_l007h00_l000000ol0087o0000o`00Q002o`00Q00<o`000?l008Oo0027
o`000?l03I?o0000o`02R_l0003o01>Go`000?l01hgo00000ol66IX2o`0000?o3AnM0_l00003oa<T
X003o`000?lX>Zoo:3Z_00;o00001Ol]?[401_l0003oA5JoodAF_ol0003o<46co`0000GoAUW200?o
0000oeaacomLLLl00omLLLl2o`0000KoFg?A00?o0000ofn;gOm_Rmd01?m_Rmd00ol0003oP:3Woh2P
i`05oh2Pi`03o`000?n=/^ooSK;_00KoSK;_00?o0000oiG1mOnE`OD01onE`OD00ol0003oVL_io`00
0002o`0000GoXm;h00?o0000oj3GnonPeo/01onPeo/3o`0000[oWm_l0ol000000onGf_ko0000oiOJ
oP06oiOJoP03o`000?n;e?ooRmCo00Co00001?n;e?l00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo03Oooooo0019ooooo`03o`000?oooooooooo00kooooo0_l00008ohk?oP04o`000?n>coko
S/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oP03o`000?n>
cokoS/on00?o00000on>coh2o`0000KoS/on1?l00005ohk?oP;o00001_n>coh5o`0000GoS/on0_l0
0003ohk?oPGo00002?n>coh00ol0003oS/onohk?oP02ohk?oPGo00001on>coh00ol0003oS/onohk?
oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o
0000ohk?o_n>coh01?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on00?o
0000oeR;iomHRnL01?mHRnL2o`000003obeAaOl0003o001j00;o00000_l007`2o`0000;o001n00Co
0000o`00POl0003o00000_l008@2o`00000:o`00Qol0003o00fCo`000?l00X[o0000o`0CUol0003o
00N=o`0000?o1QVJ0_l00003o`dOW@03o`000?lR=:co000000;o4bBP00Co0000obPj[olX>Zoo:3Z_
0_l00004obdn/@06o`000?m4E[ooA5Joo`000?l`@K?o00001Om6FL800ol0003oG77?oeaac`04oeaa
c`;o00001OmKLm400ol0003oKh_Mofn;g@05ofn;g@03o`000?n0X>OoP:3W00GoP:3W00?o0000ohfb
kon=/^l01_n=/^l00ol0003oUL7eoiG1m@05oiG1m@?o00002OnSd_P00ol0003oX=Okoj3Gn`03oj3G
n`?o00000_nVfoX00ol0003oWm_loioKo006oioKo0;o000000GoX]glo`000?nGf_koUm[no`000007
oiOJoP?o00002On;e?l00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Kooooo0019oooo
o`03o`000?oooooooooo013ooooo0_l00006ohk?oPCo00001On>coh3o`0000?oS/on1Ol00008ohk?
oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006
ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on1?l00005ohk?oP;o00001_n>coh5
o`0000GoS/on0_l00003ohk?oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o
0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol0
0004ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000oeR;iomHRnL00omHRnL01?l0003o001io`00
0?l00002o`00NP;o00000_l007`01Ol0003o001no`00O_l0003o002100;o00000_l008@2o`0000;o
00270_l000001?l00X[o0000o`0CUol04iL2o`0000Co1QVJ00Oo0000o`dOWOl=7igo3AnMo`000?lR
=:co000000;o4bBP00Co0000obPj[olX>Zoo:3Z_0_l00005obdn/@03o`000?m4E[ooA5Jo00;o0000
1_m6FL800ol0003oG77?oeaac`03oeaac`03o`000?maRM_o000000;o00000_mKLm400ol0003oKh_M
ofn;g@05ofn;g@03o`000?n0X>OoP:3W00GoP:3W00?o0000ohfbkon=/^l01_n=/^l00ol0003oUL7e
oiG1m@05o`0000;oXL_e00?o0000oj?Bn?nSd_P02?nSd_P00ol0003oX=Oko`000002o`0000KoY]_j
00?o0000oioKo?nOfo`00_nOfo`3o`0000CoX]gl00?o0000oiOJo_l000001?nGf_h3o`0000?oVM[m
00?o0000oh_Doon;e?l01On;e?l3o`0004?ooooo00?o0000ooooooooool0=Oooool004Wooooo00?o
0000ooooooooool04_ooool00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPCo00001On>
coh2o`0000KoS/on1?l00005ohk?oP?o00000on>coh5o`0000SoS/on00Co0000ohk?o_n>cokoS/on
1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on00?o0000ohk?o_n>coh0
0ol00003ohk?oP;o00001_n>coh4o`0000GoS/on0_l00006ohk?oPCo00001On>coh2o`0000KoS/on
0ol00008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh01?l0003oS/onohk?o_n>coh8o`00
0003oeR;iol0003o001i00;o00000_l007X01?l0003o001lo`00O?l00002o`00OP04o`000?l0087o
0021o`0000;o00240_l00002o`00Q`04o`000?l03I?o0000o`0000;o01>G0_l00004o`HIVP05o`00
0?l=7igo3AnMo`dOWOl000000_lR=:`00ol0003o4bBPo`000004obPj[`03o`000?l]?[7o;Cja00?o
;Cja00Co0000odAF_om4E[ooA5Jo0_l00005odII`P03o`000?mLLLooG77?00CoG77?00Co0000og69
fomaRM_oLHWK1?l00007ofn;g@03o`000?n0X>OoP:3W00GoP:3W00?o0000ohfbkon=/^l01?n=/^l4
o`0000SoXL_e00?o0000oj?Bn?nSd_P01onSd_P2o`0000[oY]_j00Co0000oioKo?l0003o00002?nR
gO`2o`000004oiOJo_l0003o0000o`0000OoVM[m00?o0000oh_Doon;e?l01?l00003ohcDo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0=?ooool004Wooooo00?o0000ooooooooool04ooo
ool2o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?
oP03o`0000?oS/on0_l00006ohk?oPCo00001On>coh2o`0000KoS/on1?l00005ohk?oP?o00000on>
coh5o`0000SoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o0000
0on>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/on
ohk?oP05ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oPGo0000
1On>coh00ol0003oS/onohk?oP04ohk?oPGo00001On>coh2o`000006o`00O?l0003o0000o`000?l0
07Wo00000_l007X01?l0003o001lo`00O?l00002o`00OP;o000000[o0021o`000?l0003o0024o`00
0?l01i3o0000o`00Qol0003o00fC0_l00002o`0CU`;o00001?l66IX2o`0000;o3AnM00Ko0000ob8d
[?lR=:co0000oa<TX?l00004obPj[`03o`000?l]?[7o;Cja00?o;Cja00?o0000odAF_om4E[l00_m4
E[l2o`0000CoAUW200?o0000oeaacomLLLl01?mLLLl00ol0003oLHWKog69f`04og69f`Ko00000_m_
Rmd00ol0003oP:3Woh2Pi`05oh2Pi`03o`000?n=/^ooSK;_00Co00000_nK_o400ol0003oXL_eoj7;
m@08oj7;m@03o`000?nSd_SoXm;h00?oXm;h0ol00002oj[Hn003o`000?nVfo[oY]_j00OoY]_j0ol0
0009oj;Mo0?o00002_nIf_d3o`0000SoS=Co00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0dooooo`00BOooool00ol0003oooooooooo`0Eooooo`?o00000on>coh5o`0000SoS/on00Co0000
ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`0000KoS/on00?o
0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4o`0000GoS/on00?o0000ohk?o_n>coh01?n>
coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000OoS/on00?o0000ohk?o_n>coh00_n>
coh5o`0000OoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000OoS/on00?o0000ohk?o_n>coh00ol0
0004ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>
cokoS/on00CoS/on0_l00002o`00O003o`000?l007Wo000000;o001j00?o0000o`00O?l007`00_l0
00001?l007ko0000o`000?l00842o`00000:o`00Q?l0003o00N@o`000?l008Oo0000o`0=Tol0003o
00::o`0000;o01>G00?o0000o`HIV_l66IX00_l66IX2o`0000?o3AnM00Ko0000ob8d[?lR=:co0000
oa<TX?l00003obPj[`;o00001?l]?[400ol0003oA5JoodAF_`02odAF_`03o`000?mKK/go000000Co
AUW200?o0000oeaacomLLLl00omLLLl00ol0003oLHWKog69f`04og69f`03o`000?n3W^CoPikT00?o
PikT3Ol00007oi^ol@03o`000?nQboGoXL_e00SoXL_e00?o0000oj?Bn?l000000_l00006oj[Hn003
o`000?nVfo[oY]_j00?oY]_j0ol00003oj[Nn@03o`000?nRgOcoX]gl00?oX]gl0ol000001?nTg__o
0000ojCNnol00006oiWJo@?o000000?oV]_mo`000?n<e?l02On<e?l00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo03?ooooo0019ooooo`?o00005oooool4o`0000GoS/on0_l00006ohk?oPCo
00001On>coh3o`0000?oS/on1Ol00008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0
003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`00
00CoS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?
o_n>coh01?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on0_l00003ohk?
oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00000
1ol02i3o0000o`00O?l007co0000o`00NOl000000_l007X2o`0000;o001l00Go0000o`00O_l007ko
0000o`00P@02o`0000;o00240_l000001?l008Oo0000o`0=Tol03I<2o`0000;o01>G0_l00004o`HI
VP;o00000_l=7id01_l0003o8SB/ob8d[?l0003o4bBPo`0000Co:3Z_0_l00003obdn/@03o`000?m4
E[ooA5Jo00?oA5Jo00?o0000oe]^cOl000000om6FL800ol0003oG77?oeaac`04oeaac`03o`000?ma
RM_oLHWK00CoLHWK00?o0000oh>Ni?n3W^@01On3W^@00ol0003oTK3/oi6`k005oi6`k003o`000?nK
_o7oVkoa00OoVkoa00?o0000oj7;mOnQboD01onQboD2o`0000[oZ]Sh00?o0000ojKKn_l000000_l0
0007oj[Nn@03o`000?nRgOco000000;o00001?nTg_/01?l0003oY=kkojCNnol00002oiWJo@?o0000
1OnJfod00ol0003oS=CoohcDo`06ohcDo`?o0000@_ooool00ol0003oooooooooo`0booooo`00BOoo
ool00ol0003oooooooooo`0Iooooo`?o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l0
0006ohk?oPCo00001On>coh2o`0000KoS/on1?l00005ohk?oP03o`000?n>cokoS/on00CoS/on1?l0
0007ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000So
S/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?o
S/on0_l00006ohk?oPCo00001On>coh00ol0003oS/onohk?oP04ohk?oPGo00001On>coh2o`0000Co
S/on1Ol00004o`0;T003o`000?l007co001l00Co00000_l007X01?l0003o001lo`00O?l00002o`00
OP?o000000Go00:<o`000?l008Co0000o`07T002o`0000;o00fC0_l00002o`0CU`;o00001?l66IX2
o`0000;o3AnM00Co0000ob8d[?lR=:co8SB/0_l00004obPj[`03o`000?loD[go000000?o;Cja00?o
0000odAF_om4E[l00_m4E[l00ol0003oFfk=oe]^c@02o`000003odII`_l0003oG77?00GoG77?00?o
0000og69fomaRM/01?maRM/00ol0003oPikToh>Ni006oh>Ni003o`000?nA/>coTK3/00GoTK3/00?o
0000oi^olOnK_o401_nK_o400ol0003oXL_eoj7;m@04oj7;m@?o000000?oZm;eo`000?nZf?P02OnZ
f?P2o`0000[oZ]ki0_l00007ojCNn`03o`000?nTg__oY=kk00?o00002OnJfod00ol0003oS=CoohcD
o`05o`0000?oS=Co00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0aooooo`00BOooool0
0ol0003oooooooooo`0Kooooo`;o00000on>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003
ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh0
0ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on0_l00006
ohk?oPCo00001On>coh3o`0000?oS/on1Ol00008ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>
coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?
oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on00Co0000o`0;T?l02i3o00^@
0_l000001Ol007co0000o`000?l007Wo000000;o001j00?o0000o`00O?l007`00_l000002Ol007ko
0000o`000?l0003o00:<o`000?l008Co0000o`07T002o`0000;o00fC0_l00003o`0CU`03o`000?l6
6I[o1QVJ00;o1QVJ00Go0000oaX_ZOl0003o3AnMo`000004ob8d[003o`000?lX>Zoo:3Z_00;o:3Z_
00Co0000ocmB_OloD[go00000_l]?[400ol0003oA5JoodAF_`02odAF_`03o`000?mKK/goFfk=00;o
Ffk=0_l00006oeaac`03o`000?maRM_oLHWK00GoLHWK00?o0000oh>Ni?n3W^@01On3W^@00ol0003o
TK3/oi6`k005oi6`k003o`000?nK_o7oVkoa00OoVkoa00?o0000oj7;mOnQboD00ol00005oj_Bm@03
o`000?nZf?SoZ]Sh00GoZ]Sh0_l00002ojoLm`03o`000?nZg_WoZ]ki00GoZ]ki0_l00002ojgPn@03
o`000?nTg__oY=kk00CoY=kk0ol00002ojKOn`03o`000?nJfogoV]_m00OoV]_m0ol00009ohcDo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0<?ooool004Wooooo00?o0000ooooooooool0
7Oooool3o`0000GoS/on0ol00003ohk?oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000Oo
S/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh2o`00
00KoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4o`0000GoS/on00?o0000ohk?
o_n>coh01?n>coh5o`0000GoS/on0_l00004ohk?oPGo00001on>coh01?l0003oS/onohk?o_n>coh5
o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00GoS/on00Go0000
o`0;T?l02i3o00^@o`000002o`00O003o`000?l007Wo000000;o001j0_l000001?l007co0000o`00
0?l007h2o`000009o`00POl0003o0000o`00Q?l0003o00N@o`000?l008Oo000000;o00fC00Go0000
o`0CUol04iOo01>Go`000004o`HIVP05o`000?lJ;jWo0000o`dOWOl000001?lR=:`2o`0000?o:3Z_
00Oo0000ocmB_OloD[go?e:mo`000?l]?[7o000000GoA5Jo00?o0000oe]^cOmKK/d00_mKK/d2o`00
00KoG77?00?o0000og69fomaRM/01?maRM/00ol0003oPikToh>Ni006oh>Ni003o`000?nA/>coTK3/
00GoTK3/00?o0000oi^olOnK_o401_nK_o43o`0000WoZm;e00?o0000oj[Hn?nZf?P00_nZf?P2o`00
00Go[mcg00?o0000oj[NnOnZg_T00_nZg_T2o`0000Go[N3i00?o0000ojCNnonTg_/00_nTg_/2o`00
00GoY]ok00?o0000oi[KoOnJfod00onJfod3o`0000?oV]_m00?o0000ohcDoon<e?l01On<e?l3o`00
04;ooooo00?o0000ooooooooool0;oooool004Sooooo00?o0000ooooooooool07oooool3o`0000Ko
S/on1?l00005ohk?oP;o00001_n>coh4o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000Go
S/on0ol00003ohk?oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?
o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00004ohk?
oP03o`000?n>cokoS/on00CoS/on1Ol00005ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?
oP?o00000on>coh5o`0000OoS/on00?o0000ohk?o_n>coh00_n>coh4o`0000;o00^@00Go0000o`00
O?l007co0000o`00N@02o`000004o`00N_l0003o0000o`00O0;o000000Ko001no`000?l0003o0021
o`000?l00X`2o`0000;o00N@0_l00002o`0=T`04o`000?l04iOo01>Go`0CU`;o00000ol66IX01_l0
003o6RnYoaX_ZOl0003o3AnMo`0000Co8SB/00?o0000obPj[olX>Zl00_lX>Zl01?l0003o?e:mocmB
_OloD[d2o`0000GoA5Jo00?o0000oe]^cOmKK/d00omKK/d2o`0000GoG77?00?o0000og69fomaRM/0
1OmaRM/00ol0003oPikToh>Ni005oh>Ni003o`000?nA/>coTK3/00KoTK3/00?o0000oi^olOnK_o40
0_nK_o43o`000003ojO:l_l0003oZm;e00[oZm;e00Co0000oj[Hn?l0003o00002?n_g?L01?l0003o
Z]kio`000?l00008ojgPn@06o`000?nTg__o0000o`000?nVgo_o00001_nVgo/00ol0003oV]_mo`00
0002o`0000OoV]_m00?o0000ohcDoon<e?l01?l00003ohcDo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0;_ooool004Sooooo00?o0000ooooooooool08Oooool2o`0000;oS/on0ol00003
ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh0
0ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPCo00001On>coh2o`0000KoS/on1?l00005
ohk?oP;o00001?n>coh5o`0000OoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?n>
cokoS/on00?o00000on>coh00ol0003oS/onohk?oP05ohk?oP03o`000?n>cokoS/on00?o00000on>
coh00ol0003oS/onohk?oP04ohk?oPGo00001On>coh00ol0003oS/onohk?oP04ohk?oPGo00000ol5
6i`00ol0003o00^@o`0;T002o`000003o`00O?l0003o000000;o000000Co001jo`000?l0003o001l
0_l000000ol007ko0000o`00R@02o`000003o`02S?l0003o000000;o00N@0_l00002o`0=T`;o0000
0ol04iL00ol0003o1QVJo`HIVP02o`HIVP05o`000?lJ;jWo0000o`dOWOl000001?lR=:`00ol0003o
:3Z_obPj[`02obPj[`03o`000?loD[go?e:m00;o?e:m0_l00004odAF_`03o`000?mKK/goFfk=00?o
Ffk=00?o0000og66fOl000000_l00002oeaac`03o`000?maRM_oLHWK00GoLHWK00?o0000oh>Ni?n3
W^@01On3W^@00ol0003oTK3/oi6`k006oi6`k003o`000?nK_o7o000000;o00001OnWb_800ol0003o
Zm;eoj_Bm@08oj_Bm@;o00002_n_g?L2o`0000[o[N3i0_l00003ojKOn`03o`000?nVgo_oY]ok00Co
Y]ok0_l0000:oi[Ko@?o00002?n<e?l00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02go
oooo0018ooooo`03o`000?oooooooooo02?ooooo0_l00008ohk?oP04o`000?n>cokoS/onohk?oPGo
00001on>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?
oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh5o`00
00GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on0ol00003ohk?oPGo00001on>coh00ol0
003oS/onohk?oP02ohk?oPGo00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?
o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000o`DKW?l56i`00_l56i`2o`00
0004o`0;T?l0003o0000o`00O0Co000000Go001jo`000?l008?o0000o`00O003o`000008o`00ROl0
003o0000o`02S?l0003o0024o`000?l01i02o`0000?o00fC00Co0000o`0CUol04iOo01>G0_l00003
o`HIVP05o`000?lJ;jWo0000o`dOWOl000001?lR=:`2o`0000?o:3Z_00?o0000ocmB_OloD[d00olo
D[d2o`0000CoA5Jo00?o0000oe]^cOmKK/d00omKK/d01?l0003oLHKIog66fOmaQ]T4o`0000OoLHWK
00?o0000oh>Ni?n3W^@01On3W^@00ol0003oTK3/oi6`k004oi6`k0?o00002OnWb_800ol0003oZm;e
oj_Bm@05oj_Bm@;o000000?o/MWdo`000?n_g?L01on_g?L2o`000003ok?Om_l0003o[N3i00Oo[N3i
0_l00002ojoRn004o`000?nVgo_oY]oko`0000?oY]ok0ol00002ojOPn`03o`000?nJfogoV]_m00Co
V]_m0ol00002oi_Ko@03o`000?n<e?ooS=Co00GoS=Co0ol00012ooooo`03o`000?oooooooooo02co
oooo0018ooooo`?o00009Oooool2o`0000KoS/on1?l00005ohk?oP;o00000on>coh6o`0000GoS/on
0ol00003ohk?oPGo00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000OoS/on00?o0000ohk?o_n>
coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>
coh01?n>coh5o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on0_l00003ohk?oPGo
00002?n>coh01?l0003oS/onohk?o_n>coh5o`0000OoS/on00Co0000o`DKW?l56ico1A^L0_l00000
1?l02i3o0000o`000?l007`3o`000003o`00POl0003o001j00;o000000Co001lo`000?l0003o001n
0ol00002o`02S0;o00000_l01i001Ol0003o00fCo`0=Tol03I?o000000?o01>G0_l00003o`HIVP03
o`000?lJ;jWo6RnY00;o00001OlR=:`2o`0000;o:3Z_00?o0000ocmB_OloD[d00oloD[d00ol0003o
Ef_;o`000003odAF_`03o`000?mKK/goFfk=00?oFfk=00?o0000og66fOmaQ]T01?maQ]T6o`0000;o
LHWK00?o0000oh>Ni?n3W^@01On3W^@00ol0003oTK3/oi6`k004o`0000;oX;k^00?o0000ojO:l_nW
b_801onWb_800ol0003oZm;eoj_Bm@02oj_Bm@?o00001?nafO@00ol0003o[mcgojoLm`02ojoLm`?o
00001?ncgoH00ol0003o[N3iojgPn@02ojgPn@?o00001On_h_P00ol0003oY]oko`000003o`0000Ko
Yn3k00?o0000oi[KoOnJfod00ol00006oi_Ko@03o`000?n<e?ooS=Co00Co00000on<e?l00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo02_ooooo0018ooooo`03o`000?oooooooooo02Oooooo
00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o0000
1_n>coh4o`0000GoS/on0ol00003ohk?oPKo00001On>coh2o`0000?oS/on1Ol00008ohk?oP04o`00
0?n>cokoS/onohk?oPGo00001on>coh00ol0003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>
coh01?n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l00006ohk?oPCo00001On>coh00ol0003o
S/onohk?oP04ohk?oPGo00001On>coh2o`0000?oS/on1?l00003o`DKW005o`000?l02i3o00^@o`00
0?l007`00_l000001?l007Wo0000o`000?l007X2o`000006o`00O?l0003o0000o`00O_l0003o0029
0_l000000ol00Xco0000o`000002o`07T005o`000?l03I?o00fCo`0=Tol000000ol04iL00ol0003o
4RRVo`000002o`HIVP03o`000?lJ;jWo6RnY00;o00001OlR=:`2o`0000;o:3Z_00?o0000ocmB_Olo
D[d00oloD[d01?l0003oEf_;oeM[bol00002odAF_`03o`000?mKK/goFfk=00?oFfk=00?o0000og66
fOmaQ]T01?maQ]T00ol0003oQ9cRohBLhP03ohBLhPgo00001onP_^h00ol0003oYl[bojO:lP07ojO:
lP04o`000?n[d_Go0000o`0000So/MWd00Co0000ojoLmol0003o00002?ncgoH01?l0003o[N3io`00
0?l00008ojoRn0?o00002OnWh?/3o`0000WoVm_m0ol00008ohcDo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0:oooool004Sooooo00?o0000ooooooooool0:?ooool2o`0000OoS/on00?o
0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on0_l0
0006ohk?oPCo00001On>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh3o`0000?oS/on1_l0
0005ohk?oP;o00000on>coh5o`0000SoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`00
0?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oP03o`000?n>cokoS/on00?o0000
1?n>coh00ol0003oS/onohk?oP04ohk?oPCo00000olF<Zh01?l0003o1A^Lo`DKW?l56i`2o`000005
o`0;T?l0003o0000o`000?l007l00ol000000ol007[o0000o`00P`03o`000003o`00O_l0003o0029
00;o000000?o00:<o`000?l000000_l01i02o`0000;o00fC0_l00003o`0CU`;o00000_l66IX01?l0
003o6RnYoaX_ZOlJ;jT2o`0000Co8SB/00?o0000ocU=^ol000000_lX>Zl00ol0003o?e:mocmB_@03
ocmB_@04o`000?mGJl_oEf_;o`0000;oA5Jo00?o0000oe]^cOmKK/d00omKK/d00ol0003oLHKIog66
f@04og66f@03o`000?n4W>;oQ9cR00GoQ9cR00?o0000oiB_jOnD[nT01OnD[nT00ol0003oX;k^oj2n
kP07oj2nkP03o`000?nWb_;oYl[b00KoYl[b0_l0000:ok7Im0;o00002_ncgoH2o`0000Wo[n;h00Co
0000ok7Sn?nahoSo00001onWh?/2o`0000?oYn7k00?o0000oi_KoOnKfod00onKfod3o`0000;oVmcm
00?o0000ohcDoon<e?l01on<e?l00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02[ooooo
0018ooooo`03o`000?oooooooooo02[ooooo0ol00003ohk?oPCo00002?n>coh01?l0003oS/onohk?
o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on
00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4o`0000GoS/on00?o0000ohk?o_n>coh0
1?n>coh4o`0000GoS/on0ol00003ohk?oPKo00001On>coh2o`0000CoS/on1Ol00007ohk?oP04o`00
0?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00Co0000oaHb[_lF
<Zko5S:^0_l00002o`DKW0;o000000Co00^@o`000?l0003o001l0ol000001?l0087o0000o`000?l0
08<2o`000004o`00Q_l0003o0000o`00R@;o00000_l00X`01Ol0003o00N@o`07T?l01i3o000000?o
00fC00Oo0000o`0CUol04iOo01>Go`000?lB::Ko000000;o1QVJ00?o0000oaX_ZOlJ;jT00_l00004
ob8d[006o`000?liCK_o>Dfko`000?lX>Zoo00001OloD[d01ol0003oEf_;oeM[bomGJl_o0000odAF
_ol000001OmKK/d00ol0003oLHKIog66f@04og66f@03o`000?n4W>;oQ9cR00KoQ9cR00?o0000oiB_
jOnD[nT01OnD[nT00ol0003oX;k^oj2nkP06oj2nkP03o`000?nWb_;oYl[b00?oYl[b0ol000000on`
d_;o0000ok7Im008ok7Im004o`000?nggO?o]mgco`0000Oo/mof0_l00002okKRm@03o`000?n_h_So
[n;h00Co[n;h0_l00003ok7Sn0;o00001?nWh?/2o`0000KoYn7k00?o0000oi_KoOl000000_l00006
oi_Lo@03o`000?n<e?ooS=Co00GoS=Co0ol00011ooooo`03o`000?oooooooooo02Wooooo0018oooo
o`03o`000?oooooooooo02cooooo1?l00004ohk?oP;o00001_n>coh4o`0000GoS/on0ol00003ohk?
oPGo00001on>coh01?l0003oS/onohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003
ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4
o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on0_l00003ohk?oPKo00001On>coh2
o`0000CoS/on1Ol00007ohk?oP05o`000?lF<Zko5S:^oaHb[_l000000_l56i`2o`000004o`0;T?l0
003o0000o`00O0?o000000Co0021o`000?l0003o00230_l000001?l008Ko0000o`000?l008T2o`00
00;o00:<00Go0000o`07T?l01i3o00N@o`000003o`0=T`;o00000_l04iL01_l0003o4RRVoa8XY_l0
003o1QVJo`0000?o6RnY00?o0000ob8d[?lR=:`00_lR=:`01?l0003o>DfkocU=^oliCK/2o`0000Go
?e:m00?o0000oeM[bomGJl/00_mGJl/2o`0000KoFfk=00?o0000og66fOmaQ]T01?maQ]T00ol0003o
Q9cRohBLhP05ohBLhP03o`000?nD[nWoU:oY00GoU:oY00?o0000oj2nk_nP_^h01onP_^h00ol0003o
Yl[bo`000002o`0000Go/=;b00?o0000ok7Im?nafO@01?nafO@2o`0000Co]mgc00?o0000ok?Om_nc
goH00_ncgoH2o`0000Go]^;e00Co0000ojoRn?n_h_So[n;h0_l00005ok7Sn004o`000?nahoSo0000
ojOPn`;o00002?nWhO/2o`0000[oVmcm00?o0000ohcDoon<e?l01?l00003ohcDo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0:?ooool004Sooooo00?o0000ooooooooool0;_ooool2o`00
00KoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4o`0000GoS/on00?o0000ohk?
o_n>coh01?n>coh4o`0000GoS/on0ol00003ohk?oPGo00001on>coh01?l0003oS/onohk?o_n>coh5
o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000
ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1Ol00005ohk?oP03o`000?n>coko
S/on00CoS/on1Ol00005ohk?oP03o`000?n>cokoS/on00;oS/on1?l00002oaHb[P;o000000?o1A^L
o`000?l007h00ol000001ol007co0000o`00Ool0003o0021o`000?l007X00_l000001?l007co0000
o`000?l00002o`00R@03o`000?l00Xco00:<00;o00000_l01i001?l0003o00fCo`0=Tol03I<2o`00
00;o01>G00Ko0000oa8XY_lB::Ko0000o`HIV_l00003oaX_Z@03o`000?lR=:co8SB/00?o8SB/00?o
0000ocU=^oliCK/00_l00005ocmB_@03o`000?mGJl_oEf_;00?oEf_;0_l00005oe]^c@03o`000?ma
Q]WoLHKI00CoLHKI00?o0000ohBLh_n4W>801_n4W>800ol0003oU:oYoiB_j@05oiB_j@03o`000?nP
_^koX;k^00KoX;k^0_l00009ok3BlP04o`000?nafOCo/MWdok7Im0;o00001onggO<01?l0003o/mof
o`000?l00008okKRm@03o`000?n_h_So000000Oo/N?h00?o0000ok7Sn?l000000_l00007ojOQn`;o
000000?oYn7ko`000?nKg?d02OnKg?d3o`0000SoS=Co00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Wooooo`00B?ooool00ol0003oooooooooo`0`ooooo`04o`000?n>cokoS/onohk?oPGo
00002?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003o
S/onohk?oP03o`0000?oS/on0_l00006ohk?oPCo00001On>coh00ol0003oS/onohk?oP04ohk?oPCo
00001On>coh3o`0000?oS/on1Ol00007ohk?oP04o`000?n>cokoS/onohk?oPGo00001on>coh00ol0
003oS/onohk?oP03o`0000CoS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`00
00?oS/on00?o0000ohk?o_n>coh01?n>coh5o`0000?o<EO800?o0000oaHb[_lF<Zh00_l00002o`DK
W0?o000000Co001no`000?l0003o001o0_l000001?l0087o0000o`000?l008<2o`000005o`00Q_l0
003o0029o`00ROl000000ol00X`00ol0003o00N@o`07T002o`0000;o00fC00?o0000o`PQX_l00000
0_l04iL00ol0003o4RRVoa8XYP02o`0000?o6RnY0_l00004ob8d[004o`000?liCK_o>DfkocU=^`;o
00001OloD[d00ol0003oEf_;oeM[b`03oeM[b`;o00001OmKK/d00ol0003oLHKIog66f@04og66f@03
o`000?n4W>;oQ9cR00GoQ9cR00?o0000oiB_jOnD[nT01_nD[nT00ol0003oX;k^oj2nkP02oj2nkP?o
000000?oZlW_o`000?n`d_802On`d_800ol0003o/MWdo`000009okOMl`;o00002_nfh_D3o`0000Oo
/N?h0_l00003ok7Tn003o`000?nWhO_oYn7k00;oYn7k0_l00004ojOQn`03o`000?nKg?goVmcm00Co
Vmcm0ol00002oi[Ko@03o`000?n<e?ooS=Co00GoS=Co1?l00010ooooo`03o`000?oooooooooo02Ko
oooo0018ooooo`?o0000<Oooool3o`0000GoS/on0ol00003ohk?oPGo00001on>coh01?l0003oS/on
ohk?o_n>coh5o`0000SoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00Co
S/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1Ol00005ohk?oP03
o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o00000on>coh5o`0000SoS/on00Co0000ohk?o_n>
cokoS/on1Ol00007ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003o<EO8oc5Gb003oc5G
b003o`000?lF<Zko5S:^00;o000000Co1A^Lo`000?l0003o00^@0ol000001?l007oo0000o`000?l0
0842o`000005o`00Pol0003o0000o`00Q_l000000_l008T2o`0000;o00:<00Go0000o`07T?l01i3o
00N@o`000002o`0=T`03o`000?l88J;o000000;o01>G00?o0000oa8XY_lB::H00_l00004oaX_Z@;o
00000olR=:`00ol0003o>DfkocU=^`02ocU=^`;o00001?loD[d00ol0003oEf_;oeM[b`03oeM[b`03
o`000?m^PmOo000000;o00000_mKK/d00ol0003oLHKIog66f@04og66f@03o`000?n4W>;oQ9cR00Go
Q9cR00?o0000oiB_jOnD[nT01_nD[nT00ol0003oX;k^o`000002o`0000GoZlW_00?o0000ok3Bl_n`
d_801on`d_82o`0000Wo]mgc00Co0000ok[QlonjhO?o00001onfh_D2o`0000?o^>Ce00?o0000ok7S
n?nahoP00_nahoP3o`0000Go/NCh00Co0000ojOQnol0003o00001onWhO/00ol0003oVmcmoi_Lo@03
o`0000KoV]_m00?o0000ohcDoon<e?l01?l00004ohcDo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool09Oooool004Oooooo00?o0000ooooooooool0=?ooool2o`0000KoS/on1?l00005ohk?
oP;o00000on>coh6o`0000GoS/on0ol00003ohk?oPGo00001on>coh01?l0003oS/onohk?o_n>coh5
o`0000OoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000
ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o00001_n>coh4
o`0000GoS/on0_l00003ohk?oPGo00001on>coh00ol0003o<EO8oc5Gb002oc5Gb0;o000000Ko5S:^
o`000?l0003o1A^Lo`000?l007h4o`000004o`00Ool0003o0000o`00P@;o000000Co0023o`000?l0
003o00260_l00002o`00R@04o`000?l00Xco00:<o`0000?o00N@0_l00002o`0=T`05o`000?l88J;o
0000o`0CUol000000olB::H2o`0000?o6RnY00?o0000oc57^Ol000000_lR=:`00ol0003o>DfkocU=
^`02ocU=^`03o`000?mBI/Wo000000?o?e:m00?o0000oeM[bomGJl/01?mGJl/01?l0003oKX?Gofj3
eom^PmL3o`0000KoLHKI00?o0000ohBLh_n4W>801_n4W>800ol0003oU:oYoiB_j@04oiB_j@?o0000
2On[bNl00ol0003o/=;bok3BlP04ok3BlP;o00000_ngfO400ol0003o]mgcokOMl`04okOMl`;o0000
1?njhO<00ol0003o]^;eokKRm@02okKRm@;o00001_nhi?D01?l0003o/N?ho`000?l00002ok7Tn003
o`000?nai?So/NCh00?o/NCh0_l00009ojOQn`?o00002OnJfod3o`0000WoS=Co00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Tooooo`00Aoooool00ol0003oooooooooo`0fooooo`03o`00
0?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh2o`0000KoS/on
1?l00005ohk?oP;o00000on>coh6o`0000GoS/on0_l00003ohk?oPGo00002?n>coh01?l0003oS/on
ohk?o_n>coh5o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00Go
S/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP03
o`000?n>cokoS/on00CoS/on0ol00003oc5Gb007o`000?lF<Zko0000o`000?l56ico0000o`00OP02
o`000005o`00O_l0003o001oo`00Ool000000_l008401Ol0003o0023o`00Pol0003o002600;o0000
0_l008T00ol0003o00:<o`02S002o`0000;o00N@0_l00002o`0=T`05o`000?l88J;o0000o`0CUol0
00000olB::H2o`0000?o6RnY00?o0000oc57^Ol000000olR=:`01Ol0003o>DfkocU=^oliCK_o0000
00;oDVK900Go0000ocmB_OloD[go?e:mo`000005oeM[b`03o`000?m^PmOoKX?G00CoKX?G0ol00004
og66f@03o`000?n4W>;oQ9cR00GoQ9cR00?o0000oiB_jOnD[nT01?l00002oj:mk003o`000?n[bNoo
ZlW_00OoZlW_00?o0000ok3Bl_n`d_800_n`d_82o`0000Go]mWa00Co0000okOMlonggO?o]mgc0_l0
0007ok[Ql`04o`000?nfh_Go0000o`0000So^>Ce0ol00003ok7Tn004o`000?nai?So/NChok7Tn0;o
00000_nai?P00ol0003oYn7kojOQn`03ojOQn`?o00000onWhO/00ol0003oV]_moi[Ko@03oi[Ko@?o
00000_nJfod00ol0003oS=CoohcDo`06ohcDo`?o0000@?ooool00ol0003oooooooooo`0Sooooo`00
Aoooool00ol0003oooooooooo`0gooooo`;o00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on
0_l00006ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oPCo0000
1On>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh3o`0000?oS/on1_l00005ohk?oP;o0000
0on>coh5o`0000OoS/on00?o0000ohk?o_n>coh00_n>coh5o`0000OoS/on00?o0000ohk?o_n>coh0
0ol00003ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol000001?mLT>Wo0000
o`00P?l00002oc5Gb0;o000000Go5S:^o`000?l0003o0000o`00OP02o`000005o`00O_l0003o001o
o`00Ool000000_l008401?l0003o0023o`00Pol00002o`00QP04o`000?l008Wo0029o`0000?o00:<
00?o0000o`07T?l01i000_l00002o`0=T`03o`000?l88J;o226R00;o00001?lB::H01Ol0003o6RnY
oaX_ZOlJ;jWo000000;o<DNi00Co0000ob8d[?lR=:co00001?liCK/01?l0003oDVK9oe9VbOl00002
ocmB_@03o`000?mGJl_oEf_;00?oEf_;00?o0000ofj3eom^PmL01?m^PmL00ol0003oPi[Qoh>Jh@05
o`0000CoQ9cR1_l00007oj:mk003o`000?n[bNooZlW_00OoZlW_00Co0000ok3Bl_l0003o00002?ng
fO400ol0003o]mgco`000009ok[Ql`;o00002Onhi?D01Ol0003o^NGeokWUmOniiOGo000000;o/NCh
00Co0000ok7Tn?l0003o00001Onai?P00ol0003oYn7ko`000002o`0000OoYn7k00?o0000oi[KoOl0
00000_l00006oi[Ko@03o`000?n<e?ooS=Co00Go00000on;e?l00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo02?ooooo0017ooooo`03o`000?oooooooooo03Wooooo0ol00003ohk?oPCo0000
2?n>coh01?l0003oS/onohk?o_n>coh5o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03
o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4o`0000Go
S/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on0_l00003ohk?oPOo00001On>coh2o`0000?o
S/on1Ol00007ohk?oP04o`000?n>cokoS/onohk?oPGo00001OmLT>T00ol0003o0020o`000002o`00
0003o`00Ool0003o000000;o00000_l007h01_l0003o001no`000?l0003o001oo`0000;o00210_l0
00001Ol008?o0000o`000?l008Ko000000;o00290_l00002o`02S008o`000?l01i3o00N@o`000?l0
6Yko0000o`0=Tol00002o`PQXP03o`000?l04iOo000000?o4RRV00Go0000oaX_ZOlJ;jWo6RnYo`00
0003oc57^@03o`000?lR=:co000000Co>Dfk00Oo0000oe9VbOmBI/WoDVK9o`000?loD[go000000Ko
Ef_;00?o0000ofj3eom^PmL01?m^PmL00ol0003oPi[Qoh>Jh@03oh>Jh@Go00001?nE[NL00ol0003o
X[g/oj:mk006oj:mk003o`000?n[bNooZlW_00OoZlW_0_l0000:okOIl@;o00002OnjhO<01?l0003o
_NCbokgTl_l00006okSTm@;o00001OniiOD01?l0003o/NCho`000?l00007ok7Tn0?o00002OnWhO/2
o`0000WoV]_m0ol00009oh_Do`03o`000?oooooooooo03gooooo00?o0000ooooooooool08_ooool0
04Oooooo00?o0000ooooooooool0>oooool4o`0000CoS/on0ol00003ohk?oPKo00001On>coh2o`00
00?oS/on1Ol00007ohk?oP04o`000?n>cokoS/onohk?oPGo00002?n>coh00ol0003oS/onohk?oP03
o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000
ohk?o_n>coh01?n>coh4o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh5o`0000GoS/on0_l00003
ohk?oPKo00001On>coh2o`0000CoG93Y00?o0000o`00P?l008001?l000001?l007ko0000o`000?l0
07h4o`000003o`00Ool0003o000000;o002100Ko0000o`00Pol008?o0000o`00Q_l00002o`00R@;o
00000_l00X`2o`0000;o00N@0_l000000ol03I?o0000o`PQXP02o`PQXP;o00000olB::H2o`0000?o
6RnY00Ko0000oc57^OlaAkWo0000ob8d[?l00004ocU=^`03o`000?mBI/WoDVK900;oDVK90_l00006
oeM[b`03o`000?m^PmOoKX?G00CoKX?G00?o0000oh>JhOn3V^401?n3V^400ol0003oUJgWoiF]i`06
oiF]i`03o`000?nR_NcoX[g/00KoX[g/00?o0000oj_9kon[bNl01?n[bNl2o`000003okCBl?l0003o
]mWa00So]mWa00Co0000okcNlOnlg_7o00001_njhO<2o`0000Co_NCb00Co0000okSTmOnhi?Go^>Ce
0_l00007okWUm@?o00001_nai?P2o`0000?o/NGh00?o0000ojOQnonWhO/00onWhO/3o`0000;oY^7k
00?o0000oi[KoOnJfod00onJfod3o`0000?oVM_m00?o0000oh_Doon;e?l01On;e?l3o`0003oooooo
00?o0000ooooooooool08Oooool004Oooooo00Co0000ooooool0003o0000??ooool2o`0000KoS/on
1?l00005ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP?o00000on>coh5o`0000GoS/on
0ol00003ohk?oPGo00001on>coh01?l0003oS/onohk?o_n>coh5o`0000OoS/on00?o0000ohk?o_n>
coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00004ohk?oP03
o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o00000on>coh6o`000003oeb@jOl0003o002000;o
002000?o0000o`00Ool000000ol000001Ol007ko0000o`000?l007ko000000;o001o00Co0000o`00
POl0087o00000_l008<01?l0003o0026o`000?l00002o`00R@03o`000?l00Xco00:<00;o00000_l0
1i001Ol0003o01ZNo`000?l03I?o000000;o226R0_l00004oa8XYP05o`000?lJ;jWo6RnYoaX_ZOl0
00000olaAkT2o`0000Co>Dfk00?o0000oe9VbOmBI/T00omBI/T2o`0000GoEf_;00?o0000ofj3eom^
PmL01?m^PmL00ol0003oPi[Qoh>Jh@05oh>Jh@03o`000?nE[NOoUJgW00GoUJgW00?o0000oj:mk?nR
_N`01onR_N`01?l0003oZlW_oj_9kon[bNl2o`0000Co]=;`00?o0000okOIlOngfO401?ngfO42o`00
00Co_=ka00Co0000ok[QlonjhO?o^^7c0_l00007okgTlP03o`000?nhi?Go000000Oo^NGe0_l00002
okWVm@03o`000?nai?So/NCh00;o/NCh0_l00006ok7Un003o`000?nWhO_o000000;o00001_nVhO/0
0ol0003oV]_mo`000002o`0000OoVM_m00?o0000oh_Doon;e?l01?l00003oh_Do`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool004Oooooo0_l00010ooooo`03o`000?n>cokoS/on
00?o00000on>coh2o`0000GoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP;o00001_n>coh4o`00
00CoS/on0_l00006ohk?oPCo00001On>coh2o`0000?oS/on1_l00005ohk?oP;o00000on>coh5o`00
00OoS/on00Co0000ohk?o_n>cokoS/on1Ol00008ohk?oP03o`000?n>cokoS/on00?o00000on>coh0
0ol0003oS/onohk?oP04ohk?oPCo00001On>coh4o`0000?o002000Go0000o`00Ool0003o001no`00
0002o`00OP03o`000?l007ko000000;o001o00Co0000o`00POl0087o00000_l008<01?l0003o0026
o`00Q_l00002o`00R@;o000000[o00:<o`000?l04i[o0000o`07T?l0003o01ZNo`000?l03I?o0000
0ol88J800ol0003o4RRVoa8XYP02oa8XYP;o00000_lJ;jT00ol0003o<DNioc57^@02oc57^@;o0000
1?liCK/00ol0003oDVK9oe9Vb@03oe9Vb@;o00001OmGJl/00ol0003oKX?Gofj3e`04ofj3e`03o`00
0?n3V^7oPi[Q00CoPi[Q00?o0000oiF]ionE[NL01_nE[NL00ol0003oX[g/oj:mk006oj:mk004o`00
0?n[bNoo0000o`0000Oo]=;`00Co0000okOIlOngfO7o]mWa0_l00007okcNl@03o`000?njhO?o0000
00Wo_NCb0_l00006okWUm@;o00001Onii_D01?l0003o/NCho`000?l00008ok7Un0;o00002OnVhO/2
o`0000[oVM_m0ol00008oh_Do`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool0
02Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool3o`00
00Wooooo00?o0000ooooooooool0@?ooool2o`0000SoS/on00Co0000ohk?o_n>cokoS/on1?l00008
ohk?oP03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oP03o`000?n>coko
S/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh00ol0003oS/onohk?oP04
ohk?oPCo00001On>coh2o`0000?oS/on1_l00005ohk?oP;o00001?n>coh5o`0000OoS/on00?o0000
ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on00Co0000o`00QOl008Go00000_l0
08001Ol0003o001oo`000?l007ko000000;o001n00?o0000o`00O_l000000_l007l01?l0003o0021
o`00POl00002o`00P`;o000000Co0026o`000?l008Wo00290_l00002o`02S0;o000000Co00N@o`00
0?l06Yko01ZN0_l00003o`PQXP;o00000olB::H01Ol0003o:42fo`000?lJ;jWo000000Go<DNi00?o
0000ocU=^oliCK/00_liCK/00ol0003oDVK9oe9Vb@03oe9Vb@04o`000?mZP=Ko0000o`0000?oEf_;
00?o0000ofj3eom^PmL01?m^PmL00ol0003oPi[Qoh>Jh@05oh>Jh@03o`000?nE[NOoUJgW00GoUJgW
00?o0000oj:mk?nR_N`01_nR_N`2o`0000[o]=;`00?o0000okOIlOl000002Onlg_42o`0000Wo_NCb
00Co0000okkVl_nni_;o00001?niiOD00ol0003o^NKeokWVm@05okWVm@;o00002OnaiOP01?l0003o
/>Ghok3Un?l00005ojKQn`?o00000_nUhO/00ol0003oVM_moiWKo@04oiWKo@?o00000_nIfoh00ol0
003oRmCooh_Do`05oh_Do`?o0000?oooool00ol0003oooooooooo`0Nooooo`008oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@_ooool3o`0000?oS/on
1_l00004ohk?oP?o00000on>coh5o`0000OoS/on00Co0000ohk?o_n>cokoS/on1Ol00007ohk?oP03
o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oP03o`000?n>cokoS/on00?o
00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh2o`0000?oS/on1ol00005ohk?oP03
o`000?n>cokoS/on00;oS/on1Ol00007ohk?oP04o`000?n>cokoS/onohk?oPCo000000So0025o`00
0?l0083o0020o`000?l007oo0000o`00OP;o000000?o001no`000?l007h00_l000000ol007oo0000
o`000002o`00P@05o`000?l008?o0000o`000?l008H00_l000001ol008Wo0000o`0<U_l0003o00:<
o`000?l04iX00_l00002o`0JWP;o00001?l88J801ol0003o4RRVoa8XY_lB::Ko0000obQ0]_l00000
0_lJ;jT00ol0003o<DNioc57^@02oc57^@03o`000?liCK_o>Dfk00;o>Dfk00?o0000oe9VbOmBI/T0
0omBI/T01?l0003oJX3FofZ0e_mZP=H2o`000003oeM[bol0003oKX?G00GoKX?G00?o0000oh>JhOn3
V^401On3V^400ol0003oUJgWoiF]i`06oiF]i`03o`000?nR_NcoX[g/00;oX[g/0ol000000on]b>ko
0000okCBl009okCBl0;o00002Onlg_401?l0003o_n;`okoRl?l00006okgTlP;o00001?nni_801?l0
003o^NGeo`000?l00007okWVm@;o000000?o^NOeo`000?naiOP01OnaiOP2o`0000Co/>Gh00?o0000
ojKQnol000000_l00006ojGQn`03o`000?nIfogoVM_m00?o00001_nIfoh00ol0003oRmCooh_Do`04
o`0000?oRmCo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Mooooo`007?ooool5o`00
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`14ooooo`Co0000
1On>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh2o`0000?oS/on1_l00005ohk?oP;o0000
0on>coh5o`0000OoS/on00Co0000ohk?o_n>cokoS/on1Ol00007ohk?oP03o`000?n>cokoS/on00?o
00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh00ol0003oS/onohk?oP04ohk?oPGo
00001On>coh00ol0003oS/onohk?oP02ohk?oPKo00000ol469X01Ol0003o0025o`000?l0003o0020
00;o000000Co001oo`000?l007ko00000_l007h00ol0003o001no`000002o`00O`04o`000?l0087o
0021o`0000;o002300oo0000o`00Q_l0003o0000o`00ROl0003o00bFo`000?l00Xco0000o`0CV_l0
003o00N@o`000?l06Yh00_l00004o`PQXP05o`000?lB::Ko4RRVoa8XY_l000000_lX@;H00ol0003o
6RnYo`000004oc57^@;o00000oliCK/00ol0003oDVK9oe9Vb@04oe9Vb@03o`000?mZP=KoJX3F00;o
JX3F0ol00006ofj3e`03o`000?n3V^7oPi[Q00GoPi[Q00?o0000oiF]ionE[NL01OnE[NL00ol0003o
X[g/o`000002o`0000Go[LS^00?o0000okCBl?ndd_001Ondd_02o`0000;o^]W`00?o0000okcNlOnl
g_401?nlg_42o`0000Co_n;`00Co0000okgTl_nmi?;o_NCb0_l00006okkVlP?o00001_nii_D2o`00
0005okWWmOl0003o^NOeokWWmOl000000onaiOP2o`0000Ko/>Gh0_l00009ojGQn`?o00002OnIfoh3
o`0000SoRmCo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Looooo`008oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Kooooo0_l00006ohk?oP03o`00
0?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh2o`0000?oS/on
1_l00005ohk?oP;o00000on>coh6o`0000GoS/on0_l00003ohk?oPGo00001on>coh00ol0003oS/on
ohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000?oS/on
00?o0000ohk?o_n>coh01?n>coh5o`0000CoS/on00?o0000o`@HV_l469X00_l469X2o`000009o`00
QOl0003o0020o`00P?l0003o001oo`000?l007ko000000;o001n00?o0000o`00O_l000000_l007l0
1?l0003o0021o`00POl00002o`00P`Co00000_l008T2o`000006o`02S?l0003o01>Jo`000?l01i3o
00000_l06Yh2o`0000?o226R0_l00003oa8XYP05o`000?lX@;Ko0000oaX_ZOl000001OlaAkT2o`00
00?o>Dfk00?o0000oe9VbOmBI/T00omBI/T00ol0003oJX3FofZ0eP04ofZ0eP?o00001?m^PmL00ol0
003oPi[Qoh>Jh@05oh>Jh@03o`000?nE[NOoUJgW00;oUJgW1Ol00009ojg8kP03o`000?ndd_3o]=;`
00;o]=;`0_l00005ok[Il004o`000?nlg_7o_=kaokcNl@;o00001onoh_000ol0003o_NCbo`000007
okkVlP05o`000?noio;o_nObokoWl_l000000onii_D2o`0000?o^NOe00Oo0000okWWmOniioGo^NOe
o`000?naiOSo000000Ko/>Gh0_l00002ojoUn003o`000?nUhO_oYN7k00?oYN7k0ol00003ojCPn`03
o`000?nIfokoVM_n00?oVM_n0ol00002oiSJoP03o`000?n;e?ooRmCo00GoRmCo0ol0000oooooo`03
o`000?oooooooooo01_ooooo000Sooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool01Ol0003oooooooooool0003ooooo00Co00002Oooool00ol0003oooooooooo`18
ooooo`04o`000?n>cokoS/onohk?oPGo00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o
0000ohk?o_n>coh01?n>coh4o`0000GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on0_l0
0003ohk?oPKo00001On>coh2o`0000?oS/on1Ol00007ohk?oP04o`000?n>cokoS/onohk?oPGo0000
1on>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh01?l0003o11RJ
o`@HV_l469X2o`000008o`00QOl0003o0020o`00P?l0003o001oo`000?l007h2o`000003o`00O_l0
003o001n00;o000000Co001oo`000?l0003o00210_l000001?l008?o0000o`000?l008H2o`000003
o`00ROl0003o00bF00;o00000_l04iX2o`0000;o01ZN0_l00004o`PQXP05o`000?lB::Ko4RRVoa8X
Y_l000000_lX@;H2o`0000Go<DNi00?o0000od]Qb?l000000_liCK/00ol0003oDVK9oe9Vb@03oe9V
b@03o`000?mZP=KoJX3F00CoJX3F00?o0000oh6Gh?n1Un001Ol00004oh>Jh@So00001?nS_>/00ol0
003o[LS^ojg8kP08ojg8kP04o`000?ndd_3o0000o`0000So^]W`00?o0000okcNlOl000002Onoh_02
o`0000Ko_^Kb0_l00005okoWlP03o`000?nii_Go000000Go^NOe00Co0000okWWmOniioGo^NOe0ol0
0004ok3Un0;o00001On_iOP00ol0003oYN7ko`000002o`0000OoY>3k00?o0000oiWKo_l000000_l0
0006oiSJoP03o`000?n;e?ooRmCo00Co00000on:e?l00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo01[ooooo000Sooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000_ooooo00?o0000ooooooooool0B_ooool3o`00
00GoS/on0_l00003ohk?oPGo00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?
o_n>coh01?n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh4o`00
00GoS/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on0_l00003ohk?oPKo00001On>coh2o`00
00?oS/on1Ol00007ohk?oP04o`000?n>cokoS/onohk?oPCo00000ol469X01Ol0003o0025o`000?l0
003o002000Ko000000?o001no`000?l000000_l000001?l007oo0000o`000?l00842o`000004o`00
Pol0003o0000o`00QP;o000000Oo0029o`000?l039Ko0000o`02S?l0003o01>J00;o00000ol06Yh0
0ol0003o226Ro`PQXP02o`PQXP;o00000_lB::H01Ol0003o:42fobQ0]_lX@;Ko000000Go<DNi00Ko
0000od]Qb?m;HLSo0000ocU=^ol00006oe9Vb@03o`000?mZP=KoJX3F00CoJX3F00?o0000oh6Gh?n1
Un000on1Un05o`0000CoU:cW00?o0000oj>ljonS_>/01_nS_>/00ol0003o[LS^ojg8kP07ojg8kP;o
00002_njfO02o`0000Wo_n;`00Co0000ol7Ul?o1iO3o00000onni_82o`0000Oo_nOb0ol00005okWW
m@04o`000?niioGo0000o`0000?o^NSe00Co0000ok3Un?l0003o00001on_iOP3o`0000WoY>3k0_l0
0009oiSJoP?o00002?n:e?l00ol0003oooooooooo`0looooo`03o`000?oooooooooo01[ooooo000T
ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`Go00001oooool3o`0004cooooo0ol00003
ohk?oPGo00001On>coh3o`0000?oS/on1?l00007ohk?oP04o`000?n>cokoS/onohk?oPGo00001on>
coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?
oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on0_l00003ohk?oPKo00001On>
coh2o`0000?oS/on1_l00003oa0XY`04o`000?l469[o11RJo`@HVPCo000000?o0020o`000?l00000
1?l000000ol007ko0000o`000002o`000003o`00Ool0003o000000;o002100Co0000o`00Pol0003o
006>0_l000001ol01Y;o0000o`000?l039Ko0000o`02S?l000000_l04iX01Ol0003o01ZNo`0JW_l0
6Yko000000Co226R00Go0000oahi/_l0003o4RRVo`000003obQ0]P;o00001?laAkT01?l0003oBf78
od]Qb?m;HLP2o`0000KoDVK900?o0000ofZ0e_mZP=H01?mZP=H00ol0003oPIOPoh6Gh004oh6Gh003
o`000?nD[>OoU:cW00KoU:cW00?o0000oj>ljonS_>/01_nS_>/00ol0003o[LS^ojg8kP04ojg8kP;o
000000?o]];_o`000?njfO002?njfO001?l0003o_mk_okoNkol00006okoRl0;o00001?o1iO000ol0
003o_^Kbo`000008okoWlP05o`000?nojO;o_nWbokoYl_l000001?niioD2o`0000Go^NSe0_l00007
ojoUn0;o00000on^iOT00ol0003oY>3kojCPn`03ojCPn`?o00000_nSh?`00ol0003oV=[noiSJoP03
oiSJoP?o00000_nGf_h00ol0003oR]Cooh[Do`05oh[Do`?o0000?_ooool00ol0003oooooooooo`0I
ooooo`00A_ooool00ol0003oooooooooo`1>ooooo`Co00001?n>coh3o`0000?oS/on1_l00004ohk?
oP?o00000on>coh5o`0000GoS/on0ol00003ohk?oPCo00001on>coh01?l0003oS/onohk?o_n>coh5
o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005
ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o00000_l@::L2o`0000;o11RJ1?l00000
1_l0083o0000o`000?l007oo0000o`00OP;o000000?o001no`000?l007h00_l000001?l007oo0000
o`000?l00843o`000004o`01S_l0003o0000o`06TP;o00000_l039H2o`0000;o01>J0_l00002o`0J
WP;o00000ol88J800ol0003o7SVbo`000002oa8XYP05o`000?lX@;Ko:42fobQ0]_l000001OlaAkT0
1?l0003oBf78od]Qb?m;HLP2o`0000GoDVK900?o0000ofZ0e_mZP=H01?mZP=H00ol0003oPIOPoh6G
h005oh6Gh003o`000?nD[>OoU:cW00GoU:cW00?o0000oj>ljonS_>/01_nS_>/00ol0003o[LS^ojg8
kP02ojg8kP;o00001?nfd^l00ol0003o^]W`ok[Il004ok[Il0;o00001?nog^l01?l0003o_n;`okoR
l?noh_02o`0000Ko`NG`0_l00008okoWlP03o`000?nojO;o_nWb00?o_nWb00?o0000okWWmOl00000
0_l00005okWXm@04o`000?nhj?Ko^>Sfo`0000Co[nGh0_l00006ojkUn@03o`000?nTh?_o000000;o
00001_nSh?`00ol0003oV=[no`000002o`0000KoUm[n00?o0000oh[Doon:e?l01?l00003oh[Do`03
o`000?oooooooooo03cooooo00?o0000ooooooooool06?ooool004Kooooo00?o0000ooooooooool0
D?ooool2o`0000KoS/on1?l00005ohk?oP03o`000?n>cokoS/on00CoS/on1?l00004ohk?oP?o0000
0on>coh6o`0000CoS/on0ol00003ohk?oPGo00001On>coh2o`0000?oS/on1Ol00007ohk?oP03o`00
0?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP04ohk?oP03o`000?n>cokoS/on00?o0000
0on>coh00ol0003oS/onohk?oP04ohk?oP;o00000_l@::L00ol0003o11RJo`@HVP02o`000005o`00
QOl0003o0000o`000?l008D01Ol000000ol007ko0000o`000002o`000004o`00Ool0003o0000o`00
P@;o000000Wo0023o`000?l0003o0000o`06T_l0003o0029o`000?l039H00_l00002o`0CVP;o0000
0ol06Yh2o`0000?o226R00Go0000oahi/_l0003o4RRVo`000003obQ0]P;o00001?laAkT00ol0003o
Bf78od]Qb002od]Qb0;o00001OmBI/T00ol0003oJX3FofZ0eP04ofZ0eP03o`000?n1Un3oPIOP00Co
PIOP00?o0000oiB/ionD[>L01_nD[>L00ol0003oXkc[oj>lj`06oj>lj`04o`000?n]b>ko0000o`00
00Oo]];_00Co0000ok[Il?njfO3o^]W`0_l00007okoNk`03o`000?noh_3o000000Oo`NG`00Co0000
ol?Wl?o3io3o00001Onoio82o`0000Ko_nWb0_l00002okWXm@04o`000?nij?Go^NSeokWXm@;o0000
1?nhj?H01?l0003o[nGho`000?l00008ojkUn@;o00002OnSh?`2o`0000WoUm[n0ol00008oh[Do`03
o`000?oooooooooo03cooooo00?o0000ooooooooool05oooool004Kooooo00?o0000ooooooooool0
D_ooool00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/on
ohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh4o`0000GoS/on00?o0000ohk?o_n>coh0
1?n>coh4o`0000CoS/on0ol00003ohk?oPGo00001On>coh2o`0000?oS/on1Ol00007ohk?oP04o`00
0?n>cokoS/onohk?oPGo00001on>coh00ol0003oS/onohk?oP03o`000004oalm]_l0003o42RWoa0X
Y`;o000000?o11RJo`000?l008T00ol000000ol0083o0000o`000003o`000003o`00Q?l0003o0000
00;o000000Co0026o`000?l0003o00280ol000000ol008?o0000o`01SP02o`000003o`06T_l0003o
000000;o00bF00Go0000o`0CV_l04i[o01>Jo`000003o`0JWP;o00000ol88J801Ol0003o7SVbo`00
0?lB::Ko000000?o:42f00?o0000od9KaOl000000olaAkT00ol0003oBf78od]Qb002od]Qb004o`00
0?mTNmGo0000o`0000?oDVK900?o0000ofZ0e_mZP=H01?mZP=H00ol0003oPIOPoh6Gh005oh6Gh003
o`000?nD[>OoU:cW00GoU:cW00?o0000oj>ljonS_>/01_nS_>/2o`0000[o]];_00?o0000ok[Il?l0
00002Onog^l2o`0000Oo`NG`00?o0000ol?Wl?o3io000_o3io001Ol0003o_nObokoWl_noio;o0000
00Oo_nWb00Oo0000okoZl_noj_;o0000okWXmOl0003o^NSe00;o00001_nhj?H3o`0000Oo[^Gi0_l0
0002ojgTn@03o`000?nSh?coXn3l00?oXn3l0ol00002oj;Oo003o`000?nGf_koUm[n00?oUm[n0ol0
0002oiKJoP03o`000?n:e?ooR]Co00GoR]Co0ol0000nooooo`03o`000?oooooooooo01Kooooo0016
ooooo`03o`000?oooooooooo05?ooooo0_l00007ohk?oP04o`000?n>cokoS/onohk?oPGo00001on>
coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh00ol0003oS/onohk?
oP03o`0000?oS/on00?o0000ohk?o_n>coh01?n>coh4o`0000CoS/on0_l00003ohk?oPKo00001On>
coh2o`0000?oS/on1_l00005ohk?oP;o00000on>coh5o`0000Go7cff00Co0000oa0XYol0003o0000
0_l469X4o`000003o`00P?l0003o000000?o000000?o0024o`000?l000000_l000001?l008Ko0000
o`000?l008P2o`000004o`00Rol0003o0000o`01SP;o000000?o00JBo`000?l000000_l039H2o`00
00;o01>J00Oo0000o`0JW_l06Yko01ZNo`000?lC<Jko000000;o226R00?o0000oahi/_lN>K800_l0
0004obQ0]P03o`000?m2FlGo000000?o<DNi00?o0000od]Qb?m;HLP00_m;HLP00ol0003oI7_EofAk
e@02o`000003oe9VbOl0003oJX3F00GoJX3F00?o0000oh6Gh?n1Un001On1Un000ol0003oU:cWoiB/
i`06oiB/i`03o`000?nS_>_oXkc[00;oXkc[0ol000000on^b>go0000okKBk`09okKBk`;o00002Ono
g^l00ol0003o`^?_o`000005ol7Ul0;o00001_o3io000ol0003o_nObo`000007okoYlP03o`000?no
j_;o_n[b00;o_n[b0ol00007okSXmP05o`000?nfj?Ko]^SfokKXm_l000001?n^iOT2o`0000Go[NCi
00?o0000oj?Po?l000000_l00006oj;Oo003o`000?nGf_ko000000;o00001_nFf_h00ol0003oR]Co
oh[Do`04o`0000?oR]?o00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Eooooo`00A_oo
ool00ol0003oooooooooo`1Eooooo`;o00000on>coh6o`0000GoS/on0_l00003ohk?oPGo00001on>
coh01?l0003oS/onohk?o_n>coh5o`0000OoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`00
0?n>cokoS/on00?oS/on1?l00005ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o0000
0on>coh6o`0000GoS/on0_l00003oalm]P03o`000?l@::Oo42RW00;o000000Go11RJo`000?l0003o
0000o`00Q`02o`000005o`00QOl0003o0025o`000?l008@00_l000000ol008Go0000o`00QP02o`00
0003o`00R?l0003o002100?o000000Co006>o`000?l0003o00JB0_l00002o`0<UP;o00000_l04iX2
o`0000;o01ZN00?o0000oa<a[_l000000_l88J801Ol0003o7SVboahi/_lN>K;o000000Co:42f00Co
0000od9KaOm2FlGo00000_laAkT00ol0003oBf78od]Qb002od]Qb003o`000?mTNmGoI7_E00;oI7_E
0ol00006ofZ0eP03o`000?n1Un3oPIOP00CoPIOP00?o0000oiB/ionD[>L01_nD[>L00ol0003oXkc[
o`000002o`0000Go[/S]00?o0000okKBkonfd^l01_nfd^l00ol0003o_=[_o`000008okoNk`05o`00
0?o2hnoo`^?_ol;Skol000000oo1iO000ol0003o`nO`ol?Wl006ol?Wl0?o00001OnojO82o`0000Go
_n[b0ol00005okSXmP;o00001Onfj?H01?l0003o[^Gio`000?l00007ojgTn@;o00002OnRgo`3o`00
00OoU][n1?l00008oh[Co`03o`000?oooooooooo03cooooo00?o0000ooooooooool05?ooool004Ko
oooo00?o0000ooooooooool0Eoooool3o`0000GoS/on0_l00003ohk?oPKo00001On>coh2o`0000?o
S/on1_l00005ohk?oP;o00000on>coh5o`0000OoS/on00?o0000ohk?o_l000000_l00003ohk?oP03
o`000?n>cokoS/on00CoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00Co
S/on1?l00005ohk?oP;o00000on>coh4o`0000;o7cff0_l000001_l@::Oo0000o`000?l469[o0000
o`00R@Co000000?o0025o`000?l000000_l000000ol008Co0000o`000002o`000004o`00Q_l0003o
0000o`00R0Co00000_l00Hh01?l0003o00JBo`06T_l00003o`0<UP05o`000?l04i[o01>Jo`0CV_l0
00000_l06Yh01_l0003o4c6^oa<a[_l0003o226Ro`0000?o7SVb0_l00003obQ0]P07o`000?m2FlGo
@U_5od9KaOl0003o<DNio`000004od]Qb003o`000?mTNmGoI7_E00CoI7_E0ol00004ofZ0eP03o`00
0?n1Un3oPIOP00GoPIOP00?o0000oiB/ionD[>L01?nD[>L3o`0000Wo[/S]00?o0000okKBkonfd^l0
0onfd^l2o`0000?o_=[_00?o0000okoNkonog^l00onog^l2o`0000Go`^?_00?o0000ol7Ul?l00000
2?o3io001Ol0003o`nW`ol?Yl?o3jO3o000000?o_nWb00?o0000okoZl_noj_801?noj_801Ol0003o
_^[co`000?nnj_?o000000?o^>Sf00?o0000okKXm_nfj?H01Onfj?H2o`0000Oo[NCi0_l00002oj_T
nP03o`000?nRgocoX]ol00?oX]ol0ol00003oj7Oo003o`000?nFf_koU][n00Co00000onEfOh00ol0
003oR]?ooh[Co`05oh[Co`?o0000?_ooool00ol0003oooooooooo`0Cooooo`00A_ooool3o`0005Wo
oooo0_l00005ohk?oPCo00001On>coh2o`0000?oS/on1_l00005ohk?oP;o00000on>coh6o`0000Go
S/on0_l00003ohk?oPGo00001_n>coh01?l0003oS/onohk?o_n>coh5o`0000OoS/on00?o0000ohk?
o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1?l00003oc9Fa`06o`000?lO?KKo7cff
oalm]_l0003o42RW0_l000000ol469[o0000o`00R@04o`000003o`00QOl0003o000000;o000000?o
0024o`000?l000000_l000001?l008Ko0000o`000?l008P2o`000005o`00Rol0003o006>o`01S_l0
00000_l01Y82o`0000;o00bF00Co0000o`0CV_l04i[o01>J0_l00002o`0JWP06o`000?lC<Jko4c6^
o`000?l88J;o00000olN>K801Ol0003o:42fobQ0]_lX@;Ko000000Co@U_50_l00005od]Qb003o`00
0?mTNmGoI7_E00?oI7_E00?o0000ogbDgomlU=l01Ol00007oh6Gh003o`000?nD[>OoU:cW00Co0000
0_nQ^n/00ol0003o[/S]ojk8k@07ojk8k@04o`000?nfd^oo]];_okKBk`;o00001_nlf^l01Ol0003o
_mk_okoNkonog^oo000000Oo`^?_0ol00006ol?Wl0;o00001Oo3jO000ol0003o_nWbo`000005okoZ
lP;o00000_nnj_<01_l0003o_^[cokkZlol0003o^>Sfo`0000Oo]^Sf00Co0000okGXmonej?Oo0000
1?n]i?T2o`0000GoZnCj00?o0000oj;Oo?l000000_l00006oj7Oo0?o00002?nEfOh00ol0003oR]?o
oh[Co`04o`0000?oRM?o00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Booooo`00A_oo
ool00ol0003oooooooooo`1Kooooo`03o`000?n>coko000000;o00000on>coh2o`0000GoS/on1?l0
0005ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o00000on>coh6o`0000GoS/on0_l0
0003ohk?oPGo00001On>coh2o`0000?oS/on1Ol00007ohk?oP03o`000?n>cokoS/on00?o00000on>
coh00ol0003o<UK7oc9Fa`02oc9Fa`03o`000?lO?KKo7cff00?o000000Co002;o`000?l0003o0029
0_l000002?l008Oo0000o`00QOl008Go0000o`00QOl0003o00240_l000000ol008Go0000o`00QP02
o`000005o`00R?l0003o0000o`00Rol000000_l00Hh2o`000003o`06T_l0003o000000;o00bF0_l0
0002o`0CVP;o00000_l06Yh01_l0003o4c6^oa<a[_l0003o226Ro`0000?o7SVb00?o0000obQ0]_lX
@;H00_lX@;H00ol0003o@U_5od9Ka@02od9Ka@;o00001?m;HLP00ol0003oI7_EofAke@04ofAke@03
o`000?mlU=ooO9CO00?oO9CO2ol00007oj6kj`03o`000?n^b>go[/S]00Oo[/S]00?o0000okKBkol0
00002Onlf^l00ol0003o_mk_o`000007ol;Sk`05o`000?o4i^ooa>K_olCVkol000000oo3io02o`00
00Oo`nW`0ol00003okoZlP;o00001?nnj_<00ol0003o_^[cokkZl`02o`0000Ko]^Sf0_l00004okGX
m`04o`000?n]i?Wo0000o`0000OoZnCj0ol00005oj7Oo0?o00000_nOg_d00ol0003oUMWnoiGIoP05
oiGIoPCo00002?n9dol00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01;ooooo0016oooo
o`03o`000?oooooooooo05cooooo0_l00007ohk?oP03o`000?n>coko000000;o00000on>coh2o`00
00GoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00CoS/on1?l00005ohk?
oP;o00000on>coh6o`0000CoS/on0_l00003ohk?oPKo00001On>coh2o`0000?oS/on1Ol00007ohk?
oP04o`000?lbE/Oo<UK7oc9Fa`;o000000?o7cffo`000?l008h01?l00002o`00R@03o`000?l008Oo
000000;o002500?o0000o`00QOl000000_l008@00ol0003o0025o`000002o`00QP05o`000?l008So
0028o`000?l008/00_l00002o`01SP04o`000?l01Y;o00JBo`0000?o00bF00So0000o`0CV_l04i[o
0000o`PYZ_l0003o01ZNo`0000?o4c6^0_l00003oahi/P;o00000olX@;H00ol0003o@U_5od9Ka@03
od9Ka@;o00001?m;HLP00ol0003oI7_EofAke@03ofAke@03o`000?mlU=ooO9CO00CoO9CO00?o0000
oi6Yi_nAZNH01OnAZNH00ol0003oXK_[oj6kj`06oj6kj`03o`000?n^b>go[/S]00Oo[/S]0_l0000:
okcJk`?o00001Oo2hnl2o`0000Goa>K_00?o0000ol?Wl?l000002?o3jO001ol0003o`n_`ol?[l?o3
jo3o0000okoZl_l000001_nnj_<00ol0003o_^[co`000002okg[l`04o`000?nfj?Ko]^SfokKXmP;o
00001_nej?L3o`0000GoZnCj0ol00003ojWSnP;o000000?oXMolo`000?l000001_nOg_d00ol0003o
UMWnoiGIoP04o`0000?oU=Wn00?o0000ohWCoon9dol01On9dol3o`0003gooooo00?o0000oooooooo
ool04Oooool004Gooooo00?o0000ooooooooool0Goooool2o`0000?oS/on1Ol00007ohk?oP04o`00
0?n>cokoS/onohk?oPCo00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>
coh01?n>coh4o`0000GoS/on00Co0000ohk?o_n>cokoS/on1_l00005ohk?oP;o00000on>coh6o`00
00GoS/on0_l00003ohk?oPCo00000_lbE/L01?l0003o00FAo`000?lO?KH3o`000006o`00Rol0003o
0000o`00ROl0003o00270_l000001?l008Go0000o`00QOl00002o`00Q003o`000?l008Go000000;o
002600?o0000o`00R?l008P00_l000001Ol008_o0000o`01S_l00Hko000000;o00JB00Co0000o`0<
U_l039Ko00bF0_l000001_l04i[o0000o`PYZ_l0003o01ZNo`0000?o4c6^0_l00004oahi/P;o0000
0_lX@;H00ol0003o@U_5od9Ka@03od9Ka@03o`000?mLM]Co000000?oBf7800?o0000ofAkeOmTNmD0
0omTNmD00ol0003oO9COogbDg`05ogbDg`03o`000?nAZNKoTJWV00GoTJWV00?o0000oj6kjonQ^n/0
1_nQ^n/00ol0003o[/S]ojk8k@04ojk8k@;o000000?o]];^o`000?nlf^l02?nlf^l01Ol0003o`Mo_
ol7Okoo1gnoo000000?o`^?_00?o0000olCVkoo4i^l01Oo4i^l3o`0000Ko`nW`0_l00004ol?[l0?o
00001_nnj_<2o`0000Co_N_c00?o0000okKXm_l000001_nej?L2o`0000?o/nOg00?o0000oj_Tn_l0
00000_l00007ojWSnP;o00002?nOg_d3o`0000SoU=Wn00?o0000ohWCoon9dol01?l00003ohWCo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool004Gooooo00?o0000ooooooooool0
HOooool3o`0000GoS/on0_l00003ohk?oPKo00001?n>coh2o`0000?oS/on1Ol00007ohk?oP03o`00
0?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?oP03ohk?oPCo00001On>coh00ol0003oS/on
ohk?oP04ohk?oPCo00001On>coh2o`0000?oS/on1_l00003odMcfP;o00000_lbE/L2o`000005oalm
]_l0003o002>o`000?l008/00_l000001Ol008Wo0000o`000?l008Oo000000;o002500Co0000o`00
QOl0003o00240_l000000ol008Go0000o`00QP02o`000005o`00R?l0003o0000o`00Rol000000_l0
0Hh00ol0003o00JBo`06TP02o`0000;o00bF0_l00002o`0CVP05o`000?l8:J[o0000o`0JW_l00000
0olC<Jh2o`0000?o7SVb00?o0000ocMC`ol000000_lX@;H00ol0003o@U_5od9Ka@02od9Ka@03o`00
0?mLM]CoG7KD00;o00000_m;HLP00ol0003oI7_EofAke@03ofAke@03o`000?mlU=ooO9CO00CoO9CO
00?o0000oi6Yi_nAZNH01OnAZNH00ol0003oXK_[oj6kj`07oj6kj`04o`000?n^b>go[/S]ojk8k@;o
00001?nfd^h00ol0003o_=[_okcJk`04okcJk`;o00001Oo1gnl00ol0003o`^?_o`000007olCVk`05
o`000?o6jNooa^W_olKYkol000000oo3jO02o`0000Go`n_`00Go0000ol?/lOo3k?7o`ncao`000003
okkZl`?o00001Onmjo<3o`0000Co]NSg0_l00005ok?Wm`?o00001onYhoX2o`0000;oZ>?k00?o0000
oioNoOnOg_d00_nOg_d3o`0000?oW]km00?o0000oiCIo_nDfOh01?nDfOh4o`0000SoRM?o00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`00AOooool00ol0003oooooooooo`1Soooo
o`;o00000on>coh6o`0000GoS/on0_l00003ohk?oPGo00001On>coh2o`0000?oS/on1Ol00007ohk?
oP03o`000?n>coko000000;o00000on>coh00ol0003oS/onohk?oP04ohk?oP03o`000?n>cokoS/on
00?o00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh00ol0003oAg?JodMcfP02odMc
fP;o000000?o<UK7o`000?l01I400_l000001Ol008ko0000o`000?l008_o000000;o002900?o0000
o`00Qol000000_l008D00ol0003o0025o`000002o`00Q003o`000?l008Go000000;o002600Ko0000
o`00R?l008So0000o`00Rol00002o`01SP;o00000_l01Y803?l0003o00bFo`0<U_l0003o026Vo`00
0?l04i[o0000o`PYZ_l0003o01ZNo`0000Co4c6^00Go0000oahi/_lN>K;o7SVbo`000002ocMC``03
o`000?lX@;Ko000000Go@U_500Co0000oeafe?mLM]CoG7KD0ol00005ofAke@03o`000?mlU=ooO9CO
00GoO9CO00?o0000oi6Yi_nAZNH01OnAZNH00ol0003oXK_[oj6kj`06oj6kj`04o`000?n^b>go0000
o`0000Oo]];^00Co0000okcJkonlf^oo_=[_0_l00007ol7Ok`;o00001oo4i^l00ol0003oa^W_olKY
k`03olKYk`03o`000?o3jO3o000000Ko`n_`00?o0000ol?/lOo3k?400oo3k?400ol0003o_^[co`00
0002okg[l`04o`000?nmjo?o_N_cokg[l`;o00000onkjo@01?l0003o]NSgo`000?l00006ok?Wm`05
o`000?naioSo/NOhok7Wn?l000001?nYhoX2o`0000GoZ>?k00Co0000oioNoOl0003o00001onNg_d0
0ol0003oU=WnoiCIoP03o`0000?oTmSn00?o0000ohWCoon9dol01On9dol3o`0003gooooo00?o0000
ooooooooool03_ooool004Gooooo00?o0000ooooooooool0IOooool3o`0000GoS/on0_l00003ohk?
oPKo00001?n>coh2o`0000?oS/on1_l00005ohk?oP;o00000on>coh5o`0000KoS/on00Co0000ohk?
o_n>cokoS/on1Ol00007ohk?oP03o`000?n>cokoS/on00?o00000_n>coh00ol0003oS/onohk?oP04
ohk?oP?o00000_m7LmX01?l0003o00ZDo`000?l00002o`05T@;o000000Co002>o`000?l008_o0000
0_l008T00ol0003o0027o`000002o`00Q@03o`000?l008Go000000;o002400?o0000o`00QOl00000
0_l008H01Ol0003o0028o`00R?l0003o002;00;o00000_l00Hh00ol0003o00JBo`06TP02o`0000;o
00bF0_l000001?l04i[o0000o`PYZ_l8:JX2o`0000Co4c6^00Go0000oahi/_lN>K;o7SVbo`000002
ocMC``03o`000?lX@;Ko000000Go@U_500?o0000oeafe?mLM]@00omLM]@00ol0003oI7_EofAke@03
ofAke@03o`000?mlU=ooO9CO00GoO9CO00?o0000oi6Yi_nAZNH01_nAZNH00ol0003oXK_[oj6kj`04
oj6kj`?o00002_nfd^h00ol0003o_=[_o`000008ol7Ok`03o`000?o4i>ko000000Goa>K_0_l00006
olKYk`;o00001Oo3jo02o`0000Ko`nca0ol00002okg[l`04o`000?nmjo?o0000o`0000Go^n_d0ol0
0005ok?Wm`;o00001OnaioP01?l0003oZN?jo`000?l00007ojSSn`;o00002OnNg_d3o`0000OoTmSn
00?o0000ohWCoon9dol01?l00003ohWCo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3Oooool004Gooooo0ol0001Wooooo`03o`000?n>cokoS/on00CoS/on1?l00005ohk?oP;o00000on>
coh5o`0000GoS/on0_l00003ohk?oPKo00001On>coh2o`0000?oS/on1Ol00005ohk?oP;o00000on>
coh5o`0000KoS/on00?o0000ohk?o_n>coh00ol000001?mOT^[o0000o`0?V?l00002odMcfP04o`00
0?l02YCo0000o`0000;o00FA00Co0000o`00S_l0003o002;0_l000000ol008Wo0000o`000002o`00
0003o`00QOl0003o000000;o000000?o0024o`000?l000000_l000001?l008Ko0000o`000?l008P2
o`000004o`00Rol0003o006>o`01SP;o000000?o00JBo`000?l000000_l039H01?l0003o026Vo`00
0?l00002o`PYZP;o00001?lC<Jh2o`0000?o7SVb00?o0000ocMC`olgDl<00_l00005od9Ka@03o`00
0?mLM]CoG7KD00CoG7KD0_l00004ofAke@03o`000?mlU=ooO9CO00CoO9CO00?o0000oi6Yi_nAZNH0
1_nAZNH00ol0003oXK_[oj6kj`04o`0000;o[LS^00?o0000okKBk_nfd^h02?nfd^h2o`0000So`Mo_
00Go0000olCTk_o4i>koa>C^o`000003olCVk`03o`000?o6jNooa^W_00Goa^W_00Co0000olK[koo6
jnoo00000oo3jo000ol0003o`ncaol?/l@05ol?/l@06o`000?o2kO7o`^gaol;]lOl0003o_N_c0_l0
0006ok_[m005o`000?nijoGo^N_eokW[mOl000000oncioL00ol0003o/NOhok7Wn005ok7Wn0;o0000
1onXho/2o`0000;oY^;k00?o0000oikNoOnNg_d00onNg_d3o`0000;oW=gm00?o0000oi?Ho_nCf?h0
1?nCf?h4o`0000SoRM?o00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`00AOoo
ool00ol0003oooooooooo`1Xooooo`03o`000?n>cokoS/on00?o00000on>coh00ol0003oS/onohk?
oP04ohk?oPCo00001?n>coh00ol0003oS/onohk?oP04ohk?oPCo00001On>coh2o`0000?oS/on1_l0
0004ohk?oP;o00000on>coh6o`0000GoS/on0_l00003ohk?oPCo00001OmOT^X00ol0003o00nHo`00
0002o`0000;o00ZD00Go0000o`05TOl01I7o0000o`00SP02o`000008o`00Rol0003o0029o`00ROl0
003o0027o`000?l008D2o`000003o`00QOl0003o002400;o000000Ko0025o`000?l008Ko0026o`00
0?l008P2o`000004o`00Rol0003o0000o`01SP;o000000[o00JBo`000?l06J7o0000o`0<U_l0003o
026Vo`000?l04i[o00000_l8:JX00ol0003o4c6^oa<a[P03oa<a[P;o00000_lN>K801?l0003o=e?3
ocMC`olgDl<2o`0000Go@U_500?o0000oeafe?mLM]@00omLM]@00ol0003oMY3Oo`000002o`000003
ofAkeOl0003oO9CO00KoO9CO00?o0000oi6Yi_nAZNH01?nAZNH4o`0000Oo[LS^00?o0000okKBk_nf
d^h01Onfd^h2o`0000;o_M[_00?o0000ol7Okoo1gnl00oo1gnl2o`0000Goa>C^00?o0000olCVkol0
00001oo6jNl00ol0003oa^__olK[k`02olK[k`03o`000?o3jo3o000000Ko`nca0_l00004ol;]l@?o
00001Onkjo@2o`0000Go^N_e00?o0000ok?Wmol000001_naioP2o`0000;o[nOi00?o0000ojSSnonX
ho/00_nXho/2o`0000GoY^;k00?o0000oikNoOl000000_l00006oicMo@03o`000?nCf?koTmSn00?o
00001?nBf?h00ol0003oRM?oohWCo`02ohWCo`Ko0000??ooool00ol0003oooooooooo`0;ooooo`00
AOooool00ol0003oooooooooo`1Yooooo`;o00001on>coh00ol0003oS/onohk?oP03o`0000?oS/on
00?o0000ohk?o_n>coh00on>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh0
1?n>coh4o`0000GoS/on00Co0000ohk?o_n>cokoS/on1_l00005ohk?oP;o00000on>coh6o`0000Co
S/on0_l00004oenBjP04o`000?l03iSo00nHo`0000;o00ZD00?o0000o`05TOl01I400_l000001?l0
08ko0000o`00Rol00002o`00R@03o`000?l008Oo000000;o002500?o0000o`00QOl000000_l008@0
0ol0003o0025o`000002o`00QP05o`000?l008So0028o`000?l008/00_l000000ol00Hko0000o`00
0002o`06TP;o000000Ko00bFo`000?l08JKo0000o`0CV_l00002o`PYZP;o00001?lC<Jh2o`0000;o
7SVb00?o0000ocMC`olgDl<00_lgDl<2o`0000Co@U_500?o0000oeafe?mLM]@01?mLM]@01?l0003o
MY3OogJ@gomfT=l2o`0000OoO9CO00?o0000oi6Yi_nAZNH01?l00002oinij`03o`000?n]b>ko[LS^
00Oo[LS^00?o0000okKBk_nfd^h00_nfd^h2o`0000Go_M[_00Go0000ol7Okoo1gnoo`Mo_o`000007
olCTkP?o00001Oo6jNl2o`0000Goa^__0ol00004ol?/l@;o00001Oo2kO400ol0003o`>gbol3]lP02
o`0000?o^n_d00?o0000okW[mOnijoD01OnijoD3o`0000Co/NOh0_l00005ojoWn@04o`000?nXho_o
0000o`0000OoY^;k0ol00007oicMo@Co00001_nBf?h6o`0000KoR=?o00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0:ooooo`00AOooool00ol0003oooooooooo`1[ooooo`;o00000on>coh5
o`0000OoS/on00Co0000ohk?o_n>cokoS/on1?l00007ohk?oP03o`000?n>cokoS/on00?o00000on>
coh00ol0003oS/onohk?oP03ohk?oPCo00001On>coh2o`0000?oS/on1_l00005ohk?oP04o`000?n>
cokoS/onohk?oPKo000000?oGi;Zo`000?l03iP00_l03iP01?l0003o00ZDo`000?l00002o`05T@04
o`000?l008ko0000o`00R`;o000000?o0029o`000?l000000_l000000ol008Go0000o`000002o`00
0003o`00Q?l0003o000000;o000000Co0026o`000?l0003o00281?l00002o`01SP;o000000?o00JB
o`000?l06J400_l00002o`0QYP;o00000ol8:JX00ol0003o4c6^oa<a[P02oa<a[P03o`000?l/Bkoo
000000;o7SVb00Oo0000ocMC`olgDl?o=e?3o`000?mBL=;o000000?o@U_500?o0000oeafe?mLM]@0
1?mLM]@00ol0003oMY3OogJ@g`03ogJ@g`[o00001onO^N/00ol0003o[LS^ojg8kP07ojg8kP04o`00
0?nfd^ko0000o`0000So_M[_00?o0000ol7Okol000001oo4i>h01Ol0003oa^S^olKXk_o6j>ko0000
00?oa^W_00?o0000olK[koo6jnl01?o6jnl01?l0003oa^g_olK]koo6kNl2o`000003ol?/lOl0003o
`^ga00Go`^ga00Wo0000ol3]l_o0kO;o`>gbo`000?o0kO;o0000ok_[m?l000001_nijoD2o`0000?o
]n_f00Co0000ok7Wn?l0003o00001on_ioT3o`0000GoY^;k0ol00003ojCQo003o`000?nLgOgoW=gm
00Co00001?nKg?d00ol0003oT]Snoi;HoP03o`0000?oTMSn00?o0000ohSCoon8dol01On8dol3o`00
03Wooooo1?l0000;ooooo`00AOooool00ol0003oooooooooo`1]ooooo`?o00001On>coh2o`0000?o
S/on1_l00004ohk?oP;o00000on>coh5o`0000OoS/on00?o0000ohk?o_l000000_l00003ohk?oP03
o`000?n>cokoS/on00CoS/on1?l00005ohk?oP03o`000?n>cokoS/on00?oS/on1?l00004ogB]mP03
o`000?l05I_o000000;o00000_l03iP01?l0003o00ZDo`0:U?l00002o`05T@03o`000?l008ko0000
00?o000000?o0029o`000?l000000_l000000ol008Go0000o`000002o`000003o`00Q?l0003o0000
00;o000000Co0026o`000?l0003o00280_l000001?l008_o0000o`000?l00Hh2o`000007o`06T_l0
003o01VQo`000?l039Ko0000o`0QYP02o`0000?o22VZ00?o0000oa<a[_lC<Jh00_lC<Jh01_l0003o
;4^ooba;_ol0003o7SVbo`0000Co=e?300?o0000oe9`d_l000000om2FlD00ol0003oG7KDoeafe003
oeafe003o`000?mfT=ooMY3O00?oMY3O00?o0000ohbWion<YnL01On<YnL00ol0003oWkW[oinij`06
oinij`03o`000?n]b>ko[LS^00Oo[LS^0_l0000:okgJk`;o00001oo4i>h00ol0003oa^S^olKXkP03
olKXkP03o`000?o6jNoo000000Koa^__00?o0000olK]koo6kNl00oo6kNl3o`0000Go`^ga00?o0000
ol3]l_o0kO800_o0kO800ol0003o`>gbo`000002o`0000Co^N_e0_l00005okO[mP?o00001On_ioT3
o`0000?o[NKi00?o0000ojKRnol000000_l00006ojCQo0?o00002?nKg?d3o`0000OoTMSn00?o0000
ohSCoon8dol01?l00003ohSCo`03o`000?oooooooooo037ooooo1Ol00003ooooo`03o`000?oooooo
oooo00Wooooo0015ooooo`03o`000?oooooooooo06oooooo0_l00003ohk?oPKo00001On>coh2o`00
00?oS/on1Ol00005ohk?oP;o00000on>coh5o`0000KoS/on00?o0000ohk?o_n>coh00ol00003ohk?
oP03o`000?n>cokoS/on00CoS/on00?o0000ohk?o_l000000_l00003ohk?oP03o`000?md[OKoM:gf
00?oM:gf00Ko0000o`0EVol05I_o01FKo`000?l03iP2o`000004o`0:U?l0003o0000o`05T@Co0000
00Go002;o`000?l0003o0000o`00SP02o`000006o`00QOl0003o0000o`00QOl0003o00240_l00000
1_l008Go0000o`000?l008Ko0000o`00R0;o000000Ko002;o`000?l0003o006>o`000?l04Y`2o`00
00;o01VQ0_l00002o`0QYP04o`000?l8:J[o22VZo`PYZP;o00001?lC<Jh00ol0003o;4^ooba;_`02
o`0000Co=e?300?o0000oe9`d_mBL=800_l000000om2FlGo0000oeafe005oeafe003o`000?mfT=oo
MY3O00?oMY3O00?o0000ohbWion<YnL01On<YnL00ol0003oWkW[oinij`06oinij`03o`000?n]b>ko
[LS^00Co[LS^0_l000000oned^oo0000okgJk`08okgJk`03o`000?o1hNoo000000Goa>C^0_l00006
olKXkP?o00001Oo6jnl00ol0003oa^g_olK]k`03olK]k`05o`000?o5k^ooaNk_olG^kol000000oo2
kO400ol0003o`>gbol3]lP03ol3]lP;o00000onnkO<01?l0003o^N_eo`000?l00006okO[mP06o`00
0?nej_Oo]N[gokGZmol0003o[nOi0ol00006ojgVn@;o00001onThO`2o`0000;oX^7l00?o0000oi_L
oOnKg?d00onKg?d3o`0000;oVMcn00?o0000oi7Ho_nAf?h01?nAf?h4o`0000SoR=?o00?o0000oooo
ooooool0:_ooool6o`0000Sooooo00?o0000ooooooooool02Oooool004Gooooo00?o0000oooooooo
ool0LOooool3o`0000GoS/on0_l00003ohk?oPKo00001?n>coh2o`0000?oS/on1_l00005ohk?oP;o
00000on>coh4o`0000OoS/on00Co0000ohk?o_n>cokoS/on1Ol00006ohk?oP03o`000?md[OKoM:gf
00?oM:gf00Co0000o`0EVol05I_o00000_l03iP01Ol0003o00ZDo`000?l0003o00FA00?o000000Go
00BCo`000?l0003o0000o`00R@05o`000003o`00S?l0003o000000;o000000Go002=o`000?l0003o
0000o`00QP03o`000004o`05U?l0003o0000o`0;V0;o000000?o01:Lo`000?l000000_l06J42o`00
00;o026V0_l00003o`PYZP;o00000olC<Jh00ol0003o;4^ooba;_`02o`0000Co=e?300?o0000oe9`
d_mBL=800_mBL=82o`0000KoG7KD00?o0000ogJ@gomfT=l00omfT=l00ol0003oS:OWohbWi`05ohbW
i`03o`000?nO^N_oWkW[00OoWkW[00Co0000ojg8k_n]b>ko[LS^0_l00004okGBk`03o`000?nmf^oo
_M[_00Co_M[_0_l00003ol7Qk`05o`000?o4i>koa>C^olCTk_l000001oo6j>h01Ol0003oan_^olO[
k_o7jnko000000?oa^__00?o0000olK]koo6kNl00oo6kNl00ol0003oaNk_olG^k`03olG^k`03o`00
0?o2kO7o000000Go`>gb0_l00004okk]l`;o00001_ngjoH2o`0000Co]N[g0_l00007ojgVn@;o0000
0_n[iOX00ol0003oY>7lojCQo002ojCQo0;o00001OnRhO`00ol0003oVmcmo`000002o`0000KoVMcn
00?o0000oi7Ho_nAf?h00ol00003oi3Go`03o`000?n8doooR=?o00GoR=?o0ol0000Vooooo`Go0000
3_ooool00ol0003oooooooooo`09ooooo`00A?ooool00ol0003oooooooooo`1dooooo`;o00001On>
coh4o`0000GoS/on0_l00003ohk?oPGo00001On>coh2o`0000?oS/on1_l00004ohk?oP;o00000on>
coh6o`0000GoS/on00Co0000ohk?o_n>cokoS/on2_l000001?l05I_o0000o`000?l03iP4o`000004
o`05TOl0003o0000o`00SPCo000000?o0029o`000?l000000_l000000ol008Go0000o`000002o`00
0005o`00Q?l0003o0000o`000?l008l00ol000001Ol008So0000o`000?l0003o00^H00;o00000_l0
4Y`2o`0000;o01VQ00Go0000o`0QY_l08JKo026Vo`000003o`PYZP03o`000?lO@kco000000;o4c6^
00Co0000oba;_ol/Bkoo;4^o0_l00004ocMC``03o`000?mBL=;oDW3B00;oDW3B0_l00005oeafe003
o`000?mfT=ooMY3O00CoMY3O00?o0000ohbWion<YnL01On<YnL00ol0003oWkW[oinij`06oinij`04
o`000?n]b>ko0000o`0000Oo]M;_00Co0000okgJkonmf^oo_M[_0_l00006ol7Qk`03o`000?o4i>ko
000000Ooa^S^00?o0000olO[k_o7jnh00oo7jnh00ol0003oa^__o`000004olK]k`;o00001_o5k^l3
o`0000?o`>gb0_l000000onnkO?o0000okk]l`02okk]l`04o`000?nlkO?o_>gco`0000?o]n_f0_l0
0005okGZm`04o`000?ncjOOo/nWgo`0000Co[NKi0_l00005oj_UnP04o`000?nThOco0000o`0000Oo
X^7l0_l00009oiWLoP?o00001on@eol00ol0003oR=?oohSCo`04o`0000?oR=;o00?o0000oooooooo
ool07Oooool6o`0001?ooooo00?o0000ooooooooool02Oooool004Cooooo0ol0001fooooo`03o`00
0?n>coko000000;o00000on>coh00ol0003oS/onohk?oP04ohk?oPCo00001?n>coh2o`0000?oS/on
1_l00005ohk?oP04o`000?n>cokoS/onohk?oPKo00001On>coh2o`0000?oS/on1Ol00005ohC2o0;o
00000_l06il01Ol0003o01FKo`0EVol0003o00nH00;o000000Co00ZDo`000?l0003o00FA1Ol00000
1?l0093o0000o`000?l008h4o`000003o`00S?l0003o002<00;o000000?o002=o`000?l008l00_l0
00001Ol00I7o0000o`000?l01ICo000000;o00^H0_l000000ol04Yco0000o`000002o`0IX@;o0000
0_l08JH01Ol0003o22VZo`PYZ_l8:J[o000000;o7d>l00Co0000oa<a[_lC<Jko00000ol/Bkl2o`00
00?o=e?300?o0000oe9`d_mBL=800omBL=82o`0000GoG7KD00?o0000ogJ@gomfT=l00omfT=l00ol0
003oS:OWohbWi`06ohbWi`03o`000?nO^N_oWkW[00CoWkW[0ol0000:okGBk`03o`000?nmf^oo0000
00So`N7_0ol00005olKXkP;o00001_o7jnh3o`0000?oa^g_00?o0000olG^koo5k^l01Oo5k^l01ol0
003oa>o`olC_l?o4ko3o0000ol3]l_l000001?nnkO<3o`0000Co_>gc00?o0000okO[m_l000001One
j_L2o`0000Co/nWg00Co0000ojgVnOl0003o00001on[iOX3o`0000GoX^7l0ol00002oj3Po003o`00
0?nIg?koVMcn00?oVMcn0ol000000onHfoko0000oi3Go`06oi3Go`Co00002?n8d_l00ol0003ooooo
ooooo`0Gooooo`Go00006Oooool00ol0003oooooooooo`09ooooo`00A?ooool00ol0003ooooooooo
o`1gooooo`;o00001_n>coh00ol0003oS/onohk?oP03o`0000?oS/on00?o0000ohk?o_n>coh00on>
coh4o`0000GoS/on0_l00003ohk?oPGo00001On>coh2o`0000?oS/on1_l00004ohk?oP;o00000on4
`_`4o`000004o`0KWol0003o0000o`0EV`;o000000?o00nHo`000?l000000_l000001Ol01I7o0000
o`000?l0003o00BC00Co000000?o002>o`000?l000000_l000000ol008co0000o`000002o`000003
o`00SOl0003o000000;o000000Co006Ao`000?l0003o00FD0_l000001?l02iSo0000o`000?l04Y`2
o`0000?o01VQ00?o0000o`0QY_l08JH00_l00003o`PYZP03o`000?lO@kco000000;o4c6^00Oo0000
oba;_ol/Bkoo;4^oo`000?m7J=3o000000;o=e?300?o0000oe9`d_mBL=800omBL=800ol0003oKH_O
o`000002o`0000;oG7KD00?o0000ogJ@gomfT=l00omfT=l00ol0003oS:OWohbWi`06ohbWi`03o`00
0?nO^N_oWkW[00Co00000_nZanl00ol0003o]M;_okGBk`08okGBk`;o00002?o1hNl01Ol0003oa>K^
olCVk_o4i^ko000000?oa^S^00?o0000olO[k_o7jnh01Oo7jnh01ol0003oang^olO]k_o7kNko0000
olK]kol000001_o5k^l2o`0000Coa>o`0ol00003okk]l`;o00001_nlkO<3o`0000Co]N[g00?o0000
ok?YmoncjOL01?ncjOL3o`0000GoZnGj0ol00003ojSTn`03o`000?nRhOco000000;o00001_nPh?`0
0ol0003oVMcno`000002o`0000GoV=_n00?o0000oi3Goon@eol01?l00004ohoGo`03o`000?n8d_oo
R=;o00;oR=;o1_l0000Booooo`Go00007_ooool00ol0003oooooooooo`09ooooo`00A?ooool00ol0
003oooooooooo`1iooooo`;o00000on>coh4o`0000OoS/on00?o0000ohk?o_l000000_l00003ohk?
oP03o`000?n>cokoS/on00CoS/on1?l00004ohk?oP;o00000on>coh6o`0000GoS/on00Co0000ohk?
o_n>cokoS/on1_l00003o`LQXP05o`000?l06ioo01^Oo`000?l05I/00_l000001Ol03iSo0000o`00
0?l0003o00fI00Co000000Go00BCo`000?l0003o002@o`000002o`00SP?o000000?o002<o`000?l0
00000_l000001?l008go0000o`000?l008l4o`000004o`05U?l0003o0000o`0;V0;o00000_l04Y`0
1Ol0003o01VQo`0IXOl06J7o000000?o026V0_l00002o`PYZP06o`000?lO@kco7d>lo`000?lC<Jko
00001?l/Bkl00ol0003oAfS@o`000002ocMC``03o`000?mBL=;oDW3B00?oDW3B00Co0000off;gom]
RmooKH_O0ol00006ogJ@g`03o`000?n<YnOoS:OW00CoS:OW1?l00007oj[7k`03o`000?ned^oo]M;_
00Go]M;_0_l00002okcKl003o`000?o1hNoo`N7_00?o`N7_0_l00005olCVkP03o`000?o6j>ko0000
00Koan_^0_l00004olO]kP?o00001?o5k^l2o`0000Goa>o`00Wo0000ol;`lOo2l?7o`_3ao`000?nn
kO?o0000okc]lol000001?nlkO<2o`0000?o^^gd0_l000000onej_Oo0000ok?Ym`04ok?Ym`;o0000
0on`jOP2o`000003oj_Un_l0003o000000KoZ>Ck0_l00009oj3Po0?o00001_nHfoh4o`0000OoSmOo
1_l00006ohOBo`03o`000?oooooooooo00Wooooo1_l0000Sooooo`03o`000?oooooooooo00Wooooo
0014ooooo`03o`000?oooooooooo07_ooooo0ol00004ohk?oP;o00000on>coh5o`0000KoS/on00?o
0000ohk?o_n>coh00ol00003ohk?oP03o`000?n>cokoS/on00?oS/on1?l00005ohk?oP;o00000on>
coh5o`0000GoSLkm0_l00002o`LQXP;o000000Go01^Oo`000?l05I_o0000o`0HX003o`000006o`0:
U?l0003o0000o`000?l029Ko00000_l019<02?l0003o002@o`000?l0003o002>o`000?l008go0000
0_l008`00ol0003o002<o`000002o`00S@06o`000?l008oo0000o`000?l00I7o00000_l01I@01?l0
003o00^Ho`0;V?l00002o`0BW0;o00000_l06J42o`0000;o026V0_l00002o`PYZP04o`000?lO@kco
7d>loam3_0;o00001?l/Bkl01_l0003oAfS@odMXd?l0003o=e?3o`0000GoDW3B00?o0000off;gom]
Rml01?m]Rml5o`000004ogJ@gol0003oS:OWohbWi`Co00000_nJ^>d00ol0003oZ/O_oj[7k`07oj[7
k`03o`000?ned^oo]M;_00;o]M;_0_l00005okcKl005o`000?o1hNoo`N7_ol7Qkol000001oo4i^h3
o`0000Coan_^0_l00005olO]kP04o`000?o7knkoano^olO_kP;o000000?oaNk_o`000?o4ko001Oo4
ko000ol0003o`_3aol;`l@02ol;`l@?o000000?o_>gco`000?nlkO<00_nlkO<00ol0003o^^gdok[]
m004ok[]m0?o00001?ncjOL00ol0003o/>Whok3Yn004ok3Yn0?o00001?nXi?/3o`0000;oY^?k00?o
0000oj3Po?nPh?`00onPh?`3o`0000?oW]om00?o0000oiSKo_nHfoh00ol00004oiKJoP03o`000?n?
eoooSmOo00Co00000on>e_l00ol0003oQm;oohOBo`05ohOBo`?o00001Oooool5o`0002[ooooo00?o
0000ooooooooool02?ooool004Cooooo00?o0000ooooooooool0OOooool01?l0003oS/onohk?o_n>
coh6o`0000GoS/on00Co0000ohk?o_n>cokoS/on1Ol00007ohk?oP03o`000?n>coko000000;o0000
0on>coh00ol0003oS/onohk?oP04ohk?oPCo00001?n>coh2o`0000?oSLkm1?l00002o`LQXP03o`00
0?l06ioo000000;o000000Co01RPo`000?l0003o01:L0_l000000ol03IWo0000o`08UP02o`000003
o`04Tol0003o002@00;o000000?o002>o`000?l000000_l000000ol008co0000o`00S002o`000006
o`00SOl0003o002?o`00Sol0003o006A0_l000001?l01ICo0000o`0;V?l02iP2o`0000;o01:L00Go
0000o`0IXOl06J7o01VQo`000002o`0QYP05o`000?lB>[Oo0000o`PYZ_l000001?lO@k`2o`0000?o
;4^o00Co0000odMXd?m7J=3oAfS@0_l00005oe9`dP03o`000?m]RmooKH_O00CoKH_O00?o0000ohJT
ion6Y>L00_n6Y>L4o`0000OoV[S]00?o0000oj[7konZanl01onZanl01?l0003o]M;_o`000?l00008
okcKl003o`000?o1hNoo000000Ooa>K^00Co0000olKZk_o6j^koa^[^0_l000000oo7jnko0000olO]
kP05olO]kP03o`000?o7knkoano^00?oano^0_l00005olC_l0;o00001?o2l?401?l0003o`?3bol3`
l_o0l?82o`000003okc]lol0003o000000Go^^gd0_l00003okS]mP04o`000?ncjOOo0000o`0000Go
/>Wh0_l00003ojkXn@04o`000?nXi?_o0000o`0000KoY^?k00?o0000oj3Po?l000000_l00006oikO
o@?o00001onFf_h3o`0000SoS]Ko00?o0000ohOBoon7d_l01?l00002ohOBo`Ko0000;oooool00ol0
003oooooooooo`08ooooo`00A?ooool00ol0003oooooooooo`1nooooo`?o00001On>coh2o`0000?o
S/on1Ol00005ohk?oP;o00000on>coh5o`0000KoS/on00?o0000ohk?o_n>coh00ol00002ohk?oP03
o`000?n>cokoS/on00CoS/on1?l00003oa0XYP05o`000?l78J;o1b6Ro`000?l06il00_l000000ol0
5I_o0000o`0HX004o`000003o`0=VOl0003o000000;o000000Go00BCo`000?l0003o002@o`000002
o`00SP?o000000?o002<o`000?l000000_l000001_l008go0000o`000?l008oo0000o`01T@;o0000
00?o00FDo`000?l000000_l02iP01?l0003o01:Lo`0BW?l00003o`0IX@;o00000_l08JH01Ol0003o
4SZgo`000?l8:J[o000000Co7d>l00?o0000oba;_ol/Bkl00_l/Bkl01?l0003oAfS@odMXd?m7J=02
o`0000GoDW3B00?o0000off;gom]Rml01?m]Rml00ol0003oQZCWohJTi`03ohJTi`03o`000?nJ^>go
V[S]00KoV[S]00?o0000oj[7konZanl01onZanl2o`0000[o_=_`0_l00006olCVkP;o00001Oo6j^h3
o`0000Goang^00?o0000olO_k_o7knh00oo7knh01?l0003oa_3_olK`kol00003olC_l003o`000?o2
l?7o`_3a00?o`_3a00?o0000ol3`l_o0l?800oo0l?83o`0000Co^^gd0_l00005okS]mP?o00001?n`
jOP2o`0000Go[^Si0_l00008ojKSn`?o00001OnNgod3o`0000;oW=km00?o0000oiKJo_nFf_h00_nF
f_h3o`0000;oUM[n00?o0000ohkFoon>e_l01On>e_l4o`0000OoQm;o00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`08ooooo`00A?ooool00ol0003oooooooooo`20ooooo`;o00000on>coh6
o`0000CoS/on0_l00003ohk?oPKo00001On>coh01?l0003oS/onohk?o_n>coh5o`0000KoS/on00?o
0000ohk?o_n>coh00ol00003ohk?oP04o`000?l@::Ko42RVoa0XYP;o000000Go1b6Ro`000?l0003o
0000o`0NX`02o`000006o`0HX?l0003o0000o`0BW?l0003o00fI0_l000001ol029Ko0000o`04Tol0
19?o0000o`00T?l000000_l008h00ol0003o002=o`000002o`00S003o`000?l008co000000;o002=
00Ko0000o`00Sol0003o0000o`01TOl00002o`05U004o`000?l02iSo00^Ho`0000;o01:L0_l00002
o`0IX@05o`000?l6<;;o0000o`0QY_l000000_lB>[L2o`0000Co7d>l0_l00003oba;_`03o`000?m7
J=3oAfS@00;oAfS@0_l00004oe9`dP03o`000?m]RmooKH_O00CoKH_O00?o0000ohJTion6Y>L01?n6
Y>L00ol0003oV[S]oiZhk@06oiZhk@03o`000?nZanooZ/O_00CoZ/O_0_l000000oncdo3o0000okcK
l008okcKl004o`000?o1h_3o`N;`o`0000?oa>K^0_l00006olKZkP05o`000?o7kNkoang^olO]k_l0
00000oo7kNh00ol0003oano^olO_kP03olO_kP03o`000?o6l>ooa_3_00;oa_3_00?o0000olC_l?l0
00001Oo2l?400ol0003o`?3bol3`lP03ol3`lP;o00000_nml?<01?l0003o^^gdo`000?l00005okS]
mP;o00000onek?H01?l0003o/>Who`000?l00005ojkXn@;o00000_n[ioX00ol0003oY^?kojKSn`02
ojKSn`?o00000onTho`00ol0003oW]omo`000002o`0000KoW=km00Co0000oiKJo_l0003o00001_nE
f_h00ol0003oS]KoohkFo`04o`0000?oS]Ko00?o0000ohOBoon7d_l01?n7d_l3o`0003;ooooo00?o
0000ooooooooool02?ooool004Cooooo00Co0000ooooool0003o0000POooool3o`0000GoS/on0_l0
0003ohk?oPGo00001On>coh2o`0000?oS/on1Ol00005ohk?oP;o00000on>coh4o`0000OoS/on00Ko
0000oa0XY_l@::Ko42RVo`000?l78J82o`000004o`0KWol0003o0000o`0000;o01RP00So0000o`0B
W?l0003o0000o`0=VOl0003o00RFo`0000;o00BC00Go0000o`00T?l0003o0000o`00SP03o`0000;o
002<00?o0000o`00S?l000000_l008d01_l0003o002?o`00Sol0003o006Ao`0000;o00FD00?o0000
o`0;V?l02iP00_l00002o`0BW008o`000?l06J7o01VQo`000?l6<;;o0000o`0QY_l00002oa8j]`;o
00001OlO@k`2o`0000;o;4^o00?o0000odMXd?m7J=000_m7J=001?l0003oHhGNo`000?l00003oe9`
dP03o`000?m]RmooKH_O00CoKH_O00?o0000ohJTion6Y>L00on6Y>L00ol0003oV[S]oiZhk@07oiZh
k@04o`000?nZanooZ/O_oj[7k`;o00001?ncdo000ol0003o_=_`okcKl004okcKl0;o00001?o1h_00
0ol0003oa>K^o`000007olKZkP03o`000?o7kNkoang^00?oang^00?o0000olO]k_l000001?o7knh2
o`0000Goa_3_0ol00004ol;`l@03o`000?o0l?;o`?3b00;o`?3b0_l000001?nml??o0000okg`lonm
l?<3o`0000Co^>gf0_l00005okG/mP?o00001?n^j?T2o`0000GoZnOj00Co0000ojKSnol0003o0000
1_nTho`3o`0000OoW=km1?l00006oiGJoPCo00002?n>e_l00ol0003oQm;oohOBo`03o`0000?oQm;o
00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`00>Oooool2o`0000Wooooo0_l0
0025ooooo`;o00000on>coh6o`0000CoS/on0_l00003ohk?oPKo00001?n>coh2o`0000?oS/on1_l0
0004ohk?oP;o00000on>coh4o`0000;o42RV0ol000001Ol39:Oo0000o`000?l07Z?o000000;o01RP
0_l000001Ol04Yco0000o`0=VOl0003o00RF00;o000000Go00BCo`000?l0003o002@o`000002o`00
SP?o000000?o002<o`000?l000000_l000001_l008go0000o`000?l008oo0000o`01T@;o000000?o
00FDo`000?l000000_l02iP00ol0003o01:Lo`0BW002o`0000;o01VQ00Co0000o`H`/_l0003o0000
0olB>[L2o`0000Co7d>l00?o0000ocYPcOl000000_l/Bkl00ol0003oAfS@odMXd002odMXd003o`00
0?mSQMkoHhGN00;o000000?oDW3Bo`000?m]Rml01Om]Rml00ol0003oQZCWohJTi`04ohJTi`03o`00
0?nJ^>goV[S]00KoV[S]00Co0000oj[7kol0003o00001oncdo001?l0003o_=_`okcKl?nlfo02o`00
00Ko`N;`0ol00005olKZkP;o00001_o7kNh3o`0000?oano^00?o0000olK`koo6l>l01?o6l>l01?l0
003oa?7_olCakoo4lNl2o`000003ol;`lOl0003o`?3b00;o`?3b0_l00003okg`l`03o`000?nml??o
000000?o^nod00Co0000okS]m_l0003o00001Onek?H2o`0000?o/^_g00Co0000ojkXnOl0003o0000
1on[ioX3o`0000CoY>?l0ol00003oj;Ro003o`000?nLg_goW=km00Co00001?nKgOd00ol0003oUM[n
oiGJoP03o`0000?oTmWn00?o0000ohkFoon>e_l01On>e_l4o`0000OoQm;o00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`08ooooo`00>?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo08Kooooo0ol00005ohk?oP;o00000on>coh5o`0000GoS/on00Co0000ohk?o_n>coko
S/on1_l00005ohk?oP04o`000?n>cokoS/onohk?oPKo00000olE;JT00ol0003o42RVoa0XYP02o`00
0006o`LQX_l0003o0000o`000?l07Z?o00000ol06:001?l0003o01:Lo`000?l03IT2o`000006o`08
U_l0003o00BCo`04Tol0003o002@0_l000001?l008ko0000o`000?l00002o`00S003o`000?l008co
000000;o002=00Ko0000o`00Sol0003o0000o`01TOl00002o`05U003o`000?l02iSo00^H00;o0000
00[o01:Lo`000?l09jgo0000o`0IXOl0003o1S2bo`000?l08JKo00000olB>[L00ol0003o7d>loam3
_002oam3_006o`000?ljH<go>V3=o`000?l/Bkoo00001?m7J=000ol0003oHhGNof>5gP02of>5gP;o
00001om]Rml00ol0003oQZCWohJTi`04ohJTi`03o`000?nJ^>goV[S]00CoV[S]0ol0000:ok?Cl003
o`000?nlfo3o000000Oo`N;`00Go0000olCWkoo4inooa>O_o`000003olKZkP03o`000?o7kNkoang^
00Goang^00Oo0000olO_k_o7knkoano^o`000?o7knko000000Goa_3_0_l00005olCak`Co000000?o
`?3bo`000?nml?<01?nml?<2o`0000Co^nod0ol00004okG/mP;o00001OnbjoL3o`0000GoZnOj0ol0
0003ojWVnP04o`000?nThoco0000o`0000KoX^;l0ol00008oi_Mo@?o00001onCfOh00ol0003oS]Ko
ohkFo`04o`0000?oSMGo00?o0000ohOBoon7d_l00_n7d_l6o`0002kooooo00?o0000ooooooooool0
2?ooool003Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`29ooooo`;o0000
0on>coh6o`0000CoS/on0_l00003ohk?oPGo00001On>coh2o`0000?oS/on1Ol00005ohc=o@04o`00
0?lE;JWo5BfYoaD]Z@;o000000?o42RVo`000?l;:ZX00_l000000ol39:Oo0000o`0NX`02o`0000;o
01RP00Oo0000o`0BW?l0003o0000o`0=VOl0003o00RF00;o000000?o00BCo`000?l000000_l00000
0ol008ko0000o`000002o`000003o`00S?l0003o000000;o000000Ko002=o`000?l0003o002?o`00
0?l00I42o`000004o`05U?l0003o0000o`0;V0;o00000_l04Y`2o`000004o`0IXOl0003o1S2bo`H`
/P;o00000olB>[L2o`0000Co7d>l00?o0000ocYPcOljH<d00_l00005odMXd003o`000?mSQMkoHhGN
00?oHhGN1Ol00002off;g`03o`000?n6Y>OoQZCW00CoQZCW00?o0000oiZhkOnJ^>d01?l00002ojK6
l003o`000?ncdo3o/m?`00So/m?`0_l00007ol7Rl003o`000?o4inooa>O_00?oa>O_00?o0000olKZ
k_l000001oo7kNh00ol0003oano^olO_kP02olO_kP?o00001?o6l>l00ol0003oa?7_olCak`04olCa
k`04o`000?o2l_3o`_;`ol;bl0?o00000onml?<3o`0000Co^nod00Ko0000okW_mOnikoGo^Noeo`00
0?nek?H2o`0000Go/^_g0_l00003ok3Zn003o`000?n[io[o000000;o00001_nYi_X3o`0000CoX^;l
0ol00002oioQo003o`000?nKgOgoVmgm00?oVmgm0ol00002oiWLoP03o`000?nCfOkoTmWn00CoTmWn
1?l00006ohgEo`Ko00001_n6d_l00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo
000hooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0Roooool3o`0000GoS/on
00Co0000ohk?o_n>cokoS/on1_l00004ohk?oP;o00000on>coh6o`0000CoS/on0_l00003ohc=o@?o
00000olE;JT01?l0003o42RVo`000?l;:ZX2o`000005o`<TYol0003o01jSo`0NXol000000_l06:02
o`000003o`0BW?l0003o00fI00Co000000Ko00BCo`000?l0003o002@o`000?l008h4o`000003o`00
S?l0003o000000;o000000Co002=o`000?l0003o002?1?l000000ol01ICo0000o`000002o`0;V0;o
000000Ko01:Lo`000?l09jgo0000o`0IXOl00002o`H`/P03o`000?lB>[Oo4SZg00;o4SZg0_l00003
oam3_004o`000?ljH<go>V3=ocYPc@;o00001?m7J=000ol0003oHhGNof>5gP03of>5gP03o`000?mn
WnSoOYoX00;oOYoX3?l00007ojK6l003o`000?ncdo3o/m?`00Go/m?`0_l00002ok[Ll@03o`000?o1
h_3o`N;`00?o`N;`00?o0000olCWkoo4inl01?o4inl3o`0000Goang^0_l00004olO_kP04o`000?o6
lNkoa_7^olKakP;o000000?oa_3_o`000?o4lNl01?o4lNl2o`0000?o`_;`00Oo0000ol3blOo0l_7o
`?;ao`000?nml??o000000;o^nod00?o0000ok__m?nkko@00_l00004okW_m@?o00001OnbjoL00ol0
003o/>[hok3Zn003ok3Zn0?o00001OnYi_X3o`0000?oY^Gk00Co0000oj;Ro?l0003o00001_nOhO`0
0ol0003oVmgmo`000002o`0000KoVMcn00?o0000oi?Io_nCfOh00ol00004oi;HoP03o`000?n=eOoo
SMGo00?o00000on<eOl00ol0003oQ];oohKBo`05ohKBo`?o0000;?ooool00ol0003oooooooooo`08
ooooo`00>?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo08cooooo0_l00005
ohk?oPCo00001On>coh2o`0000?oS/on1Ol00005ohk?oP04o`000?n>cokoS/onohk?oPKo00000_lM
<jd01?l0003o5BfYoaD]ZOlE;JT2o`000005oa0XY_l0003o0000o`000?l39:L00_l000000ol07Z?o
0000o`0HX002o`0HX003o`000?l04Yco000000?o000000Go00RFo`000?l0003o0000o`09V@04o`00
0003o`04U_l0003o000000?o000000Ko002<o`000?l0003o002=o`000?l008l2o`000004o`01TOl0
003o0000o`05U0;o000000?o00^Ho`000?l07jP00_l000001?l09jgo0000o`0IXOl00002o`H`/P;o
00000olB>[L00ol0003o;5O:o`000002oam3_003o`000?ljH<go>V3=00;o>V3=0_l00004odMXd003
o`000?mSQMkoHhGN00?oHhGN00?o0000ogjOj?mnWnP01?mnWnP00ol0003oU;K^oiBfkP04oiBfkP03
o`000?nVa_3oY/K`00OoY/K`00?o0000ok?Cl?ncdo000_ncdo02o`0000Go^]ca00Go0000ol7Rl?o1
h_3o`N;`o`000006olCWk`05o`000?o5k>ooaNc_olG/kol000000oo7kNh00ol0003oano^olO_kP03
olO_kP03o`000?o6lNkoa_7^00?oa_7^0ol00003olCak`;o00001?o2l_000ol0003o`?;aol3bl@02
ol3bl@?o00000_nkko@00ol0003o^nodo`000005okW_m@04o`000?nfk_Ko]^kfokK^mP;o000000?o
/^_go`000?l000001?n`j_P2o`0000?o[NWi00?o0000ojWVn_l000000_l00006ojKUn`;o00002?nO
hO`3o`0000OoVMcn1?l00006oi;HoPCo00001on<eOl00ol0003oQ];oohKBo`04o`0000;oQ];o00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`00>?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo08kooooo00?o0000ohk?o_l000000_l00003ohk?oP03o`000?n>
cokoS/on00CoS/on1?l00004ohk?oP;o00000on>coh5o`0000CoPl7k00Co0000oadc[OlM<jgo7C>]
0_l00002oaD]Z@;o000000Co42RVo`000?l;:Z[o00000_l39:L01?l0003o01jSo`0NXol00002o`0H
X005o`000?l04Yco0000o`000?l03IT01?l000000ol019?o0000o`000002o`000003o`00S_l0003o
000000;o000000?o002<o`000?l000000_l000001Ol008go0000o`000?l0003o00bK00?o000000?o
00FDo`000?l06:<00_l000000ol07jSo0000o`000002o`0W[@;o00000ol6<;801Ol0003o4SZgoa8j
]olB>[Oo000000;o;5O:00Co0000oam3_?lO@kco00000oljH<d00ol0003oEgkMo`000003odMXd003
o`000?mSQMkoHhGN00?oHhGN00?o0000ogjOj?mnWnP01OmnWnP00ol0003oU;K^oiBfkP04oiBfkP03
o`000?nVa_3oY/K`00OoY/K`00Co0000ok?Cl?l0003o00002?njg?400ol0003o`N;`o`000006olCW
k`03o`000?o5k>ooaNc_00?oaNc_00?o0000olO]k_l000001Oo7knh00ol0003oa_7^olKakP03olKa
kP07o`000?o5l^ooaO;_olGbkol0003oa?7_o`000005ol;bl003o`000?o0l_7o`?;a00;o`?;a00?o
0000okkbl_nnl_801Ol00004okW_m@;o00001Onfk_H3o`0000Co/>[h00?o0000ojgYnOn]jOT00on]
jOT3o`0000GoY^Gk0ol00002ojCTo003o`000?nOhOcoWn7l00;oWn7l0ol00003oigOo@03o`000?nI
g?koVMcn00Co00000onGg?h00ol0003oT]Snoi;HoP04o`0000?oTMSn00?o0000ohcEoon<eOl01?n<
eOl4o`0000OoQ];o00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo0_l00008ooooo`?o0000Soooool2
o`0000KoS/on00?o0000ohk?o_n>coh00ol00003ohk?oP04o`000?n>cokoS/onohk?oPKo00001?n>
coh2o`0000CoPl7k00Co0000oadc[OlM<jgo7C>]0_l000000olE;JWo0000oa<`[P02o`000005o`/Z
Z_l0003o0000o`<TYol000000_l07Z<00ol0003o01RPo`0HX003o`000003o`0GX_l0003o000000?o
000000Go00BCo`000?l0003o0000o`06U`02o`000004o`04U_l0003o0000o`00S0?o000000Go00FF
o`000?l0003o0000o`00S`03o`000004o`0AWol0003o0000o`0HX`;o00000_l07jP2o`0000;o02N]
00Go0000o`H`/_l6<;;o1S2bo`000004oa8j]`06o`000?l/El[o;5O:o`000?lO@kco00001?ljH<d0
1_l0003oEgkMo`000?l0003oAfS@o`0000KoHhGN00?o0000ogjOj?mnWnP01?mnWnP00ol0003oU;K^
oiBfkP05oiBfkP03o`000?nVa_3oY/K`00KoY/K`0_l0000:ok[Ll@?o00001Oo4inl00ol0003oaNc_
olG/k`04olG/k`?o00001?o7knh00ol0003oa_7^olKakP03olKakP03o`000?o5l^ooaO;_00;oaO;_
0ol00004ol;bl004o`000?o0l_7o`?;aol3bl@Go00000_nnl_84o`0000;o^Noe00?o0000okK^m_nf
k_H01?nfk_H01_l0003o/nggok?]monckOOo0000ok3Zn0;o00001?n]jOT2o`0000?oZ^Sj00?o0000
ojKUnol000000_l00006ojCTo004o`000?nOhOco0000o`0000KoWMom0ol00006oiOLoPCo00002?nA
f?h00ol0003oS=GoohcEo`03o`0000CoRmCo00?o0000ohKBoon6d_l00_n6d_l5o`0002Wooooo00?o
0000ooooooooool02?ooool000_ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo097ooooo0_l00003ohk?oPCo00001_n>coh4o`0000GoS/on00Co
0000ohk?o_n>cokoS/on2Ol00002oadc[@;o00000_lE;JT3o`0000;o2bZZ00Go0000o`<TYol39:Oo
0000o`0NX`02o`000004o`0HX?l0003o0000o`0BW0?o000000?o016No`000?l000000_l000000ol0
2IWo0000o`000002o`000003o`04U_l0003o000000;o000000?o00BEo`000?l01IH00_l000000ol0
29So0000o`000002o`000003o`0AWol0003o000000;o01RS0_l000000ol07jSo0000o`000002o`0W
[@;o00000ol6<;801Ol0003o4SZgoa8j]olB>[Oo000000?o;5O:0_l00004ocYPc@04o`000?mGO]go
EgkMoeMng@?o00001OmSQMh00ol0003oOYoXogjOj005ogjOj003o`000?nD]^koU;K^00CoU;K^00?o
0000ojK6l?nVa_000onVa_03o`0000;o[m?b00?o0000ok[LlOnjg?401Onjg?42o`0000?o_^?a00Go
0000olCWkoo4inooa>O_o`000006olG/k`04o`000?o6knooa^o_olK_k`;o000000?oano^o`000?o6
lNh00oo6lNh2o`0000CoaO;_00Co0000ol?ckoo3lnoo`o?_0_l000000oo2l_3o0000o`000003o`00
00Ko__;b00Co0000ok_alonklO?o^o7c0ol00005okK^mP;o00001?nckOL3o`0000Co[NWi00?o0000
oj[Xn_nZj?X00onZj?X2o`0000WoY>Cl0ol00004oigOo@?o00000onKgod00ol0003oUmcnoiOLoP03
o`0000?oU]_n00?o0000oi7Ho_nAf?h01OnAf?h4o`0000KoRmCo1_l00005ohKBo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02?ooool000;ooooo0ol00002ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo09?ooooo0ol00004ohk?oP;o000000CoS/ono`000?l0003o00000on>coh00ol0003oS/on
ohk?oP03ohk?oPCo00000omc[OH00ol0003o9CV`obDi/002obDi/00:o`000?lM<jgo7C>]o`000?lJ
=[7o0000oaD]ZOl0003o4c2^o`0000;o2bZZ00?o0000o`<TYol39:L00_l000001?l07Z?o0000o`0H
X?l06:03o`000003o`0GX_l0003o000000Co000000Go00VIo`000?l0003o00JGo`000002o`04UP?o
000000Co00BEo`000?l0003o00FF1?l000001?l039_o0000o`000?l04Il2o`000003o`0HXol0003o
000000;o01nX00Go0000o`0W[Ol09jgo02N]o`000003o`H`/P;o00000_lB>[L00ol0003o;5O:obaG
bP02obaGbP;o00000oljH<d00ol0003oEgkMoeMng@03oeMng@03o`000?mSQMkoHhGN00?oHhGN00?o
0000ogjOj?mnWnP01OmnWnP00ol0003oU;K^oiBfkP05oiBfkP03o`000?nVa_3o000000;o00001_n_
do800ol0003o^]caok[Ll@02ok[Ll@;o00001_nnho400ol0003oa>O_o`000005olG/k`;o00001Oo6
knl3o`0000?oa_7^00?o0000olGbkoo5l^l00oo5l^l00ol0003o`o?_o`000007o`000003ol3blOl0
003o__;b00Co__;b0_l00004ok_al`?o00000onfk_H2o`0000Co/ngg0_l00003ok3/n004o`000?n]
jOWo0000o`0000CoZ^Sj0_l00002ojOWn`03o`000?nTi?coY>Cl00?oY>Cl0ol00003oj;So004o`00
0?nMgogo0000o`0000KoVmom0ol00007oiKKoP03o`000?nAf?koTMSn00Co00000on@eol00ol0003o
RmCooh_Do`04o`0000;oRmCo00?o0000ohKBoon6d_l01On6d_l3o`0002Sooooo00?o0000oooooooo
ool01oooool000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Eoooo
o`04o`000?n>cokoS/onohk?oPGo00001_n>coh00ol0003oS/ono`000002o`0000?oS/on00?o0000
og>]m_mc[OH00_mc[OH00ol0003o9CV`obDi/002obDi/003o`000?lM<jgo7C>]00;o000000?o5BfY
o`000?lC<:h00_l000001?l;:Z[o0000o`000?l39:L2o`000004o`0NXol0003o0000o`0HX0?o0000
00Oo01NRo`000?l0003o016No`000?l03I_o000000;o00VI00?o0000o`06Uol000000_l019H00ol0
003o00BEo`000002o`04U@07o`000?l01IKo0000o`000?l029So0000o`0<V`02o`000003o`0AWol0
003o000000;o01RS00?o0000o`0OZ?l07jP00_l00002o`0W[@07o`000?l6<;;o1S2bo`H`/_l0003o
7Tg5o`000002oa8j]`03o`000?l/El[o;5O:00;o;5O:0_l00003ocYPc@03o`000?mGO]goEgkM00?o
EgkM0ol00003of>5gP03o`000?mnWnSoOYoX00GoOYoX00?o0000oiBfk_nD]^h00onD]^h3o`0000[o
[m?b00Co0000ok[LlOl0003o00002?nnho43o`0000?oaNc_0_l00006olK_k`07o`000?o6lNooa_7_
olKakol0003oa_7^o`000003olGbk`Go00000oo3lnl01?l0003o`OC`ol7dl?o1m?03o`0000?o__;b
0_l00005ok_al`04o`000?nhlOCo^?7dokSam0?o00001?nckOL2o`0000Go/>ch0ol00004oj[XnP03
o`000?nWio_oYnOk00?oYnOk00?o0000ojCTo?l000000_l00006oj;So0?o00001?nKgod3o`0000;o
V]kn00?o0000oiKKo_nFfoh01?nFfoh4o`0000KoT=Oo1?l00007oh_Do`03o`000?n6d_ooQ];o00Co
00000on6d_l00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo0003ooooo`03o`00
0?oooooo000000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0U_ooool3o`0000GoS/on00Co0000ohk?o_n>
cokoS/on1Ol00006ohk?oP03o`000?mc[OKoLjgf00;oLjgf00Co0000obDi/?lU>K3o9CV`0_l00000
0olM<jgo0000oaXf/@02o`0000;o4c2^00?o0000o`/ZZ_l;:ZX00_l000001Ol39:Oo0000o`000?l0
003o02:X00;o000000Ko01bUo`000?l05j;o01NRo`000?l04Ih4o`000003o`09VOl0003o000000;o
000000?o00BFo`000?l000000_l000001ol019Go0000o`05U_l01IKo0000o`08V?l000000_l039/0
1?l0003o016Oo`0AWol00002o`0HX`;o00000_l07jP01Ol0003o02N]o`0W[Ol09jgo000000?o1S2b
00Go0000oai=aOl0003o4SZgo`000004obaGbP03o`000?m9M]_o000000;o>V3=00?o0000oeMngOmG
O]d00omGO]d00ol0003oLi[Yog>Jj@04o`0000OoOYoX00?o0000oiBfk_nD]^h00ol00002oj35lP03
o`000?n_do;o[m?b00So[m?b0_l00009okkSl@07o`000?o2jO7o`^Waol;YlOl0003oaNc_o`000007
olK_k`03o`000?o6lNooa_7_00;oa_7_1_l000000oo5l^oo0000ol?ck`03ol?ck`;o00000oo1m?00
1ol0003o_oCaokodlOnom?7o0000okkbl_l000001OnklO<2o`0000Co^?7d1?l000000onckOOo0000
o`000005ok3/n0;o00000on]joT01?l0003oZ^Sjo`000?l00006ojOWn`?o00001OnRho`3o`0000?o
Wn;m00Co0000oi_OoOl0003o00001_nJg_h00ol0003oU]_noiKKoP03o`0000CoU=[n00?o0000oi3G
oon@eol00ol00004ohoGo`03o`000?n;e?ooRmCo00;oRmCo1Ol00008ohKBo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01oooool000?ooooo0ol00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09So
oooo0_l00003ohk?oPGo00001On>coh01?l0003oS/onohk?o_n>coh9o`0000;o9CV`0_l000001OlM
<jgo0000oaXf/OlJ=[7o000000;o4c2^00?o0000o`/ZZ_l;:ZX00_l000001?l39:Oo0000o`000?l0
7Z<3o`000004o`0LYOl0003o01NRo`0GXP;o000000Co016No`000?l03I_o00000_l02IT00ol0003o
00JGo`000002o`04UP04o`000?l019Go0000o`04U@;o000000?o00FFo`000?l000000_l000001?l0
39_o0000o`000?l04Il2o`0000;o01RS00Co0000o`0OZ?l07jSo00000ol09jd2o`0000;o1S2b00?o
0000oai=aOlNCLD00_l00005obaGbP06o`000?m9M]_o0000o`000?ljH<go00001OmGO]d00ol0003o
Li[Yog>Jj@02og>Jj@_o00001_nPaO800ol0003o[m?bojoClP05ojoClP;o00000_nfgO<00ol0003o
_^?aokkSl@04okkSl@;o00001?o2jO43o`0000Goa^o_2?l00002olGckP;o000000?oaO;_o`000?o3
lnl00_o3lnl2o`0000Co`OC`00?o0000okodlOnom?400_nom?43o`0000Co^o7c00?o0000okSam?nh
lO@00_nhlO@2o`0000?o]O3e0ol00005ok3/n003o`000?n]joWo[N_i00?o[N_i0ol00004ojOWn`?o
00000onUi_/00ol0003oX^?lo`000002o`0000KoWn;m0_l00007oi[NoPCo00001_nDf_h4o`0000Ko
SmOo1_l00005oh[Do`03o`000?n6d_ooQ];o00;oQ];o1Ol0000Uooooo`03o`000?oooooooooo00Oo
oooo0003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooooooo`2Jooooo`?o00001?n>coh2
o`0000?oS/on1Ol00003of6Ek003o`000?l/?k?o;3nc00;o;3nc00Co0000obDi/?lU>K3o9CV`0_l0
00000olM<jgo0000oaXf/@02o`000006oa<`[_l0003o0000o`/ZZ_l0003o1bj_0_l000001_l0::co
0000o`000?l08ZSo0000o`0LY@;o00000_l05j801Ol0003o016No`000?l03I_o000000;o00VI00?o
0000o`06Uol000000_l019H00ol0003o00BEo`000002o`04U@06o`000?l01IKo00FFo`000?l029So
00000_l039/01?l0003o016Oo`0AWol00002o`0HX`05o`000?l07jSo01nXo`0OZ?l000000_l09jd0
1Ol0003o3d;1o`000?l6<;;o000000?o7Tg50_l00004obaGbP04o`000?m9M]_oBGKKodUff`;o0000
1OmGO]d00ol0003oLi[Yog>Jj@03og>Jj@03o`000?n</_3oS;;`00GoS;;`00?o0000oj35l_nPaO80
1_nPaO800ol0003o[m?bojoClP02ojoClP;o00001OnfgO<01?l0003o_^?aokkSlOnnho42o`0000Go
`^Wa00Ko0000ol?^l?o3k_3o`nk`o`000?o6knl5o`0000?oa_7_00?o0000olGck_o5lnh00oo5lnh4
o`000003ol?ckol0003o`OC`00Co`OC`00?o0000okodlOnom?400_nom?401?l0003o_??bokccl_nl
lo82o`000003ok_alol0003o^?7d00?o^?7d00?o0000okG`mOnel?D00_nel?D01?l0003o/^ofo`00
0?nbkoH2o`000003ok3/n?l0003o000000Co[N_i0_l00003oj[Zn@04o`000?nWio_o0000o`0000Ko
YNKk0ol00005oioRo@?o00000_nMhOd00ol0003oV]knoi[NoP04o`0000?oV=gn00?o0000oiCJo_nD
f_h01?l00004oi?IoP03o`000?n?eoooSmOo00?o00000on>e_l00ol0003oR]Cooh[Do`04oh[Do`Ko
00001On5dOl00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0003ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0W?ooool2o`0000?oS/on1Ol00004ohk?oP;o00000omQUN`00ol0
003o;3ncob`o/`02ob`o/`05o`000?lU>K3o9CV`o`000?lR?;@00_l00002oaXf/@0=o`000?lC<:ko
4c2^o`000?l;:Z[o0000o`L^[ol0003o0bBWo`000?l0::co0000o`0RZ002o`000005o`0LYOl0003o
01NRo`0GX_l000000_l04Ih01?l0003o00fKo`000?l02IT2o`000003o`06Uol0003o00BF00;o0000
00Co00BEo`000?l019Go00000_l01IH00ol0003o00RHo`000002o`0<V`04o`000?l04Ioo016Oo`00
00?o01RS00?o0000o`0OZ?l07jP00_l00002o`0W[@05o`000?l?@/7o0000o`H`/_l000000olNCLD2
o`0000?o;5O:00?o0000odUffom9M]/00_m9M]/00ol0003oEgkMoeMng@04oeMng@03o`000?mcV^Wo
Li[Y00?oLi[Y00?o0000ohbbl?n</_001On</_000ol0003oX<Gboj35lP06oj35lP04o`000?n_do;o
0000o`0000So]]gc00?o0000okkSlOl000001_o2jO400ol0003o`nk`o`000004o`000003olK_kol0
003oa_7_00Coa_7_00?o0000olGck_o5lnh00oo5lnh01?l0003o`oC_ol?dkoo3m>l3o`0000Co`OC`
00Co0000okodlOnom?7o_oCa0_l00005okcclPCo000000?o^?7do`000?l000000onel?D2o`0000?o
/^of1Ol00004ojg[n@03o`000?nZj_WoZ^[i00?oZ^[i0ol00004ojGVn`?o00000onRiO`00ol0003o
Wn;mo`000002o`0000GoWN7m0ol00006oiSMoPCo00001onCfOh4o`0000OoS]Ko00?o0000oh[Doon:
e?l00ol00003ohWCo`03o`000?n5dOooQM7o00CoQM7o0ol0000Sooooo`03o`000?oooooooooo00Oo
oooo0002ooooo`Co0000??ooool3o`0009oooooo0ol00004ohk?oP;o00000on>coh7o`0000?o;3nc
0_l000000olU>K3o0000ob8l]002o`0000;o6SJa00?o0000oa<`[_lC<:h00_l000000ol;:Z[o0000
o`L^[`02o`000007o`0X[?l0003o0000o`0RZ?l0003o01bUo`000002o`0GXP;o000000Co016No`00
0?l03I_o00000_l02IT00ol0003o00JGo`000002o`04UP03o`000?l019Go000000;o00BE00Ko0000
o`05U_l0003o0000o`08V?l00002o`0<V`04o`000?l04Ioo016Oo`0000;o01RS0_l000002_l07jSo
0000o`4h^ol0003o02N]o`000?l?@/7o0000o`H`/_l00003oai=a@03o`000?ljK=So000000?o;5O:
00?o0000odUffom9M]/00_m9M]/2o`0000CoEgkM00?o0000og>JjOmcV^T00omcV^T00ol0003oS;;`
ohbbl006ohbbl003o`000?nPaO;oX<Gb00GoX<Gb0_l0000:okKMl`?o00000oo2jO45o`0000Co`nk`
0ol00004olKak`03o`000?o5lnkoaO?^00;oaO?^0_l00003ol?dk`04o`000?o1mNoo`OG_ol7ek`;o
000000?o`OC`o`000?nom?400_nom?400ol0003o_??bokcclP03okcclP;o00000onjlo<3o`0000?o
]O3e00?o0000ok;_m_nbkoH00onbkoH3o`0000;o[nkg00Co0000ojg[nOl0003o00000onZj_T3o`00
00?oYnWj00Co0000ojGVnol0003o00001_nRiO`3o`0000CoWN7m0ol00003oi_Oo@03o`000?nHgOko
V=gn00?o00001?nFg?h00ol0003oTmWnoi?IoP04o`0000;oTMWo00?o0000ohkFoon>e_l01On>e_l4
o`0000OoRM?o00?o0000ohGAoon5dOl00ol00003ohGAo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01oooool004;ooooo00?o0000ooooooooool0XOooool01?l0003oS/onohk?o_n>coh6
o`0000;oCG[N00Co0000oc95]_lbAKKo<TFf0_l00002ob`o/`06o`000?lY@[So0000obDi/?l0003o
8Sbd0_l000001_lJ=[7o0000o`000?lC<:ko0000o`ld/`;o00000_l7;Zl01_l0003o02R/o`0X[?l0
003o02:Xo`0000;o01bU00?o0000o`0GX_l05j801_l000000ol02IWo0000o`000002o`000003o`04
U_l0003o000000;o000000Ko00BEo`000?l01IKo00FFo`000?l029P2o`000004o`0<Vol0003o0000
o`0AW`;o000000?o01RSo`000?l000000_l07jP01?l0003o0CRko`000?l00002o`m2`@;o00001?lN
CLD00ol0003o>VcHo`000002obaGbP03o`000?m9M]_oBGKK00;oBGKK00?o0000ofNDjOl000000_l0
0002oeMng@03o`000?mcV^WoLi[Y00?oLi[Y00?o0000ohbbl?n</_001On</_000ol0003oX<Gboj35
lP02oj35lP?o00000_nZd_D00ol0003o]]gcokKMl`05okKMl`So000000?o`^Wao`000?o3k_001Oo3
k_001?l0003oa?7`olCal?o4lO02o`000003olKakol0003oaO?^00;oaO?^0_l00004ol?dk`03o`00
0?o1mNoo`OG_00?o`OG_1?l000000onom?7o0000okcclP03okcclP;o00001?njlo<01ol0003o]o;d
okObm?ngl_Co0000okG`mOl000001?nbkoH2o`0000?o[nkg00?o0000ojo^mol000000ol000000onZ
j_Wo0000o`000006ojOYnP?o00001?nRiO`3o`0000?oX>?l00Co0000oigQoOl0003o00001_nKgod3
o`0000KoU]cn1?l00007oi7Io`03o`000?n>e_ooS]Ko00Co00000on=e_l00ol0003oRM?oohWCo`02
ohWCo`Ko00001on5dOl00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo0012oooo
o`03o`000?oooooooooo0:;ooooo0ol00005ohk?oP05o`000?m=N]koCG[Nodejg_l000000olbAKH0
1?l0003o;3ncob`o/ol/?k<2o`000005obDi/?l0003o8Sbdob8l]?l000000_lJ=[42o`000004oa<`
[_l0003o0000o`0000;o1bj_0_l000000ol0::co0000o`0RZ002o`000004o`0LYOl0003o0000o`0G
XP;o000000Go016No`000?l03I_o0000o`09V@02o`000003o`06Uol0003o00BF00;o000000?o00BE
o`000?l000000_l000000ol01IKo0000o`000002o`000004o`0<Vol0003o0000o`0AW`;o00000_l0
6:<2o`000006o`0OZ?l0003o0CRko`000?l09jgo00000_l?@/42o`0000?o7Tg500?o0000ocY/f?lj
K=P00_l000000ol/El[o0000odUff`03odUff`04o`000?mWU>WoIiCYofNDj@?o00001_mcV^T00ol0
003oS;;`ohbbl005ohbbl004o`000?nPaO;o0000o`0000KoZ];e00Co0000okKMlonfgO?o]]gc1Ol0
0004ok_Ul`03o`000?o2jO7o000000Go`nk`0_l00005olCal0Co000000?oaO?^o`000?o3m>l01?o3
m>l00ol0003o`OG_ol7ek`03ol7ek`04o`000?nomO3o_oG`okoel0Co000000?o_??bo`000?l00000
1?njlo<2o`0000Co]o;d1?l000000onbkoKo0000o`000004ojo^m`?o00000on/kOP3o`0000CoYnWj
0ol00003ojGWn`04o`000?nRiOco0000o`0000KoX>?l0ol00004oi_Oo@?o00000onIg_h00ol0003o
U]cnoiKLoP03o`0000?oU=_n00?o0000oi7IoonAfOl01?nAfOl4o`0000KoSMKo1_l00005ohWCo`03
o`000?n5dOooQM7o00;oQM7o1Ol0000Pooooo`03o`000?oooooooooo00Oooooo0012ooooo`03o`00
0?oooooooooo0:Cooooo0_l00003ohk?oPCo00000_m=N]h01Ol0003o<TFfoc95]_lbAKKo000000;o
;3nc00Co0000obU2^?l0003o00000_lR?;@00ol0003o6SJaoaXf/@02o`000004oa<`[_l0003o3cBc
o`0000?o1bj_00Go0000o`0X[?l0003o0000o`0RZ004o`000003o`0GX_l0003o01bX00Go000000?o
00VIo`000?l000000_l000000ol019Ko0000o`000002o`000003o`04UOl0003o00FF00;o000000Co
00RHo`000?l0003o00bK0_l000001_l04Ioo0000o`000?l06:?o0000o`0_]@;o00000_l1>;/2o`00
00?o3d;10_l00002oai=a@03o`000?ljK=So>VcH00;o>VcH0_l00004odUff`03o`000?mWU>WoIiCY
00CoIiCY1Ol000000omcV^Wo0000ohbbl003ohbbl0Go00001onZd_D6o`0000So^nGc0ol00003ol?^
l0;o00001_o4lO001?l0003o`o?_ol?ckoo3lnl3o`0000Co`oC_00?o0000ol7ekoo1mNl00_o1mNl2
o`0000?o_oG`00Co0000okcel?nlmO3o_?G`0ol00004ok[cl`03o`000?ngl_Co]o;d00;o]o;d0_l0
0003ok?am@Co000000Co[nkgo`000?l0003o00000on/kOP3o`0000?oZNci00Co0000ojOYn_l0003o
00001_nUio/3o`0000CoX>?l0ol00003oigRo@04o`000?nKgogo0000o`0000KoVMkn0ol00007oiCK
oP03o`000?nAfOooTMWo00?o00001?n@f?l00ol0003oSMKoohgFo`03o`0000?oS=Go00?o0000ohWC
oon9dol01?n9dol6o`0000GoQM7o00?o0000ooooooooool07Oooool00ol0003oooooooooo`07oooo
o`00@_ooool00ol0003oooooooooo`2Vooooo`?o00000_ljHLl00ol0003o>D^io`000002o`0000?o
<TFf0_l000001?l/?k?o0000obU2^?lY@[P2o`000006ob8l]?l0003o0000oaXf/Ol0003o5cZf0_l0
00000ol?=;?o0000o`000002o`L^[`05o`000?l0::co02R/o`000?l08ZP00_l000001?l07:Go0000
o`000?l05j83o`000003o`0HYOl0003o01BR00;o000000?o016Qo`000?l03il01?l000001Ol03ioo
0000o`000?l0003o00FF00?o000000Co01VVo`000?l0003o01j[0_l000000ol09[3o0000o`000002
o`0_]@;o00000_l1>;/01ol0003o3d;1o`m2`Ol?@/7o0000obYRe?l000000_lNCLD00ol0003o>VcH
ocY/f002ocY/f003o`000?m9M]_oBGKK00?oBGKK00?o0000ofNDjOmWU>T00omWU>T00ol0003oPZka
oh:^l@02oh:^l@Ko00001OnI`oD7o`0000;oZ];e0ol00007ok_Ul`;o00000onnjo<00ol0003o`nk`
o`000006olCal0;o00000oo3lnl01?l0003o`_G_ol;ekoo2mNl2o`000003ol?dkol0003o`OG_00;o
`OG_0_l00003okoel0;o00000onlmO001?l0003o^_Gaok[elOnjmO42o`000003ok[clol0003o]o;d
00?o]o;d00Co0000ok?amOnclOGo/o7e0_l00003ok7`mP?o00001?n/kOP2o`000003ojW/nOl0003o
ZNci00;oZNci0ol00004ojGWn`?o00000onRi_`01?l0003oX>?lo`000?l00005oigRo@Co00001?nI
g_h3o`0000;oUmgn00?o0000oiCKo_nDfoh01?nDfoh4o`0000KoT=So1?l00007ohcEo`03o`000?n9
doooRM?o00?o00001?n8dol00ol0003oQM7oohGAo`02ohGAo`Go00007Oooool00ol0003ooooooooo
o`07ooooo`00@_ooool00ol0003oooooooooo`2Xooooo`05o`000?ljHLoo>V7?ocYQcol000000oli
BkT02?l0003o<TFfoc95]_l0003o<4Rko`000?l/?k?o00000_lY@[P00ol0003o8Sbdob8l]002o`00
0004oaXf/Ol0003o0000o`0000;o3cBc00?o0000o`L^[ol7;Zl00_l000001Ol0::co0000o`000?l0
003o02N^00?o000000?o01NRo`000?l07:P01_l000000ol04J7o0000o`000002o`000003o`0?Wol0
003o000000;o000000?o016Qo`000?l000000_l000001?l06JKo0000o`000?l07Z/2o`0000;o02J`
0_l000000ol0;kGo0000o`000003o`4h^`09o`000?l?@/7o3d;1o`m2`Ol0003o:V;Do`000?lNCLGo
000000Go>VcH0_l00003odUff`03o`000?mWU>WoIiCY00CoIiCY00?o0000oh:^lOn2[_400on2[_40
0ol0003oVL?eoiW3m@02oiW3m@Ko00001?nZd_D3o`0000?o/Mgf00?o0000ok_UlonkiO<00_nkiO<2
o`0000Go_^_c0ol00004olCal0;o00001?o3lnl00ol0003o`_G_ol;ek`03ol;ek`Co000000?o`OG_
o`000?nomO000onomO001?l0003o_?G`okcel?nlmO02o`0000Go^_Ga1?l000000ongl_Co0000o`00
0003ok?am@04o`000?nal?Ko/O3fok7`mP;o00000on^koL01?l0003o[>gho`000?l00004ojW/n@?o
00000onVj_X01?l0003oYNOko`000?l00005oj;Vo0Go00000_nMh_d3o`0000CoVn7m00Co0000oiWN
o_l0003o00001_nGgOh00ol0003oU=_noiCKoP03o`0000CoTm[n00?o0000oi3Hoon@f?l00ol00004
ohoGo`03o`000?n<eOooS=Go00;oS=Go1Ol00006ohSCo`Ko00001On5dOl00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Oooooo0012ooooo`03o`000?oooooooooo0:Wooooo0_l000000olj
HLoo0000ocU;^@02ocU;^@04o`000?lbAKKo<TFfoc95]P;o000000Go;3nco`000?lY@[So:D:ho`00
0002ob8l]0;o000000?o6SJao`000?lG>[H00_l000000ol?=;?o0000o`L^[`02o`L^[`04o`000?l0
::co0000o`0]/P;o000000?o02N^o`000?l000000_l00002o`0LZ005o`000?l06:Go0000o`0DX_l0
00000_l04J401?l0003o00nOo`000?l03il2o`000003o`0?Wol0003o000000;o000000Co01BSo`00
0?l0003o01VV0_l000001?l07Z_o0000o`000?l09[02o`0000;o02ne00Co0000o`4h^ol1>;_o0CRk
0_l00002o`m2`@06o`000?lZH]Co:V;Do`000?lNCLGo00001?ljK=P01_l0003oF8cXo`000?l0003o
BGKKo`0000KoIiCY00?o0000oh:^lOn2[_400on2[_45o`0000KoVL?e00Co0000oj[BmOl0003o0000
1onagOH01?l0003o^nGco`000?l00006okk[l`04o`000?noko;o_noboko_lP;o000000?oa?7`o`00
0?o3lnl01?o3lnl00ol0003o`_G_ol;ek`03ol;ek`04o`000?o0m^oo`?K_ol3fk`Co00000_nomO00
1Ol0003o_?G`okcel?nlmO3o000000Go^_Ga0_l00003okOdlPCo000000?o/o7eo`000?l000000ona
l?H00ol0003o[^ogojk_m`03ojk_m`Co000000KoZNcio`000?l0003o0000ojKZn_l00004ojKZnPCo
00000_nRi_`3o`0000CoWnGl0ol00006oi_Qo@?o00001onGgOh4o`0000KoTm[n1?l00006ohoGo`Ko
00001?n;eOl00ol0003oR=?oohSCo`04o`0000;oR=?o00?o0000ohGAoon5dOl01On5dOl3o`0001_o
oooo00?o0000ooooooooool01oooool004;ooooo0ol0002Yooooo`05o`000?loD;co0000ocYQcol0
00000oliBkT01Ol0003o<TFfoc95]_l0003o<4Rk00;o00000_lY@[P2o`000003ob8l]?l0003o7d2i
00;o00000_lG>[H01?l0003o3cBco`ld/ol00002o`L^[`;o000000Go02R/o`000?l0003o0000o`0W
[P02o`000008o`0RZol0003o01bXo`0LZ?l0003o01RUo`000?l05:82o`000003o`0AXOl0003o00nO
00;o000000So00nOo`000?l03ioo00nOo`000?l04J7o0000o`0DX`;o000000Co01VVo`000?l0003o
01j[0_l00002o`0V/005o`000?l0;kGo02neo`0_]Ol000000ol1>;/2o`0000;o3d;100?o0000obYR
e?lZH]@00_l00005ocY/f006o`000?mHS>SoF8cXo`000?m9M]_o00001OmWU>T6o`0000;oPZka00?o
0000oiW3mOnI`oD01OnI`oD3o`0000Wo/Mgf0ol00005okk[l`;o00001Onoko83o`0000Co`o?_00?o
0000ol;ekoo2mNl00_o2mNl2o`0000?o`?K_00?o0000okkgkonnmnl00_nnmnl4o`000003okcel?l0
003o^_Ga00?o^_Ga0_l00004okOdlP04o`000?ndlo?o]??cokCcl`Co000000?o/O3fo`000?l00000
1?n^koL2o`0000?oZnkh0ol00004ojKZnPCo00000onTj?/3o`0000CoWnGl0ol00003oigSo@03o`00
0?nKhOgoVn7m00?o00000onIh?d00ol0003oUmgnoiOMoP04o`0000?oUMcn00?o0000oi?Jo_nCf_h0
1?l00003oi7Io`03o`000?n?eoooSmOo00Co00000on>eol00ol0003oRmGooh_Eo`02oh_Eo`Go0000
1on8dol00ol0003oQM7oohGAo`04o`0000;oQM7o00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`06ooooo`00@_ooool00ol0003oooooooooo`2Zooooo`03o`000?loD;co000000;o00000_li
BkT2o`000004oc95]_l0003o<4Rkoc18^`;o00000_lY@[P2o`000004ob8l]?l0003o0000o`0000;o
5cZf00?o0000o`ld/ol?=;<00_l000000ol7;Zoo0000o`@c]@02o`000006o`0]/_l0003o02N^o`0W
[_l0003o02:[0_l00002o`0LZ005o`000?l06:Go0000o`0DX_l000000_l04J401?l0003o00nOo`00
0?l03il2o`000003o`0?Wol0003o016Q00;o000000Go01BSo`000?l06JKo01VVo`000002o`0NZ`05
o`000?l09[3o02J`o`0V/?l000000_l0;kD02Ol0003o0CRko`4h^ol1>;_o0000oaYGcol0003o3d;1
o`000003obYRe003o`000?ljK=So>VcH00?o>VcH00Co0000oeR<j?mHS>SoF8cX1ol00002ofNDj@03
o`000?n2[_7oPZka00CoPZka00?o0000oiW3mOnI`oD01?l00003oj;Bn003o`000?nagOKo/Mgf00Co
/Mgf0_l00003okKVmP05o`000?nnjo?o_^_cokk[lol000001_noko801?l0003o_o;aokoblOnol_42
o`000003ol?ckol0003o`_G_00;o`_G_0_l00003ol3fk`;o00001?nnmnl01?l0003o^oO_ok_gkonk
mnl4o`000003ok[elOl0003o000000Co]oCb0_l00003okCcl`04o`000?nal_Co/O;dok7bm0?o0000
1?n^koL01?l0003oZnkhoj_^n?n[k_P2o`0000?oYngi00?o0000ojKZn_l000000_l000001?nTj?_o
0000ojCXnonTj?/2o`0000?oXNOk00Co0000oioUo?l0003o00001_nMhod3o`0000GoVN3m1?l00006
oiGLoPCo00001_nAfOl4o`0000KoS]Oo1_l00005oh_Do`03o`000?n8doooR=?o00;oR=?o1Ol00007
ohGAo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool004;ooooo00?o0000oooo
ooooool0Z_ooool01Ol0003o?e2locm@_?loD;co000000;o>D^i00Go0000ocM>_Ol0003o<TFfo`00
0002oc18^`03o`000?lY@[So:D:h00;o000000?o8Sbdo`000?lO@;T00_l00002oaLj]P06o`000?l?
=;?o0000o``i^Ol0003o1bj_0ol000000ol0;K;o0000o`000002o`0W[P03o`000?l08Z_o000000;o
01bX00Go0000o`0HYOl0003o01BRo`000002o`0AX@03o`000?l03ioo000000;o00nO00Oo0000o`0?
Wol03ioo0000o`0AXOl0003o01BS00;o00000_l06JH01?l0003o01j[o`0NZol00002o`0V/005o`00
0?l0;kGo02neo`0_]Ol000000_l1>;/00ol0003o6UO?oaYGc`02o`0000Co:V;D0_l00004ocY/f0[o
00000_mWU>T00ol0003oPZkaoh:^l@02oh:^l@Go00002?nRd_P00ol0003o/Mgfok7MmP02ok7MmP03
o`000?nfi_Ko]^Kf00Co]^Kf00?o0000okk[lol000001Onoko82o`0000Go_o;a1?l000000oo2mNoo
0000ol3fk`03ol3fk`03o`000?nnmnoo__O_00;o__O_0_l00003ok_gk`04o`000?nim_3o^OK`okWf
l0?o00000ongm?82o`0000?o]??c0_l00003ok7bm006o`000?n^lOKo[_7fojkam_l0003o[^og0_l0
0003oj_^n003o`000?nWkOWoYngi00?oYngi0ol00004ojCXn`;o00001OnQio/2o`0000GoWN?m0ol0
0002oi_Ro@03o`000?nIh?goVN3m00?o00001?nGg_h00ol0003oUMcnoiGLoP03o`0000CoTm_n00?o
0000oi7IoonAfOl00ol00004oi3Io`03o`000?n>eoooS]Oo00?o00000on=e_l00ol0003oRmCooh_D
o`04oh_Do`Ko00001On7d_l00ol0003oQM7oohGAo`02ohGAo`Co00006_ooool00ol0003ooooooooo
o`06ooooo`00@_ooool00ol0003oooooooooo`2[ooooo`05o`000?loD;co?e2locm@_?l000000_li
BkT2o`000005oc95]_l0003o<4Rkoc18^ol000000_lY@[P01?l0003o9dJlo`000?l00002oam0^@03
o`000?lG>[Ko5cZf00;o000000Oo3cBco`000?l0003o1bj_o`000?l4<kGo000000;o02fb00Ko0000
o`0W[_l09jko0000o`0RZol00003o`0LZ005o`000?l06:Go0000o`0DX_l000000_l04J401Ol0003o
00nOo`000?l03ioo000000;o00nO00?o0000o`0AXOl000000_l05:<01?l0003o01VVo`0IY_l00002
o`0NZ`05o`000?l09[3o02J`o`0V/?l000000_l0;kD2o`0000;o0CRk00?o0000oaYGcolJEll00_l0
0003obYRe0Oo00001?mHS>P00ol0003oMZWbogJYlP02ogJYlPOo00000on?`OL00ol0003oX];hoj;B
n008oj;Bn004o`000?nagOKo0000o`0000Oo]^Kf0ol00004oko_lP03o`000?nol_7o_o;a00Co_o;a
00Co0000okoel?nomO3o_oG`1?l00002ol3fk`04o`000?nnmnoo__O_okkgk`;o00000onkmnl2o`00
00?o^OK`00Oo0000okKflOnfm_7o]_Kao`000?ngm?;o000000Co]??c00Co0000ok7bm?nal_Co/O;d
0_l00004ojkamPCo000000?oZnkho`000?l000000onWkOT3o`0000?oYN_j00Ko0000ojCXnol0003o
0000oj7Wnol00002oj7Wn`?o00000_nNi_`00ol0003oWN?mo`000002o`0000GoVn;m0ol00006oiON
oPCo00001_nCfoh4o`0000KoT=Wo1?l00007ohgFo`03o`000?n;e?ooRmCo00?o00000on:e?l00ol0
003oQm;oohOBo`02ohOBo`So00001?n5dOl00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Kooooo0011ooooo`03o`000?oooooooooo0:cooooo00Go0000ocm@_?loD;co?e2lo`000002ocU;
^@04o`000?lgC[go0000o`0000;o<4Rk0_l00002obU2^0?o00000_lO@;T01Ol0003o5cZfoaLj]_l0
003o53nl00;o000000Co33Vio`000?l0003o13>e0_l000001?l0;K;o0000o`0W[_l09jh2o`000006
o`0RZol0003o01bXo`0LZ?l0003o01RU1?l000000ol04J7o0000o`000002o`000009o`0?Wol0003o
00nOo`0?Wol0003o016Qo`000?l05:?o000000?o01VV00Co0000o`0NZol07Z_o00000_l09[02o`00
0006o`0_]Ol0003o2T_9o`000?l1>;_o00000_lJEll5o`000004obYRe?l0003oB8?UodR3i@;o0000
00?o>VcHo`000?mHS>P00omHS>P00ol0003oMZWbogJYlP04ogJYlP03o`000?n?`OOoSl7g00GoSl7g
00?o0000oj;Bn?nRd_P01onRd_P2o`0000Oo]^Kf0_l00003okW/m@;o000000?o_nobo`000?nol_40
1?nol_42o`0000?o_oG`00?o0000okgfl?nmm_000_nmm_04o`000003okkgkol0003o^oO_00?o^oO_
00Co0000okWfl?nim_3o^OK`0_l00004okKfl@Co00000_ndlo<01Ol0003o/O;dok7bm?nal_Co0000
00Co[_7f0_l00003oj_`m`Co000000?oYngio`000?l000001_nUjoX4o`000004oj7Wnol0003o0000
o`0000GoW^Kl0ol00004oi_Ro@?o00000onIhOd00ol0003oUmknoiONoP03o`0000CoUMgn00?o0000
oi?Ko_nCfoh00ol00004oi;JoP03o`000?n@fOooT=Wo00?o00001?n?f?l00ol0003oSMKoohgFo`02
ohgFo`Go00001On:e?l6o`0000GoQm;o00?o0000ohGAoon5dOl00_n5dOl5o`0001Oooooo00?o0000
ooooooooool01_ooool0047ooooo00?o0000ooooooooool0[?ooool01?l0003o?e2locm@_?loD;`2
o`000004ocU;^Ol0003o=djmocM>_@;o00000_l`B;/2o`000003obU2^?l0003o9dJl00;o00000_lO
@;T00ol0003o5cZfoaLj]P02o`000003o`ld/ol0003o33Vi00;o000000Go13>eo`000?l0;K;o02fb
o`000002o`0W[PCo000000?o01bXo`000?l000000_l000001?l05:;o0000o`000?l04J43o`000004
o`0?Wol0003o0000o`0?W`Co000000Co01BSo`000?l06JKo01VV0_l000002?l07Z_o0000o`000?l0
9[3o0000o`11`ol0003o02ne1_l00002oaYGc`;o00000_lZH]@00ol0003oB8?UodR3i@02odR3i@;o
00001OmHS>P00ol0003oMZWbogJYlP04ogJYlP03o`000?n?`OOoSl7g00GoSl7g00?o0000oj;Bn?nR
d_P00onRd_P3o`0000;oZ]gi00?o0000okKVm_nfi_H00_nfi_H2o`0000Ko^Nce0ol00003okobl@;o
00000onomO02o`0000Co_OK`00Co0000ok_gkonkmnoo^oO_1?l00002ok_gk`05o`000?nim_3o^OK`
okWfl?l000001?nfm_42o`0000Co/oGb1?l000000onal_Co0000ojkamP03ojkamP04o`000?n[l?Oo
Zo3goj_`m`;o00000onXkoP3o`0000CoYN_j0ol00003oj;Yn`?o00000_nNi_`00ol0003oW^Klo`00
0002o`0000?oW>Cm00Co0000oi_RoOl0003o00001_nIhOd3o`0000KoUMgn1?l00006oi;JoPCo0000
1_n?f?l6o`0000CoS=Ko00?o0000oh[Doon:e?l00ol00003ohWDo`03o`000?n7d_ooQm;o00CoQm;o
1_l00005ohGAo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool0047ooooo00?o
0000ooooooooool0[Oooool01?l0003o?e2locm@_?loD;`2o`000005ocU;^Ol0003o=djmocM>_Ol0
00000_l`B;/01?l0003o;Tboo`000?l00002obM6_003o`000?lO@;Wo7d2i00;o000000?o5cZfo`00
0?lD?k`00_l00002o``i^@03o`000?l4<kGo000000;o02fb0_l000001?l09jko0000o`000?l08Z/2
o`000003o`0LZ?l0003o000000?o000000?o01j[o`000?l000000ol000000ol03ioo0000o`0?W`04
o`000008o`0DXol0003o0000o`0IY_l0003o02jgo`000?l07Z/7o`0000;o2T_90_l00003oaYGc`03
o`000?lgN>;o000000;o:V;D00?o0000odR3iOm8PnD00om8PnD3o`0000;oF8cX00?o0000ogJYl_mf
ZO801OmfZO800ol0003oSl7goho1m`05oho1m`03o`000?nRd_So000000;o00001_nZgOT01?l0003o
]^Kfo`000?l00007okW/m@07o`000?njl?Co^_3dok[`m?l0003o_o;ao`000004okoel003o`000?nm
m_3o_OK`00;o_OK`0_l00003ok_gk`03o`000?nimnoo^OO_00;o^OO_1?l000000onim_3o0000okKf
l@03okKfl@03o`000?ncmO;o/oGb00;o/oGb0_l00003ok3dl`Co000000?o[_7fo`000?l000000on[
l?L01?l0003oZ>ohojS_n?nXkoP2o`0000?oYNgi00Co0000ojG[n_l0003o00000onRjO/3o`0000?o
WnSk00Co0000oikVo?l0003o00001OnLi?d4o`0000CoVN7m0ol00003oiOOoP03o`000?nEgOkoUMgn
00?o00001?nCg?h00ol0003oT][noi;JoP03o`0000?oT=[o00?o0000ohoHoon?f?l01?l00002ohkG
o`03o`000?n<e_ooS=Ko00CoS=Ko1?l00007ohWDo`03o`000?n7d_ooQm;o00?o00000on7d_l00ol0
003oQM7oohGAo`04ohGAo`?o00005Oooool00ol0003oooooooooo`06ooooo`00@Oooool00ol0003o
ooooooooo`2]ooooo`06o`000?loD;co?e2locm@_?l0003o?E?00_l00002ocM>_@05o`000?l`B;_o
<4Rko`000?l^C;l00_l00002obM6_00:o`000?lO@;Wo7d2io`000?lLAKoo0000oaLj]_l0003o53nl
o`0000;o33Vi00Go0000o`@c]Ol4<kGo0000o`0]/P02o`000003o`0W[_l0003o02je00?o000000Oo
01bXo`000?l0003o0000o`0Q[Ol0003o01j[00Co000000Go01^Yo`000?l0003o0000o`0?W`04o`00
0003o`0DXol0003o000000Go000000Oo03Nmo`000?l0003o0473o`000?l0;kGo000000;o2T_900?o
0000oaYGcolJEll00_lJEll00ol0003o=gSRo`000002o`0000GoB8?U00?o0000ofNRl_mWX_801?l0
0007ogJYlP03o`000?n?`OOoSl7g00;oSl7g1Ol00008oj[Mn@?o00001_nik?D2o`0000Co^_3d1?l0
0002okoel004o`000?nmm_3o_OK`okgfl0;o00000onkmnl2o`0000Co^OO_00Co0000okKgkonfmnoo
]_O_1?l000000onfm_7o0000o`000004ok?elP04o`000?n`m??o/?Ccok3dl`;o00000on]lo@4o`00
0003oj_`mol0003o000000?oZ>oh00?o0000ojG]nOnUkOT00onUkOT4o`000003oj;Ynol0003o0000
00KoWnSk1Ol000001?nLi?go0000o`000?l00004oi[So@04o`000?nIhOgo0000o`0000GoUmon1?l0
0006oi?LoPCo00001On@f_l4o`0000OoS]Oo00?o0000ohcFoon<e_l00ol00004oh_Eo`03o`000?n9
e?ooRMCo00;oRMCo1Ol00007ohOBo`03o`000?n5dOooQM7o00?o00000_n4dOl00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Kooooo0011ooooo`?o0000[_ooool01Ol0003o?e2locm@_?l0
003o?E?000;o00000_lgC[d2o`0000;o<4Rk00Co0000obi<_ol0003o00000_lWA[`01Ol0003o7d2i
oam0^Ol0003o74Fo00;o00000_lD?k`01Ol0003o33Vio``i^Ol0003o13>e00;o000000So02fbo`00
0?l0003o02N^o`000?l0;[Go0000o`0Y/P;o000000?o02B_o`000?l08Jd00_l000000ol07Z_o0000
o`000002o`000003o`0KZOl0003o01bZ00[o000000So02jgo`000?l0003o03Nmo`000?l09[3o0000
o`11``;o00000ol:BlT2o`0000;o6UO?00Co0000ocMhh_lgN>;o=gSR0_l00005odR3i@03o`000?mW
X_;oIj;b00;oIj;b3Ol00005oiW@n`03o`000?nZgOWoZ]gi00;oZ]gi0ol00003ojkVn@04o`000?ni
k?Go^NceokW/m@;o00001?njl?@2o`0000Co^_?b1?l000000onmm_3o0000ok_gk`03ok_gk`03o`00
0?nimnoo^OO_00;o^OO_0_l00003okKgk`04o`000?ncmo3o/oO`ok?gl0Co00000_ncmO82o`0000?o
/?Cc00Co0000ojgcm?n]loCo[O?d0_l00003oj[bm@Co000000?oZ>oho`000?l000000onUkOT3o`00
00?oX^ci0ol00004oioXn`?o00000onMi_`4o`0000GoV^?m1Ol00002oiOOoP?o00001?nEg_h00ol0
003oTmcnoi?LoP03o`0000?oT]_n00?o0000oi3Joon@f_l00ol00004ohoIo`03o`000?n>eoooS]Oo
00;oS]Oo1Ol00006oh_Eo`Ko00001?n8dol00ol0003oQm;oohOBo`02ohOBo`Ko00001_n4dOl00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo0011ooooo`03o`000?oooooooooo0:ko
oooo00Ko0000ocm@_?loD;co?e2lo`000?lmDl02o`0000;o=djm0_l000001Ol`B;_o0000obi<_ol^
C;oo000000;o9dJl0_l000001OlO@;Wo0000oaa5_olLAKoo000000;o53nl00?o0000o``i^Ol<>KT0
0_l000001Ol4<kGo0000o`000?l0003o03>h00;o000000Co02jeo`000?l0003o02Vb1?l000001_l0
8Jgo0000o`0NZol07Z_o0000o`0LZ@Wo000000Oo02:^o`000?l09k;o0000o`0IY_l0003o02jg00;o
000000?o03Nmo`000?l000000_l0@L<01ol0003o2T_9o`Y;bOl:BlWo0000obE/gOl000000_lJEll0
1Ol0003o=gSRocMhh_lgN>;o000000GoB8?U00?o0000ofNRl_mWX_800omWX_800ol0003oP[cioh:l
n@05oh:ln@03o`000?nId?_oVM3k00OoVM3k00Co0000oj[MnOl0003o00001on^i_T00ol0003o^Nce
o`000005ok[`m003o`000?njlo;o^_?b00?o^_?b00Co0000okWelOnimO7o^OGa1?l00002ok_gk`04
o`000?nimnoo^OO_okWgk`;o00000onfmnl2o`0000?o/oO`00?o0000ok7fl?nam_000_nam_04o`00
0003ok3dlol0003o000000?o[O?d00Co0000oj[bmOnZl_GoZ_;e0_l00003ojO`mPCo000000?oYNgi
o`000?l000000onRk?T3o`0000?oWn[j00Co0000oioXnol0003o00000onMi_`3o`0000?oV^Gl0_l0
00001?nJhogo0000o`000?l00004oiSQo@?o00001_nEg_h4o`0000GoT]_n1?l00006ohoIo`Ko0000
1On=eol00ol0003oRmGooh_Eo`03o`0000?oR]Co00?o0000ohSCoon8dol00_n8dol7o`0000GoQ];o
00?o0000ohCAoon4dOl00_n4dOl4o`0001?ooooo00?o0000ooooooooool01_ooool0047ooooo00?o
0000ooooooooool0[_ooool2o`0000;o?e2l00Co0000oceC`?lmDl3o00000_lgC[d01?l0003o=E;2
o`000?l00002obi<_`08o`000?lWA[co9dJlo`000?lTBl;o0000oam0^Ol00002oaa5_`07o`000?lD
?kco53nlo`000?l<>KWo0000o`To_`03o`000004o`0]/_l0003o0000o`0000;o02je00Ko0000o`0Y
/_l0:K;o0000o`0T[ol00002o`0Q[@Go00000_l06jT01ol0003o01bZo`000?l0003o01j[o`000?l0
8Zh00_l000000ol09k;o0000o`000002o`0^]`04o`000?l0=kgo03Nmo`0000?o04730_l00002o`Y;
b@03o`000?lUK=go000000;o00001?lgN>82o`0000CoB8?U00?o0000ofNRl_mWX_800omWX_800ol0
003oP[cioh:ln@05oh:ln@03o`000?nId?_oVM3k00KoVM3k0ol00008ojkVn@Co00000_njl?@2o`00
00Co^_?b0_l00003okWel@03o`000?ngmo3o]oO`00;o]oO`1?l000000onimnoo0000okKgk`03okKg
k`04o`000?ncmo3o/oO`ok?gl0;o00000onam_02o`0000?o[_Ga1?l000000on]loCo0000o`000003
oj[bm@03o`000?nWl?KoYo3f00?o00000onTkoL4o`000003oj;/nOl0003o000000KoWn[j1?l00000
0onMi_co0000o`000006oi[Uo0?o00001?nHhOd3o`0000?oU^3n00?o0000oiGNo_nEg_h00ol00003
oi?MoP03o`000?nBfokoT]_n00?o00001?n@f_l00ol0003oSmWoohoIo`03o`0000CoS]So00?o0000
ohgGoon=eol00_n=eol5o`0000GoR]Co1_l00005ohSCo`03o`000?n6d_ooQ];o00;oQ];o1ol00004
ohCAo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool0047ooooo00?o0000oooo
ooooool0[oooool2o`000005ocm@_?l0003o?E?0oceC`?l000000_lgC[d00ol0003o=E;2ocEB`P02
o`0000;o;Tbo00Go0000obM6_?lWA[co0000obA;`P02o`0000;o74Fo00?o0000oa@o_?lD?k`00_l0
00001Ol<>KWo0000o`000?l0003o0CVl00;o000000?o03>ho`000?l000000_l0;[D00ol0003o02Vb
o`000005o`0000;o01j[00?o0000o`0LZOl000000_l06jT01Ol0003o01bZo`000?l07Z_o000000;o
02:^00Co0000o`0W/_l09k;o00000ol0;[L00ol0003o03Nmo`0g_@02o`000006o`11`ol0003o4f3G
o`000?l:BlWo00000olUK=d2o`0000?o=gSR00?o0000oeJIlOl000000_l00002odR3i@03o`000?mW
X_;oIj;b00?oIj;b00?o0000oh:lnOn2_?T01On2_?T00ol0003oVM3koiW@n`02oiW@n`?o00000onP
g?`00ol0003o[^KiojkVn@02ojkVn@?o00001?nak?P3o`0000?o^_?b0_l00003okWel@;o00001?ng
mo001?l0003o]OO_okGgkonemnl4o`0000;o]_O_00Go0000ok?gl?ncmo3o/oO`o`000003ok7fl0;o
00000on^mO42o`0000?oZoCb1?l000001?nZl_Go0000o`000?nWl?H2o`0000?oY>og0ol00003oj7]
n0?o00001?nOj_X3o`0000?oWNSk0ol00004oi[Uo0?o00000onHhod01?l0003oV>7mo`000?l00005
oiKPoPCo00001OnCgOh4o`0000KoT=[o1?l00006ohkHo`Ko00001?n<e_l00ol0003oR]Cooh[Do`03
o`0000?oRMCo00?o0000ohSCoon8dol01?n8dol6o`0000CoQ];o00?o0000ohCAoon4dOl00_n4dOl5
o`00013ooooo00?o0000ooooooooool01_ooool0047ooooo00?o0000ooooooooool0[oooool01?l0
003oA5W3o`000?l00003oceC`004o`000?lgC[go=djmo`0000;o=E;200?o0000obi<_ol^C;l00_l0
00001OlWA[co0000obA;`_lTBl;o000000?o74Fo00Co0000oa@o_?l0003o4TG20_l000001Ol9?koo
0000o`000?l1>Kco000000;o03>h1Ol000001?l0:K;o0000o`0T[ol00002o`0Q[@03o`000?l07Z_o
01j[00;o00000_l06jT00ol0003o01bZo`000002o`0NZ`04o`000?l08Zko02:^o`0000;o02Nb00?o
0000o`0^]ol0;[L00_l000002_l0=kgo0000o`ADd?l0003o0473o`000?lCH=Oo0000o`Y;bOl00003
obE/g@03o`000?lgN>;o=gSR00;o=gSR00Co0000oeJIlOmFVO7oEYWa0ol00006ofNRlP03o`000?n2
_?WoP[ci00CoP[ci00?o0000oiW@nol000000_l00007oj3Lo004o`000?n^i_Wo0000o`0000Go/Nch
0_l00003ok;`mP03o`000?njlo;o000000Co^OGa00?o0000okOgl?ngmo000_ngmo02o`0000?o]OO_
00?o0000ok;gkonbmnl00_nbmnl4o`000004ok?gl?l0003o/OK`ok7fl0;o00001?n^mO401?l0003o
ZoCboj_dl_n[m?82o`0000?oZ??c1ol000000onTkoOo0000o`000003oj7]n0?o00000onNk?T01?l0
003oWn[jo`000?l00003oigXn`?o00000onJio`01?l0003oV^Glo`000?l00005oiSSo@Go00000_nF
h?h3o`0000?oU=on00?o0000oi?Mo_nCgOh00ol00004oi7LoP03o`000?n@f_ooT=[o00?o00001?n?
fOl00ol0003oS]SoohkHo`03o`0000?oSMOo00?o0000ohcFoon<e_l00_n<e_l5o`0000OoRMCo00?o
0000ohSCoon8dol00ol00003ohOCo`03o`000?n6d_ooQ];o00;oQ];o1ol00005ohCAo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01_ooool0047ooooo00?o0000ooooooooool0[oooool0
0ol0003oA5W3odAI``02o`0000;o?E?00_l000001OlgC[go0000ocEB`_leD/;o000000;o;Tbo00Co
0000obaAaOl0003o00000olTBl800ol0003o74Fooaa5_`02o`000005oa@o_?l0003o0000o`000?l9
?kl01ol00003o`0^]@03o`000?l0:K;o000000?o000000Co026]o`000?l0003o01j[0ol00002o`0K
Z@04o`000?l07:[o0000o`0NZ`;o000000Co02:^o`000?l0003o02Nb0_l00002o`0^]`;o000000?o
03Nmo`000?l4E=000_l00002oa=Pe`;o00001?lUK=d2o`0000?o=gSR00?o0000oeJIlOmFVO400omF
VO4@o`0000WoX=cl0ol00004ok7/n0;o00001Onbl?H4o`0000;o^OGa00?o0000okOgl?ngmo000_ng
mo001?l0003o]OO_okGgkonemnl2o`0000?o/_O_0_l00003ok3gk`Oo00000_n^mO42o`0000?oZoCb
00?o0000ojSclonXlo<00ol000000onUlOCo0000o`000003oj;`mPCo000000?oXNgho`000?l00000
1_nNk?T4o`000003oigXnol0003o000000GoV^Ol1Ol00002oiSSo@?o00001?nFh_d3o`0000GoU=on
1?l00006oi7LoPCo00001_n?fOl4o`0000GoSMOo1_l00005oh_Eo`03o`000?n9e?ooRMCo00;oRMCo
1Ol00005ohOCo`Ko00001On6d_l00ol0003oQ=7oohCAo`02ohCAo`Co00003oooool00ol0003ooooo
ooooo`05ooooo`00@Oooool00ol0003oooooooooo`2`ooooo`04o`000?m4FL?oA5W3o`0000;o?E?0
00Co0000ocaHaOl0003o00000oleD/801Ol0003o;Tboobi<_ol0003o;57500;o00000_lTBl801Ol0
003o74Fooaa5_ol0003o6T_500Go00000_l9?kl01_l0003o0CVlo`000?l0003o03>ho`0000;o02je
0_l000000ol0:K;o0000o`000002o`000005o`0Q[Ol0003o0000o`000?l0:k@00_l000000ol06jWo
0000o`000002o`000004o`0NZol0003o0000o`0R[P;o000000Ko02Nbo`000?l0003o02jgo`000?l0
B/T2o`0000;o15C@0_l00002oa=Pe`;o00000olUK=d00ol0003oA8k^o`000003o`0000GoEYWa00?o
0000og>fn_mc]_X01?mc]_X00ol0003oSLcmohg<o@06ohg<o@03o`000?nPg?coX=cl00?oX=cl0ol0
0003ojGUn`04o`000?nak?So0000o`0000Go/_3f0_l00004ok;cl`Co00000_ngmo001Ol0003o]OO_
okGgkonemnoo000000?o/_O_0_l00003ok3gk`;o000000?o[OK_o`000?l000001?nZmO04o`000004
oj_dl_l0003o0000ojScl`;o00000onUlO@01?l0003oX_3foj;`m_nRl?H2o`0000?oWnkg0ol00004
oik/n@?o00000onLj_X4o`0000;oV^Ol0ol00004oiSUo0?o00001?nFh_d3o`000003oiCPo_l0003o
000000;oU=on0ol00004oi;MoP03o`000?nAg?koTMcn00?o00001?n@fol00ol0003oSmWoohoIo`03
o`0000?oS]Wo00?o0000ohgGoon=eol00ol00003ohcGo`03o`000?n;eOooRmGo00CoRmGo1_l00004
ohWDo`03o`000?n7doooQm?o00?o00000_n7d_l00ol0003oQ];oohKBo`05ohKBo`Ko00001?n4dOl0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`000?oooooo0000
00;o0000[oooool00ol0003oA5W3odAI``02o`0000;o?E?000Co0000ocaHaOl0003o00000_leD/82
o`000005obi<_ol0003o;575obaAaOl000000_lTBl87o`0000;o4TG200Co0000o`To_ol9?koo0000
0_l1>K`4o`000003o`0^]Ol0003o03Nl00Co000000Go02ngo`000?l0003o0000o`0NZ`05o`000003
o`0[]?l0003o000000;o000000Co03:jo`000?l0003o03Rn0_l000001Ol0@<?o0000o`0^]ol0003o
04[900;o00000_l4E=02o`0000;o4f3G00?o0000obE/gOlUK=d00_lUK=d01?l0003oA8k^odB>k_m4
S^h2o`0000GoEYWa00?o0000og>fn_mc]_X01?mc]_X00ol0003oSLcmohg<o@06ohg<o@03o`000?nP
g?co000000;o00001_nUiO/3o`0000Go/_3f00?o0000ok;clonblo<00_nblo<2o`0000Co/OGb1?l0
00001?nemnoo0000ok;gkonbmnl2o`0000Co/?O_00Co0000ojgfkon]m^oo00001?nZmO02o`0000?o
YoC`1ol000000onUlOCo0000o`000003oj;`mP04o`000?nOk_OoWnkgoio^m`;o00000onMkOP01?l0
003oW^cio`000?l00003oicZnP?o00000onJj?/3o`0000CoV>Gl0ol00003oiKSo@04o`000?nFh_go
0000o`0000CoU>3n1?l00006oi;MoPCo00001_n@fol4o`0000GoS]Wo1?l00007ohcGo`03o`000?n;
eOooRmGo00?o00000on:eOl00ol0003oRMCoohWDo`02ohWDo`Go00001_n7d_l00ol0003oQ];oohKB
o`04o`0000?oQM7o00?o0000ohCAoon4dOl00_n4dOl4o`0000gooooo00?o0000ooooooooool01Ooo
ool001gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool3
o`0000Wooooo0_l0002booooo`04o`000?m4FL?oA5W3odAI``;o000000Go?E?0o`000?llF<Go?5S5
o`000002ocEB`P03o`000?lcElSo000000Ko000000Ko94_2o`000?l0003o74Foo`000?lJBlD2o`00
0003oa95`_l0003o2Cno00;o2Cno00Co0000o`4i_?l0003o04730ol000000ol0;[Go0000o`0g_004
o`000003o`0_]ol0003o000000;o000000Co02^do`000?l0003o01^Y0ol000001?l0;[Oo0000o`00
0?l0<[X2o`000004o`0h__l0003o0000o`10``;o00000_l0B/T2o`0000;o15C@00Co0000oa=PeolC
H=Oo4f3G0_l00003obE/g@03o`000?m4S^koA8k^00;oA8k^0ol00003oeJIl@03o`000?mc]_[oLkKj
00CoLkKj00?o0000ohg<oOn=c?d01?n=c?d4o`0000KoYNGk0_l00003ojO[n@;o000000?o/_3fo`00
0?l000001?nblo<00ol0003o/OGbok7elP02ok7elP;o00000on_m_07o`0000;o/?O_0_l000000on]
m^oo0000o`000003oj[el0;o00000_nWm?03o`000003ojGclOl0003o000000?oX_;c1?l000000onR
l?Ko0000o`000003oio^m`03o`000?nMkOSoWNgh00?oWNgh1?l000000onLj_[o0000o`000003oi[X
n`?o00000onHi_`01?l0003oV>Glo`000?l00005oiKSo@Co00000_nDh?h3o`0000;oT]on0ol00002
oi;MoP?o00001?n@g?h00ol0003oT=_ooi3Ko`03o`0000?oSm[o00?o0000ohkIoon>fOl00ol00004
ohgHo`03o`000?n<eoooS=Oo00;oS=Oo1Ol00005oh[Eo`Ko00001?n8dol00ol0003oQm;oohOBo`02
ohOBo`Go00001_n5dOl6o`0000CoQ=7o00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`007?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/_ooool01Ol0003oA5W3odAI`ol0003o@Ug800;o00000_llF<D8o`0000;o;5750_l000000olT
Bl;o0000ob9Ab002o`0000;o6T_500Co0000oa95`_lBAL;o00000_l9?kl2o`000003o`4i_?l0003o
047300Co00000_l0=k`00ol0003o03:jo`000002o`0_]`03o`000?l0;;Ko000000;o02^d0ol00000
1?l0:kCo0000o`000?l0;[L2o`000004o`0b^_l0003o0000o`0h_P;o000000?o0433o`000?l00000
0_l0B/T01?l0003o15C@o`ADd?l4E=02o`000003oa=Peol0003o<H?Y00Co00001?m4S^h00ol0003o
HZkiof:^n@05o`0000KoLkKj00?o0000ohg<oOn=c?d00ol00004oiCIoP03o`000?nUiO_oYNGk00;o
YNGk00?o0000ojO[nOnWjoT01?nWjoT4o`0000;o/_?c0_l00003ok7elP;o00000on_m_02o`0000;o
[OK_00?o0000oj[fk_nZm^h00_nZm^h7o`000003oj[el?l0003o000000;oYoC`0_l00003ojGcl@04
o`000?nRl_?oX_;coj;bl`;o00000onOl?@4o`000003oio^mol0003o000000?oWNgh0ol00003oi_[
n@Co000000?oV^Sko`000?l000001OnHi_`5o`0000;oU^?m0ol00003oiCRo@?o00001_nBgoh4o`00
00KoT=cn1?l00005ohoJo`Co00001_n=f?l6o`0000CoRmKo00?o0000oh[Eoon:eOl00ol00003ohWD
o`03o`000?n8doooR=?o00;oR=?o1ol00005ohOBo`03o`000?n5dOooQM7o00?o00000_n5dOl00ol0
003oQ=7oohCAo`04ohCAo`?o00002oooool00ol0003oooooooooo`05ooooo`007?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;;ooooo00Go0000odAI`om4FL?o0000
od9Mb007o`000005ocEB`_l0003o<eO8oc=Gb?l000000_l/DLD01_l0003o:UO;o`000?lTBl;o0000
ob9Ab0;o000000Co6T_5o`000?l0003o4TG20_l000000ol9?koo0000o`M6aP02o`0000;o047300?o
0000o`0l_ol000000ol0=k`00ol0003o03:jo`000002o`0_]`03o`000?l0;;Ko000000;o02^d0_l0
0002o`0[]004o`000?l0;[Oo02jgo`0000;o03:j00Co0000o`0h__l0>;ko00000_l0@<<01?l0003o
04[9o`1:bOl0B/T2o`000006o`ADd?l0003o7WKSo`000?lCH=Oo00000olaPnT2o`0000CoA8k^00?o
0000of:^nOmR[_T00omR[_T:o`0000SoU=Wn00Co0000ojGUnol0003o00001OnWjoT2o`0000CoZ?3g
1?l000000onamO;o0000o`000004ojofl003o`000?n]m^oo[OK_00;o00000onZm^h2o`0000;oZ?K^
00Co0000ojGek_nUmNkoYOG^2?l000000onUlo7o0000o`000003oj;bl`03o`000?nOl?CoWo3d00?o
00000onMkoD4o`000003oig]n?l0003o000000?oVn_i0ol00003oiSYnPCo00000_nHi_`3o`0000?o
U^Gl1?l00004oiCRo@;o00000onBhOh00ol0003oT]onoi;OoP03o`0000;oTMkn00?o0000oi7No_l0
00000_n@g?h3o`0000?oSm_o00?o0000ohoJoon?f_l00ol00004ohgIo`03o`000?n=f?ooSMSo00?o
00000on<eol00ol0003oRmKooh_Fo`02oh_Fo`Go00001_n9e?l5o`0000GoR=?o00?o0000ohOBoon7
d_l00_n7d_l5o`0000KoQM7o00?o0000ohCAoon4dOl00ol00002ohCAo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool001cooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2aooooo`Ko00000_m2GLP01Ol0003o?5S5ocaHaOl0003o>Uc:00;o00000_lc
ElP2o`0000;o;57500Co0000obYGbol0003o00000_lRDLP00ol0003o6T_5oaY;a@02o`000007oa95
`_l0003o0000o`To_ol0003o1dK6o`000003o`11``03o`000?l0?;oo000000;o03Nl00?o0000o`0b
^_l000000_l0;kL00ol0003o02bfo`000002o`0[]005o`000?l0:[Co0000o`000?l0:k@00_l00000
1Ol0;[Oo0000o`0b^_l0<[[o000000;o03Rn00?o0000o`10`ol0@<<00_l000001ol0B/Wo0000o`eY
g?l0003o15C@o`000?lNM^<00ol00004oc63j@?o00000_m4S^h00ol0003oHZkiof:^n@03of:^n@03
o`000?mnaokoO/On00KoO/On00?o0000oiCIo_nDfOh01?nDfOh4o`0000GoYn_i00?o0000ojS`monX
l?L00_nXl?L2o`0000?oZ?;d1?l00002ojofl0;o00000_n]m^l00ol0003oZ_K^oj[fkP02oj[fkP03
o`000?nXm^koZ?K^00;o00000_nUmNh2o`0000;oXoC_0_l00003oj3ck`Co000000CoX_;co`000?l0
003oWo3d0_l00003oig_m@?o00000onKk_H4o`000003oi_[nOl0003o000000?oV>Wj0ol00003oiKX
n`Co00000_nFiO`3o`0000CoTn?m00Co0000oiCRoOl0003o00001?nBhOh4o`0000KoTMkn1?l00004
ohoKo`Ko00001?n=fOl5o`0000GoS=Oo1_l00005oh[Eo`03o`000?n9e?ooRMCo00?o00000on8e?l0
0ol0003oR=?oohSCo`02ohSCo`Oo00001?n6d_l00ol0003oQM7oohGAo`02ohGAo`Go00001_n4dOl0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Looooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co0000
2Oooool00ol0003oooooooooo`2/ooooo`Go00000_ooool2o`000005odAI`ol0003o@Ug8od9Mb?l0
00000_llF<D00ol0003o>Uc:ocYLbP02o`0000;o<eO80_l000001Ol/DLGo0000obYGbolZEl_o0000
00;o8U780_l000000olJBlGo0000oaQBc002o`000003o`m<bOl0003o000000;o1dK600Go0000o`11
`ol0@L?o0000o`0l_`02o`0000;o03Nl00?o0000o`0b^_l000000_l0;kL00ol0003o02bfo`000002
o`0[]0;o000000Co03boo`000?l0003o03o10_l00002o`0b^P;o000000[o03Rno`000?l0003o0433
o`000?l0G]Go0000o`1:bOl0003o3FWL0ol00002oaifh`03o`000?laPnWo<H?Y00;o<H?Y00?o0000
odnTmom?Y?L01?l00005of:^n@03o`000?mnaokoO/On00KoO/On00?o0000oiCIo_nDfOh00ol00004
oiWRo@;o000000?oYn_io`000?l000000onXl?L2o`0000?oZ?;d0_l00004ojOdlPCo000000?o[OK_
o`000?nZm^h00_nZm^h2o`0000;oZ?K^00Go0000ojGek_nUmNkoYOG^o`000003oj?dk`04o`000?nP
lnooX??_oj3ck`;o00000onNl_07o`000003oig_mOl0003o000000?oVnkf0ol00002oiS/m`Go0000
00?oV>Wjo`000?l000000onFj?/3o`0000?oU>Kk0ol00006oi?So@Co00000_nBhOh3o`0000CoTMon
00?o0000oi7No_nAg_h00ol000000on?gOko0000o`000005o`0000CoS][o1_l00004ohcHo`03o`00
0?n<eoooS=Oo00?o00001?n;e_l00ol0003oR]Gooh[Eo`02oh[Eo`Go00001On8e?l6o`0000CoQm?o
00?o0000ohKBoon6d_l00_n6d_l7o`0000CoQM7o00?o0000ohCAoon4dOl00_n4dOl5o`0000Sooooo
00?o0000ooooooooool01Oooool001cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00003?ooool00ol0003oooooooooo`2W
ooooo`Go00001oooool01?l0003oB6?:o`000?l00003od9Mb004o`000?llF<Go?5S5o`0000;o>Uc:
0_l000000olcElSo0000oc9Lc@02o`0000?o:UO;00?o0000ob9Ab?lRDLP00_l000000olJBlGo0000
oaQBc002o`000004o`m<bOl0003o1dK6o`M6aP;o00000_l0@L<01Ol0003o03boo`000?l0003o03Nl
00Co000000?o02ngo`000?l000000_l000001Ol0:kCo0000o`000?l0003o03bo00;o000000?o03o1
o`000?l000000_l0<[X2o`000006o`0h__l0003o0000o`10`ol0003o05kE0_l00003o`eYg005o`00
0?lNM^?o7WKSoaifhol000001?laPnT00ol0003oCjCgodnTm`02odnTm`Ko000000?oHZkio`000?mn
aoh00omnaoh6o`0000OoVN;m1Ol000000onXl?Oo0000o`000004ojSbm003o`000?nWm?;oYoCb00;o
YoCb0_l00003ojGdl0So000000CoZ?K^o`000?nUmNkoYOG^0_l00002oj?dk`;o00000onPlnl00ol0
003oW_;`oikbl003o`000003oi_`l_l0003o000000?oVNoc1?l000000onKk_Ko0000o`000002oiS/
m`?o00000onFj_P5o`000003oiKXnol0003o000000?oU>Kk0ol00003oi;Uo003o`000?nChogoTn?m
00?o00000onBh_d3o`0000KoTMon1Ol00002ohoMoPCo00000_n>fol00ol0003oS][oohkJo`03o`00
00?oSMWo00?o0000ohcHoon<f?l00_n<f?l5o`0000KoRmKo1_l00004ohWEo`03o`000?n8e?ooR=Co
00?o00000on8dol00ol0003oQm?oohOCo`02ohOCo`Oo00001?n6d_l00ol0003oQM7oohGAo`02ohGA
o`Oo00001On4dOl00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Mooooo`;o
00002_ooool2o`0000Cooooo0_l00002ooooo`Go00002?ooool00ol0003oooooooooo`2Qooooo`Ko
00003?ooool00ol0003oB6?:odQSbP02o`0000;o@Ug80_l000002_llF<Go0000ocYLb_ljG<[o0000
ocURd?l0003o<eO8o`000?lbG<d2o`0000;o:UO;00Go0000ob9Ab?lRDLSo0000ob1HcP02o`0000;o
65;<00?o0000o`m<bOl?C<T00_l000001?l7A/Ko0000o`000?l0@L<3o`000003o`16aol0003o03Nl
00Co000000?o02ngo`000?l000000_l000001Ol0:kCo0000o`000?l0003o03bo00;o000000Ko03o1
o`000?l0003o03:jo`000?l0BlT2o`000003o`1Ccol0003o000000;o05kE0_l00003o`eYg004o`00
0?lNM^?o7WKSoaifh`?o00000_laPnT00ol0003oCjCgodnTm`03odnTm`04o`000?m]_okoKKonoffo
oPKo00001_n5e?l00ol0003oVN;moiWRo@04o`0000CoW>Wk1?l00002ojSbm0;o00001?nWm?801?l0
003oYOC`ojGdl?nUm?02o`0000;oXoC^0_l00003oj7dk@_o000000CoX??_o`000?l0003oW_;`0_l0
0003oi_`lP03o`000?nIko?oVNoc00?o00000onGk_@7o`0000;oU^[h0ol00003oiCYn@Go000000?o
U>Kko`000?l000001OnBiO`5o`0000;oT^;m0ol00003oi3PoP03o`000?nAgokoTMon00?o00000on?
g_h4o`0000CoS]_o1Ol00006ohgIo`Go00001On;eol00ol0003oRmKooh_Fo`03o`0000?oR]Ko00?o
0000ohWEoon9eOl00_n9eOl5o`0000GoR=?o1_l00004ohOBo`03o`000?n6d_ooQ];o00;oQ];o1ol0
0005ohGAo`03o`000?n4dOooQ=7o00;oQ=7o1?l00006ooooo`03o`000?oooooooooo00Gooooo000o
ooooo`?o0000WOooool5o`0001?ooooo00Co0000odQSb_m8Hl[o00000_m2GLP01?l0003o@F;=o`00
0?l00003ocYLbP04o`000?liH]3o0000o`0000;o<Uc=00Oo0000obYGbolZEl_o:UO;o`000?lRDLSo
000000;o85S>0_l00002oaQBc0?o000000Ko3UC?o`000?l0003o1Do=o`000?l0@L<3o`000004o`16
aol0003o0000o`12a0Co000000?o03c0o`000?l000000_l000001Ol0>[ko0000o`0l_ol0?;oo0000
00;o03o10_l000000ol0<[[o0000o`1;b@02o`000003o`1Ccol0003o000000;o05kE00?o0000o`eY
g?l=JM`00_l=JM`2o`000004oaifhol0003o?9SbocbHlPCo00001Om?Y?L00ol0003oKKonoffooP04
offooP03o`000?n5e?ooQMCo00CoQMCo1?l00005oicYn`?o00001?nMkOL4o`0000;oYoCb0_l00003
ojGdl005o`000?nSm>koXoC^oj?dk_l000000_nQm>d3o`000003oiockOl0003o000000;oW?;]0_l0
0003oi[bk@Oo000000CoVo3bo`000?l0003oVNoc0_l00004oiO^m0;o000000?oUNcfo`000?l00000
0onCjoL4o`0000;oU>Wi0ol00003oi;WnPGo00000_nBiO`3o`0000?oTN?m1?l00005oi3PoPGo0000
0_n?g_h3o`0000?oS]gn00?o0000ohkKoon>fol01?l00003ohgJo`03o`000?n=fOooSMWo00?o0000
0on<f?l00ol0003oRmOooh_Go`02oh_Go`Go00001On:e_l6o`0000CoRMCo00?o0000ohSCoon8dol0
0ol00004ohOCo`04o`000?n7d_ooQm;oohOBo`Oo00001On6d_l00ol0003oQM7oohGAo`02ohGAo`Oo
00001?n4dOl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`00
0?oooooooooo09Oooooo1Ol0000Hooooo`03o`000?m8Hl[oB6?:00;o00000_m2GLP01?l0003o@F;=
o`000?l00002ocYLbP03o`000?liH]3o>F;@00;o00000_lbG<d00ol0003o:UO;obYGb`02o`000005
ob9Ab?l0003o85S>ob1Hc_l000000_lHD/`01Ol0003o5U[Bo`000?l0003o3UC?00;o000000Co1Do=
o`000?l0003o04[:0_l000001ol0A/Oo0000o`12a?l0@/Co0000o`0n`_l000000_l0?<000ol0003o
03Zoo`000002o`0j_P04o`000?l0?;oo03boo`0000;o03o10ol00002o`1;b@04o`000?l0Dloo05??
o`0000?o05kE0_l00002o`eYg003o`000?lXRngo000000;o00001?llV?86o`000003odnTmol0003o
KKon00GoKKon00?o0000ohGDoon5e?l00ol00004oh_NoP;o000000?oW>Wko`000?l000001?nMkOL3
o`0000CoW>od1?l000000onUm?3o0000o`000002oj?dkP;o000000?oXOC]o`000?l000000onOlnd0
1Ol0003oW?;]oicbkOnLl^go000000;oV_;]1_l00003oiK_k`Oo00000_nGk_@2o`000003oiG/m_l0
003o000000?oTn_g0_l00003oi;Yn0Co00000_nBioX3o`0000?oTNGk1Ol00002oi7So@?o00000on?
h_d00ol0003oT>3noi3PoP03o`0000?oSmon1?l00005ohkMoPCo00001?n=f_l6o`0000GoS=So1_l0
0004oh[Go`03o`000?n:e_ooR]Ko00?o00000on9eOl00ol0003oRMCoohWDo`02ohWDo`Go00001_n7
dol5o`0000GoQ];o00?o0000ohKBoon6d_l00_n6d_l7o`0000CoQM7o00?o0000ohCAoon4dOl00_n4
dOl4o`0000Cooooo00?o0000ooooooooool01Oooool0043ooooo00?o0000ooooooooool0TOooool6
o`0001gooooo00Co0000odQSb_m8Hl[oB6?:0_l000001?m2GLSo0000od5RcOm1H/d2o`0000;o>Uc:
00Co0000ocURd?liH]3o00000_lbG<d2o`000003obYGbol0003o:5gA00;o00000olPF<h01Ol0003o
65;<oaQBc?l0003o5U[B00;o000000Go3UC?o`000?l0003o1Do=o`000002o`1:bP03o`000?l0A/Oo
04K700;o000000?o04;4o`000?l000000_l000000ol0?<3o0000o`000002o`000005o`0j__l0003o
0000o`0l_ol000000_l0?l42o`0000?o04_90_l000001_l0Dloo0000o`000?l0G]Go0000oaIniP;o
000000Co3FWLo`000?lXRngo:8_]0_l00005ocbHlP04o`000?mJ]_coF[KloeZfo0_o00001on;g_h5
o`0000;oWNgg0_l00004oic_m0?o00000onKlO4;o`000003oiockOl0003o000000;oW?;]0_l00000
1?nJl^go0000o`000?nHlNh2o`0000?oU^o_0ol000000onDk_7o0000o`000004oi?]lPOo000000?o
Tn_go`000?l000000onBjOP2o`0000?oT>Oi1?l00002oi7Un`?o00000on?i?`4o`0000KoSn;m1?l0
0002ohoOoP?o00000on=g_h00ol0003oS]gnohkMoP03o`0000CoSM_o00?o0000ohgJoon=f_l01?l0
0002ohcIo`03o`000?n<f?ooS=So00?o00000on;f?l00ol0003oR]Oooh[Go`02oh[Go`Ko00000on9
eOl7o`0000GoR=Co00?o0000ohOCoon7dol00ol00003ohOCo`03o`000?n6d_ooQ];o00;oQ];o1ol0
0004ohGBo`03o`000?n5dOooQM7o00;oQM7o1ol00004ohCAo`05o`000?ooooooooooooooool00000
1oooool0043ooooo00?o0000ooooooooool0S?ooool5o`0002Cooooo00Go0000odQSb_m8Hl[o0000
odMWc`02o`0000;o@F;=00Go0000od1Wd_l0003o>Uc:o`000003ocURd003o`000?lbG<go<Uc=00;o
000000Co:UO;o`000?lXGM7o00000olPF<h2o`000005oaQBc?l0003o5U[BoaIJd_l000000_l>E<l0
0ol0003o1Do=o`E?c@02o`000005o`1:b_l0003o0000o`000?l0D/h00_l000000ol0Clco0000o`1<
bP02o`000003o`1;bOl0003o04c800;o000000Go04g9o`000?l0003o0000o`0o`@04o`000003o`1;
bOl0003o06OH00;o000000Co1W;Oo`000?l0003o00000_lFO^H00ol0003o3FWLo`000002obR;k@;o
00001OllV?800ol0003oF[KloeZfo004oeZfo003o`000?mdcOooM<go00CoM<go0_l00002oh_NoP?o
00001On>iO/4o`000004oic_m?l0003o0000o`0000?oVo7a0ol00002oi[ak`;o000000?oV?7]o`00
0?l000000onFlN`>o`000003oiK_kol0003o000000;oU>ka0_l00003oi?]lPKo00000on@joD4o`00
0003oi;Yn?l0003o000000?oT>Oi0_l00003ohoVnPCo00000_n?i?`3o`0000CoS^;l00?o0000ohoR
oOn?h_d00ol00002ohkPo@Co00001_n=g_h4o`0000CoSM_o1Ol00004ohcIo`Go00001_n;f?l5o`00
00CoRMKo1Ol00005ohSEo`03o`000?n8e?ooR=Co00;oR=Co1Ol00005ohOCo`Ko00001?n6d_l00ol0
003oQM;oohGBo`02ohGBo`Oo00001?n5dOl00ol0003oQ=7oohCAo`02ohCAo`Co00000oooool00ol0
003oooooooooo`04ooooo`00?oooool00ol0003oooooooooo`28ooooo`Go0000:Oooool2o`000004
odQSb_l0003oAfO?odMWc`;o00000_m1H/d00ol0003o@6OBo`000002o`0000;o>F;@0_l000000olb
G<go0000oc1Sd`02o`0000;o:5gA0_l00002ob1HcP;o000000Go65;<o`000?lFF];o5U[Bo`000002
o`iDc`?o000000Co15[Co`000?l0003o05GA0_l000001_l0D/ko0000o`000?l0Clco0000o`1<bP;o
000000?o04_9o`000?l0C<P00_l000001Ol0CLWo0000o`000?l0003o03o100;o000000Go05kBo`00
0?l0003o0000o`1Wf002o`0000;o1W;O0_l00002oaIniP;o00001?lXRnd5o`000003ocbHl_l0003o
F[Kl00GoF[Kl00?o0000ogC=oomdcOl00_mdcOl5o`0000GoS^Gk0ol00003ohoYm`Co00000_nKlO42
o`0000?oV_7_0_l00002oiSak@03o`000?nFlNcoU_7/00?o000000?oU?3[o`000?l000001?l00000
0onAknco0000o`000003oi3^k@So000000CoTngbo`000?l0003oTNcc0_l00003oi3[m@?o00000_n>
jOH5o`000003oi3WnOl0003o000000;oSnKj0ol00003ohgTn`?o00001_n>h_`4o`0000;oS^3m0ol0
0004ohgOoP03o`000?n=g_koSMkn00?o00000_n<g?h6o`0000CoS=[o1Ol000000on;fOoo0000oh_I
o`02oh_Io`03o`000?n;f?ooRmSo00?o00000on:eol00ol0003oRMKoohWFo`03o`0000?oRMKo00?o
0000ohSEoon8eOl00_n8eOl7o`0000CoQm?o00?o0000ohOCoon7dol00ol00003ohKCo`03o`000?n6
d_ooQ];o00;oQ];o1ol00004ohGAo`03o`000?n5dOooQM7o00;oQM7o1ol00004ohCAo`04o`000?oo
ooooooooo`0000Kooooo000oooooo`03o`000?oooooooooo08?ooooo1Ol0000^ooooo`05o`000?m=
K=7o0000odQSb_l000000_m7Ill2o`000003od5RcOl0003o@6OB00;o@6OB00Co0000ocURd?liH]3o
>F;@0_l000001?lbG<go0000oc1Sdol00002obQMd@06o`000?lWIMOo0000ob1Hc_l0003o7eoE0_l0
0003oaIJdP04o`000?l>E<oo0000o`eNeP;o000000Co15[Co`000?l0003o05GA0_l000001_l0D/ko
0000o`000?l0Clco0000o`1<bP;o000000Go04_9o`000?l0C<So04c8o`000002o`1=b@?o000000Co
05K>o`000?l0G];o05kB0_l00002o`1Wf003o`000?l6L]oo1W;O00;o00000olFO^H3o`0000;o:8_]
00Co0000odJ[n?m6ZoSoAZ_h3Ol00005og[Ho@;o000000?oS^Gko`000?l000000on?jOL3o`0000Co
Sn_c1?l000000onJlNoo0000o`000002oiSak@;o000000?oU_7/o`000?l000000_nDl>/2o`000003
oi?_jol0003o000000?oTNo/00Co0000oi3^kOn@k^goT>k]0_l000001?n>kNko0000o`000?l00002
ohg/l0So000000?oT>_eo`000?l000000_n>jOH3o`0000?oSNSh1?l000000on?i_[o0000o`000003
ohgTn`?o00000on<ho`00ol0003oS^;lohkRo003o`0000?oSN7m1?l00004ohgOoPGo00000_n<g?h3
o`0000CoRm_o00?o0000ohcJoon<f_l00ol00003oh_Io`04o`000?n;fOooRmWooh_Io`Ko00001?n:
eol5o`0000GoRMKo1_l00004ohSDo`03o`000?n7doooQm?o00;oQm?o1Ol00005ohKCo`Ko00001?n6
d_l00ol0003oQM7oohGAo`02ohGAo`Oo00001?n4dOl00ol0003oQ=7oohCAo`02ohCAo`Co000000?o
ooooo`000?ooool01Oooool003oooooo00?o0000ooooooooool0OOooool6o`0003Cooooo00Co0000
ode/dOl0003o00000_m7Ill01Ol0003oAVcDo`000?m1H/go000000?o@6OB00Go0000ocURd?liH]3o
0000ocQXeP02o`0000;o<6?C0_l000000olXGM7o0000obMUe`03o`000003oamOeOl0003o5U[B00;o
5U[B0_l000000ol>E<oo0000o`eNeP02o`000005o`AJdol0003o0000o`1EdOl000000_l0D/h01_l0
003o04o<o`1?c?l0003o04c:o`0000;o04_900Co0000o`1<b?l0C<So00000_l0CLT3o`000004o`1F
c_l0003o05kBo`1NdP;o00000_l0ImP01?l0003o1W;Oo`Ibgol6L]l2o`0000;o5WkV00?o0000oc:N
l_l000000ol00005odJ[n003o`000?mRa?goH/Cm00CoH/Cm00?o0000og[HoOmjf?d01Omjf?d5o`00
0003ohoYmol0003o000000CoSn_c0ol00003ohk/l1;o000000?oTNo/o`000?l000000_n@k^d2o`00
0003ohk]k_l0003o000000;oSNc`0ol000001?n<jo7o0000o`000?l00002oh_Yl`So00000_n=j?P3
o`0000?oS>Ki1?l000000on=i?_o0000o`000005ohcSo0Go00000_n=hOd3o`0000;oS=om1_l00004
ohcMoP?o00001_n;fol4o`0000GoRmWo1_l000001?n:f?oo0000oh[Hoon:f?l5o`0000CoRMKo00?o
0000ohWFoon9e_l00ol00004ohSEo`04o`000?n8e?ooR=CoohSDo`Oo00001?n7dol00ol0003oQ]?o
ohKCo`03o`0000?oQ];o00?o0000ohKBoon6d_l00_n6d_l7o`0000CoQM7o00?o0000ohCAoon4dOl0
0_n4dOl7o`0000CoQ=7o0_l00006ooooo`00?oooool3o`0007Sooooo1Ol0000jooooo`04o`000?m=
K=7oCFcAo`0000?oAfO?00?o0000odI/e?l000000_l00002od1WdP;o000000Go>F;@o`000?lhJ=Ko
>6SFo`000002oc1Sd`05o`000?l_J]Wo0000obQMdOl000000_lWIML00ol0003o7eoEoamOe@02o`00
00;o5U[B0ol00002o`eNeP04o`000?l4F]?o15[Co`0000;o05GA00?o0000o`1Bc_l0D/h00_l00000
0ol0Clco0000o`000002o`000004o`1;bOl0003o0000o`1<b0;o000000?o04g9o`000?l000000_l0
E/h01?l0003o05kBo`1Nd_l0G]82o`000003o`1Wf?l0003o000000;o1W;O1Ol00003oc:NlPKo0000
00?oAZ_ho`000?mRa?d01OmRa?d00ol0003oN]Smog[Ho@04o`0000?oOMkj1Ol00002oho[l`;o0000
0on>k?03o`000003ohg]kOl0003o000000Co000000GoRncZo`000?l0003o0000oh[/j@02o`0000?o
RN_Y3_l000000on<jo7o0000o`000002oh_Yl`?o000000CoR^Sdo`000?l0003o00000_n9ioH5o`00
00;oS>Ki0ol00003oh_UnPCo00000_n<ho`3o`0000?oRn;l1?l00002ohcOo@?o00001?n;g_h00ol0
003oS=gnohcMoP03o`0000?oRmcn00?o0000oh_Koon;fol00ol00003oh[Jo`03o`000?n;fOooRmWo
00?o00001?n9fOl00ol0003oR]Sooh[Ho`03o`0000?oRMOo00Co0000ohWFoon9e_ooRMKo1Ol00006
ohSEo`Go00001On7e?l01?l0003oQm?oohOCoon7dol5o`0000KoQ];o1Ol00004ohGBo`03o`000?n5
dOooQM7o00;oQM7o1ol00004ohCAo`03o`000?n4dOooQ=7o00;oQ=7o1?l00006ooooo`00?oooool0
0ol0003oooooooooo`1cooooo`Go0000?oooool01?l0003oCFcAode/dOm=K=42o`000003odMWcol0
003oAVcD00;oAVcD00Co0000od1Wd_m0Im;o@6OB0_l000001?liH]3o0000ocQXe_lhJ=H2o`000003
oc1Sdol0003o;f[I00;o00000olWIML3o`000005oaeXfol0003o5U[Bo`000?lEHmT00_l00002o`eN
eP03o`000?l4F]?o15[C00;o000000Go05GAo`000?l0003o0000o`1Oe@02o`000003o`1Mdol0003o
05cA00;o000000Co05g@o`000?l0003o05oA0_l000001?l0Hm;o0000o`000?l0E/h2o`0000;o05kB
2?l00002ob2Ak0;o00001OlbW_800ol0003oC[Wiodjin@0<o`0000?oOMkj0ol00004ogoSm@Go0000
00?oS^c`o`000?l000000_n=kNd2o`000003ohc]jol0003o000000;oRncZ0_l00003oh[/j@03o`00
0?n9jnWoRN_Y00?o000000?oR>_Zo`000?l000001ol00002ohKYk`So000000?oR^Sdo`000?l00000
0_n9ioH3o`0000?oR>Kg1Ol00002oh_UnP?o00000on:ho/4o`0000;oRn;l0ol00003oh[Po@?o0000
1_n;g_h4o`0000CoRmcn1_l00003oh[Jo`Ko00001?n9fOl5o`0000;oRMOo00?o0000ohWGoon9eol0
1Ol00005ohSFo`03o`000?n8eOooR=Go00?o00000on7e?l00ol0003oQmCoohODo`02ohODo`Ko0000
1On6dol00ol0003oQ];oohKBo`03o`0000?oQ];o00Co0000ohGBoon5d_ooQM;o1ol00004ohGAo`03
o`000?n4dOooQ=7o00;oQ=7o1ol00003ooooo`03o`000?oooooooooo00Cooooo000oooooo`03o`00
0?oooooooooo06gooooo1_l00015ooooo`08o`000?m=K=7oCFcAo`000?m<LMKo0000odMWcol00003
odI/e0;o000000?o@6OBo`000?loKMP00_l00002ocQXeP05o`000?lgKm_o0000oc1Sdol000000_l_
J]T01Ol0003o9fGGobMUeol0003o9VgM00;o000000Ko7FSKo`000?l0003o0000oaESfOl00003o`eN
eP?o000000Co16GJo`000?l0003o06;G0_l000001_l0GmGo0000o`000?l0GM?o0000o`1Ld@;o0000
00Co05g@o`000?l0003o05oA0_l000000ol0Hm;o0000o`000006o`000003o`9jg_l0003o000000;o
48GU0_l00003ob2Ak0Go000000?o<Ykbo`000?m>^OT01?m>^OT2o`0000CoJ<ok1_l00003ogoSm@?o
00000on0iO4@o`000004oh[/jOl0003o0000ohW[j@;o00000_n8jnX2o`000004ohOZk?l0003o0000
ohKYk@;o00000_n6jNl3o`000004ohGXl?l0003o0000o`0000;oQNOb2?l00002ohSVm`?o00000on8
iOP5o`0000;oR^?k0ol00002ohWRn`Go00000_n:h?d3o`0000?oRMom00?o0000oh_No_n;g_h00ol0
0003ohWMoPGo00001?n9fol5o`0000CoRMWo1_l00004ohWHo`03o`000?n9eoooRMOo00?o00000on8
e_l00ol0003oR=KoohSFo`02ohSFo`Go00001?n7e?l7o`0000CoQm?o00?o0000ohKCoon6dol00_n6
dol5o`0000GoQ];o1Ol00005ohGBo`04o`000?n5dOooQM7oohGAo`Oo00002_ooool00ol0003ooooo
ooooo`04ooooo`00?oooool00ol0003oooooooooo`1Xooooo`Go0000Boooool01_l0003oCFcAode/
dOm=K=7o0000odaaeP;o00000om6K=@01ol0003oAG;Jo`000?m0Im;o0000ocm]f?l000000olhJ=H0
1?l0003o=foKo`000?l00003obmZf@;o000000?o9fGGo`000?lVKMd00_l00002oaeXf`03o`000?lE
HmWo5F?I00;o000000?o3EkFo`000?l<JM`00_l000001?l4IM[o0000o`000?l0H]L2o`000005o`1O
eOl0003o0000o`1Mdol000000_l0G=401Ol0003o05g@o`000?l0003o05oA00;o000000Co06?Bo`00
0?l0J=Go06SE0_l000001?l0L=Wo0000o`000?l2N]h2o`0000?o48GU0ol00002ob2Ak003o`000?lk
[OCo>jgd00go00001Om/e_L5o`0000;oP>Ga0ol00002oh3Vk@Ko000000CoOnOXo`000?l0003o0000
0_moinLEo`000003ohGXl?l0003o000000;oQNOb0ol00002ohGVm0;o00000on4iOD4o`0000;oR>Gh
0ol00003ohOSnPCo00000_n9h_/3o`0000?oR>7l1Ol00003ohWOo@Ko00000_n9gOh3o`0000?oRMcn
00?o0000ohWKoon9fol00ol00003ohWJo`03o`000?n9fOooRMWo00?o00000on8f?l00ol0003oRMSo
ohWHo`02ohWHo`Ko00000_n8e_l8o`0000CoR=Go1Ol00004ohODo`03o`000?n7doooQm?o00;oQm?o
1ol00004ohKCo`03o`000?n6d_ooQ];o00?o00000on5d_l00ol0003oQM;oohGBo`02ohGBo`Ko0000
4Oooool00ol0003oooooooooo`04ooooo`00?oooool00ol0003oooooooooo`1Sooooo`Go0000D?oo
ool01Ol0003oCFcAode/dOm=K=7o000000;oC77F00?o0000odI/e?m6K=@00_m6K=@01?l0003oAG;J
o`000?l00002ocm]f0;o000000?o>6SFo`000?lgKm/00_lgKm/01Ol0003o;f[IobmZfOl0003o;W7O
00;o00000olVKMd00ol0003o7FSKoaeXf`03o`000005oaE]g_l0003o3EkFo`000?l<JM`00_l00002
o`AUfP06o`000?l0H]Oo06;Go`000?l0GmGo00000_l0GM<01_l0003o05cAo`1LdOl0003o05g@o`00
00;o05oA00Co0000o`1Sd_l0Hm;o00000ol0J=D2o`000004o`1`fOl0003o0000o`9jgP?o00000_l@
QND5o`0000Go>jgd0_l00005oeG5m`;o00000_m/e_L3o`0000?oK]_b1Ol00002oh3Vk@;o000000?o
P>O[o`000?l000000_moinP2o`0000;oOnOW0ol000000omoinOo0000o`000004o`000003ogkWjOl0
003o000000Co000000?oOnK/o`000?l000000omoi^h7o`0000;oQNKd0_l00002ohCUm@?o00000_n4
i?L5o`0000;oQn?j0ol00003ohORnPCo00000_n8hO`3o`0000?oQmom1Ol00004ohSMoPGo00000on9
g?h6o`0000?oRM[o1_l00003ohSHo`Oo00001?n8eol6o`0000CoQmKo00?o0000ohSEoon8eOl00ol0
0003ohODo`04o`000?n7e?ooQmCoohODo`Oo00001?n6dol00ol0003oQ]?oohKCo`02ohKCo`Go0000
1?n5d_l7o`0001Oooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0GOoo
ool6o`0005Kooooo0_l000000om=K=7o0000odaaeP02odaaeP;o00000_m6K=@01?l0003oAG;JodEb
f_l00002ocm]f003o`000?lnM=go000000;o00000olgKm/2o`000003obmZfOl0003o;W7O00;o0000
0olVKMd3o`000004oaeahOl0003o0000oaE]gP?o00000_l<JM`00ol0003o16GJo`AUfP02o`000003
o`1Reol0003o000000;o000000Co05gCo`000?l0003o05cA1?l000001?l0Gm7o0000o`000?l0Hm82
o`0000;o06SE3?l00002obVQkQ;o00000_m^fo83o`0000CoL=g^5_l000001?mninWo0000o`000?mn
i^X2o`0000;oOnK/0_l00002ogoVkP?o000000?oOnG`o`000?l000000omoiO47o`0000;oQ>Cg0ol0
0003ohCSn0Go00000_n7h_X3o`0000?oQ^7k1?l00002ohOOo@?o00000on7g_d00ol0003oR=gnohSM
oP03o`0000?oR=cn1Ol00004ohSKo`Go00001?n8fOl5o`0000GoR=So00?o0000ohSGoon8eol00ol0
0003ohOFo`05o`000?n7e_ooQmKoo`000?n7e_l01Ol00005ohODo`Go00001On6dol01?l0003oQ]?o
ohKCoon6dol7o`0000CoQ];o1Ol0000Nooooo`03o`000?oooooooooo00Cooooo000oooooo`03o`00
0?oooooooooo05Sooooo1Ol0001Looooo`05o`000?mBM]So0000ode/dOl000000_m<LMH00ol0003o
C7OKo`000002odI/e003o`000?m5L][oAG;J00;o000000Go?fgHo`000?lnM=go?WCMo`000003ocM_
f`04o`000?lfM^7o0000o`0000;o;W7O00Ko0000obI]gOlVKMgo9VgMo`000?lUM^<2o`000003oaea
hOl0003o000000;o5FgN00Co0000o`aYg?l<JMco36WL0_l000001Ol4IM[o0000o`000?l0003o06oL
01Co00000_l1PMd2o`000003o`b:h_l0003o000000;o6IGW2?l00005od:ilP03o`000?mJc??oF/cc
00;oF/cc1_l00003og3MkP?o000000?oLMo[o`000?l000001?l000001OmchNKo0000o`000?l0003o
Ln7U00Ko00000_meh^H?o`000003ogoUl?l0003o000000;oOnGa0ol000001?moi??o0000o`000?l0
0002oh3Sm@Co00000_n4hoP3o`0000?oQ>;i1Ol00002ohKQn`?o00000on6go`4o`0000?oQmkm1_l0
0002ohSLoP?o00000on7foh00ol0003oR=_oohSKo`03o`0000?oQm[o00?o0000ohSIoon8fOl00ol0
0003ohOHo`03o`000?n8f?ooR=So00;oR=So1Ol00004ohOFo`So00000on7eOl00ol0003oQmCoohOD
o`03o`0000?oQmCo00?o0000ohKCoon6dol00_n6dol6o`0000GoQ]?o00?o0000ohKBoon6d_l00ol0
000Sooooo`03o`000?oooooooooo00Cooooo000oooooo`03o`000?oooooooooo05?ooooo1Ol0001R
ooooo`04o`000?mBM]So0000o`0000?oC77F00?o0000odagfol000000_l00002odEbfP04o`000?m5
N=oo0000o`0000?o?WCM0_l00002ocM_f`04o`000?lfM^7o0000o`0000;o;W7O0_l00002obI]g@04
o`000?lUM^?o0000o`0000;o7G7Q00?o0000oaE]g_lEKMh00_l000000ol<JMco0000o`idh@05o`00
0004o`1_g?l0003o0000o`1]fP;o000000Co06gHo`000?l0003o06kG0_l000001?l0L=Oo0000o`00
0?l0LmP2o`000003o`1if_l0003o000000?o0H7M1ol000001?lIUNOo0000oc6]kOla[Nd<o`0000Co
GM7_3Ol000000omchNKo0000o`000002og?Qi@;o000000?oM>;Uo`000?l000000_meh^H3o`000003
ogKRiol0003o000000Oo00000omhh^d8o`000003ogoTlol0003o000000;oP>?e0ol00003oh3Rm`Co
00000_n4h_T3o`0000?oPn7j1Ol00002ohKOo0?o00000_n5g_d5o`0000GoQ]gn1?l00003ohOKoPKo
00000on7f_l5o`0000KoQmSo1Ol00004ohOGo`Go00001?n7e_l01?l0003oQmGoohOEoon7eOl6o`00
00CoQmCo1ol00004ohKCo`03o`000?n6doooQ]?o00;oQ]?o1Ol0000Vooooo`03o`000?oooooooooo
00Cooooo000nooooo`?o0000C_ooool6o`0006Oooooo00Co0000oe9ff?mBM]So00000om<LMH01Ol0
003oC7OKodagfom<Mm_o000000?oAG;J00Co0000odEhgol0003o00000_lnM=d01Ol0003o?G_So`00
0?lgKm_o000000;o=WKQ00Go0000obiagol^LMoo0000obeji@02o`000004obI]gOl0003o9GKSo`00
00?o7G7Q0_l000000olEKMko0000o`000002o`0000;o3WCQ0_l000001Ol6LMko0000o`1_g?l0Kmco
000000;o06gJ0_l000001?l0KMSo0000o`000?l0K]L2o`000003o`1`eol0003o000000Oo000000?o
0H7Mo`000?lEV><00ol000000olRX^Oo0000o`000005o`000003oc6]kOl0003oB<;_00?oB<;_1ol0
0002of3Ej`Ko00001?mUfNDHo`0000;oN>;]1_l00003og[Rl@So00000_n0h_L3o`0000?oP>7h1?l0
0002oh?QnP?o00000on3go/4o`0000;oQMkm0ol00004ohGMo@03o`000?n6gOkoQ]gn00?o00000_n6
g?h5o`0000CoQ][o1Ol00005ohOIo`03o`000?n7f?ooQmSo00?o00000on7eol00ol0003oQmOoohOG
o`03o`0000?oQmKo00Co0000ohOFoon7e_ooQmKo2?l00003ohKDo`Go00001?n6dol00ol0003oQ]?o
ohKCo`02ohKCo`Oo0000:oooool00ol0003oooooooooo`04ooooo`00?_ooool00ol0003ooooooooo
o`19ooooo`Go0000K_ooool00ol0003oDWKHoe9ff002o`0000;oC77F00Co0000odagfom<Mm_oC7OK
0_l000001Om5L][o0000odEhgom5N=oo000000?o?WCM00?o0000ocekhol000000_l00002ocIfh@;o
000000Co;W7Oo`000?l]N^Go;G[U0_l00002obEfh`;o000000?o7G7Qo`000?lMNnH00ol000000olE
N>?o0000o`000003o`idh@Co000000Go06oLo`000?l0003o0000o`1]fP09o`000003o`23fol0003o
000000Oo00000olEV><7o`000003ocRgj_l0003o000000Co00001?m=b>/9o`0000?oIMWU2Ol00000
0omZg>Co0000o`000007o`000004ofoNj?l0003o0000o`0000?oLMo[1ol00002og[Rl@Ko00000oml
hOD5o`0000;oP>7h0ol000000on0h?Wo0000o`000004o`0000;oPmok0ol00003oh?No0Co00001?n5
gOd5o`0000;oQ]cn0ol00003ohGKoP03o`000?n6f_ooQ][o00?o00000on6fOl00ol0003oQmWoohOI
o`02ohOIo`Go00001?n7eol5o`0000CoQmKo1_l00005ohKEo`03o`000?n6e?ooQ]Co00?o00000on6
e?l01?l0003oQ]?oohKCoon6dol7o`0003?ooooo00?o0000ooooooooool00oooool003kooooo00?o
0000ooooooooool0A?ooool5o`0007Cooooo00Co0000oe9ff?l0003oDGcM0_l000001_m<LMKo0000
odagfom<Mm_o0000od]mh@?o00000_m5N=l2o`0000;o?WCM00Co0000ocekholmNn?o00000_lfM^40
0ol0003o=GkVo`000002o`0000?o;G[U0_l000000olUM^?o0000o`000002o`0000;o7G_V0_l00002
oaEhh`;o000000?o3WCQo`000?l@P>D01Ol000001Ol5ON3o0000o`000?l0003o0GcM00;o000000?o
07gLo`000?l000000_l00003o`23f`go000000?o:ZcVo`000?l000002ol000001?mAc>Oo0000o`00
0?l00003oeG?i1Ko000000?oKmkXo`000?l000000omagn/6o`0000?oM=o_1ol00002ogcQm@?o0000
0_mlh?L9o`0000?oPMoj1_l00002oh?No0?o00000on3gOd5o`0000CoQ=cn1?l00003ohGKoPKo0000
0on6fOl7o`0000;oQ]So1ol00004ohKGo`Go00001?n6e_l00ol0003oQ]GoohKEo`02ohKEo`Go0000
00CoQ]Coo`000?l0003oQ]Co1_l0000jooooo`03o`000?oooooooooo00?ooooo000nooooo`03o`00
0?oooooooooo03kooooo1_l0001iooooo`04o`000?mBM]SoDWKHo`0000;oDGcM0_l00003odagf`04
o`000?m;ON7oBggQo`0000;oAGSO00?o0000odAoi?l000000_l00003ocekh`;o000000Co=WKQo`00
0?leO^Ko=GkV0_l00002obeji@03o`000?l]PnWo000000;o000000?o9GoXo`000?l000000olMNnH2
o`000003oaEhhol0003o000000;o00000_l@P>D4o`0000?o1GgP0_l000000ol1O=go0000o`00000@
o`000003oajSh_l0003o000001So00000_mKdn89o`000005of?Hi?l0003o0000o`000?mVf^H03Ol0
0002ogCOk`Ko00000omggo<8o`000004oggOn?l0003o0000o`0000?oOMoi1Ol00003oh7Nn`Ko0000
0_n3gOd3o`0000?oPmcm00?o0000ohCLo_n4g?h00ol00002ohCKoPGo00001On5f_l4o`0000GoQ]So
1?l00005ohKGo`03o`000?n6eoooQ]Oo00?o00000on6e_l01?l0003oQ]KoohKFoon6e_l7o`0000Co
Q]Co1Ol00010ooooo`03o`000?oooooooooo00?ooooo000nooooo`03o`000?oooooooooo03Wooooo
1Ol00020ooooo`;o000000?oDWKHo`000?mAO=d00_mAO=d2o`000003odagfol0003oBggQ00;oBggQ
0_l000001?m5N=oo0000odAoi?m4On@2o`0000;o?G_S00?o0000ocf2j?l000000_l00003ocEniP;o
000000Co;G[Uo`000?l]PnWo;H?Y0_l00002obEoj0;o000000?o7G_Vo`000?lNQNT00ol000000olG
P^Oo0000o`000003oa20i@Go000000?o1GgPo`000?l000000_l000000ol9Rmoo0000o`000004o`00
0003o`Z@gOl0003o000001Oo00000_m8an83o`0000;oCL_P4ol00002ofSKj0Ko00000_m]g>d9o`00
00;oMmoc1_l00003ogWNm`Co00000_mmgoT3o`0000?oO]kj1Ol00003oh7Mo0Go00001?n3g?d5o`00
00;oQ=_n0ol00004ohCJoP03o`000?n5f_ooQM[o00?o00000on5fOl00ol0003oQ]SoohKHo`03o`00
00;oQMOo00?o0000ohKGoon6eol00_n6eol5o`0000CoQ]Ko1_l00005ohKEo`03o`000?n6e?ooQ]Co
00?o00001Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00?ooooo000nooooo`03
o`000?oooooooooo03Cooooo1Ol00025ooooo`04o`000?mGP=oo0000o`0000?oDGcM00?o0000oe62
h_l000000_l00002od]mh@03o`000?m;PnKo000000;o00000om4On@2o`000004ocekhol0003o?H;X
ocf2j0;o00000_leO^H00ol0003o=HK[o`000002o`0000?o;H?Y0_l000000olUOnSo0000o`000002
o`0000;o7XGY0_l00002oaN2i`?o000000?o483Uo`000?l000001Ol000000ol;R^;o0000o`000003
o`V;g`Oo000000?o2Y3Mo`000?l000000_l000000olNYMoo0000o`00000Ho`0000;oEM3Q2Ol00002
of3FiPgo00000_m_gNl3o`000003og7MlOl0003o000000Oo00000_mig_L3o`0000?oN]kh1?l00002
ogkNnP?o00000omngO/5o`0000CoPMcm1Ol00002oh?KoPKo00001?n4f_h5o`0000CoQMWo1Ol00003
ohGGo`Oo00001?n5e_l5o`0000CoQMGo00?o0000ohKEoon6eOl00_n6eOl5o`0000Wooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`03ooooo`00?_ooool00ol0003oooooooooo`0^oooo
o`Ko0000Roooool01?l0003oEh3OoeN0gol00003oe5lg@04o`000?mAP^;oDH;Ro`0000?oBggQ00?o
0000od^3i_m;PnH00_l00002odAoi003o`000?m4Q^Wo000000;o00000olmP^P2o`000005ocEni_l0
003o=HK[ocF6jol000000ol]PnT00ol0003o;X_]o`000002o`000003obJ8k?l0003o000000?o7XGY
0ol000000olGP^Oo0000o`000002o`000003oaB;iol0003o000000;o3h[T3?l000000olDVmoo0000
o`00000Go`0000CoB<SO4?l00002of?Gj0Ko00000_mYf^d9o`0000;oLmgc0ol00003ogGMm@Co0000
0_mjg_P3o`0000?oNmgj1?l00002ogkMn`?o00000omog?`00ol0003oPMcmoh7Lo@03o`0000?oPM_m
1?l00005oh?JoPGo00001?n4fOl5o`0000CoQ=So1?l00005ohGGo`03o`000?n5e_ooQMKo00?o0000
0on5e_l01?l0003oQMGoohGEoon5eOl7o`0000oooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`03ooooo`00?_ooool00ol0003oooooooooo`0Yooooo`Go0000TOooool01?l0003oEh3O
oeN0gomGP=l2o`000003oe5lgOl0003oDH;R00;oDH;R0_l00002od]mh@04o`000?m;PnKoBh?Vod^3
iP;o000000GoA7oTo`000?m4Q^WoA8KYo`000003ocf2j003o`000?llR^co000000;o00000_leQ^/3
o`000004obf3jOl0003o;X_]obj;k@;o00000_lVR>`3o`000003oaj5jOl0003o8Ho/00?o00000_lJ
SNT<o`000003oa>Gh_l0003o000002Ko00000_mGd>@3o`0000;oFm;V3Ol000001?m/f_3o0000o`00
0?l00002ofkKlPKo00000_megOD3o`000003ogOMmol0003o000000Co00000_mkgOX3o`0000?oO=ck
1?l00003ogoLo0Ko00000_n1fod3o`0000?oPM[n00?o0000oh?Jo_n3f_h00ol00003oh?IoP03o`00
0?n4fOooQ=Wo00?o00000on4f?l00ol0003oQ=SoohCHo`03o`0000?oQ=Oo00Co0000ohGGoon5eooo
QMOo1_l00003ohGFo`Ko00005oooool2o`0003_ooooo00?o0000ooooooooool00oooool003gooooo
0ol0000Uooooo`Go0000Uoooool01Ol0003oEh3OoeN0gol0003oEhKT00?o00000_mAP^800ol0003o
DHOWo`000002o`0000?oBh?V00?o0000odZ:j_l000000_l00002odB6j@?o000000?o?H;Xo`000?ll
R^`00_llR^`3o`000003ocF6jol0003o000000;o00000ol^Rnd2o`000003obJ8k?l0003o9i7^00?o
00000olQSn`3o`000003oaZ=jOl0003o000000;o000000?o6IKWo`000?l000001ol000000olCUn;o
0000oafRhP06o`000003oajUh?l0003o:K3O00Ko00000olf^]l:o`0000?oCL[R3Ol00002of;Fj`?o
000000?oI]O^o`000?l000002?l00003og3Km0Wo00000omhg?T6o`0000;oO=ck0ol00002oggLo0Go
00000omofod6o`0000?oPM[n1_l00003oh?IoPGo00001?n4f?l5o`0000CoQ=Oo1_l00003ohGFo`Ko
00007oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo000nooooo`03o`00
0?oooooooooo01oooooo1Ol0002Looooo`05o`000?mGP=ooEh3OoeN0gol000000_mGQ^@01Ol0003o
DH;Roe62h_mAP^;o000000?oDHOW0_l00002od^3iP04o`000?m:R^[oBX[Zo`0000?oA8KY00?o0000
od>>k_l000000_l00002ocb:k003o`000?llT_3o?9;`00?o00000_leSnl3o`000003obj;kOl0003o
000000;o00000olWTNh4o`000003ob6?k?l0003o000000;o00000_lNUnX4o`000003oaVFiol0003o
7j3W01_o00001?m3`n89o`0000;oEm3W0ol00002oe_BjPWo00000_mYf?03o`000003ofcIl_l0003o
000000Go000000CoL]_fo`000?l0003o00000omdfoP5o`0000?oNMcj1Ol00002oggLo0?o00000omm
fo`5o`0000?oP=[m1_l00003oh7IoPKo00000_n3f?l7o`0000;oPmOo1ol00004ohCFo`Go00009_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00?ooooo000nooooo`03o`000?oooooo
oooo01Wooooo1_l0002Rooooo`;o00000_mGP=l00ol0003oEhKToeN6i002o`0000;oDH;R00Go0000
oe67iomAQnOo0000oe2>j`02o`000004od^3i_l0003oBX[ZodZ:jP?o000000?oA8KYo`000?m3S^h0
0_m3S^h2o`000003ocb:k?l0003o?9;`00?o?9;`0ol000000oleSnoo0000o`000002o`0000;o;iC`
1?l000000olWTNko0000obZJk`0`o`0000?oCl_V2_l00002oeoDk@?o000000?oHmG_o`000?l00000
1ol00003ofkIm0Ko00000_mdfoP3o`000003ogKKnOl0003o000000Go00000_mjfo/6o`0000;oOM_l
0ol00003ogkJo@Go00001?n0fOh5o`0000CoP]Wn1?l00005oh?Ho`Co00001On3eol00ol0003oQ=Ko
ohCFo`03o`0002cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`00?Ooo
ool00ol0003oooooooooo`0Eooooo`Go0000Z?ooool00ol0003oG8[Uo`000002o`0000;oEhKT00?o
0000oeJ<j?l000000_l00003oe67i`03o`000?m@S^_oD8k[00;o00000_m:R^X00ol0003oBY7_odZA
k`03o`0000;o@hk^00?o0000od>ElOl000000_l00003ocbBl003o`000?lmVO?o?IWc00?o00000_lf
Uo83o`000003obnDl?l0003o<9ca00Go000000?o:Y[_o`000?l]Xnl00ol000000olXXNgo0000o`00
0006o`000003obVYjOl0003o000001Ko00000om7aNH9o`0000CoFM3[2Ol00002ofOGl@?o000000?o
J]Oco`000?l000001?l00003og7Jm`Wo00000omhf_X6o`0000?oNm_l1_l00002ogkJo@?o00000omn
fOd00ol0003oP=Wnoh3IoP03o`0000?oP=Wn00?o0000oh;Io_n2fOh00ol00003oh;Ho`03o`000?n3
f?ooPmSo00?o00000on3eol01?l0003oPmOooh?Goon3eol5o`00033ooooo0_l0000fooooo`03o`00
0?oooooooooo00?ooooo000mooooo`03o`000?oooooooooo013ooooo1Ol0002^ooooo`04o`000?mL
R^GoG8[Uoeb:i@;o000000?oEhKTo`000?mFS>P00_mFS>P3o`000003oe67iol0003oD8k[00;oD8k[
0_l000000om:R^[o0000odZAk`03odZAk`;o000000?o@hk^o`000?m3UO400_m3UO43o`000003ocbB
l?l0003o?IWc00?o?IWc0_l000000olfUo;o0000ocNNl`03o`0000Co<9ca1?l00003obfSk`Co0000
00?o::7]o`000?l]ZN`08Ol00003oe;<j`[o00000omRe?09o`0000?oKMSf1_l00002og?Jn0?o0000
0omef_T4o`0000?oNM[k1_l00003ogcJo0Ko00000omnfOd6o`0000?oP=Wn1_l00003oh;Ho`Go0000
1?n3eol6o`0003Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`03ooooo`00?Ooo
ool00ol0003oooooooooo`0:ooooo`Ko0000]?ooool01Ol0003oG8[Uoeb:iOl0003oFhoY00?o0000
0omFS>P00ol0003oEY7/o`000002o`0000;oD8k[00?o0000oe2Dkol000000_l00003odZAk`03o`00
0?m9V?;o000000;o00001?m3UO44o`0000Co?IWc1?l00003ocNNl`Co000000Co<9cao`000?lcY?;o
<jCb1?l000000ol]Xnoo0000oc6Zk`0No`0000?oC<OZ2Ol00003oecAl0Oo00000_mUeO83o`000003
ofWFm?l0003o000000Co00000om_f?L6o`0000;oMM[i0ol00003ogKIn`Co00000omjf_`6o`0000?o
OMWm1_l00003ogoIoPKo00000on1f?h6o`0000;oP]Oo1ol0000nooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool00oooool003gooooo00?o0000ooooooooool01Oooool5o`000;[ooooo
00Go0000oeb:iOmLR^GoG8[Uo`000002oe^?j@03o`000?mFS>SoEXcX00;oEXcX00Co0000oeJAk?mF
TNcoEY7/0_l000000om@S^_o0000oe2Dk`02oe2Dk`?o000000?oBY7_o`000?m9V?800_m9V?84o`00
0004od>ElOl0003o@icdod>Lm0Co000000Co?IWco`000?lmXOGo?J7e1?l000000olgW_?o0000ocVV
m00_o`0000?oElg_1_l00004of7BlPWo00000om/eoL6o`0000?oL]Si1_l00002ogKIn`?o00000omh
fO`4o`0000?oNmWm1_l00002oggIoPOo00000_mof?h7o`0000CoPMOo1?l00016ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool00_ooool003gooooo00?o0000ooooool000001Ol00030
ooooo`;o00000_mLR^D00ol0003oFhoYoe^?j@04o`000006oeJ<j?l0003oEY7/oeJAk?l0003oEYS`
0ol00004oe2Dk`Co00000om9V?800ol0003oBYkeodZNm@04o`000004od>Lm?l0003oA:?fodBSmPko
000000?o>JKdo`000?lk[?@03_l00004ocfgk`;o00000om2_Nh<o`0000?oD/W_1_l00003oec?l@Oo
000000CoIMCdo`000?l0003o00000_mXeOH6o`0000?oKmOh1_l00003ogCHnPKo00000_mhfO`3o`00
00;oNMWl1Ol00004ogcHo@Co00001Omnf?h4o`0000GoP=Oo00?o0000oh7Goon1eol00ol0001;oooo
o`;o0000<_ooool00ol0003oooooooooo`02ooooo`008?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00009ooooo`?o0000aOooool00ol0003oH9?Zo`000002o`0000?o
FhoY00?o0000oe^EkOmKUNd01?l000000omFTNco0000oeJHl002oeJHl0Co000000CoD9C_o`000?m@
Vo?oD9_c1Ol00004odZNm@Co00001?m4XoH00ol0003oAJWgodFYm`07o`000003od2^m_l0003o0000
00[o000000?o?[;co`000?m1^?802ol00003odW1l0co00000omHc?46o`0000?oHM7c2_l00003ofcF
n0Ko00000omaeoT6o`0000?oM]Sk1Ol00002ogWIo0?o00000omjf?d00ol0003oO=SmogcHo@03o`00
00?oOMSn00?o0000ogkHo_mnf?h00ol00003ogoGoP04o`000?n0eoooP=Oooh3Go`Go0000D?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000Oooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`?o0000a?oo
ool01?l0003oH9?Zof2Cj_mPTnX3o`000003oe^?jOl0003oFiG]00;oFiG]00?o0000oe^KlOl00000
0_l00002oeJHl004o`000?mEWOCoEIgdoeFMm0Co000000CoD9_co`000?m@XOKoD:7f1Ol000001?m:
W_Go0000odZUmom:YOL4o`000003odBSm_l0003oAJWg00CoAJWg00?o0000odJ_n?l000001?l00000
0om0[_Ko0000od:cmP04od:cmP03o`000?m5^?Go0000013o00000om?aO8Ho`0000?oJ=Cg1ol00002
ofkFn@Oo00000_mceo/7o`0000;oMmSl1_l00003og[Ho@Ko00000ommf?h6o`0000?oOmOn1_l0001F
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool001oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00gooooo0_l0
0033ooooo`06o`000?mPTn[oH9?Zof2Cj_l0003oH9S^0ol00003oe^Ek@04o`000?mKVo7oFi_aoe^K
l@;o000000?oEYS`o`000?mEWO@00omEWO@00ol0003oEJ?go`000002o`0000CoD:7f00?o0000oe2W
n?l00000<_l00003oeG8m0Ko00000omNc_D6o`0000?oIM;g1_l00003ofcDn@Ko00000omae_X6o`00
00?oMMOl1_l00003ogWHo@Ko00000omkf?h6o`0000?oOMOn1_l0001Mooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool00_ooool001oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00oooooo0ol00004ooooo`03o`000?oooooo
oooo0;Wooooo00?o0000of2Cj_mPTnX00_mPTnX01?l0003oH9S^of2Hk_mPV>h5o`0000;oFi_a00?o
0000oeZPm?l000000_l00004oeFMm004o`000?mEXoOoEJ?goeFSm`Co000000?oD:7fo`000?m@YoP0
0_m@YoP00ol0003oD:gioe2]n@07o`0000GoBk3i00?o0000odbfnOl000008Ol00003oe[;m@Ko0000
0omRd?L6o`0000?oJM?h1_l00003ofkEnPKo00000omce_/6o`0000?oMmOl1_l00003og[Go@Ko0000
0omleoh6o`0006Cooooo0_l0000]ooooo`03o`000?oooooooooo00;ooooo000Oooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Booooo`?o
000000?oooooo`000?ooool0^oooool4o`000005of2Cj_l0003oH9S^of2Hk_l000000omOWO83o`00
0003oe^KlOl0003oFZ3d00;oFZ3d1?l000000omEWOCo0000oeFSm`02oeFSm`03o`000?mEZOWoEJWi
00Oo00001?m@[OT00ol0003oDK;joe6bnP0;o`000003odbfnOl0003oC[[i00CoC[[i00?o0000oe2n
n?m@__P00_m@__P2o`0000CoD/;g00Co0000oeC5m_mDaOKoE<Gf3?l00003oeo=m`Ko00000omVdOP6
o`0000?oK=Cj1_l00003og7En`Ko00000omee_`6o`0000?oN=Om1_l00003og_GoPKo0000K?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo000Oooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0001Oooooo0_l0002mooooo`03o`000?mT
VnooI9__00Co000000?oH9S^o`000?mOWO800_mOWO800ol0003oGj?eo`000002o`0000CoFZ3d00?o
0000oeZVmol000001_l00004oeFYn@03o`000?mE[_[oEJkj00Go000000?oD:gio`000?mA/_X00omA
/_X2o`0000CoDKOj00?o0000oe:kn_l000005Ol00004oe[8n0_o00000omScoP6o`0000?oJM;i1_l0
0003ofoDn`Ko00000omce_`6o`0000?oMmKm1_l00003og[FoPKo0000Loooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00;ooooo000Pooooo`;o00002_ooool2o`0000Cooooo00?o0000
ooooooooool05oooool3o`000;_ooooo00Ko0000ofBKkomTVnooI9__o`000?mTXO83o`0000?oGigb
00Co0000oenSmOmOXoGoGj?e1?l000000omJX?Co0000oeZVm`02oeZVm`03o`000?mJZoWoFZ_i00Go
000000?oEJWio`000?mE[_X00omE[_XZo`0000?oGl_i2ol00003ofOAn@Ko00000om]do/6o`0000?o
LMCl1_l00003ogGFo@Ko00000omhe_d6o`0007[ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`02ooooo`00Coooool2o`000;[ooooo00Go0000ofBKkomTVnooI9__o`000003ofBQlPGo
00001?mOXoD00ol0003oGjSgo`000006o`0000CoFZ_i3ol00005oeJhn`03o`000?mG_?_oEkck00;o
Ekck0_l00004oeRon`03o`000?mI`o[oFL?j00?oFL?j00Co0000oe_6n_mKa_[oFlKj3?l00005of?=
nP04o`000?mUco[oILojofG?nPGo00000om[d_X6o`0000?oKm?k1_l00003og?Eo0Ko00000omge_d6
o`00087ooooo0_l0000Xooooo`03o`000?oooooooooo00;ooooo001Aooooo`?o00001?ooool00ol0
003oooooooooo`2aooooo`Go00000omTXO800ol0003oI:GeofBUm@05o`000003oenSmOl0003oGjSg
00;oGjSg00?o0000oen]nOmO[OT03?l00005oeZdo003o`000?mK^Oco000001[o00001OmOb?/01?l0
003oHL_jof7;n_mQboX<o`0000?oJM3k1Ol00003ofkBn`Ko00000ombe?`6o`0000?oMMGm1_l00029
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool005Cooooo0ol000000ooo
oooo0000ooooo`2booooo`04o`000?mXXo?oJ:?cofRSl`Ko00000omTYOD00ol0003oHj[hof>Zn007
o`0000CoGjgi00?o0000oenanomO/O/00_mO/O/00ol0003oGkKloenfo00<o`0000GoFkcl00?o0000
oec0o?mL`?`00omL`?`01?l0003oGL?loeg3o?mM`o`Ao`0000?oILgk3?l00003ofcAn`Go00000om`
do`6o`0000?oM=Cm1_l0002@ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_oo
ool0033ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Booooo`;o0000]?ooool0
1Ol0003oJ:?cofRSlomXXo?o000000?oJ:Sf1_l00004of>Zn003o`000?mS[o[oHjoj00[o000000?o
Gk7ko`000?mO]_`00omO]_`00ol0003oGk[moenjo@03oenjo@03o`000?mO_Ogo000000oo00001?mQ
a_`2o`0000?oH/Sl2ol00005ofW>o004o`000?mZd?coJ]3lof[@o0Ko00000om_d_`5o`0000?oL]?m
1_l0002Gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool0037ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00004oooool3o`000;;ooooo00Go0000ofRSlomXXo?oJ:?co`000004
ofRXmP03o`000?mW[?SoIjch00Go000000?oHj[ho`000?mS[oX00omS[oX00ol0003oHk?kof>cn`02
of>cn`03o`000?mS]oco000002Ko00001?mVbo`01?l0003oIlclofO<o?mWc?`<o`0000?oKM7l1_l0
0002og7Bo@Ko0000W_ooool2o`0002Cooooo00?o0000ooooooooool00Oooool0037ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00005_ooool2o`000;7ooooo1Ol00004ofRXmP03o`000?mW[?SoIjch00;o
Ijch00?o0000ofN`n_l000002_l000000omS/o_o0000of>go003of>go003o`000?mS^ogoHk_m00;o
Hk_m0_l00004of>no@03o`000?mS`OgoHl7m00?oHl7m00?o0000ofC4oOmTa?d00_mTa?d00ol0003o
I<KmofC6o@03ofC6o@04o`000?mUb?goILSmofG8o@_o00000om[c_d<o`0000?oL=7m1Ol0002Voooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00Oooool0037ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00006?ooool3o`0000Cooooo00?o0000ooooooooool0Z?ooool00ol0003oK:[fofbZ
mP0:o`000003ofN/n?l0003oIk3j00?oIk3j00Go0000ofNdnomW]?_oIkCko`000002ofNho2Ko0000
1OmYbod01?l0003oJ/cmof[<oOmZc?d5o`0000GoK/om00Co0000ofo@oOm_d?goKm3m1_l0002/oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00Oooool0037ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00006oooool2o`0000;ooooo00?o0000ooooooooool0ZOooool01Ol0003oK:[fofbZ
m_m/Z_Ko000000CoJjkh00?o0000of^bn_m[/_X03?l00005ofNho003o`000?mW_?goIkcm00;oIkcm
00?o0000ofNoo_mW_oh00omW_oh00ol0003oIl;nofO2oP02ofO2oP03o`000?mWa?koIlCn00?oIlCn
00Co0000ofO6o_mWa_koIlKn4Ol00003ofg>o@_o0000/oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo007ooooo000`ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007Oooool3o`000:cooooo1Ol00004
of^^n003o`000?m[/_[oJk;j00;oJk;j00?o0000of^fo?m[]_`00_m[]_`00ol0003oJ[WmofZio@0P
o`0000CoJlWn00Co0000of_;o_m[bokoJl_n3?l0002oooooo`;o00007oooool00ol0003ooooooooo
o`01ooooo`00<Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l0000Q
ooooo`?o0000ZOooool01?l0003oooooooooooooool:o`000003of^bn_l0003oJkKl00?oJkKl00?o
0000ofZioOmZ^Od00_mZ^Od00ol0003oJ[cmofZlo@03ofZlo@03o`000?mZ_okoJ[on00;oJ[on00?o
0000of[2o_mZ`_h00omZ`_h00ol0003oJ/Gnof[5oP02of[5oP04o`000?mZaokoJ/Onof[7oP_o0000
cOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo007ooooo001Yooooo`;o0000Yooo
ool00ol0003oooooooooo`0;ooooobGo0000fOooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo007ooooo001[ooooo`?o00000oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
oooo0?oooooo2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo007ooooo001^oooo
o`;o000000?oooooo`000?ooool0Woooool00ol0003oooooooooo`3oooooo`cooooo0_l0000Joooo
o`03o`000?oooooooooo007ooooo001`ooooo`?o0000Woooool00ol0003oooooooooo`3oooooo`ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`01ooooo`00Loooool3o`0000Oooooo
00?o0000ooooooooool0T_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`01ooooo`00M_ooool2o`0000Gooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`01ooooo`00N?ooool3o`0000;ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`3o
oooooa7ooooo0_l0000Eooooo`03o`000?oooooooooo007ooooo001kooooo`?o0000U?ooool00ol0
003oooooooooo`3ooooooa?ooooo00?o0000ooooooooool04oooool1o`00007ooooo0Oooool007go
oooo0ol0002Booooo`03o`000?oooooooooo0?oooooo5?ooool00ol0003oooooooooo`0Booooo`7o
00000Oooool1ooooo`00P?ooool3o`0008oooooo00?o0000ooooooooool0oooooolEooooo`03o`00
0?oooooooooo017ooooo0Ol00001ooooo`7ooooo0023ooooo`;o00001?ooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo0?oooooo5_ooool2o`00017ooooo0Ol00001ooooo`7ooooo0025
ooooo`?o000000?oooooo`000?ooool0Qoooool00ol0003oooooooooo`3ooooooaSooooo00?o0000
ooooooooool03_ooool1o`00007ooooo0Oooool008Sooooo0_l00028ooooo`03o`000?oooooooooo
0?oooooo6Oooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00R_ooool3o`0008Go
oooo00?o0000ooooooooool0oooooolJooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7o
oooo002=ooooo`;o0000Poooool00ol0003oooooooooo`3ooooooa_ooooo0_l0000<ooooo`7o0000
0Oooool1ooooo`00Soooool3o`0000?ooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`3ooooooagooooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool009;ooooo1?l0001l
ooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1
ooooo`00M?ooool2o`0000Cooooo0ol00004ooooo`;o00004Oooool3o`0007_ooooo00?o0000oooo
ooooool0oooooolOooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001fooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0A
ooooo`?o0000N?ooool00ol0003oooooooooo`3oooooob3ooooo0_l00007ooooo`7o00000Oooool1
ooooo`00Moooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool05?ooool2o`0000Cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`3o
ooooob;ooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool007Cooooo1?l00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05_ooool3o`000003ooooool0003o
oooo073ooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`00Loooool01_l0003ooooooooooooooooo0000ooooo`Co00000oooool01?l0003ooooooooo
ool0000Kooooo`?o0000L?ooool00ol0003oooooooooo`3oooooobCooooo00?o0000ooooooooool0
0oooool1o`00007ooooo001cooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04
o`000?ooooooooooo`0001kooooo0_l0001^ooooo`03o`000?oooooooooo0?oooooo9Oooool2o`00
00?ooooo0Ol00001ooooo`00M?ooool3o`0000;ooooo1Ol00003ooooo`;o00008Oooool3o`0000?o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`3oooooobOooooo00Co0000oooooooo
oooo00000Oooool00:Oooooo0_l000000ooooooo0000ooooo`1Vooooo`03o`000?oooooooooo0?oo
oooo:?ooool00ol0003oooooo`000001ooooo`00ZOooool3o`0006Kooooo00?o0000ooooooooool0
oooooolYooooo`;o00000Oooool00:cooooo0_l00007ooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool0oooooolVooooo`Go00000Oooool00:kooooo0ol00004ooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0oooooolNooooo`So00001_ooool00;7ooooo0ol000000ooo
oooo0000ooooo`1Kooooo`03o`000?oooooooooo0?oooooo5oooool7o`0000kooooo002dooooo`;o
0000G?ooool00ol0003oooooooooo`3oooooo`oooooo2?l0000Eooooo`00]_ooool3o`0005Wooooo
00?o0000ooooooooool0ooooool7ooooo`So00007Oooool00;Wooooo0_l00004ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool0ooooool7o`0002Gooooo002kooooo`?o000000?ooooo
o`000?ooool0DOooool00ol0003oooooooooo`3gooooo`So0000;?ooool00;kooooo0ol0001Aoooo
o`03o`000?oooooooooo0>oooooo2?l0000dooooo`00`Oooool2o`0004oooooo00?o0000oooooooo
ool0ioooool8o`0003cooooo0033ooooo`?o00000oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo0>3ooooo1ol00014ooooo`00a_ooool2o`000003ooooool0003ooooo04Oooooo00?o
0000ooooooooool0f?ooool8o`0004_ooooo0038ooooo`?o0000A_ooool00ol0003oooooooooo`3A
ooooo`So0000Doooool00<_ooooo0_l00014ooooo`03o`000?oooooooooo0<[ooooo1ol0001Koooo
o`00[?ooool2o`0000Gooooo0_l00004ooooo`;o00004_ooool3o`0000?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`32ooooo`So0000H_ooool00:kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04_ooool4o`00
03gooooo00?o0000ooooooooool0^_ooool8o`0006[ooooo002_ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Eooooo`;o0000??ooool0
0ol0003oooooooooo`2booooo`So0000L_ooool00:cooooo1?l00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00006Oooool3o`0000Cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`2[ooooo`Oo0000N_ooool00:_ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007?ooool2o`0000;o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Sooooo`So0000POooool00:_ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00007_ooool3o`0003Cooooo00?o0000ooooooooool0Voooool8o`0008Wooooo002/oooo
o`?o00001?ooool2o`0000Cooooo0_l0000Rooooo`?o00001_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo09?ooooo2?l0002Aooooo`00h?ooool2o`0000Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`2<ooooo`Oo0000VOooool00>;ooooo0ol000000ooooooo0000
ooooo`0Yooooo`03o`000?oooooooooo08Cooooo2?l0002Pooooo`00iOooool2o`0002[ooooo00?o
0000ooooooooool0O?ooool8o`000:Sooooo003Wooooo`?o00001Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo07Gooooo1ol0002`ooooo`00j_ooool3o`0000;ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1]ooooo`So0000]oooool00>gooooo0ol0000Qooooo`03
o`000?oooooooooo06Gooooo2?l0002oooooo`00koooool3o`0001oooooo00?o0000ooooooooool0
GOooool8o`000<Oooooo003booooo`;o00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo05Kooooo1ol0003?ooooo`00m?ooool3o`000003ooooool0003ooooo01Oooooo00?o0000
ooooooooool0C_ooool8o`000=Kooooo003gooooo`;o00006?ooool00ol0003oooooooooo`16oooo
o`So0000g_ooool00?Wooooo0ol00004ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0?oooool7o`000>Kooooo003looooo`?o000000?oooooo`000?ooool03oooool00ol0003ooooo
ooooo`0gooooo`So0000kOooool00=gooooo0ol00003ooooo`?o00001?ooool2o`0001?ooooo0_l0
000@ooooo`03o`000?oooooooooo02oooooo2?l0003eooooo`00g?ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01;o
oooo0ol00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool8o`000?go
oooo003Looooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo01Gooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08?ooool7o`000?oooooo1_ooool00=gooooo0ol00006ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool05oooool3o`0000Sooooo00?o0000ooooooooool06?ooool8o`00
0?oooooo3Oooool00=cooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000?ooooo00Co0000
oooooooooooo00007?ooool3o`0000Gooooo00?o0000ooooooooool04?ooool8o`000?oooooo5Ooo
ool00=cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooooooo
00007oooool2o`0000?ooooo00?o0000ooooooooool02Oooool7o`000?oooooo7Oooool00=gooooo
0ol00002ooooo`Go00000oooool2o`0002;ooooo1?l00003ooooo`So0000oooooolTooooo`00oooo
oolBooooo`Co0000ooooool/ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2
ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00;7ooooo0ol0001Dooooo`?o0000
1?ooool2o`0000Cooooo0_l0003oooooob[ooooo002booooo`03o`000?oooooooooo05;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo0000oooooolYooooo`00/_ooool00ol0003oooooooooo`1Booooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo:Ooo
ool00;;ooooo00?o0000ooooooooool0Doooool3o`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0003oooooobWooooo002`ooooo`05o`000?oooooo0000ooooool00000
D_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0003oooooobWooooo002`ooooo`05o`000?oooooo0000ooooool00000D_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0003oooooobWooooo002`ooooo`Go0000Doooool3o`0000Cooooo0_l00004ooooo`;o0000
oooooolZooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00oooooooooooood;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {360.5, 0}} -> {-0.111548, 0.115336, \
0.00182444, 0.00182444}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Note the following trends:
As the undercooling below the spinodal temperature of 1000 K increases
\t(1) The kinetic wavenumber \[Beta]Max increases, so the kinetic wavelength \
decreases
\t(2) There is a temperature at which the amplification rate R(\[Beta]Max) is \
a maximum. In the plot above this occurs around 930 K.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 796}, {0, 578}},
WindowSize->{877, 618},
WindowMargins->{{3, Automatic}, {Automatic, 4}},
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 71, 2, 112, "Title"],
Cell[1828, 55, 29, 0, 48, "Subtitle"],

Cell[CellGroupData[{
Cell[1882, 59, 53, 0, 65, "Subsection"],
Cell[1938, 61, 109, 2, 70, "Input"],
Cell[2050, 65, 66, 0, 46, "Text"],
Cell[2119, 67, 138, 2, 74, "Input"],
Cell[2260, 71, 141, 1, 77, "Subsubtitle"],
Cell[2404, 74, 307, 6, 74, "Text"],
Cell[2714, 82, 187, 4, 66, "Text"],
Cell[2904, 88, 630, 11, 132, "Input"],
Cell[3537, 101, 158, 4, 66, "Text"],

Cell[CellGroupData[{
Cell[3720, 109, 256, 4, 91, "Input"],
Cell[3979, 115, 196, 3, 92, "Output"],
Cell[4178, 120, 312, 4, 156, "Output"],
Cell[4493, 126, 83, 1, 67, "Output"]
}, Open  ]],
Cell[4591, 130, 632, 15, 133, "Text"],
Cell[5226, 147, 42, 0, 48, "Subtitle"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5305, 152, 120, 3, 65, "Subsection"],
Cell[5428, 157, 127, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[5580, 164, 56, 1, 50, "Input"],
Cell[5639, 167, 63, 1, 67, "Output"]
}, Open  ]],
Cell[5717, 171, 72, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[5814, 175, 218, 5, 70, "Input"],
Cell[6035, 182, 115, 2, 89, "Output"],
Cell[6153, 186, 79, 1, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6269, 192, 59, 1, 50, "Input"],
Cell[6331, 195, 66, 1, 65, "Output"]
}, Open  ]],
Cell[6412, 199, 140, 3, 66, "Text"],
Cell[6555, 204, 85, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[6665, 211, 434, 6, 130, "Input"],
Cell[7102, 219, 73516, 1827, 437, 21114, 1175, "GraphicsData", "PostScript", \
"Graphics"],
Cell[80621, 2048, 130, 3, 65, "Output"]
}, Open  ]],
Cell[80766, 2054, 104, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[80895, 2061, 153, 2, 50, "Input"],
Cell[81051, 2065, 189122, 3375, 496, 55807, 1725, "GraphicsData", \
"PostScript", "Graphics"],
Cell[270176, 5442, 137, 3, 65, "Output"]
}, Open  ]],
Cell[270328, 5448, 345, 7, 86, "Text"],
Cell[270676, 5457, 126, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[270827, 5464, 50, 1, 50, "Input"],
Cell[270880, 5467, 36, 1, 65, "Output"]
}, Open  ]],
Cell[270931, 5471, 132, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[271088, 5478, 230, 5, 90, "Input"],
Cell[271321, 5485, 37, 1, 65, "Output"],
Cell[271361, 5488, 66, 1, 65, "Output"],
Cell[271430, 5491, 53, 1, 65, "Output"]
}, Open  ]],
Cell[271498, 5495, 52, 0, 46, "Text"],
Cell[271553, 5497, 358, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[271936, 5507, 146, 4, 70, "Input"],
Cell[272085, 5513, 28055, 700, 277, 8287, 451, "GraphicsData", "PostScript", \
"Graphics"],
Cell[300143, 6215, 130, 3, 65, "Output"]
}, Open  ]],
Cell[300288, 6221, 311, 5, 86, "Text"],
Cell[300602, 6228, 463, 8, 150, "Input"],
Cell[301068, 6238, 58, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[301151, 6242, 221, 4, 90, "Input"],
Cell[301375, 6248, 38740, 893, 384, 9268, 525, "GraphicsData", "PostScript", \
"Graphics"],
Cell[340118, 7143, 130, 3, 65, "Output"]
}, Open  ]],
Cell[340263, 7149, 159, 4, 66, "Text"],
Cell[340425, 7155, 535, 9, 170, "Input"],
Cell[340963, 7166, 167, 4, 66, "Text"],

Cell[CellGroupData[{
Cell[341155, 7174, 425, 9, 110, "Input"],
Cell[341583, 7185, 45487, 969, 384, 9134, 516, "GraphicsData", "PostScript", \
"Graphics"],
Cell[387073, 8156, 130, 3, 65, "Output"]
}, Open  ]],
Cell[387218, 8162, 115, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[387358, 8169, 61, 1, 50, "Input"],
Cell[387422, 8172, 53686, 1195, 384, 11529, 670, "GraphicsData", \
"PostScript", "Graphics"],
Cell[441111, 9369, 130, 3, 65, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[441290, 9378, 76, 0, 65, "Subsection"],
Cell[441369, 9380, 230, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[441624, 9389, 392, 7, 240, "Input"],
Cell[442019, 9398, 57, 1, 67, "Output"]
}, Open  ]],
Cell[442091, 9402, 393, 7, 106, "Text"],

Cell[CellGroupData[{
Cell[442509, 9413, 444, 8, 130, "Input"],
Cell[442956, 9423, 53, 1, 65, "Output"],
Cell[443012, 9426, 57, 1, 65, "Output"]
}, Open  ]],
Cell[443084, 9430, 187, 5, 48, "Text"],
Cell[443274, 9437, 138, 3, 74, "Input"],

Cell[CellGroupData[{
Cell[443437, 9444, 178, 3, 70, "Input"],
Cell[443618, 9449, 47644, 1023, 384, 10129, 555, "GraphicsData", \
"PostScript", "Graphics"],
Cell[491265, 10474, 130, 3, 65, "Output"]
}, Open  ]],
Cell[491410, 10480, 151, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[491586, 10489, 158, 3, 60, "Input"],
Cell[491747, 10494, 55, 1, 65, "Output"]
}, Open  ]],
Cell[491817, 10498, 122, 5, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491976, 10508, 53, 0, 65, "Subsection"],
Cell[492032, 10510, 59, 0, 46, "Text"],
Cell[492094, 10512, 77, 1, 73, "Input"],
Cell[492174, 10515, 107, 2, 71, "Input"],
Cell[492284, 10519, 186, 4, 70, "Input"],
Cell[492473, 10525, 95, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[492593, 10532, 109, 2, 70, "Input"],
Cell[492705, 10536, 62, 1, 67, "Output"]
}, Open  ]],
Cell[492782, 10540, 71, 0, 46, "Text"],
Cell[492856, 10542, 144, 3, 74, "Input"],

Cell[CellGroupData[{
Cell[493025, 10549, 170, 3, 72, "Input"],
Cell[493198, 10554, 42110, 925, 384, 10420, 529, "GraphicsData", \
"PostScript", "Graphics"],
Cell[535311, 11481, 130, 3, 65, "Output"]
}, Open  ]],
Cell[535456, 11487, 67, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[535548, 11491, 77, 1, 51, "Input"],
Cell[535628, 11494, 137, 2, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535802, 11501, 158, 3, 70, "Input"],
Cell[535963, 11506, 57, 1, 67, "Output"],
Cell[536023, 11509, 55, 1, 65, "Output"]
}, Open  ]],
Cell[536093, 11513, 188, 4, 66, "Text"],

Cell[CellGroupData[{
Cell[536306, 11521, 89, 1, 52, "Input"],
Cell[536398, 11524, 68, 1, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[536503, 11530, 76, 1, 50, "Input"],
Cell[536582, 11533, 57, 1, 67, "Output"]
}, Open  ]],
Cell[536654, 11537, 104, 3, 46, "Text"],
Cell[536761, 11542, 136, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[536922, 11549, 285, 5, 72, "Input"],
Cell[537210, 11556, 424609, 8457, 390, 209286, 5794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[961822, 20015, 137, 3, 65, "Output"]
}, Open  ]],
Cell[961974, 20021, 345, 7, 162, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

